"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsSqAddIncidentNoteName = Literal["sq_add_incident_note",]


class V3WorkflowsSqAddIncidentNoteDataTypedDict(TypedDict):
    note: str


class V3WorkflowsSqAddIncidentNoteData(BaseModel):
    note: str


class V3WorkflowsSqAddIncidentNoteTypedDict(TypedDict):
    name: V3WorkflowsSqAddIncidentNoteName
    data: V3WorkflowsSqAddIncidentNoteDataTypedDict


class V3WorkflowsSqAddIncidentNote(BaseModel):
    name: V3WorkflowsSqAddIncidentNoteName

    data: V3WorkflowsSqAddIncidentNoteData
