"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_overlay_overlayresponse import (
    V3ServicesOverlayOverlayResponse,
    V3ServicesOverlayOverlayResponseTypedDict,
)
from .v3_services_overlay_updatededupkeyoverlayrequest import (
    V3ServicesOverlayUpdateDedupKeyOverlayRequest,
    V3ServicesOverlayUpdateDedupKeyOverlayRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


class OverlayUpdateDedupKeyOverlayRequestTypedDict(TypedDict):
    service_id: str
    alert_source: str
    v3_services_overlay_update_dedup_key_overlay_request: (
        V3ServicesOverlayUpdateDedupKeyOverlayRequestTypedDict
    )


class OverlayUpdateDedupKeyOverlayRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    alert_source: Annotated[
        str,
        pydantic.Field(alias="alertSource"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_overlay_update_dedup_key_overlay_request: Annotated[
        V3ServicesOverlayUpdateDedupKeyOverlayRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ResponseBody2TypedDict(TypedDict):
    data: V3ServicesOverlayOverlayResponseTypedDict


class ResponseBody2(BaseModel):
    data: V3ServicesOverlayOverlayResponse


class ResponseBody1TypedDict(TypedDict):
    data: V3ServicesOverlayOverlayResponseTypedDict


class ResponseBody1(BaseModel):
    data: V3ServicesOverlayOverlayResponse


OverlayUpdateDedupKeyOverlayResponseTypedDict = TypeAliasType(
    "OverlayUpdateDedupKeyOverlayResponseTypedDict",
    Union[ResponseBody1TypedDict, ResponseBody2TypedDict],
)
r"""The request has succeeded."""


OverlayUpdateDedupKeyOverlayResponse = TypeAliasType(
    "OverlayUpdateDedupKeyOverlayResponse", Union[ResponseBody1, ResponseBody2]
)
r"""The request has succeeded."""
