"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3ServicesDedupInitConfigTimeUnit = Literal[
    "minute",
    "hour",
]


class V3ServicesDedupInitConfigTypedDict(TypedDict):
    time_window: int
    time_unit: V3ServicesDedupInitConfigTimeUnit


class V3ServicesDedupInitConfig(BaseModel):
    time_window: int

    time_unit: V3ServicesDedupInitConfigTimeUnit
