"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSqAddIncidentNoteUpdateName = Literal["sq_add_incident_note",]


class V3WorkflowsSqAddIncidentNoteUpdateDataTypedDict(TypedDict):
    note: NotRequired[str]


class V3WorkflowsSqAddIncidentNoteUpdateData(BaseModel):
    note: Optional[str] = None


class V3WorkflowsSqAddIncidentNoteUpdateTypedDict(TypedDict):
    name: V3WorkflowsSqAddIncidentNoteUpdateName
    data: NotRequired[V3WorkflowsSqAddIncidentNoteUpdateDataTypedDict]


class V3WorkflowsSqAddIncidentNoteUpdate(BaseModel):
    name: V3WorkflowsSqAddIncidentNoteUpdateName

    data: Optional[V3WorkflowsSqAddIncidentNoteUpdateData] = None
