"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_participant import V4Participant, V4ParticipantTypedDict
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V4ParticipantGroupTypedDict(TypedDict):
    participants: List[V4ParticipantTypedDict]


class V4ParticipantGroup(BaseModel):
    participants: List[V4Participant]
