"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class SchedulesDeleteScheduleRequestTypedDict(TypedDict):
    schedule_id: str


class SchedulesDeleteScheduleRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class SchedulesDeleteScheduleResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class SchedulesDeleteScheduleResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""
