"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class CommonV3EntityOwnerTypedDict(TypedDict):
    r"""Represents the owner of an entity."""

    id: str
    r"""The ID of the owner."""
    type: str
    r"""The type of the owner ( \"user\", \"squad\")."""


class CommonV3EntityOwner(BaseModel):
    r"""Represents the owner of an entity."""

    id: str
    r"""The ID of the owner."""

    type: str
    r"""The type of the owner ( \"user\", \"squad\")."""
