"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_componentstatus import (
    V4StatusPagesIssuesComponentStatus,
    V4StatusPagesIssuesComponentStatusTypedDict,
)
from .v4_statuspages_issues_issuestatemessage import (
    V4StatusPagesIssuesIssueStateMessage,
    V4StatusPagesIssuesIssueStateMessageTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesIssuesIssueDetailTypedDict(TypedDict):
    state: NotRequired[V4StatusPagesIssuesComponentStatusTypedDict]
    state_messages: NotRequired[List[V4StatusPagesIssuesIssueStateMessageTypedDict]]


class V4StatusPagesIssuesIssueDetail(BaseModel):
    state: Optional[V4StatusPagesIssuesComponentStatus] = None

    state_messages: Annotated[
        Optional[List[V4StatusPagesIssuesIssueStateMessage]],
        pydantic.Field(alias="stateMessages"),
    ] = None
