"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsSnoozeNotificationsSnoozeIncidentRequestTypedDict(TypedDict):
    snooze_duration_in_mins: int


class V3IncidentsSnoozeNotificationsSnoozeIncidentRequest(BaseModel):
    snooze_duration_in_mins: int
