"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V3AuditLogsActorTypedDict(TypedDict):
    r"""Represents an actor (user) in audit logs"""

    user_id: str
    user_name: str
    user_email: str
    full_name: str


class V3AuditLogsActor(BaseModel):
    r"""Represents an actor (user) in audit logs"""

    user_id: Annotated[str, pydantic.Field(alias="userID")]

    user_name: Annotated[str, pydantic.Field(alias="userName")]

    user_email: Annotated[str, pydantic.Field(alias="userEmail")]

    full_name: Annotated[str, pydantic.Field(alias="fullName")]
