"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsPostmortemsTotalPostmortemCountTypedDict(TypedDict):
    r"""Represents the total count of postmortems."""

    count: int


class V3IncidentsPostmortemsTotalPostmortemCount(BaseModel):
    r"""Represents the total count of postmortems."""

    count: int
