"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ExtensionsMSTeamsIncidentActionAlertStateTypedDict(TypedDict):
    r"""A set of booleans to easily configure which incident-related alerts are sent to MS Teams."""

    is_trigger_active: bool
    is_retrigger_active: bool
    is_acknowledge_active: bool
    is_resolve_active: bool
    is_reassign_active: bool
    is_notes_added_active: bool
    is_postmortem_active: bool
    is_priority_updated_active: bool


class V3ExtensionsMSTeamsIncidentActionAlertState(BaseModel):
    r"""A set of booleans to easily configure which incident-related alerts are sent to MS Teams."""

    is_trigger_active: bool

    is_retrigger_active: bool

    is_acknowledge_active: bool

    is_resolve_active: bool

    is_reassign_active: bool

    is_notes_added_active: bool

    is_postmortem_active: bool

    is_priority_updated_active: bool
