"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsSlackArchiveChannelName = Literal["slack_archive_channel",]


class V3WorkflowsSlackArchiveChannelTypedDict(TypedDict):
    name: V3WorkflowsSlackArchiveChannelName


class V3WorkflowsSlackArchiveChannel(BaseModel):
    name: V3WorkflowsSlackArchiveChannelName
