"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .common_v4_pageinfo import CommonV4PageInfo, CommonV4PageInfoTypedDict
from .v4_squads_squadresponse import (
    V4SquadsSquadResponse,
    V4SquadsSquadResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class SquadsGetAllSquadsRequestTypedDict(TypedDict):
    owner_id: str


class SquadsGetAllSquadsRequest(BaseModel):
    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]


class SquadsGetAllSquadsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V4SquadsSquadResponseTypedDict]
    page_info: CommonV4PageInfoTypedDict


class SquadsGetAllSquadsResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V4SquadsSquadResponse]

    page_info: Annotated[CommonV4PageInfo, pydantic.Field(alias="pageInfo")]
