"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsMsTeamsMessageUserUpdateName = Literal["msteams_message_user",]


class V3WorkflowsMsTeamsMessageUserUpdateDataTypedDict(TypedDict):
    member_id: NotRequired[str]
    message: NotRequired[str]


class V3WorkflowsMsTeamsMessageUserUpdateData(BaseModel):
    member_id: Optional[str] = None

    message: Optional[str] = None


class V3WorkflowsMsTeamsMessageUserUpdateTypedDict(TypedDict):
    name: V3WorkflowsMsTeamsMessageUserUpdateName
    data: NotRequired[V3WorkflowsMsTeamsMessageUserUpdateDataTypedDict]


class V3WorkflowsMsTeamsMessageUserUpdate(BaseModel):
    name: V3WorkflowsMsTeamsMessageUserUpdateName

    data: Optional[V3WorkflowsMsTeamsMessageUserUpdateData] = None
