"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_escalationpolicies_escalationpolicyresponse import (
    V3EscalationPoliciesEscalationPolicyResponse,
    V3EscalationPoliciesEscalationPolicyResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class EscalationPoliciesCreateEscalationPoliciesResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3EscalationPoliciesEscalationPolicyResponseTypedDict
    r"""Represents an Escalation Policy in the system."""


class EscalationPoliciesCreateEscalationPoliciesResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3EscalationPoliciesEscalationPolicyResponse
    r"""Represents an Escalation Policy in the system."""
