"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V4StatusPagesComponentsDeleteComponentByIDResponseTypedDict(TypedDict):
    id: int
    name: str
    description: str
    allow_subscription: bool


class V4StatusPagesComponentsDeleteComponentByIDResponse(BaseModel):
    id: int

    name: str

    description: str

    allow_subscription: Annotated[bool, pydantic.Field(alias="allowSubscription")]
