"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .common_v3_entityowner import CommonV3EntityOwner, CommonV3EntityOwnerTypedDict
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3RunbooksUpdationInfoTypedDict(TypedDict):
    r"""Represents information about the creation or updation of an entity."""

    user_name: str
    r"""The full name of the user who performed the action."""
    username_for_display: str
    r"""The display name of the user who performed the action."""
    user_id: str
    r"""The ID of the user who performed the action."""
    at: datetime
    r"""The timestamp of the action."""
    entity_owner: NotRequired[CommonV3EntityOwnerTypedDict]
    r"""The owner of the entity at the time of the action."""


class V3RunbooksUpdationInfo(BaseModel):
    r"""Represents information about the creation or updation of an entity."""

    user_name: str
    r"""The full name of the user who performed the action."""

    username_for_display: str
    r"""The display name of the user who performed the action."""

    user_id: str
    r"""The ID of the user who performed the action."""

    at: datetime
    r"""The timestamp of the action."""

    entity_owner: Optional[CommonV3EntityOwner] = None
    r"""The owner of the entity at the time of the action."""
