"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V4PauseResumeScheduleResponseTypedDict(TypedDict):
    action: str
    success: bool


class V4PauseResumeScheduleResponse(BaseModel):
    action: str

    success: bool
