"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequestTypedDict(
    TypedDict
):
    owner_id: str


class GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequest(BaseModel):
    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]


class GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBodyTypedDict(
    TypedDict
):
    r"""There is no content to send for this request, but the headers may be useful."""


class GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""
