"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3SLOSLOActionType = Literal[
    "SERVICE",
    "USER",
    "SQUAD",
]
