"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class AbilitiesTypedDict(TypedDict):
    r"""A map of abilities granted to the user."""


class Abilities(BaseModel):
    r"""A map of abilities granted to the user."""


class CommonV3RBACEntityPermissionTypedDict(TypedDict):
    r"""Represents a permission granted to a user for a specific entity."""

    user_id: str
    r"""The ID of the user receiving the permission."""
    abilities: AbilitiesTypedDict
    r"""A map of abilities granted to the user."""


class CommonV3RBACEntityPermission(BaseModel):
    r"""Represents a permission granted to a user for a specific entity."""

    user_id: str
    r"""The ID of the user receiving the permission."""

    abilities: Abilities
    r"""A map of abilities granted to the user."""
