"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ExtensionsMSTeamsSquadCastServiceMappingTypedDict(TypedDict):
    r"""Maps a specific Squadcast service to a channel configuration."""

    squadcast_service_id: str
    r"""The MongoDB ObjectID of the Squadcast service."""
    squadcast_service_name: str
    r"""The name of the Squadcast service."""


class V3ExtensionsMSTeamsSquadCastServiceMapping(BaseModel):
    r"""Maps a specific Squadcast service to a channel configuration."""

    squadcast_service_id: str
    r"""The MongoDB ObjectID of the Squadcast service."""

    squadcast_service_name: str
    r"""The name of the Squadcast service."""
