"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3IncidentsExportFormat = Literal[
    "json",
    "csv",
]
r"""Defines the format of the export."""
