"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_getworkflowlogsresponse import (
    V3WorkflowsGetWorkflowLogsResponse,
    V3WorkflowsGetWorkflowLogsResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Callable, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WorkflowsGetWorkflowLogsRequestTypedDict(TypedDict):
    workflow_id: str
    page_size: NotRequired[int]
    page_number: NotRequired[int]


class WorkflowsGetWorkflowLogsRequest(BaseModel):
    workflow_id: Annotated[
        str,
        pydantic.Field(alias="workflowID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    page_number: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None


class WorkflowsGetWorkflowLogsResponseTypedDict(TypedDict):
    result: V3WorkflowsGetWorkflowLogsResponseTypedDict


class WorkflowsGetWorkflowLogsResponse(BaseModel):
    next: Callable[[], Optional[WorkflowsGetWorkflowLogsResponse]]

    result: V3WorkflowsGetWorkflowLogsResponse
