"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3AnalyticsAnalyticsResponseTypedDict(TypedDict):
    mtta: float
    mttr: float


class V3AnalyticsAnalyticsResponse(BaseModel):
    mtta: float

    mttr: float
