"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_auditlogs_auditlogidresponse import (
    V3AuditLogsAuditLogIDResponse,
    V3AuditLogsAuditLogIDResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3AuditLogsGetAuditLogByIDResponseTypedDict(TypedDict):
    r"""Response model for getting audit log by ID"""

    data: V3AuditLogsAuditLogIDResponseTypedDict
    r"""Represents detailed audit log entry response"""


class V3AuditLogsGetAuditLogByIDResponse(BaseModel):
    r"""Response model for getting audit log by ID"""

    data: V3AuditLogsAuditLogIDResponse
    r"""Represents detailed audit log entry response"""
