"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_issue import (
    V4StatusPagesIssuesIssue,
    V4StatusPagesIssuesIssueTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4StatusPagesIssuesListIssuesResponseMetaTypedDict(TypedDict):
    total_count: int


class V4StatusPagesIssuesListIssuesResponseMeta(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]


class V4StatusPagesIssuesListIssuesResponseTypedDict(TypedDict):
    data: List[V4StatusPagesIssuesIssueTypedDict]
    meta: V4StatusPagesIssuesListIssuesResponseMetaTypedDict


class V4StatusPagesIssuesListIssuesResponse(BaseModel):
    data: List[V4StatusPagesIssuesIssue]

    meta: V4StatusPagesIssuesListIssuesResponseMeta
