"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teammember import V3TeamsTeamMember, V3TeamsTeamMemberTypedDict
from .v3_teams_teamrole import V3TeamsTeamRole, V3TeamsTeamRoleTypedDict
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class OrganizationTypedDict(TypedDict):
    id: str
    name: str
    slug: str


class Organization(BaseModel):
    id: str

    name: str

    slug: str


class V3TeamsTeamResponseTypedDict(TypedDict):
    id: str
    created_at: str
    updated_at: str
    created_by: str
    organization_id: str
    name: str
    description: str
    slug: str
    members: List[V3TeamsTeamMemberTypedDict]
    roles: List[V3TeamsTeamRoleTypedDict]
    default: bool
    organization: OrganizationTypedDict


class V3TeamsTeamResponse(BaseModel):
    id: str

    created_at: str

    updated_at: str

    created_by: str

    organization_id: str

    name: str

    description: str

    slug: str

    members: List[V3TeamsTeamMember]

    roles: List[V3TeamsTeamRole]

    default: bool

    organization: Organization
