"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSlackCreateIncidentChannelName = Literal["slack_create_incident_channel",]


class V3WorkflowsSlackCreateIncidentChannelDataTypedDict(TypedDict):
    auto_name: bool
    channel_name: NotRequired[str]


class V3WorkflowsSlackCreateIncidentChannelData(BaseModel):
    auto_name: bool

    channel_name: Optional[str] = None


class V3WorkflowsSlackCreateIncidentChannelTypedDict(TypedDict):
    name: V3WorkflowsSlackCreateIncidentChannelName
    data: V3WorkflowsSlackCreateIncidentChannelDataTypedDict


class V3WorkflowsSlackCreateIncidentChannel(BaseModel):
    name: V3WorkflowsSlackCreateIncidentChannelName

    data: V3WorkflowsSlackCreateIncidentChannelData
