"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3IncidentsPostmortemsPostmortemStatus = Literal[
    "in_progress",
    "under_review",
    "published",
]
r"""Represents the status of a postmortem."""
