"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_taggingrules_tagconfigobject import (
    V3ServicesTaggingRulesTagConfigObject,
    V3ServicesTaggingRulesTagConfigObjectTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3ServicesTaggingRulesTagsObjectTypedDict(TypedDict):
    severity: NotRequired[V3ServicesTaggingRulesTagConfigObjectTypedDict]


class V3ServicesTaggingRulesTagsObject(BaseModel):
    severity: Optional[V3ServicesTaggingRulesTagConfigObject] = None
