"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_overlay_optinforkeybaseddeduplicationrequest import (
    V3ServicesOverlayOptInForKeyBasedDeduplicationRequest,
    V3ServicesOverlayOptInForKeyBasedDeduplicationRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverlayOptinForKeyBasedDeduplicationForAServiceRequestTypedDict(TypedDict):
    service_id: str
    v3_services_overlay_opt_in_for_key_based_deduplication_request: (
        V3ServicesOverlayOptInForKeyBasedDeduplicationRequestTypedDict
    )


class OverlayOptinForKeyBasedDeduplicationForAServiceRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_overlay_opt_in_for_key_based_deduplication_request: Annotated[
        V3ServicesOverlayOptInForKeyBasedDeduplicationRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverlayOptinForKeyBasedDeduplicationForAServiceResponseTypedDict(TypedDict):
    r"""The request has succeeded."""


class OverlayOptinForKeyBasedDeduplicationForAServiceResponse(BaseModel):
    r"""The request has succeeded."""
