"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsPostmortemsPostmortemAttachmentRequestTypedDict(TypedDict):
    r"""Represents an attachment in a postmortem request."""

    key: NotRequired[str]
    mime_type: NotRequired[str]
    file_size: NotRequired[str]


class V3IncidentsPostmortemsPostmortemAttachmentRequest(BaseModel):
    r"""Represents an attachment in a postmortem request."""

    key: Optional[str] = None

    mime_type: Optional[str] = None

    file_size: Optional[str] = None
