"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict(TypedDict):
    title: str
    note: str
    components: List[int]
    start_time: datetime
    end_time: datetime


class V4StatusPagesMaintenancesCreateMaintenanceRequest(BaseModel):
    title: str

    note: str

    components: List[int]

    start_time: Annotated[datetime, pydantic.Field(alias="startTime")]

    end_time: Annotated[datetime, pydantic.Field(alias="endTime")]
