"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class IncidentActionsCreateATicketOnJiraServerRequestTypedDict(TypedDict):
    incident_id: str


class IncidentActionsCreateATicketOnJiraServerRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class IncidentActionsCreateATicketOnJiraServerResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: str


class IncidentActionsCreateATicketOnJiraServerResponse(BaseModel):
    r"""The request has succeeded."""

    data: str
