"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsJiraCreateTicketUpdateName = Literal["jira_create_ticket",]


class V3WorkflowsJiraCreateTicketUpdateDataTypedDict(TypedDict):
    account: NotRequired[str]
    project: NotRequired[str]
    issue_type: NotRequired[str]
    title: NotRequired[str]
    description: NotRequired[str]


class V3WorkflowsJiraCreateTicketUpdateData(BaseModel):
    account: Optional[str] = None

    project: Optional[str] = None

    issue_type: Optional[str] = None

    title: Optional[str] = None

    description: Optional[str] = None


class V3WorkflowsJiraCreateTicketUpdateTypedDict(TypedDict):
    name: V3WorkflowsJiraCreateTicketUpdateName
    data: NotRequired[V3WorkflowsJiraCreateTicketUpdateDataTypedDict]


class V3WorkflowsJiraCreateTicketUpdate(BaseModel):
    name: V3WorkflowsJiraCreateTicketUpdateName

    data: Optional[V3WorkflowsJiraCreateTicketUpdateData] = None
