"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsSqTriggerManualWebhookName = Literal["sq_trigger_manual_webhook",]


class V3WorkflowsSqTriggerManualWebhookDataTypedDict(TypedDict):
    id: str


class V3WorkflowsSqTriggerManualWebhookData(BaseModel):
    id: str


class V3WorkflowsSqTriggerManualWebhookTypedDict(TypedDict):
    name: V3WorkflowsSqTriggerManualWebhookName
    data: V3WorkflowsSqTriggerManualWebhookDataTypedDict


class V3WorkflowsSqTriggerManualWebhook(BaseModel):
    name: V3WorkflowsSqTriggerManualWebhookName

    data: V3WorkflowsSqTriggerManualWebhookData
