"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsSlackArchiveChannelUpdateName = Literal["slack_archive_channel",]


class V3WorkflowsSlackArchiveChannelUpdateTypedDict(TypedDict):
    name: V3WorkflowsSlackArchiveChannelUpdateName


class V3WorkflowsSlackArchiveChannelUpdate(BaseModel):
    name: V3WorkflowsSlackArchiveChannelUpdateName
