"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_suppressionrules_suppressionrule import (
    V3ServicesSuppressionRulesSuppressionRule,
    V3ServicesSuppressionRulesSuppressionRuleTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict(
    TypedDict
):
    rules: List[V3ServicesSuppressionRulesSuppressionRuleTypedDict]


class V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequest(BaseModel):
    rules: List[V3ServicesSuppressionRulesSuppressionRule]
