"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsCommunicationCardsArchiveSlackChannelRequestTypedDict(TypedDict):
    r"""Request body for archiving a Slack channel."""

    slack_channel_id: str


class V3IncidentsCommunicationCardsArchiveSlackChannelRequest(BaseModel):
    r"""Request body for archiving a Slack channel."""

    slack_channel_id: str
