"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_extensions_webhooks_webhookresponse import (
    V3ExtensionsWebhooksWebhookResponse,
    V3ExtensionsWebhooksWebhookResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class WebhooksGetWebhookByIDRequestTypedDict(TypedDict):
    event_webhook_id: str
    r"""(Required) event webhook ID"""


class WebhooksGetWebhookByIDRequest(BaseModel):
    event_webhook_id: Annotated[
        str,
        pydantic.Field(alias="eventWebhookID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""(Required) event webhook ID"""


class WebhooksGetWebhookByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ExtensionsWebhooksWebhookResponseTypedDict


class WebhooksGetWebhookByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ExtensionsWebhooksWebhookResponse
