"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V4StatusPagesDeleteStatusPageByIDResponseTypedDict(TypedDict):
    id: int
    name: str
    organization_id: str
    team_id: str


class V4StatusPagesDeleteStatusPageByIDResponse(BaseModel):
    id: int

    name: str

    organization_id: Annotated[str, pydantic.Field(alias="organizationID")]

    team_id: Annotated[str, pydantic.Field(alias="teamID")]
