"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


V3WorkflowsSqSendEmailName = Literal["sq_send_email",]


class V3WorkflowsSqSendEmailDataTypedDict(TypedDict):
    to: List[str]
    subject: str
    body: str


class V3WorkflowsSqSendEmailData(BaseModel):
    to: List[str]

    subject: str

    body: str


class V3WorkflowsSqSendEmailTypedDict(TypedDict):
    name: V3WorkflowsSqSendEmailName
    data: V3WorkflowsSqSendEmailDataTypedDict


class V3WorkflowsSqSendEmail(BaseModel):
    name: V3WorkflowsSqSendEmailName

    data: V3WorkflowsSqSendEmailData
