"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3GlobalEventRulesRuleActionTypedDict(TypedDict):
    route_to: str
    r"""The service ID to which the alert should be routed."""


class V3GlobalEventRulesRuleAction(BaseModel):
    route_to: str
    r"""The service ID to which the alert should be routed."""
