"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesExtensionsSlackExtensionResponseTypedDict(TypedDict):
    id: int
    service_id: str
    organization_id: str
    channel_id: str
    created_at: str
    name: str


class V3ServicesExtensionsSlackExtensionResponse(BaseModel):
    id: int

    service_id: str

    organization_id: str

    channel_id: str

    created_at: str

    name: str
