"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsSlackMessageUserName = Literal["slack_message_user",]


class V3WorkflowsSlackMessageUserDataTypedDict(TypedDict):
    member_id: str
    message: str


class V3WorkflowsSlackMessageUserData(BaseModel):
    member_id: str

    message: str


class V3WorkflowsSlackMessageUserTypedDict(TypedDict):
    name: V3WorkflowsSlackMessageUserName
    data: V3WorkflowsSlackMessageUserDataTypedDict


class V3WorkflowsSlackMessageUser(BaseModel):
    name: V3WorkflowsSlackMessageUserName

    data: V3WorkflowsSlackMessageUserData
