"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_getworkflowactionbyidresponse import (
    V3WorkflowsGetWorkflowActionByIDResponse,
    V3WorkflowsGetWorkflowActionByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class WorkflowsGetWorkflowActionByIDRequestTypedDict(TypedDict):
    workflow_id: str
    action_id: str


class WorkflowsGetWorkflowActionByIDRequest(BaseModel):
    workflow_id: Annotated[
        str,
        pydantic.Field(alias="workflowID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    action_id: Annotated[
        str,
        pydantic.Field(alias="actionID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class WorkflowsGetWorkflowActionByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3WorkflowsGetWorkflowActionByIDResponseTypedDict


class WorkflowsGetWorkflowActionByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3WorkflowsGetWorkflowActionByIDResponse
