"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3IncidentsIngestionStatusRequestTypedDict(TypedDict):
    r"""Request body for getting ingestion status."""

    request_ids: List[str]


class V3IncidentsIngestionStatusRequest(BaseModel):
    r"""Request body for getting ingestion status."""

    request_ids: List[str]
