"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from squadcast_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from typing import List
from typing_extensions import TypedDict


class V3SLOSLOViolatingIncidentResponseTypedDict(TypedDict):
    id: int
    owner_type: str
    owner_id: str
    org_id: str
    slo_id: int
    incident_id: str
    slis: List[str]
    error_budget_spent: float
    is_false_positive: bool
    start_time: datetime
    end_time: datetime
    created_at: datetime
    updated_at: datetime
    deleted_at: Nullable[datetime]


class V3SLOSLOViolatingIncidentResponse(BaseModel):
    id: int

    owner_type: str

    owner_id: str

    org_id: str

    slo_id: int

    incident_id: str

    slis: List[str]

    error_budget_spent: float

    is_false_positive: bool

    start_time: datetime

    end_time: datetime

    created_at: datetime

    updated_at: datetime

    deleted_at: Nullable[datetime]

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = []
        nullable_fields = ["deleted_at"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
