"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsTagsMergeIncidentEntityReferenceTypedDict(TypedDict):
    r"""Reference to a merged incident entity."""

    id: str


class V3IncidentsTagsMergeIncidentEntityReference(BaseModel):
    r"""Reference to a merged incident entity."""

    id: str
