"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsCommunicationCardsCreateCommunicationCardRequestTypedDict(TypedDict):
    r"""Request body for creating a communication card."""

    type: str
    url: str
    title: str


class V3IncidentsCommunicationCardsCreateCommunicationCardRequest(BaseModel):
    r"""Request body for creating a communication card."""

    type: str

    url: str

    title: str
