"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V4SquadsUpdateSquadMemberRequestTypedDict(TypedDict):
    role: str


class V4SquadsUpdateSquadMemberRequest(BaseModel):
    role: str
