"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesAPTAConfigRequestTypedDict(TypedDict):
    is_enabled: bool
    timeout_in_mins: int


class V3ServicesAPTAConfigRequest(BaseModel):
    is_enabled: bool

    timeout_in_mins: int
