"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_scheduleresponse import V4ScheduleResponse, V4ScheduleResponseTypedDict
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class SchedulesCreateScheduleResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4ScheduleResponseTypedDict


class SchedulesCreateScheduleResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4ScheduleResponse
