"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DetailTypedDict(TypedDict):
    field: str
    message: str


class Detail(BaseModel):
    field: str

    message: str


class ErrorTypedDict(TypedDict):
    code: str
    message: str
    details: NotRequired[List[DetailTypedDict]]


class Error(BaseModel):
    code: str

    message: str

    details: Optional[List[Detail]] = None
