"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3SLOMarkSLOAffectedRequestTypedDict(TypedDict):
    incident_id: str
    slis: List[str]
    error_budget_spent: float
    owner_type: str
    owner_id: str
    org_id: str


class V3SLOMarkSLOAffectedRequest(BaseModel):
    incident_id: str

    slis: List[str]

    error_budget_spent: float

    owner_type: str

    owner_id: str

    org_id: str
