"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class AdditionalResponderTypedDict(TypedDict):
    id: str
    type: str


class AdditionalResponder(BaseModel):
    id: str

    type: str


class V3IncidentsAdditionalRespondersAddAdditionalRespondersRequestTypedDict(TypedDict):
    r"""Request body for adding additional responders to an incident."""

    additional_responders: List[AdditionalResponderTypedDict]


class V3IncidentsAdditionalRespondersAddAdditionalRespondersRequest(BaseModel):
    r"""Request body for adding additional responders to an incident."""

    additional_responders: List[AdditionalResponder]
