"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_communicationcards_communicationcardresponse import (
    V3IncidentsCommunicationCardsCommunicationCardResponse,
    V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class CommunicationCardsArchiveSlackChannelResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict


class CommunicationCardsArchiveSlackChannelResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsCommunicationCardsCommunicationCardResponse
