"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsIncidentExportAsyncResponseTypedDict(TypedDict):
    message: str
    request_id: str


class V3IncidentsIncidentExportAsyncResponse(BaseModel):
    message: str

    request_id: str
