"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3ServicesOverlayOptInForKeyBasedDeduplicationRequestTypedDict(TypedDict):
    dedup_key_enabled: NotRequired[bool]


class V3ServicesOverlayOptInForKeyBasedDeduplicationRequest(BaseModel):
    dedup_key_enabled: Optional[bool] = None
