"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3WorkflowsUpdateActionsOrderResponseDataTypedDict(TypedDict):
    action_order: List[int]


class V3WorkflowsUpdateActionsOrderResponseData(BaseModel):
    action_order: List[int]


class V3WorkflowsUpdateActionsOrderResponseTypedDict(TypedDict):
    data: V3WorkflowsUpdateActionsOrderResponseDataTypedDict


class V3WorkflowsUpdateActionsOrderResponse(BaseModel):
    data: V3WorkflowsUpdateActionsOrderResponseData
