"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3SquadsUpdateSquadRequestTypedDict(TypedDict):
    name: NotRequired[str]
    members: NotRequired[List[str]]


class V3SquadsUpdateSquadRequest(BaseModel):
    name: Optional[str] = None

    members: Optional[List[str]] = None
