"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3ServicesServiceMaintainerType = Literal[
    "user",
    "squad",
]


class V3ServicesServiceMaintainerTypedDict(TypedDict):
    id: str
    type: V3ServicesServiceMaintainerType


class V3ServicesServiceMaintainer(BaseModel):
    id: str

    type: V3ServicesServiceMaintainerType
