"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsIncidentPriorityUpdateResponseTypedDict(TypedDict):
    incident_id: str
    priority: str


class V3IncidentsIncidentPriorityUpdateResponse(BaseModel):
    incident_id: str

    priority: str
