"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V4StatusPagesTotalSubscribersCountTypedDict(TypedDict):
    total_count: int


class V4StatusPagesTotalSubscribersCount(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]
