"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_rotationresponse import V4RotationResponse, V4RotationResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class RotationsGetScheduleRotationsRequestTypedDict(TypedDict):
    schedule_id: str


class RotationsGetScheduleRotationsRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class RotationsGetScheduleRotationsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V4RotationResponseTypedDict]


class RotationsGetScheduleRotationsResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V4RotationResponse]
