"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsMsTeamsMessageChannelUpdateName = Literal["msteams_message_channel",]


class V3WorkflowsMsTeamsMessageChannelUpdateDataTypedDict(TypedDict):
    channel_id: NotRequired[str]
    message: NotRequired[str]


class V3WorkflowsMsTeamsMessageChannelUpdateData(BaseModel):
    channel_id: Optional[str] = None

    message: Optional[str] = None


class V3WorkflowsMsTeamsMessageChannelUpdateTypedDict(TypedDict):
    name: V3WorkflowsMsTeamsMessageChannelUpdateName
    data: NotRequired[V3WorkflowsMsTeamsMessageChannelUpdateDataTypedDict]


class V3WorkflowsMsTeamsMessageChannelUpdate(BaseModel):
    name: V3WorkflowsMsTeamsMessageChannelUpdateName

    data: Optional[V3WorkflowsMsTeamsMessageChannelUpdateData] = None
