"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_communicationcards_communicationcardresponse import (
    V3IncidentsCommunicationCardsCommunicationCardResponse,
    V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict,
)
from .v3_incidents_communicationcards_updatecommunicationcardrequest import (
    V3IncidentsCommunicationCardsUpdateCommunicationCardRequest,
    V3IncidentsCommunicationCardsUpdateCommunicationCardRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class CommunicationCardsUpdateCommunicationCardRequestTypedDict(TypedDict):
    incident_id: str
    r"""Required"""
    communication_card_id: str
    v3_incidents_communication_cards_update_communication_card_request: (
        V3IncidentsCommunicationCardsUpdateCommunicationCardRequestTypedDict
    )


class CommunicationCardsUpdateCommunicationCardRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="IncidentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Required"""

    communication_card_id: Annotated[
        str,
        pydantic.Field(alias="communicationCardId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_incidents_communication_cards_update_communication_card_request: Annotated[
        V3IncidentsCommunicationCardsUpdateCommunicationCardRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CommunicationCardsUpdateCommunicationCardResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict


class CommunicationCardsUpdateCommunicationCardResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsCommunicationCardsCommunicationCardResponse
