"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_serviceresponse import (
    V3ServicesServiceResponse,
    V3ServicesServiceResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class ServicesGetServicesByNameRequestTypedDict(TypedDict):
    name: str
    owner_id: str


class ServicesGetServicesByNameRequest(BaseModel):
    name: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]

    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]


class ServicesGetServicesByNameResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ServicesServiceResponseTypedDict


class ServicesGetServicesByNameResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ServicesServiceResponse
