"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_webforms_createorupdatewebformrequest import (
    V3WebformsCreateOrUpdateWebformRequest,
    V3WebformsCreateOrUpdateWebformRequestTypedDict,
)
from .v3_webforms_webformresponse import (
    V3WebformsWebformResponse,
    V3WebformsWebformResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class WebformsUpdateWebformRequestTypedDict(TypedDict):
    webform_id: int
    v3_webforms_create_or_update_webform_request: (
        V3WebformsCreateOrUpdateWebformRequestTypedDict
    )


class WebformsUpdateWebformRequest(BaseModel):
    webform_id: Annotated[
        int,
        pydantic.Field(alias="webformId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_webforms_create_or_update_webform_request: Annotated[
        V3WebformsCreateOrUpdateWebformRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class WebformsUpdateWebformResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3WebformsWebformResponseTypedDict


class WebformsUpdateWebformResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3WebformsWebformResponse
