"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class ResolutionReasonTypedDict(TypedDict):
    message: str


class ResolutionReason(BaseModel):
    message: str


class V3IncidentsResolveIncidentRequestTypedDict(TypedDict):
    r"""Request body for resolving an incident."""

    resolution_reason: ResolutionReasonTypedDict


class V3IncidentsResolveIncidentRequest(BaseModel):
    r"""Request body for resolving an incident."""

    resolution_reason: ResolutionReason
