"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class RequestsStatusTypedDict(TypedDict):
    pass


class RequestsStatus(BaseModel):
    pass


class IncidentsGetIncidentsStatusByRequestidsMetaTypedDict(TypedDict):
    error_count: int
    success_count: int


class IncidentsGetIncidentsStatusByRequestidsMeta(BaseModel):
    error_count: int

    success_count: int


class IncidentsGetIncidentsStatusByRequestidsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    requests_status: RequestsStatusTypedDict
    meta: IncidentsGetIncidentsStatusByRequestidsMetaTypedDict


class IncidentsGetIncidentsStatusByRequestidsResponse(BaseModel):
    r"""The request has succeeded."""

    requests_status: RequestsStatus

    meta: IncidentsGetIncidentsStatusByRequestidsMeta
