"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3GlobalEventRulesRuleActionUpdateTypedDict(TypedDict):
    route_to: NotRequired[str]
    r"""The service ID to which the alert should be routed."""


class V3GlobalEventRulesRuleActionUpdate(BaseModel):
    route_to: Optional[str] = None
    r"""The service ID to which the alert should be routed."""
