"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_apitokenresponse import (
    V3UsersAPITokenResponse,
    V3UsersAPITokenResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class UsersGetAllTokensResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3UsersAPITokenResponseTypedDict]


class UsersGetAllTokensResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3UsersAPITokenResponse]
