"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsMsTeamsMessageUserName = Literal["msteams_message_user",]


class V3WorkflowsMsTeamsMessageUserDataTypedDict(TypedDict):
    member_id: str
    message: str


class V3WorkflowsMsTeamsMessageUserData(BaseModel):
    member_id: str

    message: str


class V3WorkflowsMsTeamsMessageUserTypedDict(TypedDict):
    name: V3WorkflowsMsTeamsMessageUserName
    data: V3WorkflowsMsTeamsMessageUserDataTypedDict


class V3WorkflowsMsTeamsMessageUser(BaseModel):
    name: V3WorkflowsMsTeamsMessageUserName

    data: V3WorkflowsMsTeamsMessageUserData
