"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_overlay_overlayresponse import (
    V3ServicesOverlayOverlayResponse,
    V3ServicesOverlayOverlayResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class OverlayGetAllDedupKeyOverlayByServiceRequestTypedDict(TypedDict):
    service_id: str


class OverlayGetAllDedupKeyOverlayByServiceRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class OverlayGetAllDedupKeyOverlayByServiceResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3ServicesOverlayOverlayResponseTypedDict]


class OverlayGetAllDedupKeyOverlayByServiceResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3ServicesOverlayOverlayResponse]
