"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ExtensionsWebhooksWebhookListItemTypedDict(TypedDict):
    id: str
    name: str
    description: str
    trigger_type: str
    payload_type: str
    custom_payload_template_name: str


class V3ExtensionsWebhooksWebhookListItem(BaseModel):
    id: str

    name: str

    description: str

    trigger_type: str

    payload_type: str

    custom_payload_template_name: str
