"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_participantgroup import V4ParticipantGroup, V4ParticipantGroupTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4UpdateRotationParticipantsRequestTypedDict(TypedDict):
    participant_groups: List[V4ParticipantGroupTypedDict]


class V4UpdateRotationParticipantsRequest(BaseModel):
    participant_groups: Annotated[
        List[V4ParticipantGroup], pydantic.Field(alias="participantGroups")
    ]
