"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_createsquadresponse import (
    V4SquadsCreateSquadResponse,
    V4SquadsCreateSquadResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class SquadsCreateSquadV4ResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4SquadsCreateSquadResponseTypedDict


class SquadsCreateSquadV4Response(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4SquadsCreateSquadResponse
