"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal, Union
from typing_extensions import TypeAliasType


V3ExtensionsMSTeamsEventClassEnum = Literal[
    "incident_triggered",
    "incident_retriggered",
    "incident_acknowledged",
    "incident_resolved",
    "incident_reassigned",
    "incident_notes_added",
    "incident_postmortem_started",
    "incident_priority_updated",
    "incident_snoozed",
    "incident_unsnoozed",
    "incident_delayed_notifications_resumed",
]


V3ExtensionsMSTeamsEventClassTypedDict = TypeAliasType(
    "V3ExtensionsMSTeamsEventClassTypedDict",
    Union[str, V3ExtensionsMSTeamsEventClassEnum],
)
r"""Represents the specific type of an incident-related event."""


V3ExtensionsMSTeamsEventClass = TypeAliasType(
    "V3ExtensionsMSTeamsEventClass", Union[str, V3ExtensionsMSTeamsEventClassEnum]
)
r"""Represents the specific type of an incident-related event."""
