"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_createdglobaleventruleresponse import (
    V3GlobalEventRulesCreatedGlobalEventRuleResponse,
    V3GlobalEventRulesCreatedGlobalEventRuleResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class GlobalEventRulesCreateGlobalEventRuleResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3GlobalEventRulesCreatedGlobalEventRuleResponseTypedDict


class GlobalEventRulesCreateGlobalEventRuleResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3GlobalEventRulesCreatedGlobalEventRuleResponse
