"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_analyticsmetrics import (
    V3IncidentsAnalyticsMetrics,
    V3IncidentsAnalyticsMetricsTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsAnalyticsTypedDict(TypedDict):
    r"""Incident analytics data."""

    tta: V3IncidentsAnalyticsMetricsTypedDict
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""
    ttr: V3IncidentsAnalyticsMetricsTypedDict
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""


class V3IncidentsAnalytics(BaseModel):
    r"""Incident analytics data."""

    tta: V3IncidentsAnalyticsMetrics
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""

    ttr: V3IncidentsAnalyticsMetrics
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""
