"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_abilities import V3TeamsAbilities, V3TeamsAbilitiesTypedDict
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3TeamsTeamRoleResponseTypedDict(TypedDict):
    id: str
    name: str
    slug: str
    default: bool
    abilities: NotRequired[V3TeamsAbilitiesTypedDict]


class V3TeamsTeamRoleResponse(BaseModel):
    id: str

    name: str

    slug: str

    default: bool

    abilities: Optional[V3TeamsAbilities] = None
