"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsAdditionalRespondersAdditionalResponderTypedDict(TypedDict):
    r"""Represents an additional responder for an incident."""

    id: str
    type: str
    name: NotRequired[str]
    time_of_assignment: NotRequired[str]


class V3IncidentsAdditionalRespondersAdditionalResponder(BaseModel):
    r"""Represents an additional responder for an incident."""

    id: str

    type: str

    name: Optional[str] = None

    time_of_assignment: Optional[str] = None
