"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_maintenancemode_maintenancemoderesponse import (
    V3ServicesMaintenanceModeMaintenanceModeResponse,
    V3ServicesMaintenanceModeMaintenanceModeResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class MaintenanceModeGetMaintenanceModeRequestTypedDict(TypedDict):
    service_id: str


class MaintenanceModeGetMaintenanceModeRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class MaintenanceModeGetMaintenanceModeResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3ServicesMaintenanceModeMaintenanceModeResponseTypedDict]


class MaintenanceModeGetMaintenanceModeResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3ServicesMaintenanceModeMaintenanceModeResponse]
