"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_runbooks_runbookresponse import (
    V3RunbooksRunbookResponse,
    V3RunbooksRunbookResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class RunbooksGetRunbookByIDRequestTypedDict(TypedDict):
    runbook_id: str


class RunbooksGetRunbookByIDRequest(BaseModel):
    runbook_id: Annotated[
        str,
        pydantic.Field(alias="runbookID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class RunbooksGetRunbookByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3RunbooksRunbookResponseTypedDict


class RunbooksGetRunbookByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3RunbooksRunbookResponse
