"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_overlay_renderdedupkeytemplaterequest import (
    V3ServicesOverlayRenderDedupKeyTemplateRequest,
    V3ServicesOverlayRenderDedupKeyTemplateRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverlayRenderDedupKeyTemplateRequestTypedDict(TypedDict):
    service_id: str
    v3_services_overlay_render_dedup_key_template_request: (
        V3ServicesOverlayRenderDedupKeyTemplateRequestTypedDict
    )


class OverlayRenderDedupKeyTemplateRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_overlay_render_dedup_key_template_request: Annotated[
        V3ServicesOverlayRenderDedupKeyTemplateRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverlayRenderDedupKeyTemplateResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: str


class OverlayRenderDedupKeyTemplateResponse(BaseModel):
    r"""The request has succeeded."""

    data: str
