"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesDependenciesCreateOrUpdateDependenciesRequestTypedDict(TypedDict):
    dependencies: List[str]


class V3ServicesDependenciesCreateOrUpdateDependenciesRequest(BaseModel):
    dependencies: List[str]
