"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V3IncidentsResponseNoteTypedDict(TypedDict):
    r"""Represents a response note in an incident."""

    time_of_note: datetime
    note: str
    user_id: str


class V3IncidentsResponseNote(BaseModel):
    r"""Represents a response note in an incident."""

    time_of_note: Annotated[datetime, pydantic.Field(alias="timeOfNote")]

    note: str

    user_id: Annotated[str, pydantic.Field(alias="userId")]
