"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_incidentexportasyncresponse import (
    V3IncidentsIncidentExportAsyncResponse,
    V3IncidentsIncidentExportAsyncResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class IncidentsIncidentExportAsyncBodyTypedDict(TypedDict):
    r"""The body type of the operation request or response."""

    data: V3IncidentsIncidentExportAsyncResponseTypedDict


class IncidentsIncidentExportAsyncBody(BaseModel):
    r"""The body type of the operation request or response."""

    data: V3IncidentsIncidentExportAsyncResponse


class IncidentsIncidentExportAsyncResponseBodyTypedDict(TypedDict):
    r"""The request has been accepted for processing, but processing has not yet completed."""

    body: IncidentsIncidentExportAsyncBodyTypedDict
    r"""The body type of the operation request or response."""


class IncidentsIncidentExportAsyncResponseBody(BaseModel):
    r"""The request has been accepted for processing, but processing has not yet completed."""

    body: IncidentsIncidentExportAsyncBody
    r"""The body type of the operation request or response."""
