"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_componentgroups_getcomponentgroupbyidresponse import (
    V4StatusPagesComponentGroupsGetComponentGroupByIDResponse,
    V4StatusPagesComponentGroupsGetComponentGroupByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ComponentGroupsGetComponentGroupByIDRequestTypedDict(TypedDict):
    statuspage_id: str
    group_id: str


class ComponentGroupsGetComponentGroupByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    group_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class ComponentGroupsGetComponentGroupByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentGroupsGetComponentGroupByIDResponseTypedDict


class ComponentGroupsGetComponentGroupByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentGroupsGetComponentGroupByIDResponse
