"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class ExportDeleteIcalLinkRequestTypedDict(TypedDict):
    schedule_id: str
    my_on_call: bool


class ExportDeleteIcalLinkRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    my_on_call: Annotated[
        bool,
        pydantic.Field(alias="myOnCall"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ]


class ExportDeleteIcalLinkResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class ExportDeleteIcalLinkResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""
