"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .common_v3_entityowner import CommonV3EntityOwner, CommonV3EntityOwnerTypedDict
from .v3_runbooks_step import V3RunbooksStep, V3RunbooksStepTypedDict
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3RunbooksCreateRunbookRequestTypedDict(TypedDict):
    r"""Represents the request body for creating a new runbook."""

    name: str
    r"""The name of the runbook."""
    steps: List[V3RunbooksStepTypedDict]
    r"""The steps that make up the runbook."""
    owner_id: str
    r"""The ID of the team that owns this runbook."""
    entity_owner: NotRequired[CommonV3EntityOwnerTypedDict]
    r"""The owner of the entity."""


class V3RunbooksCreateRunbookRequest(BaseModel):
    r"""Represents the request body for creating a new runbook."""

    name: str
    r"""The name of the runbook."""

    steps: List[V3RunbooksStep]
    r"""The steps that make up the runbook."""

    owner_id: str
    r"""The ID of the team that owns this runbook."""

    entity_owner: Optional[CommonV3EntityOwner] = None
    r"""The owner of the entity."""
