"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3WorkflowsIssueStatusAndMessageTypedDict(TypedDict):
    messages: List[str]
    status_id: int


class V3WorkflowsIssueStatusAndMessage(BaseModel):
    messages: List[str]

    status_id: int
