"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3IncidentsRunbooksAttachRunbooksRequestTypedDict(TypedDict):
    runbooks: List[str]


class V3IncidentsRunbooksAttachRunbooksRequest(BaseModel):
    runbooks: List[str]
