"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V3IncidentsAssignedToTypedDict(TypedDict):
    r"""Schema for an assigned entity in an incident."""

    id: str
    type: str
    time_of_assignment: datetime
    reason: str


class V3IncidentsAssignedTo(BaseModel):
    r"""Schema for an assigned entity in an incident."""

    id: str

    type: str

    time_of_assignment: Annotated[datetime, pydantic.Field(alias="timeOfAssignment")]

    reason: str
