"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_entityownerupdate import (
    V3GlobalEventRulesEntityOwnerUpdate,
    V3GlobalEventRulesEntityOwnerUpdateTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3GlobalEventRulesUpdateGlobalEventRuleRequestTypedDict(TypedDict):
    name: NotRequired[str]
    description: NotRequired[str]
    entity_owner: NotRequired[V3GlobalEventRulesEntityOwnerUpdateTypedDict]


class V3GlobalEventRulesUpdateGlobalEventRuleRequest(BaseModel):
    name: Optional[str] = None

    description: Optional[str] = None

    entity_owner: Optional[V3GlobalEventRulesEntityOwnerUpdate] = None
