"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V4StatusPagesStatusPageStatusesResponseTypedDict(TypedDict):
    id: int
    name: str
    status: str
    description: str
    color: str


class V4StatusPagesStatusPageStatusesResponse(BaseModel):
    id: int

    name: str

    status: str

    description: str

    color: str
