"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class MessageOverlayTypedDict(TypedDict):
    template: str


class MessageOverlay(BaseModel):
    template: str


class DescriptionOverlayTypedDict(TypedDict):
    template: str


class DescriptionOverlay(BaseModel):
    template: str


class V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict(TypedDict):
    overlay_template_type: str
    message_overlay: MessageOverlayTypedDict
    description_overlay: DescriptionOverlayTypedDict


class V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest(BaseModel):
    overlay_template_type: str

    message_overlay: MessageOverlay

    description_overlay: DescriptionOverlay
