"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3IncidentsBulkIncidentIDsRequestTypedDict(TypedDict):
    r"""Request body for bulk incident operations (acknowledge, resolve)."""

    incident_ids: List[str]


class V3IncidentsBulkIncidentIDsRequest(BaseModel):
    r"""Request body for bulk incident operations (acknowledge, resolve)."""

    incident_ids: List[str]
