"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesSuppressionRulesCustomRepetitionTypedDict(TypedDict):
    repeats_count: int
    repeats: str
    repeats_on_weekdays: List[int]
    repeats_on_month: str


class V3ServicesSuppressionRulesCustomRepetition(BaseModel):
    repeats_count: int

    repeats: str

    repeats_on_weekdays: List[int]

    repeats_on_month: str
