"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class UsersDeleteUserRequestTypedDict(TypedDict):
    user_id: str
    swap_user_id: str
    suppress_incidents: bool
    reassign_incidents: bool


class UsersDeleteUserRequest(BaseModel):
    user_id: str

    swap_user_id: str

    suppress_incidents: bool

    reassign_incidents: bool


class UsersDeleteUserDataTypedDict(TypedDict):
    pass


class UsersDeleteUserData(BaseModel):
    pass


class UsersDeleteUserResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: UsersDeleteUserDataTypedDict


class UsersDeleteUserResponse(BaseModel):
    r"""The request has succeeded."""

    data: UsersDeleteUserData
