"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V4StatusPagesIssuesIssueStateMessageTypedDict(TypedDict):
    id: NotRequired[int]
    text: NotRequired[str]
    timestamp: NotRequired[datetime]


class V4StatusPagesIssuesIssueStateMessage(BaseModel):
    id: Optional[int] = None

    text: Optional[str] = None

    timestamp: Optional[datetime] = None
