"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_auditlogs_auditlogsexporthistoryresponse import (
    V3AuditLogsAuditLogsExportHistoryResponse,
    V3AuditLogsAuditLogsExportHistoryResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3AuditLogsGetAuditLogExportHistoryByIDResponseTypedDict(TypedDict):
    r"""Response model for getting audit log export history by ID"""

    data: V3AuditLogsAuditLogsExportHistoryResponseTypedDict
    r"""Response model for audit logs export history"""


class V3AuditLogsGetAuditLogExportHistoryByIDResponse(BaseModel):
    r"""Response model for getting audit log export history by ID"""

    data: V3AuditLogsAuditLogsExportHistoryResponse
    r"""Response model for audit logs export history"""
