"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsIncidentPriorityUpdateRequestTypedDict(TypedDict):
    r"""Request body for updating incident priority."""

    priority: NotRequired[str]


class V3IncidentsIncidentPriorityUpdateRequest(BaseModel):
    r"""Request body for updating incident priority."""

    priority: Optional[str] = None
