"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict(TypedDict):
    r"""Represents a communication card."""

    created_at: str
    updated_at: str
    deleted_at: Any
    id: int
    incident_id: str
    url: str
    type: str
    title: str
    channel_id: str
    archived_at: Any


class V3IncidentsCommunicationCardsCommunicationCardResponse(BaseModel):
    r"""Represents a communication card."""

    created_at: str

    updated_at: str

    deleted_at: Any

    id: int

    incident_id: str

    url: str

    type: str

    title: str

    channel_id: str

    archived_at: Any
