"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_suppressionrules_createorupdatesuppressionrulesrequest import (
    V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequest,
    V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict,
)
from .v3_services_suppressionrules_suppressionrulescontainerresponse import (
    V3ServicesSuppressionRulesSuppressionRulesContainerResponse,
    V3ServicesSuppressionRulesSuppressionRulesContainerResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict(TypedDict):
    service_id: str
    v3_services_suppression_rules_create_or_update_suppression_rules_request: (
        V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict
    )


class SuppressionRulesCreateOrUpdateSuppressionRulesRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_suppression_rules_create_or_update_suppression_rules_request: Annotated[
        V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SuppressionRulesCreateOrUpdateSuppressionRulesResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ServicesSuppressionRulesSuppressionRulesContainerResponseTypedDict


class SuppressionRulesCreateOrUpdateSuppressionRulesResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ServicesSuppressionRulesSuppressionRulesContainerResponse
