"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3WorkflowsWorkflowTrigger = Literal[
    "incident_triggered",
    "incident_acknowledged",
    "incident_resolved",
    "incident_reassigned",
    "incident_tag_updated",
    "incident_priority_updated",
    "incident_note_added",
]
