"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_postmortems_postmortemattachmentrequest import (
    V3IncidentsPostmortemsPostmortemAttachmentRequest,
    V3IncidentsPostmortemsPostmortemAttachmentRequestTypedDict,
)
from .v3_incidents_postmortems_postmortemfollowup import (
    V3IncidentsPostmortemsPostmortemFollowUp,
    V3IncidentsPostmortemsPostmortemFollowUpTypedDict,
)
from .v3_incidents_postmortems_postmortemstatus import (
    V3IncidentsPostmortemsPostmortemStatus,
)
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsPostmortemsUpdatePostmortemRequestTypedDict(TypedDict):
    r"""Request body for updating an existing postmortem."""

    owner_id: NotRequired[str]
    postmortem: NotRequired[str]
    follow_ups: NotRequired[List[V3IncidentsPostmortemsPostmortemFollowUpTypedDict]]
    new_attachments: NotRequired[
        List[V3IncidentsPostmortemsPostmortemAttachmentRequestTypedDict]
    ]
    title: NotRequired[str]
    status: NotRequired[V3IncidentsPostmortemsPostmortemStatus]
    r"""Represents the status of a postmortem."""


class V3IncidentsPostmortemsUpdatePostmortemRequest(BaseModel):
    r"""Request body for updating an existing postmortem."""

    owner_id: Optional[str] = None

    postmortem: Optional[str] = None

    follow_ups: Optional[List[V3IncidentsPostmortemsPostmortemFollowUp]] = None

    new_attachments: Optional[
        List[V3IncidentsPostmortemsPostmortemAttachmentRequest]
    ] = None

    title: Optional[str] = None

    status: Optional[V3IncidentsPostmortemsPostmortemStatus] = None
    r"""Represents the status of a postmortem."""
