"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V3IncidentsTagsRelevantPeopleLogTypedDict(TypedDict):
    r"""Represents a relevant people log entry."""

    user_id: str
    action_taken: str
    action_taken_by: str
    action_time: datetime


class V3IncidentsTagsRelevantPeopleLog(BaseModel):
    r"""Represents a relevant people log entry."""

    user_id: Annotated[str, pydantic.Field(alias="userId")]

    action_taken: Annotated[str, pydantic.Field(alias="actionTaken")]

    action_taken_by: Annotated[str, pydantic.Field(alias="actionTakenBy")]

    action_time: Annotated[datetime, pydantic.Field(alias="actionTime")]
