"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3TeamsCreateTeamRequestTypedDict(TypedDict):
    name: str
    member_ids: List[str]
    description: NotRequired[str]


class V3TeamsCreateTeamRequest(BaseModel):
    name: str

    member_ids: List[str]

    description: Optional[str] = None
