"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3UsersAPITokenResponseTypedDict(TypedDict):
    id: str
    organization_id: str
    user_id: str
    token: str
    last_refresh: str
    rate_limit: int
    deleted: bool


class V3UsersAPITokenResponse(BaseModel):
    id: str

    organization_id: str

    user_id: str

    token: str

    last_refresh: str

    rate_limit: int

    deleted: bool
