"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_participantgroup import V4ParticipantGroup, V4ParticipantGroupTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4GetRotationParticipantsResponseTypedDict(TypedDict):
    rotation_id: int
    participants: List[V4ParticipantGroupTypedDict]


class V4GetRotationParticipantsResponse(BaseModel):
    rotation_id: Annotated[int, pydantic.Field(alias="rotationID")]

    participants: List[V4ParticipantGroup]
