"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsIncidentActionsCircleCIErrorMetaTypedDict(TypedDict):
    r"""Represents the metadata for a CircleCI error response."""

    status_code: int
    error_message: str


class V3IncidentsIncidentActionsCircleCIErrorMeta(BaseModel):
    r"""Represents the metadata for a CircleCI error response."""

    status_code: int

    error_message: str
