"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class DedupKeyOverlayTypedDict(TypedDict):
    template: str
    duration: int


class DedupKeyOverlay(BaseModel):
    template: str

    duration: int


class V3ServicesOverlayUpdateDedupKeyOverlayRequestTypedDict(TypedDict):
    overlay_template_type: str
    dedup_key_overlay: DedupKeyOverlayTypedDict


class V3ServicesOverlayUpdateDedupKeyOverlayRequest(BaseModel):
    overlay_template_type: str

    dedup_key_overlay: DedupKeyOverlay
