"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3IncidentsNotesCreateNoteRequestTypedDict(TypedDict):
    r"""Request body for creating a new note."""

    message: str
    attachments: List[str]


class V3IncidentsNotesCreateNoteRequest(BaseModel):
    r"""Request body for creating a new note."""

    message: str

    attachments: List[str]
