"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsJiraCreateTicketName = Literal["jira_create_ticket",]


class V3WorkflowsJiraCreateTicketDataTypedDict(TypedDict):
    account: str
    project: str
    issue_type: str
    title: str
    description: str


class V3WorkflowsJiraCreateTicketData(BaseModel):
    account: str

    project: str

    issue_type: str

    title: str

    description: str


class V3WorkflowsJiraCreateTicketTypedDict(TypedDict):
    name: V3WorkflowsJiraCreateTicketName
    data: V3WorkflowsJiraCreateTicketDataTypedDict


class V3WorkflowsJiraCreateTicket(BaseModel):
    name: V3WorkflowsJiraCreateTicketName

    data: V3WorkflowsJiraCreateTicketData
