"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Any
from typing_extensions import TypedDict


class V3WorkflowsGetWorkflowActionByIDResponseTypedDict(TypedDict):
    id: int
    workflow_id: int
    name: str
    data: Any


class V3WorkflowsGetWorkflowActionByIDResponse(BaseModel):
    id: int

    workflow_id: int

    name: str

    data: Any
