"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesOverlayCustomContentTypedDict(TypedDict):
    message: str
    description: str


class V3ServicesOverlayCustomContent(BaseModel):
    message: str

    description: str
