"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_abilities import V3TeamsAbilities, V3TeamsAbilitiesTypedDict
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3TeamsUpdateTeamRoleRequestTypedDict(TypedDict):
    name: NotRequired[str]
    abilities: NotRequired[V3TeamsAbilitiesTypedDict]


class V3TeamsUpdateTeamRoleRequest(BaseModel):
    name: Optional[str] = None

    abilities: Optional[V3TeamsAbilities] = None
