"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_workflowapiresponse import (
    V3WorkflowsWorkflowAPIResponse,
    V3WorkflowsWorkflowAPIResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3WorkflowsGetWorkflowByIDResponseTypedDict(TypedDict):
    data: V3WorkflowsWorkflowAPIResponseTypedDict


class V3WorkflowsGetWorkflowByIDResponse(BaseModel):
    data: V3WorkflowsWorkflowAPIResponse
