"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_deduplicationrules_expressionbranch import (
    V3ServicesDeduplicationRulesExpressionBranch,
    V3ServicesDeduplicationRulesExpressionBranchTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit = Literal[
    "minute",
    "hour",
]


class V3ServicesDeduplicationRulesDeduplicationRuleTypedDict(TypedDict):
    expression: str
    time_window: int
    time_unit: V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit
    is_basic: bool
    basic_expression: NotRequired[
        List[V3ServicesDeduplicationRulesExpressionBranchTypedDict]
    ]
    dependency_deduplication: NotRequired[bool]
    description: NotRequired[str]


class V3ServicesDeduplicationRulesDeduplicationRule(BaseModel):
    expression: str

    time_window: int

    time_unit: V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit

    is_basic: bool

    basic_expression: Optional[List[V3ServicesDeduplicationRulesExpressionBranch]] = (
        None
    )

    dependency_deduplication: Optional[bool] = None

    description: Optional[str] = None
