"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_components_updatecomponentbyidrequest import (
    V4StatusPagesComponentsUpdateComponentByIDRequest,
    V4StatusPagesComponentsUpdateComponentByIDRequestTypedDict,
)
from .v4_statuspages_components_updatecomponentbyidresponse import (
    V4StatusPagesComponentsUpdateComponentByIDResponse,
    V4StatusPagesComponentsUpdateComponentByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ComponentsUpdateComponentByIDRequestTypedDict(TypedDict):
    statuspage_id: str
    component_id: str
    v4_status_pages_components_update_component_by_id_request: (
        V4StatusPagesComponentsUpdateComponentByIDRequestTypedDict
    )


class ComponentsUpdateComponentByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    component_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    v4_status_pages_components_update_component_by_id_request: Annotated[
        V4StatusPagesComponentsUpdateComponentByIDRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ComponentsUpdateComponentByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentsUpdateComponentByIDResponseTypedDict


class ComponentsUpdateComponentByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentsUpdateComponentByIDResponse
