"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class UserTypedDict(TypedDict):
    id: str
    first_name: str
    last_name: str
    deleted: bool


class User(BaseModel):
    id: str

    first_name: str

    last_name: str

    deleted: bool


class V3IncidentsNotesNoteResponseTypedDict(TypedDict):
    r"""Represents a note associated with an incident."""

    id: str
    created_at: str
    updated_at: str
    organization_id: str
    incident_id: str
    user_id: str
    message: str
    type: str
    attachments: List[str]
    user: UserTypedDict
    replaced_message: str


class V3IncidentsNotesNoteResponse(BaseModel):
    r"""Represents a note associated with an incident."""

    id: str

    created_at: str

    updated_at: str

    organization_id: str

    incident_id: str

    user_id: str

    message: str

    type: str

    attachments: List[str]

    user: User

    replaced_message: str
