"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_abilities import V3TeamsAbilities, V3TeamsAbilitiesTypedDict
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3TeamsTeamMemberResponseTypedDict(TypedDict):
    user_id: str
    role: NotRequired[str]
    role_ids: NotRequired[List[str]]
    abilities: NotRequired[V3TeamsAbilitiesTypedDict]


class V3TeamsTeamMemberResponse(BaseModel):
    user_id: str

    role: Optional[str] = None

    role_ids: Optional[List[str]] = None

    abilities: Optional[V3TeamsAbilities] = None
