"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_taggingrules_createorupdatetaggingrulesrequest import (
    V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest,
    V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict,
)
from .v3_services_taggingrules_taggingruleresponse import (
    V3ServicesTaggingRulesTaggingRuleResponse,
    V3ServicesTaggingRulesTaggingRuleResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class TaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict(TypedDict):
    service_id: str
    v3_services_tagging_rules_create_or_update_tagging_rules_request: (
        V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict
    )


class TaggingRulesCreateOrUpdateTaggingRulesRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_tagging_rules_create_or_update_tagging_rules_request: Annotated[
        V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class TaggingRulesCreateOrUpdateTaggingRulesDataTypedDict(TypedDict):
    rules: List[V3ServicesTaggingRulesTaggingRuleResponseTypedDict]


class TaggingRulesCreateOrUpdateTaggingRulesData(BaseModel):
    rules: List[V3ServicesTaggingRulesTaggingRuleResponse]


class TaggingRulesCreateOrUpdateTaggingRulesResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: TaggingRulesCreateOrUpdateTaggingRulesDataTypedDict


class TaggingRulesCreateOrUpdateTaggingRulesResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: TaggingRulesCreateOrUpdateTaggingRulesData
