"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSlackCreateIncidentChannelUpdateName = Literal[
    "slack_create_incident_channel",
]


class V3WorkflowsSlackCreateIncidentChannelUpdateDataTypedDict(TypedDict):
    auto_name: NotRequired[bool]
    channel_name: NotRequired[str]


class V3WorkflowsSlackCreateIncidentChannelUpdateData(BaseModel):
    auto_name: Optional[bool] = None

    channel_name: Optional[str] = None


class V3WorkflowsSlackCreateIncidentChannelUpdateTypedDict(TypedDict):
    name: V3WorkflowsSlackCreateIncidentChannelUpdateName
    data: NotRequired[V3WorkflowsSlackCreateIncidentChannelUpdateDataTypedDict]


class V3WorkflowsSlackCreateIncidentChannelUpdate(BaseModel):
    name: V3WorkflowsSlackCreateIncidentChannelUpdateName

    data: Optional[V3WorkflowsSlackCreateIncidentChannelUpdateData] = None
