"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_maintenances_getmaintenancebyidresponse import (
    V4StatusPagesMaintenancesGetMaintenanceByIDResponse,
    V4StatusPagesMaintenancesGetMaintenanceByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class MaintenancesGetMaintenanceByIDRequestTypedDict(TypedDict):
    statuspage_id: str
    maintenance_id: str


class MaintenancesGetMaintenanceByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    maintenance_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class MaintenancesGetMaintenanceByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesGetMaintenanceByIDResponseTypedDict


class MaintenancesGetMaintenanceByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesGetMaintenanceByIDResponse
