"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class UsersUpdateOrgLevelPermissionsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: str


class UsersUpdateOrgLevelPermissionsResponse(BaseModel):
    r"""The request has succeeded."""

    data: str
