"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_deduplicationrules_deduplicationrule import (
    V3ServicesDeduplicationRulesDeduplicationRule,
    V3ServicesDeduplicationRulesDeduplicationRuleTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesDeduplicationRulesCreateDeduplicationRulesRequestTypedDict(TypedDict):
    rules: List[V3ServicesDeduplicationRulesDeduplicationRuleTypedDict]


class V3ServicesDeduplicationRulesCreateDeduplicationRulesRequest(BaseModel):
    rules: List[V3ServicesDeduplicationRulesDeduplicationRule]
