"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


V3WorkflowsSqMarkIncidentSLOAffectingName = Literal["sq_mark_incident_slo_affecting",]


class V3WorkflowsSqMarkIncidentSLOAffectingDataTypedDict(TypedDict):
    slis: List[str]
    slo: int


class V3WorkflowsSqMarkIncidentSLOAffectingData(BaseModel):
    slis: List[str]

    slo: int


class V3WorkflowsSqMarkIncidentSLOAffectingTypedDict(TypedDict):
    name: V3WorkflowsSqMarkIncidentSLOAffectingName
    data: V3WorkflowsSqMarkIncidentSLOAffectingDataTypedDict


class V3WorkflowsSqMarkIncidentSLOAffecting(BaseModel):
    name: V3WorkflowsSqMarkIncidentSLOAffectingName

    data: V3WorkflowsSqMarkIncidentSLOAffectingData
