"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_createscheduleoverriderequest import (
    V4CreateScheduleOverrideRequest,
    V4CreateScheduleOverrideRequestTypedDict,
)
from .v4_overrideresponse import V4OverrideResponse, V4OverrideResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverridesCreateScheduleOverrideRequestTypedDict(TypedDict):
    schedule_id: str
    v4_create_schedule_override_request: V4CreateScheduleOverrideRequestTypedDict


class OverridesCreateScheduleOverrideRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_create_schedule_override_request: Annotated[
        V4CreateScheduleOverrideRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverridesCreateScheduleOverrideResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4OverrideResponseTypedDict


class OverridesCreateScheduleOverrideResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4OverrideResponse
