"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_actionrequestupdate import (
    V3WorkflowsActionRequestUpdate,
    V3WorkflowsActionRequestUpdateTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class WorkflowsUpdateWorkflowActionRequestTypedDict(TypedDict):
    workflow_id: str
    action_id: str
    v3_workflows_action_request_update: V3WorkflowsActionRequestUpdateTypedDict


class WorkflowsUpdateWorkflowActionRequest(BaseModel):
    workflow_id: Annotated[
        str,
        pydantic.Field(alias="workflowID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    action_id: Annotated[
        str,
        pydantic.Field(alias="actionID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_workflows_action_request_update: Annotated[
        V3WorkflowsActionRequestUpdate,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
