"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesServiceSlackTypedDict(TypedDict):
    channel_id: str
    name: str
    time: int


class V3ServicesServiceSlack(BaseModel):
    channel_id: str

    name: str

    time: int
