"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_componentandimpact import (
    V3WorkflowsComponentAndImpact,
    V3WorkflowsComponentAndImpactTypedDict,
)
from .v3_workflows_issuestatusandmessage import (
    V3WorkflowsIssueStatusAndMessage,
    V3WorkflowsIssueStatusAndMessageTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


V3WorkflowsSqCreateStatusPageIssueName = Literal["sq_add_status_page_issue",]


class V3WorkflowsSqCreateStatusPageIssueDataTypedDict(TypedDict):
    component_and_impact: List[V3WorkflowsComponentAndImpactTypedDict]
    issue_title: str
    page_status_id: int
    status_and_message: List[V3WorkflowsIssueStatusAndMessageTypedDict]
    status_page_id: int


class V3WorkflowsSqCreateStatusPageIssueData(BaseModel):
    component_and_impact: List[V3WorkflowsComponentAndImpact]

    issue_title: str

    page_status_id: int

    status_and_message: List[V3WorkflowsIssueStatusAndMessage]

    status_page_id: int


class V3WorkflowsSqCreateStatusPageIssueTypedDict(TypedDict):
    name: V3WorkflowsSqCreateStatusPageIssueName
    data: V3WorkflowsSqCreateStatusPageIssueDataTypedDict


class V3WorkflowsSqCreateStatusPageIssue(BaseModel):
    name: V3WorkflowsSqCreateStatusPageIssueName

    data: V3WorkflowsSqCreateStatusPageIssueData
