"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3SquadsCreateSquadRequestTypedDict(TypedDict):
    name: str
    members: List[str]
    owner_id: str


class V3SquadsCreateSquadRequest(BaseModel):
    name: str

    members: List[str]

    owner_id: str
