"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamresponse import V3TeamsTeamResponse, V3TeamsTeamResponseTypedDict
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class TeamsGetAllTeamsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamResponseTypedDict]


class TeamsGetAllTeamsResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamResponse]
