"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_workflowapiresponse import (
    V3WorkflowsWorkflowAPIResponse,
    V3WorkflowsWorkflowAPIResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ACLTypedDict(TypedDict):
    pass


class ACL(BaseModel):
    pass


class V3WorkflowsListWorkflowAPIResponseMetaTypedDict(TypedDict):
    total_count: int
    acl: NotRequired[ACLTypedDict]


class V3WorkflowsListWorkflowAPIResponseMeta(BaseModel):
    total_count: int

    acl: Optional[ACL] = None


class V3WorkflowsListWorkflowAPIResponseTypedDict(TypedDict):
    data: List[V3WorkflowsWorkflowAPIResponseTypedDict]
    meta: V3WorkflowsListWorkflowAPIResponseMetaTypedDict


class V3WorkflowsListWorkflowAPIResponse(BaseModel):
    data: List[V3WorkflowsWorkflowAPIResponse]

    meta: V3WorkflowsListWorkflowAPIResponseMeta
