"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_tags_incidentfortagsresponse import (
    V3IncidentsTagsIncidentForTagsResponse,
    V3IncidentsTagsIncidentForTagsResponseTypedDict,
)
from .v3_incidents_tags_updatetagrequest import (
    V3IncidentsTagsUpdateTagRequest,
    V3IncidentsTagsUpdateTagRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class TagsUpdateTagRequestTypedDict(TypedDict):
    incident_id: str
    v3_incidents_tags_update_tag_request: V3IncidentsTagsUpdateTagRequestTypedDict


class TagsUpdateTagRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="IncidentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_incidents_tags_update_tag_request: Annotated[
        V3IncidentsTagsUpdateTagRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class TagsUpdateTagResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsTagsIncidentForTagsResponseTypedDict


class TagsUpdateTagResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsTagsIncidentForTagsResponse
