"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class NotesDeleteNoteRequestTypedDict(TypedDict):
    incident_id: str
    r"""Required"""
    note_id: str
    r"""Required"""


class NotesDeleteNoteRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="IncidentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Required"""

    note_id: Annotated[
        str,
        pydantic.Field(alias="NoteId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Required"""


class NotesDeleteNoteResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class NotesDeleteNoteResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""
