"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_apta_messageresponse import (
    V3IncidentsAptaMessageResponse,
    V3IncidentsAptaMessageResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class AptaMarkAsTransientRequestTypedDict(TypedDict):
    incident_id: str


class AptaMarkAsTransientRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class AptaMarkAsTransientResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsAptaMessageResponseTypedDict


class AptaMarkAsTransientResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsAptaMessageResponse
