"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_componentstatus import (
    V4StatusPagesIssuesComponentStatus,
    V4StatusPagesIssuesComponentStatusTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesIssuesIssueComponentDetailTypedDict(TypedDict):
    id: NotRequired[int]
    status: NotRequired[V4StatusPagesIssuesComponentStatusTypedDict]
    under_maintenance: NotRequired[bool]
    status_maintenance: NotRequired[V4StatusPagesIssuesComponentStatusTypedDict]


class V4StatusPagesIssuesIssueComponentDetail(BaseModel):
    id: Optional[int] = None

    status: Optional[V4StatusPagesIssuesComponentStatus] = None

    under_maintenance: Annotated[
        Optional[bool], pydantic.Field(alias="underMaintenance")
    ] = None

    status_maintenance: Annotated[
        Optional[V4StatusPagesIssuesComponentStatus],
        pydantic.Field(alias="statusMaintenance"),
    ] = None
