"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3WorkflowsTagTypedDict(TypedDict):
    color: NotRequired[str]
    key: NotRequired[str]
    value: NotRequired[str]


class V3WorkflowsTag(BaseModel):
    color: Optional[str] = None

    key: Optional[str] = None

    value: Optional[str] = None
