"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V4StatusPagesIssuesIssueStateTypedDict(TypedDict):
    id: int
    name: str
    color: str
    slug: str


class V4StatusPagesIssuesIssueState(BaseModel):
    id: int

    name: str

    color: str

    slug: str
