"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_components_createcomponentrequest import (
    V4StatusPagesComponentsCreateComponentRequest,
    V4StatusPagesComponentsCreateComponentRequestTypedDict,
)
from .v4_statuspages_components_createcomponentresponse import (
    V4StatusPagesComponentsCreateComponentResponse,
    V4StatusPagesComponentsCreateComponentResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ComponentsCreateComponentRequestTypedDict(TypedDict):
    statuspage_id: str
    v4_status_pages_components_create_component_request: (
        V4StatusPagesComponentsCreateComponentRequestTypedDict
    )


class ComponentsCreateComponentRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_status_pages_components_create_component_request: Annotated[
        V4StatusPagesComponentsCreateComponentRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ComponentsCreateComponentResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentsCreateComponentResponseTypedDict


class ComponentsCreateComponentResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentsCreateComponentResponse
