"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_componentgroups_createcomponentgrouprequest import (
    V4StatusPagesComponentGroupsCreateComponentGroupRequest,
    V4StatusPagesComponentGroupsCreateComponentGroupRequestTypedDict,
)
from .v4_statuspages_componentgroups_createcomponentgroupresponse import (
    V4StatusPagesComponentGroupsCreateComponentGroupResponse,
    V4StatusPagesComponentGroupsCreateComponentGroupResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class ComponentGroupsCreateComponentGroupRequestTypedDict(TypedDict):
    statuspage_id: str
    v4_status_pages_component_groups_create_component_group_request: (
        V4StatusPagesComponentGroupsCreateComponentGroupRequestTypedDict
    )


class ComponentGroupsCreateComponentGroupRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_status_pages_component_groups_create_component_group_request: Annotated[
        V4StatusPagesComponentGroupsCreateComponentGroupRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class ComponentGroupsCreateComponentGroupResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentGroupsCreateComponentGroupResponseTypedDict


class ComponentGroupsCreateComponentGroupResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesComponentGroupsCreateComponentGroupResponse
