"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class WebformsRemoveWebformRequestTypedDict(TypedDict):
    webform_id: int
    owner_id: str


class WebformsRemoveWebformRequest(BaseModel):
    webform_id: Annotated[
        int,
        pydantic.Field(alias="webformId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]


class WebformsRemoveWebformResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: str


class WebformsRemoveWebformResponse(BaseModel):
    r"""The request has succeeded."""

    data: str
