"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_entityowner import (
    V3GlobalEventRulesEntityOwner,
    V3GlobalEventRulesEntityOwnerTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3GlobalEventRulesCreateGlobalEventRuleRequestTypedDict(TypedDict):
    name: str
    description: str
    owner_id: str
    entity_owner: V3GlobalEventRulesEntityOwnerTypedDict


class V3GlobalEventRulesCreateGlobalEventRuleRequest(BaseModel):
    name: str

    description: str

    owner_id: str

    entity_owner: V3GlobalEventRulesEntityOwner
