"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamresponse import V3TeamsTeamResponse, V3TeamsTeamResponseTypedDict
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class TeamsCreateTeamResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3TeamsTeamResponseTypedDict


class TeamsCreateTeamResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3TeamsTeamResponse
