"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3WorkflowsBulkEnableDisableWorkflowsRequestTypedDict(TypedDict):
    owner_id: str
    enabled: bool
    workflow_ids: List[int]


class V3WorkflowsBulkEnableDisableWorkflowsRequest(BaseModel):
    owner_id: str

    enabled: bool

    workflow_ids: List[int]
