"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_scheduleresponse import V4ScheduleResponse, V4ScheduleResponseTypedDict
from .v4_updateschedulerequest import (
    V4UpdateScheduleRequest,
    V4UpdateScheduleRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SchedulesUpdateScheduleRequestTypedDict(TypedDict):
    schedule_id: str
    v4_update_schedule_request: V4UpdateScheduleRequestTypedDict


class SchedulesUpdateScheduleRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_update_schedule_request: Annotated[
        V4UpdateScheduleRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SchedulesUpdateScheduleResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4ScheduleResponseTypedDict


class SchedulesUpdateScheduleResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4ScheduleResponse
