"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_rulesetruleresponse import (
    V3GlobalEventRulesRulesetRuleResponse,
    V3GlobalEventRulesRulesetRuleResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GlobalEventRulesGetRuleByIDRequestTypedDict(TypedDict):
    ger_id: int
    alert_source_version: str
    alert_source_shortname: str
    rule_id: str


class GlobalEventRulesGetRuleByIDRequest(BaseModel):
    ger_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_version: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_shortname: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    rule_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GlobalEventRulesGetRuleByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesRulesetRuleResponseTypedDict


class GlobalEventRulesGetRuleByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesRulesetRuleResponse
