"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_updatesquadmemberrequest import (
    V4SquadsUpdateSquadMemberRequest,
    V4SquadsUpdateSquadMemberRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import (
    FieldMetadata,
    PathParamMetadata,
    QueryParamMetadata,
    RequestMetadata,
)
from typing_extensions import Annotated, TypedDict


class SquadsUpdateSquadMemberRequestTypedDict(TypedDict):
    squad_id: str
    member_id: str
    replace_with: str
    v4_squads_update_squad_member_request: V4SquadsUpdateSquadMemberRequestTypedDict


class SquadsUpdateSquadMemberRequest(BaseModel):
    squad_id: Annotated[
        str,
        pydantic.Field(alias="squadID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    member_id: Annotated[
        str,
        pydantic.Field(alias="memberID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    replace_with: Annotated[
        str,
        pydantic.Field(alias="replaceWith"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]

    v4_squads_update_squad_member_request: Annotated[
        V4SquadsUpdateSquadMemberRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
