"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_updateuserrequest import (
    V3UsersUpdateUserRequest,
    V3UsersUpdateUserRequestTypedDict,
)
from .v3_users_userresponse import V3UsersUserResponse, V3UsersUserResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UsersUpdateUserByIDRequestTypedDict(TypedDict):
    user_id: str
    r"""(Required) user id"""
    v3_users_update_user_request: V3UsersUpdateUserRequestTypedDict


class UsersUpdateUserByIDRequest(BaseModel):
    user_id: Annotated[
        str,
        pydantic.Field(alias="userID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""(Required) user id"""

    v3_users_update_user_request: Annotated[
        V3UsersUpdateUserRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UsersUpdateUserByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3UsersUserResponseTypedDict


class UsersUpdateUserByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3UsersUserResponse
