"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_slo_slodetailedresponse import (
    V3SLOSLODetailedResponse,
    V3SLOSLODetailedResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class SLOCreateSLODataTypedDict(TypedDict):
    slo: V3SLOSLODetailedResponseTypedDict


class SLOCreateSLOData(BaseModel):
    slo: V3SLOSLODetailedResponse


class SLOCreateSLOResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: SLOCreateSLODataTypedDict


class SLOCreateSLOResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: SLOCreateSLOData
