"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GlobalEventRulesDeleteGlobalEventRuleByIDRequestTypedDict(TypedDict):
    ger_id: int


class GlobalEventRulesDeleteGlobalEventRuleByIDRequest(BaseModel):
    ger_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GlobalEventRulesDeleteGlobalEventRuleByIDResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class GlobalEventRulesDeleteGlobalEventRuleByIDResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""
