"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_globaleventruleresponse import (
    V3GlobalEventRulesGlobalEventRuleResponse,
    V3GlobalEventRulesGlobalEventRuleResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class GlobalEventRulesGetGlobalEventRuleByIDRequestTypedDict(TypedDict):
    ger_id: int


class GlobalEventRulesGetGlobalEventRuleByIDRequest(BaseModel):
    ger_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class GlobalEventRulesGetGlobalEventRuleByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesGlobalEventRuleResponseTypedDict


class GlobalEventRulesGetGlobalEventRuleByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesGlobalEventRuleResponse
