"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_assignto import V3IncidentsAssignTo, V3IncidentsAssignToTypedDict
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsNotificationDelayPolicyTypedDict(TypedDict):
    r"""Policy for delaying notifications."""

    is_notification_delayed: bool
    delayed_until: datetime
    assign_to: V3IncidentsAssignToTypedDict
    r"""Represents the assignment target for delayed notifications."""


class V3IncidentsNotificationDelayPolicy(BaseModel):
    r"""Policy for delaying notifications."""

    is_notification_delayed: bool

    delayed_until: datetime

    assign_to: V3IncidentsAssignTo
    r"""Represents the assignment target for delayed notifications."""
