"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_ruleactionupdate import (
    V3GlobalEventRulesRuleActionUpdate,
    V3GlobalEventRulesRuleActionUpdateTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3GlobalEventRulesUpdateRulesetRequestTypedDict(TypedDict):
    catch_all_action: NotRequired[V3GlobalEventRulesRuleActionUpdateTypedDict]


class V3GlobalEventRulesUpdateRulesetRequest(BaseModel):
    catch_all_action: Optional[V3GlobalEventRulesRuleActionUpdate] = None
