"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_getstatuspagebyidresponse import (
    V4StatusPagesGetStatusPageByIDResponse,
    V4StatusPagesGetStatusPageByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class StatusPagesGetStatusPageByIDRequestTypedDict(TypedDict):
    statuspage_id: str


class StatusPagesGetStatusPageByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class StatusPagesGetStatusPageByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesGetStatusPageByIDResponseTypedDict


class StatusPagesGetStatusPageByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesGetStatusPageByIDResponse
