"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3IncidentsTagsIncidentPriority = Literal[
    "P1",
    "P2",
    "P3",
    "P4",
    "P5",
]
r"""Represents the priority of an incident."""
