"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class ReassignToTypedDict(TypedDict):
    id: str
    type: str


class ReassignTo(BaseModel):
    id: str

    type: str


class V3IncidentsReassignIncidentRequestTypedDict(TypedDict):
    r"""Request body for reassigning an incident."""

    reassign_to: ReassignToTypedDict


class V3IncidentsReassignIncidentRequest(BaseModel):
    r"""Request body for reassigning an incident."""

    reassign_to: Annotated[ReassignTo, pydantic.Field(alias="reassignTo")]
