"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsSlackMessageChannelName = Literal["slack_message_channel",]


class V3WorkflowsSlackMessageChannelDataTypedDict(TypedDict):
    channel_id: str
    channel_name: str
    message: str


class V3WorkflowsSlackMessageChannelData(BaseModel):
    channel_id: str

    channel_name: str

    message: str


class V3WorkflowsSlackMessageChannelTypedDict(TypedDict):
    name: V3WorkflowsSlackMessageChannelName
    data: V3WorkflowsSlackMessageChannelDataTypedDict


class V3WorkflowsSlackMessageChannel(BaseModel):
    name: V3WorkflowsSlackMessageChannelName

    data: V3WorkflowsSlackMessageChannelData
