"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_squadmember import V4SquadsSquadMember, V4SquadsSquadMemberTypedDict
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V4SquadsCreateSquadRequestTypedDict(TypedDict):
    owner_id: str
    name: str
    members: List[V4SquadsSquadMemberTypedDict]


class V4SquadsCreateSquadRequest(BaseModel):
    owner_id: str

    name: str

    members: List[V4SquadsSquadMember]
