"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesOverlayRenderCustomContentOverlayRequestTypedDict(TypedDict):
    overlay_template_type: str
    template: str
    payload: str


class V3ServicesOverlayRenderCustomContentOverlayRequest(BaseModel):
    overlay_template_type: str

    template: str

    payload: str
