"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsMsTeamsCreateMeetingLinkName = Literal["msteams_create_meeting_link",]


class V3WorkflowsMsTeamsCreateMeetingLinkTypedDict(TypedDict):
    name: V3WorkflowsMsTeamsCreateMeetingLinkName


class V3WorkflowsMsTeamsCreateMeetingLink(BaseModel):
    name: V3WorkflowsMsTeamsCreateMeetingLinkName
