"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesServiceTagTypedDict(TypedDict):
    key: str
    value: str


class V3ServicesServiceTag(BaseModel):
    key: str

    value: str
