"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesEscalationPolicyBasicTypedDict(TypedDict):
    r"""Represents the basic details of an Escalation Policy for a service."""

    id: str
    r"""The unique identifier for the escalation policy."""
    name: str
    r"""The name of the escalation policy."""
    description: str
    r"""A description of the escalation policy."""
    slug: str
    r"""The URL-friendly slug for the policy name."""


class V3ServicesEscalationPolicyBasic(BaseModel):
    r"""Represents the basic details of an Escalation Policy for a service."""

    id: str
    r"""The unique identifier for the escalation policy."""

    name: str
    r"""The name of the escalation policy."""

    description: str
    r"""A description of the escalation policy."""

    slug: str
    r"""The URL-friendly slug for the policy name."""
