"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V4StatusPagesIssuesIssueComponentTypedDict(TypedDict):
    id: NotRequired[int]
    name: NotRequired[str]


class V4StatusPagesIssuesIssueComponent(BaseModel):
    id: Optional[int] = None

    name: Optional[str] = None
