"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_runbooks_runbookresponse import (
    V3RunbooksRunbookResponse,
    V3RunbooksRunbookResponseTypedDict,
)
from .v3_runbooks_updaterunbookrequest import (
    V3RunbooksUpdateRunbookRequest,
    V3RunbooksUpdateRunbookRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class RunbooksUpdateRunbookRequestTypedDict(TypedDict):
    runbook_id: str
    v3_runbooks_update_runbook_request: V3RunbooksUpdateRunbookRequestTypedDict


class RunbooksUpdateRunbookRequest(BaseModel):
    runbook_id: Annotated[
        str,
        pydantic.Field(alias="runbookID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_runbooks_update_runbook_request: Annotated[
        V3RunbooksUpdateRunbookRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class RunbooksUpdateRunbookResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3RunbooksRunbookResponseTypedDict


class RunbooksUpdateRunbookResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3RunbooksRunbookResponse
