"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class WorkflowsBulkEnabledisableWorkflowsResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class WorkflowsBulkEnabledisableWorkflowsResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""
