"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsIncidentActionsRebuildCircleCIProjectRequestTypedDict(TypedDict):
    r"""Request body for rebuilding a project in CircleCI."""

    vcs_type: str
    username: str
    reponame: str


class V3IncidentsIncidentActionsRebuildCircleCIProjectRequest(BaseModel):
    r"""Request body for rebuilding a project in CircleCI."""

    vcs_type: str

    username: str

    reponame: str
