"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_suppressionrules_customrepetition import (
    V3ServicesSuppressionRulesCustomRepetition,
    V3ServicesSuppressionRulesCustomRepetitionTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesSuppressionRulesTimeslotTypedDict(TypedDict):
    time_zone: str
    start_time: str
    end_time: str
    is_allday: bool
    repetition: str
    is_custom: bool
    custom: V3ServicesSuppressionRulesCustomRepetitionTypedDict
    ends_never: bool
    ends_on: str


class V3ServicesSuppressionRulesTimeslot(BaseModel):
    time_zone: str

    start_time: str

    end_time: str

    is_allday: bool

    repetition: str

    is_custom: bool

    custom: V3ServicesSuppressionRulesCustomRepetition

    ends_never: bool

    ends_on: str
