"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V4StatusPagesNewStatusPageThemeColorTypedDict(TypedDict):
    primary: NotRequired[str]
    secondary: NotRequired[str]


class V4StatusPagesNewStatusPageThemeColor(BaseModel):
    primary: Optional[str] = None

    secondary: Optional[str] = None
