"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_updatesquadnamerequest import (
    V4SquadsUpdateSquadNameRequest,
    V4SquadsUpdateSquadNameRequestTypedDict,
)
from .v4_squads_updatesquadnameresponse import (
    V4SquadsUpdateSquadNameResponse,
    V4SquadsUpdateSquadNameResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SquadsUpdateSquadNameRequestTypedDict(TypedDict):
    squad_id: str
    v4_squads_update_squad_name_request: V4SquadsUpdateSquadNameRequestTypedDict


class SquadsUpdateSquadNameRequest(BaseModel):
    squad_id: Annotated[
        str,
        pydantic.Field(alias="squadID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_squads_update_squad_name_request: Annotated[
        V4SquadsUpdateSquadNameRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SquadsUpdateSquadNameResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4SquadsUpdateSquadNameResponseTypedDict


class SquadsUpdateSquadNameResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4SquadsUpdateSquadNameResponse
