"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_export_exportresponse import (
    V3ExportExportResponse,
    V3ExportExportResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ExportGetExportDetailsRequestTypedDict(TypedDict):
    export_id: str


class ExportGetExportDetailsRequest(BaseModel):
    export_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class ExportGetExportDetailsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ExportExportResponseTypedDict


class ExportGetExportDetailsResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ExportExportResponse
