"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaloncallreminderrules_globaloncallreminderruleresponse import (
    V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse,
    V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequestTypedDict(TypedDict):
    owner_id: str
    r"""required *"""


class GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequest(BaseModel):
    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]
    r"""required *"""


class GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict


class GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse
