"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3RunbooksStepTypedDict(TypedDict):
    r"""Represents a single step in a runbook."""

    content: str
    r"""The content of the step, in Markdown format."""


class V3RunbooksStep(BaseModel):
    r"""Represents a single step in a runbook."""

    content: str
    r"""The content of the step, in Markdown format."""
