"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_routingrules_routingrule import (
    V3ServicesRoutingRulesRoutingRule,
    V3ServicesRoutingRulesRoutingRuleTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequestTypedDict(TypedDict):
    rules: List[V3ServicesRoutingRulesRoutingRuleTypedDict]


class V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequest(BaseModel):
    rules: List[V3ServicesRoutingRulesRoutingRule]
