"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class OwnerTypedDict(TypedDict):
    id: str
    type: str


class Owner(BaseModel):
    id: str

    type: str


class V3SquadsSquadResponseOrganizationTypedDict(TypedDict):
    id: str
    name: str
    slug: str


class V3SquadsSquadResponseOrganization(BaseModel):
    id: str

    name: str

    slug: str


class V3SquadsSquadResponseTypedDict(TypedDict):
    id: str
    name: str
    slug: str
    members: List[str]
    organization_id: str
    owner: OwnerTypedDict
    organization: V3SquadsSquadResponseOrganizationTypedDict


class V3SquadsSquadResponse(BaseModel):
    id: str

    name: str

    slug: str

    members: List[str]

    organization_id: str

    owner: Owner

    organization: V3SquadsSquadResponseOrganization
