"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class WebhooksGetAllWebhooksRequestTypedDict(TypedDict):
    page_limit: NotRequired[str]
    offset: NotRequired[str]


class WebhooksGetAllWebhooksRequest(BaseModel):
    page_limit: Annotated[
        Optional[str],
        pydantic.Field(alias="page-limit"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None

    offset: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
