"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3ExportExportResponseTypedDict(TypedDict):
    id: str
    type: str
    status: str
    format_: str
    download_url: NotRequired[str]
    download_url_expires_at: NotRequired[str]
    error_message: NotRequired[str]


class V3ExportExportResponse(BaseModel):
    id: str

    type: str

    status: str

    format_: Annotated[str, pydantic.Field(alias="format")]

    download_url: Optional[str] = None

    download_url_expires_at: Optional[str] = None

    error_message: Optional[str] = None
