"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesComponentGroupsCreateComponentGroupResponseTypedDict(TypedDict):
    id: int
    page_id: int
    name: str
    allow_subscription: bool
    description: NotRequired[str]


class V4StatusPagesComponentGroupsCreateComponentGroupResponse(BaseModel):
    id: int

    page_id: Annotated[int, pydantic.Field(alias="pageID")]

    name: str

    allow_subscription: Annotated[bool, pydantic.Field(alias="allowSubscription")]

    description: Optional[str] = None
