"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_rotationresponse import V4RotationResponse, V4RotationResponseTypedDict
from .v4_updaterotationrequest import (
    V4UpdateRotationRequest,
    V4UpdateRotationRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class RotationsUpdateRotationRequestTypedDict(TypedDict):
    schedule_id: str
    rotation_id: str
    v4_update_rotation_request: V4UpdateRotationRequestTypedDict


class RotationsUpdateRotationRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    rotation_id: Annotated[
        str,
        pydantic.Field(alias="rotationID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_update_rotation_request: Annotated[
        V4UpdateRotationRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class RotationsUpdateRotationResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4RotationResponseTypedDict


class RotationsUpdateRotationResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4RotationResponse
