"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_icallinkresponse import V4ICalLinkResponse, V4ICalLinkResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class ExportGetScheduleIcalLinkRequestTypedDict(TypedDict):
    schedule_id: str
    my_on_call: bool


class ExportGetScheduleIcalLinkRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    my_on_call: Annotated[
        bool,
        pydantic.Field(alias="myOnCall"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ]


class ExportGetScheduleIcalLinkResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4ICalLinkResponseTypedDict


class ExportGetScheduleIcalLinkResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4ICalLinkResponse
