"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_components_component import (
    V4StatusPagesComponentsComponent,
    V4StatusPagesComponentsComponentTypedDict,
)
from .v4_statuspages_components_componentstatus import (
    V4StatusPagesComponentsComponentStatus,
    V4StatusPagesComponentsComponentStatusTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesComponentsListComponentsResponseTypedDict(TypedDict):
    id: NotRequired[int]
    type: NotRequired[str]
    name: NotRequired[str]
    allow_subscription: NotRequired[bool]
    description: NotRequired[str]
    status: NotRequired[V4StatusPagesComponentsComponentStatusTypedDict]
    under_maintenance: NotRequired[bool]
    status_maintenance: NotRequired[V4StatusPagesComponentsComponentStatusTypedDict]
    components: NotRequired[List[V4StatusPagesComponentsComponentTypedDict]]
    is_hidden: NotRequired[bool]


class V4StatusPagesComponentsListComponentsResponse(BaseModel):
    id: Optional[int] = None

    type: Optional[str] = None

    name: Optional[str] = None

    allow_subscription: Annotated[
        Optional[bool], pydantic.Field(alias="allowSubscription")
    ] = None

    description: Optional[str] = None

    status: Optional[V4StatusPagesComponentsComponentStatus] = None

    under_maintenance: Annotated[
        Optional[bool], pydantic.Field(alias="underMaintenance")
    ] = None

    status_maintenance: Annotated[
        Optional[V4StatusPagesComponentsComponentStatus],
        pydantic.Field(alias="statusMaintenance"),
    ] = None

    components: Optional[List[V4StatusPagesComponentsComponent]] = None

    is_hidden: Annotated[Optional[bool], pydantic.Field(alias="isHidden")] = None
