"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V4TagTypedDict(TypedDict):
    key: str
    value: str
    color: str


class V4Tag(BaseModel):
    key: str

    value: str

    color: str
