"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_squadmember import V4SquadsSquadMember, V4SquadsSquadMemberTypedDict
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V4SquadsCreateSquadResponseTypedDict(TypedDict):
    organization_id: str
    owner_id: str
    id: str
    name: str
    slug: str
    members: List[V4SquadsSquadMemberTypedDict]
    created_at: str
    created_by: str


class V4SquadsCreateSquadResponse(BaseModel):
    organization_id: str

    owner_id: str

    id: str

    name: str

    slug: str

    members: List[V4SquadsSquadMember]

    created_at: str

    created_by: str
