"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_auditlogs_auditlogresponse import (
    V3AuditLogsAuditLogResponse,
    V3AuditLogsAuditLogResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V3AuditLogsListAuditLogsResponseMetadataTypedDict(TypedDict):
    total_count: int


class V3AuditLogsListAuditLogsResponseMetadata(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]


class V3AuditLogsListAuditLogsResponseTypedDict(TypedDict):
    r"""Response model for listing audit logs"""

    data: List[V3AuditLogsAuditLogResponseTypedDict]
    metadata: V3AuditLogsListAuditLogsResponseMetadataTypedDict


class V3AuditLogsListAuditLogsResponse(BaseModel):
    r"""Response model for listing audit logs"""

    data: List[V3AuditLogsAuditLogResponse]

    metadata: V3AuditLogsListAuditLogsResponseMetadata
