"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_runbooks_runbookresponse import (
    V3RunbooksRunbookResponse,
    V3RunbooksRunbookResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class RunbooksGetAllRunbooksByTeamResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3RunbooksRunbookResponseTypedDict]


class RunbooksGetAllRunbooksByTeamResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3RunbooksRunbookResponse]
