"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_suppressionrules_suppressionrule import (
    V3ServicesSuppressionRulesSuppressionRule,
    V3ServicesSuppressionRulesSuppressionRuleTypedDict,
)
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesSuppressionRulesSuppressionRulesContainerResponseTypedDict(TypedDict):
    id: str
    created_at: datetime
    updated_at: datetime
    service_id: str
    organization_id: str
    rules: List[V3ServicesSuppressionRulesSuppressionRuleTypedDict]


class V3ServicesSuppressionRulesSuppressionRulesContainerResponse(BaseModel):
    id: str

    created_at: datetime

    updated_at: datetime

    service_id: str

    organization_id: str

    rules: List[V3ServicesSuppressionRulesSuppressionRule]
