"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_snoozenotifications_snoozeincidentrequest import (
    V3IncidentsSnoozeNotificationsSnoozeIncidentRequest,
    V3IncidentsSnoozeNotificationsSnoozeIncidentRequestTypedDict,
)
from .v3_incidents_snoozenotifications_snoozeincidentresponse import (
    V3IncidentsSnoozeNotificationsSnoozeIncidentResponse,
    V3IncidentsSnoozeNotificationsSnoozeIncidentResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SnoozeNotificationsSnoozeIncidentNotificationsRequestTypedDict(TypedDict):
    incident_id: str
    v3_incidents_snooze_notifications_snooze_incident_request: (
        V3IncidentsSnoozeNotificationsSnoozeIncidentRequestTypedDict
    )


class SnoozeNotificationsSnoozeIncidentNotificationsRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_incidents_snooze_notifications_snooze_incident_request: Annotated[
        V3IncidentsSnoozeNotificationsSnoozeIncidentRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SnoozeNotificationsSnoozeIncidentNotificationsResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsSnoozeNotificationsSnoozeIncidentResponseTypedDict


class SnoozeNotificationsSnoozeIncidentNotificationsResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsSnoozeNotificationsSnoozeIncidentResponse
