"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict(TypedDict):
    id: int
    title: str
    page_id: int
    note: str
    start_time: datetime
    end_time: datetime
    components: NotRequired[List[int]]


class V4StatusPagesMaintenancesCreateMaintenanceResponse(BaseModel):
    id: int

    title: str

    page_id: Annotated[int, pydantic.Field(alias="pageID")]

    note: str

    start_time: Annotated[datetime, pydantic.Field(alias="startTime")]

    end_time: Annotated[datetime, pydantic.Field(alias="endTime")]

    components: Optional[List[int]] = None
