"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3GlobalEventRulesEntityOwnerType = Literal[
    "team",
    "user",
    "squad",
]


class V3GlobalEventRulesEntityOwnerTypedDict(TypedDict):
    id: str
    type: V3GlobalEventRulesEntityOwnerType


class V3GlobalEventRulesEntityOwner(BaseModel):
    id: str

    type: V3GlobalEventRulesEntityOwnerType
