"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_escalationpolicies_escalationpolicyresponse import (
    V3EscalationPoliciesEscalationPolicyResponse,
    V3EscalationPoliciesEscalationPolicyResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class EscalationPoliciesGetEscalationPolicyByIDRequestTypedDict(TypedDict):
    escalation_policy_id: str
    r"""(Required) escalation policy ID"""


class EscalationPoliciesGetEscalationPolicyByIDRequest(BaseModel):
    escalation_policy_id: Annotated[
        str,
        pydantic.Field(alias="escalationPolicyID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""(Required) escalation policy ID"""


class EscalationPoliciesGetEscalationPolicyByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3EscalationPoliciesEscalationPolicyResponseTypedDict
    r"""Represents an Escalation Policy in the system."""


class EscalationPoliciesGetEscalationPolicyByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3EscalationPoliciesEscalationPolicyResponse
    r"""Represents an Escalation Policy in the system."""
