"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3WorkflowsUpdateActionsOrderRequestTypedDict(TypedDict):
    action_order: NotRequired[List[int]]


class V3WorkflowsUpdateActionsOrderRequest(BaseModel):
    action_order: Optional[List[int]] = None
