"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_additionalresponders_additionalresponder import (
    V3IncidentsAdditionalRespondersAdditionalResponder,
    V3IncidentsAdditionalRespondersAdditionalResponderTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3IncidentsAdditionalRespondersAdditionalResponderResponseTypedDict(TypedDict):
    additional_responders: List[
        V3IncidentsAdditionalRespondersAdditionalResponderTypedDict
    ]


class V3IncidentsAdditionalRespondersAdditionalResponderResponse(BaseModel):
    additional_responders: List[V3IncidentsAdditionalRespondersAdditionalResponder]
