"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V4ChangeTimezoneResponseTypedDict(TypedDict):
    time_zone: str


class V4ChangeTimezoneResponse(BaseModel):
    time_zone: Annotated[str, pydantic.Field(alias="timeZone")]
