"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_componentgroups_component import (
    V4StatusPagesComponentGroupsComponent,
    V4StatusPagesComponentGroupsComponentTypedDict,
)
from .v4_statuspages_componentgroups_componentstatus import (
    V4StatusPagesComponentGroupsComponentStatus,
    V4StatusPagesComponentGroupsComponentStatusTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesComponentGroupsComponentGroupResponseTypedDict(TypedDict):
    id: int
    type: str
    name: str
    allow_subscription: bool
    description: NotRequired[str]
    status: NotRequired[V4StatusPagesComponentGroupsComponentStatusTypedDict]
    under_maintenance: NotRequired[bool]
    status_maintenance: NotRequired[
        V4StatusPagesComponentGroupsComponentStatusTypedDict
    ]
    components: NotRequired[List[V4StatusPagesComponentGroupsComponentTypedDict]]
    is_hidden: NotRequired[bool]


class V4StatusPagesComponentGroupsComponentGroupResponse(BaseModel):
    id: int

    type: str

    name: str

    allow_subscription: Annotated[bool, pydantic.Field(alias="allowSubscription")]

    description: Optional[str] = None

    status: Optional[V4StatusPagesComponentGroupsComponentStatus] = None

    under_maintenance: Annotated[
        Optional[bool], pydantic.Field(alias="underMaintenance")
    ] = None

    status_maintenance: Annotated[
        Optional[V4StatusPagesComponentGroupsComponentStatus],
        pydantic.Field(alias="statusMaintenance"),
    ] = None

    components: Optional[List[V4StatusPagesComponentGroupsComponent]] = None

    is_hidden: Annotated[Optional[bool], pydantic.Field(alias="isHidden")] = None
