"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3AuditLogsExportAuditLogsResponseDataTypedDict(TypedDict):
    id: str
    message: str


class V3AuditLogsExportAuditLogsResponseData(BaseModel):
    id: str

    message: str


class V3AuditLogsExportAuditLogsResponseTypedDict(TypedDict):
    r"""Response model for exporting audit logs"""

    data: V3AuditLogsExportAuditLogsResponseDataTypedDict


class V3AuditLogsExportAuditLogsResponse(BaseModel):
    r"""Response model for exporting audit logs"""

    data: V3AuditLogsExportAuditLogsResponseData
