"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_incidentactions_webhookactionresponse import (
    V3IncidentsIncidentActionsWebhookActionResponse,
    V3IncidentsIncidentActionsWebhookActionResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class IncidentActionsTriggerAWebhookManuallyRequestTypedDict(TypedDict):
    incident_id: str
    event_webhook_id: str


class IncidentActionsTriggerAWebhookManuallyRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    event_webhook_id: Annotated[
        str,
        pydantic.Field(alias="eventWebhookID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class IncidentActionsTriggerAWebhookManuallyResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3IncidentsIncidentActionsWebhookActionResponseTypedDict
    r"""Represents the response structure for triggering a webhook manually."""


class IncidentActionsTriggerAWebhookManuallyResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3IncidentsIncidentActionsWebhookActionResponse
    r"""Represents the response structure for triggering a webhook manually."""
