"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V3IncidentsTagsAnalyticsMetricsTypedDict(TypedDict):
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""

    time: int
    user_id: str
    escalation_policy_id: str
    squad_id: str


class V3IncidentsTagsAnalyticsMetrics(BaseModel):
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""

    time: int

    user_id: Annotated[str, pydantic.Field(alias="userId")]

    escalation_policy_id: Annotated[str, pydantic.Field(alias="escalationPolicyId")]

    squad_id: Annotated[str, pydantic.Field(alias="squadId")]
