"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_apitokenresponse import (
    V3UsersAPITokenResponse,
    V3UsersAPITokenResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class UsersCreateTokenRequestTypedDict(TypedDict):
    user_id: str


class UsersCreateTokenRequest(BaseModel):
    user_id: str


class UsersCreateTokenResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3UsersAPITokenResponseTypedDict


class UsersCreateTokenResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3UsersAPITokenResponse
