"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_globalrbacabilityname import V3UsersGlobalRBACAbilityName
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3UsersUpdateUserAbilitiesRequestDataTypedDict(TypedDict):
    user_id: str
    abilities: List[V3UsersGlobalRBACAbilityName]


class V3UsersUpdateUserAbilitiesRequestData(BaseModel):
    user_id: str

    abilities: List[V3UsersGlobalRBACAbilityName]


class V3UsersUpdateUserAbilitiesRequestTypedDict(TypedDict):
    data: List[V3UsersUpdateUserAbilitiesRequestDataTypedDict]


class V3UsersUpdateUserAbilitiesRequest(BaseModel):
    data: List[V3UsersUpdateUserAbilitiesRequestData]
