"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V4ParticipantTypedDict(TypedDict):
    id: str
    type: str


class V4Participant(BaseModel):
    id: str

    type: str
