"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSqTriggerManualWebhookUpdateName = Literal["sq_trigger_manual_webhook",]


class V3WorkflowsSqTriggerManualWebhookUpdateDataTypedDict(TypedDict):
    id: NotRequired[str]


class V3WorkflowsSqTriggerManualWebhookUpdateData(BaseModel):
    id: Optional[str] = None


class V3WorkflowsSqTriggerManualWebhookUpdateTypedDict(TypedDict):
    name: V3WorkflowsSqTriggerManualWebhookUpdateName
    data: NotRequired[V3WorkflowsSqTriggerManualWebhookUpdateDataTypedDict]


class V3WorkflowsSqTriggerManualWebhookUpdate(BaseModel):
    name: V3WorkflowsSqTriggerManualWebhookUpdateName

    data: Optional[V3WorkflowsSqTriggerManualWebhookUpdateData] = None
