"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsPostmortemsPostmortemFollowUpTypedDict(TypedDict):
    r"""Represents a single follow-up task in a postmortem."""

    task: str
    is_done: bool


class V3IncidentsPostmortemsPostmortemFollowUp(BaseModel):
    r"""Represents a single follow-up task in a postmortem."""

    task: str

    is_done: bool
