"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamresponse import V3TeamsTeamResponse, V3TeamsTeamResponseTypedDict
from .v3_teams_updateteamrequest import (
    V3TeamsUpdateTeamRequest,
    V3TeamsUpdateTeamRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class TeamsUpdateTeamRequestTypedDict(TypedDict):
    team_id: str
    v3_teams_update_team_request: V3TeamsUpdateTeamRequestTypedDict


class TeamsUpdateTeamRequest(BaseModel):
    team_id: Annotated[
        str,
        pydantic.Field(alias="teamId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_teams_update_team_request: Annotated[
        V3TeamsUpdateTeamRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class TeamsUpdateTeamResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3TeamsTeamResponseTypedDict


class TeamsUpdateTeamResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3TeamsTeamResponse
