"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3UsersUpdateUserRequestRole = Literal[
    "account_owner",
    "user",
    "stakeholder",
]


class V3UsersUpdateUserRequestTypedDict(TypedDict):
    role: V3UsersUpdateUserRequestRole


class V3UsersUpdateUserRequest(BaseModel):
    role: V3UsersUpdateUserRequestRole
