"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V3AuditLogsTeamTypedDict(TypedDict):
    r"""Represents a team in audit logs"""

    id: str
    name: str
    is_deleted: bool


class V3AuditLogsTeam(BaseModel):
    r"""Represents a team in audit logs"""

    id: str

    name: str

    is_deleted: Annotated[bool, pydantic.Field(alias="isDeleted")]
