"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3WorkflowsComponentAndImpactTypedDict(TypedDict):
    component_id: int
    impact_status_id: int


class V3WorkflowsComponentAndImpact(BaseModel):
    component_id: int

    impact_status_id: int
