"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_userresponse import V3UsersUserResponse, V3UsersUserResponseTypedDict
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class UsersGetAllUsersResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3UsersUserResponseTypedDict]


class UsersGetAllUsersResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3UsersUserResponse]
