"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesJiraStatusMapTypedDict(TypedDict):
    jira_status: str
    system_status: str


class V3ServicesJiraStatusMap(BaseModel):
    jira_status: str

    system_status: str
