"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesJiraStatusTypedDict(TypedDict):
    id: str
    name: str


class V3ServicesJiraStatus(BaseModel):
    id: str

    name: str
