"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsMsTeamsMessageChannelName = Literal["msteams_message_channel",]


class V3WorkflowsMsTeamsMessageChannelDataTypedDict(TypedDict):
    channel_id: str
    message: str


class V3WorkflowsMsTeamsMessageChannelData(BaseModel):
    channel_id: str

    message: str


class V3WorkflowsMsTeamsMessageChannelTypedDict(TypedDict):
    name: V3WorkflowsMsTeamsMessageChannelName
    data: V3WorkflowsMsTeamsMessageChannelDataTypedDict


class V3WorkflowsMsTeamsMessageChannel(BaseModel):
    name: V3WorkflowsMsTeamsMessageChannelName

    data: V3WorkflowsMsTeamsMessageChannelData
