"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_notes_createnoterequest import (
    V3IncidentsNotesCreateNoteRequest,
    V3IncidentsNotesCreateNoteRequestTypedDict,
)
from .v3_incidents_notes_noteresponse import (
    V3IncidentsNotesNoteResponse,
    V3IncidentsNotesNoteResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class NotesCreateNotesRequestTypedDict(TypedDict):
    incident_id: str
    r"""Required"""
    v3_incidents_notes_create_note_request: V3IncidentsNotesCreateNoteRequestTypedDict


class NotesCreateNotesRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="IncidentId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Required"""

    v3_incidents_notes_create_note_request: Annotated[
        V3IncidentsNotesCreateNoteRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class NotesCreateNotesBodyTypedDict(TypedDict):
    r"""The body type of the operation request or response."""

    data: V3IncidentsNotesNoteResponseTypedDict


class NotesCreateNotesBody(BaseModel):
    r"""The body type of the operation request or response."""

    data: V3IncidentsNotesNoteResponse


class NotesCreateNotesResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    body: NotesCreateNotesBodyTypedDict
    r"""The body type of the operation request or response."""


class NotesCreateNotesResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    body: NotesCreateNotesBody
    r"""The body type of the operation request or response."""
