"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3GlobalEventRulesEntityOwnerUpdateType = Literal[
    "team",
    "user",
    "squad",
]


class V3GlobalEventRulesEntityOwnerUpdateTypedDict(TypedDict):
    id: NotRequired[str]
    type: NotRequired[V3GlobalEventRulesEntityOwnerUpdateType]


class V3GlobalEventRulesEntityOwnerUpdate(BaseModel):
    id: Optional[str] = None

    type: Optional[V3GlobalEventRulesEntityOwnerUpdateType] = None
