"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_extensions_webhooks_webhookfiltercondition import (
    V3ExtensionsWebhooksWebhookFilterCondition,
    V3ExtensionsWebhooksWebhookFilterConditionTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ExtensionsWebhooksWebhookFilterTypedDict(TypedDict):
    op: str
    conditions: List[V3ExtensionsWebhooksWebhookFilterConditionTypedDict]


class V3ExtensionsWebhooksWebhookFilter(BaseModel):
    op: str

    conditions: List[V3ExtensionsWebhooksWebhookFilterCondition]
