"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_scheduleresponse import V4ScheduleResponse, V4ScheduleResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class SchedulesGetScheduleByIDRequestTypedDict(TypedDict):
    schedule_id: str


class SchedulesGetScheduleByIDRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class SchedulesGetScheduleByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4ScheduleResponseTypedDict


class SchedulesGetScheduleByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4ScheduleResponse
