"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4ShiftTimeSlotTypedDict(TypedDict):
    start_hour: int
    start_min: int
    duration: int
    day_of_week: NotRequired[str]


class V4ShiftTimeSlot(BaseModel):
    start_hour: Annotated[int, pydantic.Field(alias="startHour")]

    start_min: Annotated[int, pydantic.Field(alias="startMin")]

    duration: int

    day_of_week: Annotated[Optional[str], pydantic.Field(alias="dayOfWeek")] = None
