"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsCommunicationCardsCreateSlackChannelRequestTypedDict(TypedDict):
    r"""Request body for creating a Slack channel in a communication card."""

    channel_name: str
    incident_id: str


class V3IncidentsCommunicationCardsCreateSlackChannelRequest(BaseModel):
    r"""Request body for creating a Slack channel in a communication card."""

    channel_name: str

    incident_id: str
