"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3WorkflowsEntityOwnerUpdateTypedDict(TypedDict):
    id: NotRequired[str]
    type: NotRequired[str]


class V3WorkflowsEntityOwnerUpdate(BaseModel):
    id: Optional[str] = None

    type: Optional[str] = None
