"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsPinnedMessageTypedDict(TypedDict):
    r"""Represents a pinned message in the warroom."""

    message: str
    message_sender_id: str
    time: datetime
    time_of_pinning: datetime
    message_id: str
    message_pinned_by: str
    message_sender_name: str


class V3IncidentsPinnedMessage(BaseModel):
    r"""Represents a pinned message in the warroom."""

    message: str

    message_sender_id: str

    time: datetime

    time_of_pinning: datetime

    message_id: str

    message_pinned_by: str

    message_sender_name: str
