"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_auditlogs_actor import V3AuditLogsActor, V3AuditLogsActorTypedDict
from .v3_auditlogs_team import V3AuditLogsTeam, V3AuditLogsTeamTypedDict
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3AuditLogsAuditLogResponseTypedDict(TypedDict):
    r"""Represents an audit log entry response"""

    id: int
    resource: str
    action: str
    actor: V3AuditLogsActorTypedDict
    r"""Represents an actor (user) in audit logs"""
    client: str
    timestamp: str
    team: V3AuditLogsTeamTypedDict
    r"""Represents a team in audit logs"""


class V3AuditLogsAuditLogResponse(BaseModel):
    r"""Represents an audit log entry response"""

    id: int

    resource: str

    action: str

    actor: V3AuditLogsActor
    r"""Represents an actor (user) in audit logs"""

    client: str

    timestamp: str

    team: V3AuditLogsTeam
    r"""Represents a team in audit logs"""
