"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_squadmember import V4SquadsSquadMember, V4SquadsSquadMemberTypedDict
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V4SquadsUpdateSquadRequestTypedDict(TypedDict):
    name: NotRequired[str]
    members: NotRequired[List[V4SquadsSquadMemberTypedDict]]


class V4SquadsUpdateSquadRequest(BaseModel):
    name: Optional[str] = None

    members: Optional[List[V4SquadsSquadMember]] = None
