"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsCommunicationChannelType = Literal[
    "chat_room",
    "video_conference",
    "other",
]


class V3WorkflowsCommunicationChannelTypedDict(TypedDict):
    display_text: str
    link: str
    type: V3WorkflowsCommunicationChannelType


class V3WorkflowsCommunicationChannel(BaseModel):
    display_text: str

    link: str

    type: V3WorkflowsCommunicationChannelType
