"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


CommonV3RBACOwnerType = Literal["team",]
r"""The type of the owner."""


class CommonV3RBACOwnerTypedDict(TypedDict):
    r"""Represents the RBAC owner of an entity."""

    id: str
    r"""The ID of the owner."""
    type: CommonV3RBACOwnerType
    r"""The type of the owner."""


class CommonV3RBACOwner(BaseModel):
    r"""Represents the RBAC owner of an entity."""

    id: str
    r"""The ID of the owner."""

    type: CommonV3RBACOwnerType
    r"""The type of the owner."""
