"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from pydantic import model_serializer
from squadcast_sdk.types import BaseModel, Nullable, UNSET_SENTINEL
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsIncidentEventResponseTagsTypedDict(TypedDict):
    pass


class V3IncidentsIncidentEventResponseTags(BaseModel):
    pass


class DeduplicationReasonTypedDict(TypedDict):
    matched_event_id: str
    evaluated_expression: str
    time_window: int


class DeduplicationReason(BaseModel):
    matched_event_id: str

    evaluated_expression: str

    time_window: int


class PayloadTypedDict(TypedDict):
    pass


class Payload(BaseModel):
    pass


class V3IncidentsIncidentEventResponseTypedDict(TypedDict):
    r"""Represents an incident event."""

    incident_id: str
    alert_source_id: str
    message: str
    description: str
    time_of_creation: datetime
    tags: Nullable[V3IncidentsIncidentEventResponseTagsTypedDict]
    payload: PayloadTypedDict
    deduplication_reason: NotRequired[DeduplicationReasonTypedDict]


class V3IncidentsIncidentEventResponse(BaseModel):
    r"""Represents an incident event."""

    incident_id: str

    alert_source_id: str

    message: str

    description: str

    time_of_creation: datetime

    tags: Nullable[V3IncidentsIncidentEventResponseTags]

    payload: Payload

    deduplication_reason: Optional[DeduplicationReason] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["deduplication_reason"]
        nullable_fields = ["tags"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
