"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4StatusPagesIssuesCreateIssueResponseTypedDict(TypedDict):
    id: int
    component_i_ds: List[int]
    title: str


class V4StatusPagesIssuesCreateIssueResponse(BaseModel):
    id: int

    component_i_ds: Annotated[List[int], pydantic.Field(alias="componentIDs")]

    title: str
