"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class OverlayDeleteDedupKeyOverlayRequestTypedDict(TypedDict):
    service_id: str
    alert_source: str


class OverlayDeleteDedupKeyOverlayRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    alert_source: Annotated[
        str,
        pydantic.Field(alias="alertSource"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class OverlayDeleteDedupKeyOverlayResponseBodyTypedDict(TypedDict):
    r"""There is no content to send for this request, but the headers may be useful."""


class OverlayDeleteDedupKeyOverlayResponseBody(BaseModel):
    r"""There is no content to send for this request, but the headers may be useful."""
