"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsTagsDedupDataTypedDict(TypedDict):
    key: NotRequired[str]
    hash: NotRequired[str]


class V3IncidentsTagsDedupData(BaseModel):
    key: Optional[str] = None

    hash: Optional[str] = None
