"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing_extensions import Annotated, TypedDict


class SquadsRemoveSquadMemberRequestTypedDict(TypedDict):
    squad_id: str
    member_id: str
    replace_with: str


class SquadsRemoveSquadMemberRequest(BaseModel):
    squad_id: Annotated[
        str,
        pydantic.Field(alias="squadID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    member_id: Annotated[
        str,
        pydantic.Field(alias="memberID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    replace_with: Annotated[
        str,
        pydantic.Field(alias="replaceWith"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ]
