"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_workflows_communicationchannel import (
    V3WorkflowsCommunicationChannel,
    V3WorkflowsCommunicationChannelTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List, Literal
from typing_extensions import TypedDict


V3WorkflowsSqAddCommunicationChannelName = Literal["sq_add_communication_channel",]


class V3WorkflowsSqAddCommunicationChannelDataTypedDict(TypedDict):
    channels: List[V3WorkflowsCommunicationChannelTypedDict]


class V3WorkflowsSqAddCommunicationChannelData(BaseModel):
    channels: List[V3WorkflowsCommunicationChannel]


class V3WorkflowsSqAddCommunicationChannelTypedDict(TypedDict):
    name: V3WorkflowsSqAddCommunicationChannelName
    data: V3WorkflowsSqAddCommunicationChannelDataTypedDict


class V3WorkflowsSqAddCommunicationChannel(BaseModel):
    name: V3WorkflowsSqAddCommunicationChannelName

    data: V3WorkflowsSqAddCommunicationChannelData
