"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3WebformsRecaptchaSecretsTypedDict(TypedDict):
    r"""reCAPTCHA credentials to be validated"""

    site_key: str
    r"""reCAPTCHA site key"""
    secret: str
    r"""reCAPTCHA secret key"""


class V3WebformsRecaptchaSecrets(BaseModel):
    r"""reCAPTCHA credentials to be validated"""

    site_key: str
    r"""reCAPTCHA site key"""

    secret: str
    r"""reCAPTCHA secret key"""
