"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_maintenances_createmaintenancerequest import (
    V4StatusPagesMaintenancesCreateMaintenanceRequest,
    V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict,
)
from .v4_statuspages_maintenances_createmaintenanceresponse import (
    V4StatusPagesMaintenancesCreateMaintenanceResponse,
    V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class MaintenancesCreateMaintenanceRequestTypedDict(TypedDict):
    statuspage_id: str
    v4_status_pages_maintenances_create_maintenance_request: (
        V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict
    )


class MaintenancesCreateMaintenanceRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_status_pages_maintenances_create_maintenance_request: Annotated[
        V4StatusPagesMaintenancesCreateMaintenanceRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class MaintenancesCreateMaintenanceResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict


class MaintenancesCreateMaintenanceResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesMaintenancesCreateMaintenanceResponse
