"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3EscalationPoliciesIncidentReminderRuleTypedDict(TypedDict):
    r"""Represents a rule for sending incident reminders."""

    via: List[str]
    r"""The notification methods to use for the reminder."""
    time_interval: int
    r"""The interval in minutes at which to send the reminder."""
    till: int
    r"""The duration in minutes for which to send reminders."""


class V3EscalationPoliciesIncidentReminderRule(BaseModel):
    r"""Represents a rule for sending incident reminders."""

    via: List[str]
    r"""The notification methods to use for the reminder."""

    time_interval: int
    r"""The interval in minutes at which to send the reminder."""

    till: int
    r"""The duration in minutes for which to send reminders."""
