"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3UsersAddUserRequestRole = Literal[
    "account_owner",
    "user",
    "stakeholder",
]


class V3UsersAddUserRequestTypedDict(TypedDict):
    email: str
    role: V3UsersAddUserRequestRole
    first_name: str
    last_name: str


class V3UsersAddUserRequest(BaseModel):
    email: str

    role: V3UsersAddUserRequestRole

    first_name: str

    last_name: str
