"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesComponentsCreateComponentRequestTypedDict(TypedDict):
    name: str
    description: NotRequired[str]
    allow_subscription: NotRequired[bool]
    group_id: NotRequired[str]
    service_id: NotRequired[str]


class V4StatusPagesComponentsCreateComponentRequest(BaseModel):
    name: str

    description: Optional[str] = None

    allow_subscription: Annotated[
        Optional[bool], pydantic.Field(alias="allowSubscription")
    ] = None

    group_id: Annotated[Optional[str], pydantic.Field(alias="groupID")] = None

    service_id: Annotated[Optional[str], pydantic.Field(alias="serviceID")] = None
