"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_maintenancemode_createorupdatemaintenancemoderequest import (
    V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest,
    V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class MaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict(TypedDict):
    service_id: str
    v3_services_maintenance_mode_create_or_update_maintenance_mode_request: (
        V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict
    )


class MaintenanceModeCreateOrUpdateMaintenanceModeRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_maintenance_mode_create_or_update_maintenance_mode_request: Annotated[
        V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class MaintenanceModeCreateOrUpdateMaintenanceModeResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: str


class MaintenanceModeCreateOrUpdateMaintenanceModeResponse(BaseModel):
    r"""The request has succeeded."""

    data: str
