"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesSuppressionRulesBasicExpressionTypedDict(TypedDict):
    lhs: str
    op: str
    rhs: str


class V3ServicesSuppressionRulesBasicExpression(BaseModel):
    lhs: str

    op: str

    rhs: str
