"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsTagsUpdateTagRequestTagsTypedDict(TypedDict):
    pass


class V3IncidentsTagsUpdateTagRequestTags(BaseModel):
    pass


class V3IncidentsTagsUpdateTagRequestTypedDict(TypedDict):
    tags: V3IncidentsTagsUpdateTagRequestTagsTypedDict


class V3IncidentsTagsUpdateTagRequest(BaseModel):
    tags: V3IncidentsTagsUpdateTagRequestTags
