"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


V3UsersGlobalRBACAbilityName = Literal[
    "manage-api-tokens",
    "manage-billing",
    "manage-extensions",
    "manage-teams",
    "manage-users",
    "manage-webhooks",
    "manage-organization-analytics",
    "manage-postmortem-templates",
    "manage-audit-logs",
    "manage-feature-settings",
]
r"""Represents the name of a global RBAC ability."""
