"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_scheduleresponse import V4ScheduleResponse, V4ScheduleResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SchedulesCloneScheduleRequestBodyTypedDict(TypedDict):
    pass


class SchedulesCloneScheduleRequestBody(BaseModel):
    pass


class SchedulesCloneScheduleRequestTypedDict(TypedDict):
    schedule_id: str
    request_body: SchedulesCloneScheduleRequestBodyTypedDict


class SchedulesCloneScheduleRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    request_body: Annotated[
        SchedulesCloneScheduleRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SchedulesCloneScheduleResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4ScheduleResponseTypedDict


class SchedulesCloneScheduleResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V4ScheduleResponse
