"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsTagsAssignToTypedDict(TypedDict):
    r"""Represents the assignment target for delayed notifications."""

    id: str
    type: NotRequired[str]


class V3IncidentsTagsAssignTo(BaseModel):
    r"""Represents the assignment target for delayed notifications."""

    id: str

    type: Optional[str] = None
