"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_userresponse import V3UsersUserResponse, V3UsersUserResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class UsersGetUserByIDRequestTypedDict(TypedDict):
    user_id: str
    r"""(Required) user id"""


class UsersGetUserByIDRequest(BaseModel):
    user_id: Annotated[
        str,
        pydantic.Field(alias="userID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""(Required) user id"""


class UsersGetUserByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3UsersUserResponseTypedDict


class UsersGetUserByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3UsersUserResponse
