"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3GlobalEventRulesReorderRuleRequestTypedDict(TypedDict):
    shift_to: NotRequired[str]
    shift_index_by: NotRequired[int]


class V3GlobalEventRulesReorderRuleRequest(BaseModel):
    shift_to: Optional[str] = None

    shift_index_by: Optional[int] = None
