"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_ruleaction import (
    V3GlobalEventRulesRuleAction,
    V3GlobalEventRulesRuleActionTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3GlobalEventRulesCreateOrUpdateRuleRequestTypedDict(TypedDict):
    description: str
    expression: str
    action: V3GlobalEventRulesRuleActionTypedDict


class V3GlobalEventRulesCreateOrUpdateRuleRequest(BaseModel):
    description: str

    expression: str

    action: V3GlobalEventRulesRuleAction
