"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3IncidentsTagsAppendTagRequestTagsTypedDict(TypedDict):
    pass


class V3IncidentsTagsAppendTagRequestTags(BaseModel):
    pass


class V3IncidentsTagsAppendTagRequestTypedDict(TypedDict):
    tags: NotRequired[V3IncidentsTagsAppendTagRequestTagsTypedDict]


class V3IncidentsTagsAppendTagRequest(BaseModel):
    tags: Optional[V3IncidentsTagsAppendTagRequestTags] = None
