"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesMaintenanceModeMaintenanceModeResponseTypedDict(TypedDict):
    service_id: str
    maintenance_from: datetime
    maintenance_till: datetime
    repetition_daily: bool
    repetition_weekly: bool
    repetition_two_weekly: bool
    repetition_three_weekly: bool
    repetition_monthly: bool
    deleted: bool
    repeat_till: datetime


class V3ServicesMaintenanceModeMaintenanceModeResponse(BaseModel):
    service_id: str

    maintenance_from: datetime

    maintenance_till: datetime

    repetition_daily: bool

    repetition_weekly: bool

    repetition_two_weekly: bool

    repetition_three_weekly: bool

    repetition_monthly: bool

    deleted: bool

    repeat_till: datetime
