"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaloncallreminderrules_rule import (
    V3GlobalOncallReminderRulesRule,
    V3GlobalOncallReminderRulesRuleTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict(TypedDict):
    id: int
    is_enabled: bool
    owner_id: str
    rules: List[V3GlobalOncallReminderRulesRuleTypedDict]


class V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse(BaseModel):
    id: int

    is_enabled: bool

    owner_id: str

    rules: List[V3GlobalOncallReminderRulesRule]
