"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_overrideresponse import V4OverrideResponse, V4OverrideResponseTypedDict
from .v4_updatescheduleoverriderequest import (
    V4UpdateScheduleOverrideRequest,
    V4UpdateScheduleOverrideRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverridesUpdateScheduleOverrideRequestTypedDict(TypedDict):
    schedule_id: str
    override_id: str
    v4_update_schedule_override_request: V4UpdateScheduleOverrideRequestTypedDict


class OverridesUpdateScheduleOverrideRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    override_id: Annotated[
        str,
        pydantic.Field(alias="overrideID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_update_schedule_override_request: Annotated[
        V4UpdateScheduleOverrideRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverridesUpdateScheduleOverrideResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4OverrideResponseTypedDict


class OverridesUpdateScheduleOverrideResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4OverrideResponse
