"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_tags_analyticsmetrics import (
    V3IncidentsTagsAnalyticsMetrics,
    V3IncidentsTagsAnalyticsMetricsTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsTagsAnalyticsTypedDict(TypedDict):
    r"""Incident analytics data."""

    tta: V3IncidentsTagsAnalyticsMetricsTypedDict
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""
    ttr: V3IncidentsTagsAnalyticsMetricsTypedDict
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""


class V3IncidentsTagsAnalytics(BaseModel):
    r"""Incident analytics data."""

    tta: V3IncidentsTagsAnalyticsMetrics
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""

    ttr: V3IncidentsTagsAnalyticsMetrics
    r"""Analytics metrics for TTA (Time to Acknowledge) and TTR (Time to Resolve)."""
