"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSqMakeHTTPCallName = Literal["sq_make_http_call",]


V3WorkflowsSqMakeHTTPCallMethod = Literal[
    "GET",
    "POST",
    "PUT",
    "PATCH",
    "DELETE",
]


class V3WorkflowsSqMakeHTTPCallHeaderTypedDict(TypedDict):
    key: str
    value: str


class V3WorkflowsSqMakeHTTPCallHeader(BaseModel):
    key: str

    value: str


class V3WorkflowsSqMakeHTTPCallDataTypedDict(TypedDict):
    method: V3WorkflowsSqMakeHTTPCallMethod
    url: str
    headers: NotRequired[List[V3WorkflowsSqMakeHTTPCallHeaderTypedDict]]
    body: NotRequired[str]


class V3WorkflowsSqMakeHTTPCallData(BaseModel):
    method: V3WorkflowsSqMakeHTTPCallMethod

    url: str

    headers: Optional[List[V3WorkflowsSqMakeHTTPCallHeader]] = None

    body: Optional[str] = None


class V3WorkflowsSqMakeHTTPCallTypedDict(TypedDict):
    name: V3WorkflowsSqMakeHTTPCallName
    data: V3WorkflowsSqMakeHTTPCallDataTypedDict


class V3WorkflowsSqMakeHTTPCall(BaseModel):
    name: V3WorkflowsSqMakeHTTPCallName

    data: V3WorkflowsSqMakeHTTPCallData
