"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_updateissuerequest import (
    V4StatusPagesIssuesUpdateIssueRequest,
    V4StatusPagesIssuesUpdateIssueRequestTypedDict,
)
from .v4_statuspages_issues_updateissueresponse import (
    V4StatusPagesIssuesUpdateIssueResponse,
    V4StatusPagesIssuesUpdateIssueResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class IssuesUpdateIssueRequestTypedDict(TypedDict):
    statuspage_id: str
    issue_id: str
    v4_status_pages_issues_update_issue_request: (
        V4StatusPagesIssuesUpdateIssueRequestTypedDict
    )


class IssuesUpdateIssueRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    issue_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    v4_status_pages_issues_update_issue_request: Annotated[
        V4StatusPagesIssuesUpdateIssueRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class IssuesUpdateIssueResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesUpdateIssueResponseTypedDict


class IssuesUpdateIssueResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesUpdateIssueResponse
