"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class V3ExtensionsWebhooksWebhookFilterConditionTypedDict(TypedDict):
    op: NotRequired[str]
    lhs: NotRequired[str]
    rhs: NotRequired[str]


class V3ExtensionsWebhooksWebhookFilterCondition(BaseModel):
    op: Optional[str] = None

    lhs: Optional[str] = None

    rhs: Optional[str] = None
