"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List, Literal, Optional
from typing_extensions import NotRequired, TypedDict


V3WorkflowsSqSendEmailUpdateName = Literal["sq_send_email",]


class V3WorkflowsSqSendEmailUpdateDataTypedDict(TypedDict):
    to: NotRequired[List[str]]
    subject: NotRequired[str]
    body: NotRequired[str]


class V3WorkflowsSqSendEmailUpdateData(BaseModel):
    to: Optional[List[str]] = None

    subject: Optional[str] = None

    body: Optional[str] = None


class V3WorkflowsSqSendEmailUpdateTypedDict(TypedDict):
    name: V3WorkflowsSqSendEmailUpdateName
    data: NotRequired[V3WorkflowsSqSendEmailUpdateDataTypedDict]


class V3WorkflowsSqSendEmailUpdate(BaseModel):
    name: V3WorkflowsSqSendEmailUpdateName

    data: Optional[V3WorkflowsSqSendEmailUpdateData] = None
