"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3UsersContactTypedDict(TypedDict):
    dial_code: str
    phone_number: str


class V3UsersContact(BaseModel):
    dial_code: str

    phone_number: str
