"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3WebformsWFInputFieldTypedDict(TypedDict):
    r"""Input field definition for a webform"""

    label: str
    r"""Field label"""
    options: List[str]
    r"""Selectable options for this field"""


class V3WebformsWFInputField(BaseModel):
    r"""Input field definition for a webform"""

    label: str
    r"""Field label"""

    options: List[str]
    r"""Selectable options for this field"""
