"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_totalsubscriberscount import (
    V4StatusPagesTotalSubscribersCount,
    V4StatusPagesTotalSubscribersCountTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4StatusPagesListSubscribersResponseMetaTypedDict(TypedDict):
    maximum_subscribers_limit: int
    last_week_subscribers_count: int
    total_subscribers_count: NotRequired[V4StatusPagesTotalSubscribersCountTypedDict]


class V4StatusPagesListSubscribersResponseMeta(BaseModel):
    maximum_subscribers_limit: Annotated[
        int, pydantic.Field(alias="maximumSubscribersLimit")
    ]

    last_week_subscribers_count: Annotated[
        int, pydantic.Field(alias="lastWeekSubscribersCount")
    ]

    total_subscribers_count: Annotated[
        Optional[V4StatusPagesTotalSubscribersCount],
        pydantic.Field(alias="totalSubscribersCount"),
    ] = None
