"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_createissuerequest import (
    V4StatusPagesIssuesCreateIssueRequest,
    V4StatusPagesIssuesCreateIssueRequestTypedDict,
)
from .v4_statuspages_issues_createissueresponse import (
    V4StatusPagesIssuesCreateIssueResponse,
    V4StatusPagesIssuesCreateIssueResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class IssuesCreateIssueRequestTypedDict(TypedDict):
    statuspage_id: str
    v4_status_pages_issues_create_issue_request: (
        V4StatusPagesIssuesCreateIssueRequestTypedDict
    )


class IssuesCreateIssueRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_status_pages_issues_create_issue_request: Annotated[
        V4StatusPagesIssuesCreateIssueRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class IssuesCreateIssueResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesCreateIssueResponseTypedDict


class IssuesCreateIssueResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesCreateIssueResponse
