"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_statuspage import (
    V4StatusPagesStatusPage,
    V4StatusPagesStatusPageTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4StatusPagesListStatusPagesResponseMetaTypedDict(TypedDict):
    total_count: int
    org_total_count: int


class V4StatusPagesListStatusPagesResponseMeta(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]

    org_total_count: Annotated[int, pydantic.Field(alias="orgTotalCount")]


class V4StatusPagesListStatusPagesResponseTypedDict(TypedDict):
    data: List[V4StatusPagesStatusPageTypedDict]
    meta: V4StatusPagesListStatusPagesResponseMetaTypedDict


class V4StatusPagesListStatusPagesResponse(BaseModel):
    data: List[V4StatusPagesStatusPage]

    meta: V4StatusPagesListStatusPagesResponseMeta
