"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_snoozenotifications_reassignto import (
    V3IncidentsSnoozeNotificationsReassignTo,
    V3IncidentsSnoozeNotificationsReassignToTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequestTypedDict(TypedDict):
    reassign_to: V3IncidentsSnoozeNotificationsReassignToTypedDict


class V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequest(BaseModel):
    reassign_to: V3IncidentsSnoozeNotificationsReassignTo
