"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_overlay_customcontentoverlayresponse import (
    V3ServicesOverlayCustomContentOverlayResponse,
    V3ServicesOverlayCustomContentOverlayResponseTypedDict,
)
from .v3_services_overlay_updatecustomcontenttemplateoverlayrequest import (
    V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest,
    V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class OverlayCreateOrUpdateNotificationTemplateOverlayRequestTypedDict(TypedDict):
    service_id: str
    alert_source: str
    v3_services_overlay_update_custom_content_template_overlay_request: (
        V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict
    )


class OverlayCreateOrUpdateNotificationTemplateOverlayRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    alert_source: Annotated[
        str,
        pydantic.Field(alias="alertSource"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_services_overlay_update_custom_content_template_overlay_request: Annotated[
        V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class OverlayCreateOrUpdateNotificationTemplateOverlayResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ServicesOverlayCustomContentOverlayResponseTypedDict


class OverlayCreateOrUpdateNotificationTemplateOverlayResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ServicesOverlayCustomContentOverlayResponse
