"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_auditlogs_auditlogsexporthistoryresponse import (
    V3AuditLogsAuditLogsExportHistoryResponse,
    V3AuditLogsAuditLogsExportHistoryResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V3AuditLogsListAuditLogsExportHistoryResponseMetadataTypedDict(TypedDict):
    total_count: int


class V3AuditLogsListAuditLogsExportHistoryResponseMetadata(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]


class V3AuditLogsListAuditLogsExportHistoryResponseTypedDict(TypedDict):
    r"""Response model for listing audit logs export history"""

    data: List[V3AuditLogsAuditLogsExportHistoryResponseTypedDict]
    metadata: V3AuditLogsListAuditLogsExportHistoryResponseMetadataTypedDict


class V3AuditLogsListAuditLogsExportHistoryResponse(BaseModel):
    r"""Response model for listing audit logs export history"""

    data: List[V3AuditLogsAuditLogsExportHistoryResponse]

    metadata: V3AuditLogsListAuditLogsExportHistoryResponseMetadata
