"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V4ICalLinkResponseTypedDict(TypedDict):
    i_cal_link: NotRequired[str]
    i_cal_link_for_my_on_calls: NotRequired[str]


class V4ICalLinkResponse(BaseModel):
    i_cal_link: Annotated[Optional[str], pydantic.Field(alias="iCalLink")] = None

    i_cal_link_for_my_on_calls: Annotated[
        Optional[str], pydantic.Field(alias="iCalLinkForMyOnCalls")
    ] = None
