"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_globaleventrules_orderingresponse import (
    V3GlobalEventRulesOrderingResponse,
    V3GlobalEventRulesOrderingResponseTypedDict,
)
from .v3_globaleventrules_reorderrulerequest import (
    V3GlobalEventRulesReorderRuleRequest,
    V3GlobalEventRulesReorderRuleRequestTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class GlobalEventRulesReorderRulesetByIndexRequestTypedDict(TypedDict):
    ger_id: int
    alert_source_version: str
    alert_source_shortname: str
    rule_id: str
    v3_global_event_rules_reorder_rule_request: (
        V3GlobalEventRulesReorderRuleRequestTypedDict
    )


class GlobalEventRulesReorderRulesetByIndexRequest(BaseModel):
    ger_id: Annotated[
        int, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_version: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    alert_source_shortname: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    rule_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    v3_global_event_rules_reorder_rule_request: Annotated[
        V3GlobalEventRulesReorderRuleRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class GlobalEventRulesReorderRulesetByIndexResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesOrderingResponseTypedDict


class GlobalEventRulesReorderRulesetByIndexResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3GlobalEventRulesOrderingResponse
