"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_serviceresponse import (
    V3ServicesServiceResponse,
    V3ServicesServiceResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class ServicesGetServiceByIDRequestTypedDict(TypedDict):
    service_id: str


class ServicesGetServiceByIDRequest(BaseModel):
    service_id: Annotated[
        str,
        pydantic.Field(alias="serviceID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class ServicesGetServiceByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ServicesServiceResponseTypedDict


class ServicesGetServiceByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ServicesServiceResponse
