"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_issues_getissuebyidresponse import (
    V4StatusPagesIssuesGetIssueByIDResponse,
    V4StatusPagesIssuesGetIssueByIDResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class IssuesGetIssueByIDRequestTypedDict(TypedDict):
    statuspage_id: str
    issue_id: str


class IssuesGetIssueByIDRequest(BaseModel):
    statuspage_id: Annotated[
        str,
        pydantic.Field(alias="statuspageID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    issue_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class IssuesGetIssueByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesGetIssueByIDResponseTypedDict


class IssuesGetIssueByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesIssuesGetIssueByIDResponse
