"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_incidents_postmortems_createpostmortemrequest import (
    V3IncidentsPostmortemsCreatePostmortemRequest,
    V3IncidentsPostmortemsCreatePostmortemRequestTypedDict,
)
from .v3_incidents_postmortems_postmortemresponse import (
    V3IncidentsPostmortemsPostmortemResponse,
    V3IncidentsPostmortemsPostmortemResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class PostmortemsCreatePostmortemRequestTypedDict(TypedDict):
    incident_id: str
    v3_incidents_postmortems_create_postmortem_request: (
        V3IncidentsPostmortemsCreatePostmortemRequestTypedDict
    )


class PostmortemsCreatePostmortemRequest(BaseModel):
    incident_id: Annotated[
        str,
        pydantic.Field(alias="incidentID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v3_incidents_postmortems_create_postmortem_request: Annotated[
        V3IncidentsPostmortemsCreatePostmortemRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class PostmortemsCreatePostmortemBodyTypedDict(TypedDict):
    r"""The body type of the operation request or response."""

    data: V3IncidentsPostmortemsPostmortemResponseTypedDict


class PostmortemsCreatePostmortemBody(BaseModel):
    r"""The body type of the operation request or response."""

    data: V3IncidentsPostmortemsPostmortemResponse


class PostmortemsCreatePostmortemResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    body: PostmortemsCreatePostmortemBodyTypedDict
    r"""The body type of the operation request or response."""


class PostmortemsCreatePostmortemResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    body: PostmortemsCreatePostmortemBody
    r"""The body type of the operation request or response."""
