"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_extensions_webhooks_webhooklistitem import (
    V3ExtensionsWebhooksWebhookListItem,
    V3ExtensionsWebhooksWebhookListItemTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ExtensionsWebhooksGetAllWebhooksResponseMetaTypedDict(TypedDict):
    total_count: int


class V3ExtensionsWebhooksGetAllWebhooksResponseMeta(BaseModel):
    total_count: int


class V3ExtensionsWebhooksGetAllWebhooksResponseDataTypedDict(TypedDict):
    result: List[V3ExtensionsWebhooksWebhookListItemTypedDict]
    meta: V3ExtensionsWebhooksGetAllWebhooksResponseMetaTypedDict


class V3ExtensionsWebhooksGetAllWebhooksResponseData(BaseModel):
    result: List[V3ExtensionsWebhooksWebhookListItem]

    meta: V3ExtensionsWebhooksGetAllWebhooksResponseMeta


class V3ExtensionsWebhooksGetAllWebhooksResponseTypedDict(TypedDict):
    data: V3ExtensionsWebhooksGetAllWebhooksResponseDataTypedDict


class V3ExtensionsWebhooksGetAllWebhooksResponse(BaseModel):
    data: V3ExtensionsWebhooksGetAllWebhooksResponseData
