"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamresponse import V3TeamsTeamResponse, V3TeamsTeamResponseTypedDict
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing_extensions import Annotated, TypedDict


class TeamsGetTeamByIDRequestTypedDict(TypedDict):
    team_id: str


class TeamsGetTeamByIDRequest(BaseModel):
    team_id: Annotated[
        str,
        pydantic.Field(alias="teamId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class TeamsGetTeamByIDResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3TeamsTeamResponseTypedDict


class TeamsGetTeamByIDResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3TeamsTeamResponse
