"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_slo_slo import V3SloSlo, V3SloSloTypedDict
from squadcast_sdk.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class InsightsTypedDict(TypedDict):
    error_budget_consumption_for_past_30days: int


class Insights(BaseModel):
    error_budget_consumption_for_past_30days: int


class V3SLOSLOWithInsightsResponseTypedDict(TypedDict):
    slo: V3SloSloTypedDict
    insights: NotRequired[InsightsTypedDict]


class V3SLOSLOWithInsightsResponse(BaseModel):
    slo: V3SloSlo

    insights: Optional[Insights] = None
