"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_webforms_webformresponse import (
    V3WebformsWebformResponse,
    V3WebformsWebformResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class WebformsCreateWebformDataTypedDict(TypedDict):
    webform: V3WebformsWebformResponseTypedDict


class WebformsCreateWebformData(BaseModel):
    webform: V3WebformsWebformResponse


class WebformsCreateWebformResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: WebformsCreateWebformDataTypedDict


class WebformsCreateWebformResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: WebformsCreateWebformData
