"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


StatusTypedDict = TypeAliasType("StatusTypedDict", Union[str, int])


Status = TypeAliasType("Status", Union[str, int])


class CommonV3ErrorMetaTypedDict(TypedDict):
    r"""Represents a single response containing data of type T."""

    status: StatusTypedDict
    error_message: str


class CommonV3ErrorMeta(BaseModel):
    r"""Represents a single response containing data of type T."""

    status: Status

    error_message: str
