"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_extensions_msteams_msteamsconfigresponse import (
    V3ExtensionsMSTeamsMSTeamsConfigResponse,
    V3ExtensionsMSTeamsMSTeamsConfigResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class MSTeamsGetMsteamsConfigResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V3ExtensionsMSTeamsMSTeamsConfigResponseTypedDict
    r"""The request body for creating or updating an MS Teams extension configuration."""


class MSTeamsGetMsteamsConfigResponse(BaseModel):
    r"""The request has succeeded."""

    data: V3ExtensionsMSTeamsMSTeamsConfigResponse
    r"""The request body for creating or updating an MS Teams extension configuration."""
