"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3UsersNotificationRuleTypedDict(TypedDict):
    type: str
    time: int


class V3UsersNotificationRule(BaseModel):
    type: str

    time: int
