"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_slo_sloaction import V3SLOSLOAction, V3SLOSLOActionTypedDict
from .v3_slo_slomonitoringcheck import (
    V3SLOSLOMonitoringCheck,
    V3SLOSLOMonitoringCheckTypedDict,
)
from .v3_slo_sloownertype import V3SLOSLOOwnerType
from .v3_slo_timeintervaltype import V3SLOTimeIntervalType
from datetime import datetime
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class V3SLOCreateSLORequestTagsTypedDict(TypedDict):
    pass


class V3SLOCreateSLORequestTags(BaseModel):
    pass


class V3SLOCreateSLORequestTypedDict(TypedDict):
    name: str
    time_interval_type: V3SLOTimeIntervalType
    service_ids: List[str]
    slis: List[str]
    target_slo: float
    start_time: datetime
    end_time: datetime
    duration_in_days: int
    owner_type: str
    owner_id: str
    slo_owner_id: str
    slo_owner_type: V3SLOSLOOwnerType
    description: NotRequired[str]
    tags: NotRequired[V3SLOCreateSLORequestTagsTypedDict]
    slo_monitoring_checks: NotRequired[List[V3SLOSLOMonitoringCheckTypedDict]]
    slo_actions: NotRequired[List[V3SLOSLOActionTypedDict]]


class V3SLOCreateSLORequest(BaseModel):
    name: str

    time_interval_type: V3SLOTimeIntervalType

    service_ids: List[str]

    slis: List[str]

    target_slo: float

    start_time: datetime

    end_time: datetime

    duration_in_days: int

    owner_type: str

    owner_id: str

    slo_owner_id: str

    slo_owner_type: V3SLOSLOOwnerType

    description: Optional[str] = None

    tags: Optional[V3SLOCreateSLORequestTags] = None

    slo_monitoring_checks: Optional[List[V3SLOSLOMonitoringCheck]] = None

    slo_actions: Optional[List[V3SLOSLOAction]] = None
