"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_createstatuspageresponse import (
    V4StatusPagesCreateStatusPageResponse,
    V4StatusPagesCreateStatusPageResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class StatusPagesCreateStatusPageResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4StatusPagesCreateStatusPageResponseTypedDict


class StatusPagesCreateStatusPageResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4StatusPagesCreateStatusPageResponse
