"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_statuspages_maintenances_maintenance import (
    V4StatusPagesMaintenancesMaintenance,
    V4StatusPagesMaintenancesMaintenanceTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V4StatusPagesMaintenancesListMaintenancesResponseMetaTypedDict(TypedDict):
    total_count: int


class V4StatusPagesMaintenancesListMaintenancesResponseMeta(BaseModel):
    total_count: Annotated[int, pydantic.Field(alias="totalCount")]


class V4StatusPagesMaintenancesListMaintenancesResponseTypedDict(TypedDict):
    data: List[V4StatusPagesMaintenancesMaintenanceTypedDict]
    meta: V4StatusPagesMaintenancesListMaintenancesResponseMetaTypedDict


class V4StatusPagesMaintenancesListMaintenancesResponse(BaseModel):
    data: List[V4StatusPagesMaintenancesMaintenance]

    meta: V4StatusPagesMaintenancesListMaintenancesResponseMeta
