"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_taggingrules_tagrule import (
    V3ServicesTaggingRulesTagRule,
    V3ServicesTaggingRulesTagRuleTypedDict,
)
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict(TypedDict):
    rules: List[V3ServicesTaggingRulesTagRuleTypedDict]


class V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest(BaseModel):
    rules: List[V3ServicesTaggingRulesTagRule]
