"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3IncidentsServiceOwnerFilterTypedDict(TypedDict):
    r"""Filter criteria for service owner in an export."""

    user_i_ds: List[str]
    squad_i_ds: List[str]
    user_i_ds_and_their_squads: NotRequired[List[str]]


class V3IncidentsServiceOwnerFilter(BaseModel):
    r"""Filter criteria for service owner in an export."""

    user_i_ds: Annotated[List[str], pydantic.Field(alias="userIDs")]

    squad_i_ds: Annotated[List[str], pydantic.Field(alias="squadIDs")]

    user_i_ds_and_their_squads: Annotated[
        Optional[List[str]], pydantic.Field(alias="userIDsAndTheirSquads")
    ] = None
