"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_overrideparticipantgroup import (
    V4OverrideParticipantGroup,
    V4OverrideParticipantGroupTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing_extensions import Annotated, TypedDict


class V4CreateScheduleOverrideRequestTypedDict(TypedDict):
    start_time: str
    end_time: str
    reason: str
    overridden_participant: V4OverrideParticipantGroupTypedDict
    override_with: V4OverrideParticipantGroupTypedDict


class V4CreateScheduleOverrideRequest(BaseModel):
    start_time: Annotated[str, pydantic.Field(alias="startTime")]

    end_time: Annotated[str, pydantic.Field(alias="endTime")]

    reason: str

    overridden_participant: Annotated[
        V4OverrideParticipantGroup, pydantic.Field(alias="overriddenParticipant")
    ]

    override_with: Annotated[
        V4OverrideParticipantGroup, pydantic.Field(alias="overrideWith")
    ]
