"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_services_maintenancemode_servicemaintenance import (
    V3ServicesMaintenanceModeServiceMaintenance,
    V3ServicesMaintenanceModeServiceMaintenanceTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from typing import List
from typing_extensions import Annotated, TypedDict


class V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict(TypedDict):
    on_maintenance: bool
    service_maintenance: List[V3ServicesMaintenanceModeServiceMaintenanceTypedDict]


class V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest(BaseModel):
    on_maintenance: Annotated[bool, pydantic.Field(alias="onMaintenance")]

    service_maintenance: Annotated[
        List[V3ServicesMaintenanceModeServiceMaintenance],
        pydantic.Field(alias="serviceMaintenance"),
    ]
