"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing import Literal
from typing_extensions import TypedDict


V3WorkflowsUpdateIncidentPriorityName = Literal["sq_update_incident_priority",]


V3WorkflowsUpdateIncidentPriorityPriority = Literal[
    "P1",
    "P2",
    "P3",
    "P4",
    "P5",
    "UNSET",
]


class V3WorkflowsUpdateIncidentPriorityDataTypedDict(TypedDict):
    priority: V3WorkflowsUpdateIncidentPriorityPriority


class V3WorkflowsUpdateIncidentPriorityData(BaseModel):
    priority: V3WorkflowsUpdateIncidentPriorityPriority


class V3WorkflowsUpdateIncidentPriorityTypedDict(TypedDict):
    name: V3WorkflowsUpdateIncidentPriorityName
    data: V3WorkflowsUpdateIncidentPriorityDataTypedDict


class V3WorkflowsUpdateIncidentPriority(BaseModel):
    name: V3WorkflowsUpdateIncidentPriorityName

    data: V3WorkflowsUpdateIncidentPriorityData
