"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_changetimezoneresponse import (
    V4ChangeTimezoneResponse,
    V4ChangeTimezoneResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class SchedulesChangeTimezoneRequestBodyTypedDict(TypedDict):
    time_zone: NotRequired[str]


class SchedulesChangeTimezoneRequestBody(BaseModel):
    time_zone: Annotated[Optional[str], pydantic.Field(alias="timeZone")] = None


class SchedulesChangeTimezoneRequestTypedDict(TypedDict):
    schedule_id: str
    request_body: SchedulesChangeTimezoneRequestBodyTypedDict


class SchedulesChangeTimezoneRequest(BaseModel):
    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    request_body: Annotated[
        SchedulesChangeTimezoneRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SchedulesChangeTimezoneResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4ChangeTimezoneResponseTypedDict


class SchedulesChangeTimezoneResponse(BaseModel):
    r"""The request has succeeded."""

    data: V4ChangeTimezoneResponse
