"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_abilities import V3TeamsAbilities, V3TeamsAbilitiesTypedDict
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3TeamsCreateTeamRoleRequestTypedDict(TypedDict):
    name: str
    abilities: V3TeamsAbilitiesTypedDict


class V3TeamsCreateTeamRoleRequest(BaseModel):
    name: str

    abilities: V3TeamsAbilities
