"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ExtensionsWebhooksWebhookTriggerTypedDict(TypedDict):
    event_class: str
    event_type: str


class V3ExtensionsWebhooksWebhookTrigger(BaseModel):
    event_class: str

    event_type: str
