"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3ServicesOverlayDedupKeyOverlayTypedDict(TypedDict):
    template: str
    duration: int


class V3ServicesOverlayDedupKeyOverlay(BaseModel):
    template: str

    duration: int
