"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_squads_squadresponse import (
    V3SquadsSquadResponse,
    V3SquadsSquadResponseTypedDict,
)
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class SquadsGetSquadByTeamRequestTypedDict(TypedDict):
    owner_id: str


class SquadsGetSquadByTeamRequest(BaseModel):
    owner_id: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=True))
    ]


class SquadsGetSquadByTeamResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3SquadsSquadResponseTypedDict]


class SquadsGetSquadByTeamResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3SquadsSquadResponse]
