"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_teams_teamroleresponse import (
    V3TeamsTeamRoleResponse,
    V3TeamsTeamRoleResponseTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata
from typing import List
from typing_extensions import Annotated, TypedDict


class TeamsGetAllTeamRolesRequestTypedDict(TypedDict):
    team_id: str


class TeamsGetAllTeamRolesRequest(BaseModel):
    team_id: Annotated[
        str,
        pydantic.Field(alias="teamId"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class TeamsGetAllTeamRolesResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamRoleResponseTypedDict]


class TeamsGetAllTeamRolesResponse(BaseModel):
    r"""The request has succeeded."""

    data: List[V3TeamsTeamRoleResponse]
