"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3IncidentsSnoozeNotificationsSnoozeIncidentResponseTypedDict(TypedDict):
    incident_id: str
    is_snoozed: bool
    snooze_end_time: str


class V3IncidentsSnoozeNotificationsSnoozeIncidentResponse(BaseModel):
    incident_id: str

    is_snoozed: bool

    snooze_end_time: str
