"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class V3WebformsWFServiceTypedDict(TypedDict):
    r"""Service details for a webform"""

    service_id: str
    r"""Public identifier for the service"""
    name: str
    r"""Service name as shown in UI"""
    alias: str
    r"""Optional alias for the service"""


class V3WebformsWFService(BaseModel):
    r"""Service details for a webform"""

    service_id: str
    r"""Public identifier for the service"""

    name: str
    r"""Service name as shown in UI"""

    alias: str
    r"""Optional alias for the service"""
