"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v4_squads_squadresponse import (
    V4SquadsSquadResponse,
    V4SquadsSquadResponseTypedDict,
)
from .v4_squads_updatesquadrequest import (
    V4SquadsUpdateSquadRequest,
    V4SquadsUpdateSquadRequestTypedDict,
)
import pydantic
from squadcast_sdk.types import BaseModel
from squadcast_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class SquadsUpdateSquadV4RequestTypedDict(TypedDict):
    squad_id: str
    v4_squads_update_squad_request: V4SquadsUpdateSquadRequestTypedDict


class SquadsUpdateSquadV4Request(BaseModel):
    squad_id: Annotated[
        str,
        pydantic.Field(alias="squadID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    v4_squads_update_squad_request: Annotated[
        V4SquadsUpdateSquadRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SquadsUpdateSquadV4ResponseTypedDict(TypedDict):
    r"""The request has succeeded."""

    data: V4SquadsSquadResponseTypedDict


class SquadsUpdateSquadV4Response(BaseModel):
    r"""The request has succeeded."""

    data: V4SquadsSquadResponse
