"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .v3_users_userresponse import V3UsersUserResponse, V3UsersUserResponseTypedDict
from squadcast_sdk.types import BaseModel
from typing_extensions import TypedDict


class UsersAddUserResponseTypedDict(TypedDict):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3UsersUserResponseTypedDict


class UsersAddUserResponse(BaseModel):
    r"""The request has succeeded and a new resource has been created as a result."""

    data: V3UsersUserResponse
