"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins
import sys

if TYPE_CHECKING:
    from .additionalresponders_addadditionalrespondersop import (
        AdditionalRespondersAddAdditionalRespondersRequest,
        AdditionalRespondersAddAdditionalRespondersRequestTypedDict,
        AdditionalRespondersAddAdditionalRespondersResponse,
        AdditionalRespondersAddAdditionalRespondersResponseTypedDict,
    )
    from .additionalresponders_getadditionalrespondersop import (
        AdditionalRespondersGetAdditionalRespondersRequest,
        AdditionalRespondersGetAdditionalRespondersRequestTypedDict,
        AdditionalRespondersGetAdditionalRespondersResponse,
        AdditionalRespondersGetAdditionalRespondersResponseTypedDict,
    )
    from .additionalresponders_removeadditionalrespondersop import (
        AdditionalRespondersRemoveAdditionalRespondersRequest,
        AdditionalRespondersRemoveAdditionalRespondersRequestTypedDict,
        AdditionalRespondersRemoveAdditionalRespondersResponseBody,
        AdditionalRespondersRemoveAdditionalRespondersResponseBodyTypedDict,
    )
    from .analytics_getorganalyticsop import (
        AnalyticsGetOrgAnalyticsRequest,
        AnalyticsGetOrgAnalyticsRequestTypedDict,
        AnalyticsGetOrgAnalyticsResponse,
        AnalyticsGetOrgAnalyticsResponseTypedDict,
    )
    from .analytics_getteamanalyticsop import (
        AnalyticsGetTeamAnalyticsRequest,
        AnalyticsGetTeamAnalyticsRequestTypedDict,
        AnalyticsGetTeamAnalyticsResponse,
        AnalyticsGetTeamAnalyticsResponseTypedDict,
    )
    from .apta_markasnottransientop import (
        AptaMarkAsNotTransientRequest,
        AptaMarkAsNotTransientRequestTypedDict,
        AptaMarkAsNotTransientResponse,
        AptaMarkAsNotTransientResponseTypedDict,
    )
    from .apta_markastransientop import (
        AptaMarkAsTransientRequest,
        AptaMarkAsTransientRequestTypedDict,
        AptaMarkAsTransientResponse,
        AptaMarkAsTransientResponseTypedDict,
    )
    from .auditlogs_getauditlogbyidop import (
        AuditLogsGetAuditLogByIDRequest,
        AuditLogsGetAuditLogByIDRequestTypedDict,
    )
    from .auditlogs_getauditlogsexporthistorybyidop import (
        AuditLogsGetAuditLogsExportHistoryByIDRequest,
        AuditLogsGetAuditLogsExportHistoryByIDRequestTypedDict,
    )
    from .auditlogs_listauditlogsexporthistoryop import (
        AuditLogsListAuditLogsExportHistoryRequest,
        AuditLogsListAuditLogsExportHistoryRequestTypedDict,
        AuditLogsListAuditLogsExportHistoryResponse,
        AuditLogsListAuditLogsExportHistoryResponseTypedDict,
    )
    from .auditlogs_listauditlogsop import (
        AuditLogsListAuditLogsRequest,
        AuditLogsListAuditLogsRequestTypedDict,
        AuditLogsListAuditLogsResponse,
        AuditLogsListAuditLogsResponseTypedDict,
        Client,
    )
    from .common_v3_entityowner import CommonV3EntityOwner, CommonV3EntityOwnerTypedDict
    from .common_v3_errormeta import (
        CommonV3ErrorMeta,
        CommonV3ErrorMetaTypedDict,
        Status,
        StatusTypedDict,
    )
    from .common_v3_rbacentitypermission import (
        Abilities,
        AbilitiesTypedDict,
        CommonV3RBACEntityPermission,
        CommonV3RBACEntityPermissionTypedDict,
    )
    from .common_v3_rbacowner import (
        CommonV3RBACOwner,
        CommonV3RBACOwnerType,
        CommonV3RBACOwnerTypedDict,
    )
    from .common_v4_error import Detail, DetailTypedDict, Error, ErrorTypedDict
    from .common_v4_pageinfo import CommonV4PageInfo, CommonV4PageInfoTypedDict
    from .communicationcards_archiveslackchannelop import (
        CommunicationCardsArchiveSlackChannelResponse,
        CommunicationCardsArchiveSlackChannelResponseTypedDict,
    )
    from .communicationcards_createcommunicationcardop import (
        CommunicationCardsCreateCommunicationCardRequest,
        CommunicationCardsCreateCommunicationCardRequestTypedDict,
        CommunicationCardsCreateCommunicationCardResponse,
        CommunicationCardsCreateCommunicationCardResponseTypedDict,
    )
    from .communicationcards_createslackchannelincommunicationcardop import (
        CommunicationCardsCreateSlackChannelInCommunicationCardResponse,
        CommunicationCardsCreateSlackChannelInCommunicationCardResponseTypedDict,
    )
    from .communicationcards_deletecommunicationcardop import (
        CommunicationCardsDeleteCommunicationCardRequest,
        CommunicationCardsDeleteCommunicationCardRequestTypedDict,
        CommunicationCardsDeleteCommunicationCardResponse,
        CommunicationCardsDeleteCommunicationCardResponseTypedDict,
    )
    from .communicationcards_getallcommunicationcardop import (
        CommunicationCardsGetAllCommunicationCardRequest,
        CommunicationCardsGetAllCommunicationCardRequestTypedDict,
        CommunicationCardsGetAllCommunicationCardResponse,
        CommunicationCardsGetAllCommunicationCardResponseTypedDict,
    )
    from .communicationcards_updatecommunicationcardop import (
        CommunicationCardsUpdateCommunicationCardRequest,
        CommunicationCardsUpdateCommunicationCardRequestTypedDict,
        CommunicationCardsUpdateCommunicationCardResponse,
        CommunicationCardsUpdateCommunicationCardResponseTypedDict,
    )
    from .componentgroups_createcomponentgroupop import (
        ComponentGroupsCreateComponentGroupRequest,
        ComponentGroupsCreateComponentGroupRequestTypedDict,
        ComponentGroupsCreateComponentGroupResponse,
        ComponentGroupsCreateComponentGroupResponseTypedDict,
    )
    from .componentgroups_deletecomponentgroupbyidop import (
        ComponentGroupsDeleteComponentGroupByIDRequest,
        ComponentGroupsDeleteComponentGroupByIDRequestTypedDict,
        ComponentGroupsDeleteComponentGroupByIDResponse,
        ComponentGroupsDeleteComponentGroupByIDResponseTypedDict,
    )
    from .componentgroups_getcomponentgroupbyidop import (
        ComponentGroupsGetComponentGroupByIDRequest,
        ComponentGroupsGetComponentGroupByIDRequestTypedDict,
        ComponentGroupsGetComponentGroupByIDResponse,
        ComponentGroupsGetComponentGroupByIDResponseTypedDict,
    )
    from .componentgroups_listcomponentgroupsop import (
        ComponentGroupsListComponentGroupsRequest,
        ComponentGroupsListComponentGroupsRequestTypedDict,
        ComponentGroupsListComponentGroupsResponse,
        ComponentGroupsListComponentGroupsResponseTypedDict,
    )
    from .components_createcomponentop import (
        ComponentsCreateComponentRequest,
        ComponentsCreateComponentRequestTypedDict,
        ComponentsCreateComponentResponse,
        ComponentsCreateComponentResponseTypedDict,
    )
    from .components_deletecomponentbyidop import (
        ComponentsDeleteComponentByIDRequest,
        ComponentsDeleteComponentByIDRequestTypedDict,
        ComponentsDeleteComponentByIDResponse,
        ComponentsDeleteComponentByIDResponseTypedDict,
    )
    from .components_getcomponentbyidop import (
        ComponentsGetComponentByIDRequest,
        ComponentsGetComponentByIDRequestTypedDict,
        ComponentsGetComponentByIDResponse,
        ComponentsGetComponentByIDResponseTypedDict,
    )
    from .components_listcomponentsop import (
        ComponentsListComponentsRequest,
        ComponentsListComponentsRequestTypedDict,
        ComponentsListComponentsResponse,
        ComponentsListComponentsResponseTypedDict,
    )
    from .components_updatecomponentbyidop import (
        ComponentsUpdateComponentByIDRequest,
        ComponentsUpdateComponentByIDRequestTypedDict,
        ComponentsUpdateComponentByIDResponse,
        ComponentsUpdateComponentByIDResponseTypedDict,
    )
    from .deduplicationrules_createorupdatededuplicationrulesop import (
        DeduplicationRulesCreateOrUpdateDeduplicationRulesData,
        DeduplicationRulesCreateOrUpdateDeduplicationRulesDataTypedDict,
        DeduplicationRulesCreateOrUpdateDeduplicationRulesRequest,
        DeduplicationRulesCreateOrUpdateDeduplicationRulesRequestTypedDict,
        DeduplicationRulesCreateOrUpdateDeduplicationRulesResponse,
        DeduplicationRulesCreateOrUpdateDeduplicationRulesResponseTypedDict,
    )
    from .deduplicationrules_getdeduplicationrulesop import (
        DeduplicationRulesGetDeduplicationRulesData,
        DeduplicationRulesGetDeduplicationRulesDataTypedDict,
        DeduplicationRulesGetDeduplicationRulesRequest,
        DeduplicationRulesGetDeduplicationRulesRequestTypedDict,
        DeduplicationRulesGetDeduplicationRulesResponse,
        DeduplicationRulesGetDeduplicationRulesResponseTypedDict,
    )
    from .dependencies_createorupdatedependenciesop import (
        DependenciesCreateOrUpdateDependenciesData,
        DependenciesCreateOrUpdateDependenciesDataTypedDict,
        DependenciesCreateOrUpdateDependenciesRequest,
        DependenciesCreateOrUpdateDependenciesRequestTypedDict,
        DependenciesCreateOrUpdateDependenciesResponse,
        DependenciesCreateOrUpdateDependenciesResponseTypedDict,
    )
    from .escalationpolicies_createescalationpoliciesop import (
        EscalationPoliciesCreateEscalationPoliciesResponse,
        EscalationPoliciesCreateEscalationPoliciesResponseTypedDict,
    )
    from .escalationpolicies_getescalationpolicybyidop import (
        EscalationPoliciesGetEscalationPolicyByIDRequest,
        EscalationPoliciesGetEscalationPolicyByIDRequestTypedDict,
        EscalationPoliciesGetEscalationPolicyByIDResponse,
        EscalationPoliciesGetEscalationPolicyByIDResponseTypedDict,
    )
    from .escalationpolicies_getescalationpolicybyteamop import (
        EscalationPoliciesGetEscalationPolicyByTeamMeta,
        EscalationPoliciesGetEscalationPolicyByTeamMetaTypedDict,
        EscalationPoliciesGetEscalationPolicyByTeamRequest,
        EscalationPoliciesGetEscalationPolicyByTeamRequestTypedDict,
        EscalationPoliciesGetEscalationPolicyByTeamResponse,
        EscalationPoliciesGetEscalationPolicyByTeamResponseBody,
        EscalationPoliciesGetEscalationPolicyByTeamResponseBodyTypedDict,
        EscalationPoliciesGetEscalationPolicyByTeamResponseTypedDict,
    )
    from .escalationpolicies_removeescalationpolicyop import (
        EscalationPoliciesRemoveEscalationPolicyRequest,
        EscalationPoliciesRemoveEscalationPolicyRequestTypedDict,
        EscalationPoliciesRemoveEscalationPolicyResponseBody,
        EscalationPoliciesRemoveEscalationPolicyResponseBodyTypedDict,
    )
    from .escalationpolicies_updateescalationpolicyop import (
        EscalationPoliciesUpdateEscalationPolicyRequest,
        EscalationPoliciesUpdateEscalationPolicyRequestTypedDict,
        EscalationPoliciesUpdateEscalationPolicyResponse,
        EscalationPoliciesUpdateEscalationPolicyResponseTypedDict,
    )
    from .export_createscheduleicallinkop import (
        ExportCreateScheduleIcalLinkRequest,
        ExportCreateScheduleIcalLinkRequestBody,
        ExportCreateScheduleIcalLinkRequestBodyTypedDict,
        ExportCreateScheduleIcalLinkRequestTypedDict,
        ExportCreateScheduleIcalLinkResponse,
        ExportCreateScheduleIcalLinkResponseTypedDict,
    )
    from .export_deleteicallinkop import (
        ExportDeleteIcalLinkRequest,
        ExportDeleteIcalLinkRequestTypedDict,
        ExportDeleteIcalLinkResponseBody,
        ExportDeleteIcalLinkResponseBodyTypedDict,
    )
    from .export_getexportdetailsop import (
        ExportGetExportDetailsRequest,
        ExportGetExportDetailsRequestTypedDict,
        ExportGetExportDetailsResponse,
        ExportGetExportDetailsResponseTypedDict,
    )
    from .export_getscheduleicallinkop import (
        ExportGetScheduleIcalLinkRequest,
        ExportGetScheduleIcalLinkRequestTypedDict,
        ExportGetScheduleIcalLinkResponse,
        ExportGetScheduleIcalLinkResponseTypedDict,
    )
    from .export_refreshscheduleicallinkop import (
        ExportRefreshScheduleIcalLinkRequest,
        ExportRefreshScheduleIcalLinkRequestBody,
        ExportRefreshScheduleIcalLinkRequestBodyTypedDict,
        ExportRefreshScheduleIcalLinkRequestTypedDict,
        ExportRefreshScheduleIcalLinkResponse,
        ExportRefreshScheduleIcalLinkResponseTypedDict,
    )
    from .extensions_updateslackextensionop import (
        ExtensionsUpdateSlackExtensionRequest,
        ExtensionsUpdateSlackExtensionRequestTypedDict,
        ExtensionsUpdateSlackExtensionResponse,
        ExtensionsUpdateSlackExtensionResponseTypedDict,
    )
    from .globaleventrules_createglobaleventruleop import (
        GlobalEventRulesCreateGlobalEventRuleResponse,
        GlobalEventRulesCreateGlobalEventRuleResponseTypedDict,
    )
    from .globaleventrules_createruleop import (
        GlobalEventRulesCreateRuleRequest,
        GlobalEventRulesCreateRuleRequestTypedDict,
        GlobalEventRulesCreateRuleResponse,
        GlobalEventRulesCreateRuleResponseTypedDict,
    )
    from .globaleventrules_createrulesetop import (
        GlobalEventRulesCreateRulesetRequest,
        GlobalEventRulesCreateRulesetRequestTypedDict,
        GlobalEventRulesCreateRulesetResponse,
        GlobalEventRulesCreateRulesetResponseTypedDict,
    )
    from .globaleventrules_deletegerrulesetop import (
        GlobalEventRulesDeleteGerRulesetRequest,
        GlobalEventRulesDeleteGerRulesetRequestTypedDict,
        GlobalEventRulesDeleteGerRulesetResponseBody,
        GlobalEventRulesDeleteGerRulesetResponseBodyTypedDict,
    )
    from .globaleventrules_deleteglobaleventrulebyidop import (
        GlobalEventRulesDeleteGlobalEventRuleByIDRequest,
        GlobalEventRulesDeleteGlobalEventRuleByIDRequestTypedDict,
        GlobalEventRulesDeleteGlobalEventRuleByIDResponseBody,
        GlobalEventRulesDeleteGlobalEventRuleByIDResponseBodyTypedDict,
    )
    from .globaleventrules_deleterulebyidop import (
        GlobalEventRulesDeleteRuleByIDRequest,
        GlobalEventRulesDeleteRuleByIDRequestTypedDict,
        GlobalEventRulesDeleteRuleByIDResponseBody,
        GlobalEventRulesDeleteRuleByIDResponseBodyTypedDict,
    )
    from .globaleventrules_getglobaleventrulebyidop import (
        GlobalEventRulesGetGlobalEventRuleByIDRequest,
        GlobalEventRulesGetGlobalEventRuleByIDRequestTypedDict,
        GlobalEventRulesGetGlobalEventRuleByIDResponse,
        GlobalEventRulesGetGlobalEventRuleByIDResponseTypedDict,
    )
    from .globaleventrules_getrulebyidop import (
        GlobalEventRulesGetRuleByIDRequest,
        GlobalEventRulesGetRuleByIDRequestTypedDict,
        GlobalEventRulesGetRuleByIDResponse,
        GlobalEventRulesGetRuleByIDResponseTypedDict,
    )
    from .globaleventrules_getrulesetop import (
        GlobalEventRulesGetRulesetRequest,
        GlobalEventRulesGetRulesetRequestTypedDict,
        GlobalEventRulesGetRulesetResponse,
        GlobalEventRulesGetRulesetResponseTypedDict,
    )
    from .globaleventrules_listglobaleventrulesop import (
        GlobalEventRulesListGlobalEventRulesMeta,
        GlobalEventRulesListGlobalEventRulesMetaTypedDict,
        GlobalEventRulesListGlobalEventRulesRequest,
        GlobalEventRulesListGlobalEventRulesRequestTypedDict,
        GlobalEventRulesListGlobalEventRulesResponse,
        GlobalEventRulesListGlobalEventRulesResponseBody,
        GlobalEventRulesListGlobalEventRulesResponseBodyTypedDict,
        GlobalEventRulesListGlobalEventRulesResponseTypedDict,
    )
    from .globaleventrules_listrulesetrulesop import (
        GlobalEventRulesListRulesetRulesMeta,
        GlobalEventRulesListRulesetRulesMetaTypedDict,
        GlobalEventRulesListRulesetRulesRequest,
        GlobalEventRulesListRulesetRulesRequestTypedDict,
        GlobalEventRulesListRulesetRulesResponse,
        GlobalEventRulesListRulesetRulesResponseBody,
        GlobalEventRulesListRulesetRulesResponseBodyTypedDict,
        GlobalEventRulesListRulesetRulesResponseTypedDict,
    )
    from .globaleventrules_reorderrulesetbyindexop import (
        GlobalEventRulesReorderRulesetByIndexRequest,
        GlobalEventRulesReorderRulesetByIndexRequestTypedDict,
        GlobalEventRulesReorderRulesetByIndexResponse,
        GlobalEventRulesReorderRulesetByIndexResponseTypedDict,
    )
    from .globaleventrules_reorderrulesetop import (
        GlobalEventRulesReorderRulesetRequest,
        GlobalEventRulesReorderRulesetRequestTypedDict,
        GlobalEventRulesReorderRulesetResponse,
        GlobalEventRulesReorderRulesetResponseTypedDict,
    )
    from .globaleventrules_updateglobaleventrulebyidop import (
        GlobalEventRulesUpdateGlobalEventRuleByIDRequest,
        GlobalEventRulesUpdateGlobalEventRuleByIDRequestTypedDict,
        GlobalEventRulesUpdateGlobalEventRuleByIDResponse,
        GlobalEventRulesUpdateGlobalEventRuleByIDResponseTypedDict,
    )
    from .globaleventrules_updaterulebyidop import (
        GlobalEventRulesUpdateRuleByIDRequest,
        GlobalEventRulesUpdateRuleByIDRequestTypedDict,
        GlobalEventRulesUpdateRuleByIDResponse,
        GlobalEventRulesUpdateRuleByIDResponseTypedDict,
    )
    from .globaleventrules_updaterulesetop import (
        GlobalEventRulesUpdateRulesetRequest,
        GlobalEventRulesUpdateRulesetRequestTypedDict,
        GlobalEventRulesUpdateRulesetResponse,
        GlobalEventRulesUpdateRulesetResponseTypedDict,
    )
    from .globaloncallreminderrules_createglobaloncallreminderrulesop import (
        GlobalOncallReminderRulesCreateGlobalOncallReminderRulesResponse,
        GlobalOncallReminderRulesCreateGlobalOncallReminderRulesResponseTypedDict,
    )
    from .globaloncallreminderrules_deleteglobaloncallreminderrulesop import (
        GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequest,
        GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequestTypedDict,
        GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBody,
        GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBodyTypedDict,
    )
    from .globaloncallreminderrules_getglobaloncallreminderrulesop import (
        GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequest,
        GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequestTypedDict,
        GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponse,
        GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponseTypedDict,
    )
    from .globaloncallreminderrules_updateglobaloncallreminderrulesop import (
        GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest,
        GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict,
        GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponse,
        GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponseTypedDict,
    )
    from .incidentactions_createanincidentinservicenowop import (
        IncidentActionsCreateAnIncidentInServicenowRequest,
        IncidentActionsCreateAnIncidentInServicenowRequestTypedDict,
        IncidentActionsCreateAnIncidentInServicenowResponse,
        IncidentActionsCreateAnIncidentInServicenowResponseTypedDict,
    )
    from .incidentactions_createaticketonjiracloudop import (
        IncidentActionsCreateATicketOnJiraCloudRequest,
        IncidentActionsCreateATicketOnJiraCloudRequestTypedDict,
        IncidentActionsCreateATicketOnJiraCloudResponse,
        IncidentActionsCreateATicketOnJiraCloudResponseTypedDict,
    )
    from .incidentactions_createaticketonjiraserverop import (
        IncidentActionsCreateATicketOnJiraServerRequest,
        IncidentActionsCreateATicketOnJiraServerRequestTypedDict,
        IncidentActionsCreateATicketOnJiraServerResponse,
        IncidentActionsCreateATicketOnJiraServerResponseTypedDict,
    )
    from .incidentactions_rebuildaprojectincircleciop import (
        IncidentActionsRebuildAProjectInCircleciMeta,
        IncidentActionsRebuildAProjectInCircleciMetaTypedDict,
        IncidentActionsRebuildAProjectInCircleciRequest,
        IncidentActionsRebuildAProjectInCircleciRequestTypedDict,
        IncidentActionsRebuildAProjectInCircleciResponse,
        IncidentActionsRebuildAProjectInCircleciResponseTypedDict,
    )
    from .incidentactions_triggerawebhookmanuallyop import (
        IncidentActionsTriggerAWebhookManuallyRequest,
        IncidentActionsTriggerAWebhookManuallyRequestTypedDict,
        IncidentActionsTriggerAWebhookManuallyResponse,
        IncidentActionsTriggerAWebhookManuallyResponseTypedDict,
    )
    from .incidents_acknowledgeincidentop import (
        IncidentsAcknowledgeIncidentRequest,
        IncidentsAcknowledgeIncidentRequestTypedDict,
        IncidentsAcknowledgeIncidentResponse,
        IncidentsAcknowledgeIncidentResponseTypedDict,
    )
    from .incidents_bulkacknowledgeincidentsop import (
        IncidentsBulkAcknowledgeIncidentsResponse,
        IncidentsBulkAcknowledgeIncidentsResponseTypedDict,
    )
    from .incidents_bulkincidentspriorityupdateop import (
        IncidentsBulkIncidentsPriorityUpdateResponseBody,
        IncidentsBulkIncidentsPriorityUpdateResponseBodyTypedDict,
    )
    from .incidents_bulkresolveincidentsop import (
        IncidentsBulkResolveIncidentsResponse,
        IncidentsBulkResolveIncidentsResponseTypedDict,
    )
    from .incidents_getincidentbyidop import (
        IncidentsGetIncidentByIDRequest,
        IncidentsGetIncidentByIDRequestTypedDict,
        IncidentsGetIncidentByIDResponse,
        IncidentsGetIncidentByIDResponseTypedDict,
    )
    from .incidents_getincidenteventsop import (
        IncidentsGetIncidentEventsData,
        IncidentsGetIncidentEventsDataTypedDict,
        IncidentsGetIncidentEventsMeta,
        IncidentsGetIncidentEventsMetaTypedDict,
        IncidentsGetIncidentEventsRequest,
        IncidentsGetIncidentEventsRequestTypedDict,
        IncidentsGetIncidentEventsResponse,
        IncidentsGetIncidentEventsResponseTypedDict,
    )
    from .incidents_getincidentsstatusbyrequestidsop import (
        IncidentsGetIncidentsStatusByRequestidsMeta,
        IncidentsGetIncidentsStatusByRequestidsMetaTypedDict,
        IncidentsGetIncidentsStatusByRequestidsResponse,
        IncidentsGetIncidentsStatusByRequestidsResponseTypedDict,
        RequestsStatus,
        RequestsStatusTypedDict,
    )
    from .incidents_incidentexportasyncop import (
        IncidentsIncidentExportAsyncBody,
        IncidentsIncidentExportAsyncBodyTypedDict,
        IncidentsIncidentExportAsyncResponseBody,
        IncidentsIncidentExportAsyncResponseBodyTypedDict,
    )
    from .incidents_incidentexportop import (
        IncidentsIncidentExportRequest,
        IncidentsIncidentExportRequestTypedDict,
    )
    from .incidents_incidentpriorityupdateop import (
        IncidentsIncidentPriorityUpdateRequest,
        IncidentsIncidentPriorityUpdateRequestTypedDict,
        IncidentsIncidentPriorityUpdateResponse,
        IncidentsIncidentPriorityUpdateResponseTypedDict,
    )
    from .incidents_markincidentslofalsepositiveop import (
        IncidentsMarkIncidentSloFalsePositiveRequest,
        IncidentsMarkIncidentSloFalsePositiveRequestTypedDict,
        IncidentsMarkIncidentSloFalsePositiveResponse,
        IncidentsMarkIncidentSloFalsePositiveResponseTypedDict,
    )
    from .incidents_reassignincidentop import (
        IncidentsReassignIncidentRequest,
        IncidentsReassignIncidentRequestTypedDict,
        IncidentsReassignIncidentResponse,
        IncidentsReassignIncidentResponseTypedDict,
    )
    from .incidents_resolveincidentop import (
        IncidentsResolveIncidentRequest,
        IncidentsResolveIncidentRequestTypedDict,
        IncidentsResolveIncidentResponse,
        IncidentsResolveIncidentResponseTypedDict,
    )
    from .issues_createissueop import (
        IssuesCreateIssueRequest,
        IssuesCreateIssueRequestTypedDict,
        IssuesCreateIssueResponse,
        IssuesCreateIssueResponseTypedDict,
    )
    from .issues_deleteissuebyidop import (
        IssuesDeleteIssueByIDRequest,
        IssuesDeleteIssueByIDRequestTypedDict,
        IssuesDeleteIssueByIDResponse,
        IssuesDeleteIssueByIDResponseTypedDict,
    )
    from .issues_getissuebyidop import (
        IssuesGetIssueByIDRequest,
        IssuesGetIssueByIDRequestTypedDict,
        IssuesGetIssueByIDResponse,
        IssuesGetIssueByIDResponseTypedDict,
    )
    from .issues_listissuesop import (
        IssuesListIssuesRequest,
        IssuesListIssuesRequestTypedDict,
    )
    from .issues_liststatuspageissuestatesop import (
        IssuesListStatusPageIssueStatesRequest,
        IssuesListStatusPageIssueStatesRequestTypedDict,
        IssuesListStatusPageIssueStatesResponse,
        IssuesListStatusPageIssueStatesResponseTypedDict,
    )
    from .issues_updateissueop import (
        IssuesUpdateIssueRequest,
        IssuesUpdateIssueRequestTypedDict,
        IssuesUpdateIssueResponse,
        IssuesUpdateIssueResponseTypedDict,
    )
    from .maintenancemode_createorupdatemaintenancemodeop import (
        MaintenanceModeCreateOrUpdateMaintenanceModeRequest,
        MaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict,
        MaintenanceModeCreateOrUpdateMaintenanceModeResponse,
        MaintenanceModeCreateOrUpdateMaintenanceModeResponseTypedDict,
    )
    from .maintenancemode_getmaintenancemodeop import (
        MaintenanceModeGetMaintenanceModeRequest,
        MaintenanceModeGetMaintenanceModeRequestTypedDict,
        MaintenanceModeGetMaintenanceModeResponse,
        MaintenanceModeGetMaintenanceModeResponseTypedDict,
    )
    from .maintenances_createmaintenanceop import (
        MaintenancesCreateMaintenanceRequest,
        MaintenancesCreateMaintenanceRequestTypedDict,
        MaintenancesCreateMaintenanceResponse,
        MaintenancesCreateMaintenanceResponseTypedDict,
    )
    from .maintenances_deletemaintenancebyidop import (
        MaintenancesDeleteMaintenanceByIDRequest,
        MaintenancesDeleteMaintenanceByIDRequestTypedDict,
        MaintenancesDeleteMaintenanceByIDResponse,
        MaintenancesDeleteMaintenanceByIDResponseTypedDict,
    )
    from .maintenances_getmaintenancebyidop import (
        MaintenancesGetMaintenanceByIDRequest,
        MaintenancesGetMaintenanceByIDRequestTypedDict,
        MaintenancesGetMaintenanceByIDResponse,
        MaintenancesGetMaintenanceByIDResponseTypedDict,
    )
    from .maintenances_listmaintenancesop import (
        MaintenancesListMaintenancesRequest,
        MaintenancesListMaintenancesRequestTypedDict,
    )
    from .maintenances_updatemaintenancebyidop import (
        MaintenancesUpdateMaintenanceByIDRequest,
        MaintenancesUpdateMaintenanceByIDRequestTypedDict,
        MaintenancesUpdateMaintenanceByIDResponse,
        MaintenancesUpdateMaintenanceByIDResponseTypedDict,
    )
    from .msteams_createorupdatemsteamsconfigurationop import (
        MSTeamsCreateOrUpdateMsteamsConfigurationResponse,
        MSTeamsCreateOrUpdateMsteamsConfigurationResponseTypedDict,
    )
    from .msteams_getmsteamsconfigop import (
        MSTeamsGetMsteamsConfigResponse,
        MSTeamsGetMsteamsConfigResponseTypedDict,
    )
    from .notes_createnotesop import (
        NotesCreateNotesBody,
        NotesCreateNotesBodyTypedDict,
        NotesCreateNotesRequest,
        NotesCreateNotesRequestTypedDict,
        NotesCreateNotesResponse,
        NotesCreateNotesResponseTypedDict,
    )
    from .notes_deletenoteop import (
        NotesDeleteNoteRequest,
        NotesDeleteNoteRequestTypedDict,
        NotesDeleteNoteResponseBody,
        NotesDeleteNoteResponseBodyTypedDict,
    )
    from .notes_getallnotesop import (
        NotesGetAllNotesRequest,
        NotesGetAllNotesRequestTypedDict,
        NotesGetAllNotesResponse,
        NotesGetAllNotesResponseTypedDict,
    )
    from .notes_updatenoteop import (
        NotesUpdateNoteRequest,
        NotesUpdateNoteRequestTypedDict,
        NotesUpdateNoteResponse,
        NotesUpdateNoteResponseTypedDict,
    )
    from .overlay_createorupdatenotificationtemplateoverlayop import (
        OverlayCreateOrUpdateNotificationTemplateOverlayRequest,
        OverlayCreateOrUpdateNotificationTemplateOverlayRequestTypedDict,
        OverlayCreateOrUpdateNotificationTemplateOverlayResponse,
        OverlayCreateOrUpdateNotificationTemplateOverlayResponseTypedDict,
    )
    from .overlay_deletededupkeyoverlayop import (
        OverlayDeleteDedupKeyOverlayRequest,
        OverlayDeleteDedupKeyOverlayRequestTypedDict,
        OverlayDeleteDedupKeyOverlayResponseBody,
        OverlayDeleteDedupKeyOverlayResponseBodyTypedDict,
    )
    from .overlay_deletenotificationtemplateoverlayop import (
        OverlayDeleteNotificationTemplateOverlayRequest,
        OverlayDeleteNotificationTemplateOverlayRequestTypedDict,
        OverlayDeleteNotificationTemplateOverlayResponseBody,
        OverlayDeleteNotificationTemplateOverlayResponseBodyTypedDict,
    )
    from .overlay_getallcustomcontenttemplateoverlaybyserviceop import (
        OverlayGetAllCustomContentTemplateOverlayByServiceRequest,
        OverlayGetAllCustomContentTemplateOverlayByServiceRequestTypedDict,
        OverlayGetAllCustomContentTemplateOverlayByServiceResponse,
        OverlayGetAllCustomContentTemplateOverlayByServiceResponseTypedDict,
    )
    from .overlay_getalldedupkeyoverlaybyserviceop import (
        OverlayGetAllDedupKeyOverlayByServiceRequest,
        OverlayGetAllDedupKeyOverlayByServiceRequestTypedDict,
        OverlayGetAllDedupKeyOverlayByServiceResponse,
        OverlayGetAllDedupKeyOverlayByServiceResponseTypedDict,
    )
    from .overlay_getcustomcontenttemplateoverlayop import (
        OverlayGetCustomContentTemplateOverlayRequest,
        OverlayGetCustomContentTemplateOverlayRequestTypedDict,
        OverlayGetCustomContentTemplateOverlayResponse,
        OverlayGetCustomContentTemplateOverlayResponseTypedDict,
    )
    from .overlay_getdedupkeyoverlayforalertsourceop import (
        OverlayGetDedupKeyOverlayForAlertSourceRequest,
        OverlayGetDedupKeyOverlayForAlertSourceRequestTypedDict,
        OverlayGetDedupKeyOverlayForAlertSourceResponse,
        OverlayGetDedupKeyOverlayForAlertSourceResponseTypedDict,
    )
    from .overlay_getoptinforkeybaseddeduplicationforaserviceop import (
        OverlayGetOptinForKeyBasedDeduplicationForAServiceData,
        OverlayGetOptinForKeyBasedDeduplicationForAServiceDataTypedDict,
        OverlayGetOptinForKeyBasedDeduplicationForAServiceRequest,
        OverlayGetOptinForKeyBasedDeduplicationForAServiceRequestTypedDict,
        OverlayGetOptinForKeyBasedDeduplicationForAServiceResponse,
        OverlayGetOptinForKeyBasedDeduplicationForAServiceResponseTypedDict,
    )
    from .overlay_optinforkeybaseddeduplicationforaserviceop import (
        OverlayOptinForKeyBasedDeduplicationForAServiceRequest,
        OverlayOptinForKeyBasedDeduplicationForAServiceRequestTypedDict,
        OverlayOptinForKeyBasedDeduplicationForAServiceResponse,
        OverlayOptinForKeyBasedDeduplicationForAServiceResponseTypedDict,
    )
    from .overlay_rendercustomcontentoverlayop import (
        OverlayRenderCustomContentOverlayRequest,
        OverlayRenderCustomContentOverlayRequestTypedDict,
        OverlayRenderCustomContentOverlayResponse,
        OverlayRenderCustomContentOverlayResponseTypedDict,
    )
    from .overlay_renderdedupkeytemplateop import (
        OverlayRenderDedupKeyTemplateRequest,
        OverlayRenderDedupKeyTemplateRequestTypedDict,
        OverlayRenderDedupKeyTemplateResponse,
        OverlayRenderDedupKeyTemplateResponseTypedDict,
    )
    from .overlay_updatededupkeyoverlayop import (
        OverlayUpdateDedupKeyOverlayRequest,
        OverlayUpdateDedupKeyOverlayRequestTypedDict,
        OverlayUpdateDedupKeyOverlayResponse,
        OverlayUpdateDedupKeyOverlayResponseTypedDict,
        ResponseBody1,
        ResponseBody1TypedDict,
        ResponseBody2,
        ResponseBody2TypedDict,
    )
    from .overrides_createscheduleoverrideop import (
        OverridesCreateScheduleOverrideRequest,
        OverridesCreateScheduleOverrideRequestTypedDict,
        OverridesCreateScheduleOverrideResponse,
        OverridesCreateScheduleOverrideResponseTypedDict,
    )
    from .overrides_deletescheduleoverrideop import (
        OverridesDeleteScheduleOverrideRequest,
        OverridesDeleteScheduleOverrideRequestTypedDict,
        OverridesDeleteScheduleOverrideResponseBody,
        OverridesDeleteScheduleOverrideResponseBodyTypedDict,
    )
    from .overrides_getoverridebyidop import (
        OverridesGetOverrideByIDRequest,
        OverridesGetOverrideByIDRequestTypedDict,
        OverridesGetOverrideByIDResponse,
        OverridesGetOverrideByIDResponseTypedDict,
    )
    from .overrides_listoverridesop import (
        OverridesListOverridesRequest,
        OverridesListOverridesRequestTypedDict,
        OverridesListOverridesResponse,
        OverridesListOverridesResponseTypedDict,
    )
    from .overrides_updatescheduleoverrideop import (
        OverridesUpdateScheduleOverrideRequest,
        OverridesUpdateScheduleOverrideRequestTypedDict,
        OverridesUpdateScheduleOverrideResponse,
        OverridesUpdateScheduleOverrideResponseTypedDict,
    )
    from .postmortems_createpostmortemop import (
        PostmortemsCreatePostmortemBody,
        PostmortemsCreatePostmortemBodyTypedDict,
        PostmortemsCreatePostmortemRequest,
        PostmortemsCreatePostmortemRequestTypedDict,
        PostmortemsCreatePostmortemResponse,
        PostmortemsCreatePostmortemResponseTypedDict,
    )
    from .postmortems_deletepostmortembyincidentop import (
        PostmortemsDeletePostmortemByIncidentRequest,
        PostmortemsDeletePostmortemByIncidentRequestTypedDict,
        PostmortemsDeletePostmortemByIncidentResponse,
        PostmortemsDeletePostmortemByIncidentResponseTypedDict,
    )
    from .postmortems_getallpostmortemsop import (
        PostmortemsGetAllPostmortemsData,
        PostmortemsGetAllPostmortemsDataTypedDict,
        PostmortemsGetAllPostmortemsRequest,
        PostmortemsGetAllPostmortemsRequestTypedDict,
        PostmortemsGetAllPostmortemsResponse,
        PostmortemsGetAllPostmortemsResponseTypedDict,
    )
    from .postmortems_getpostmortembyincidentop import (
        PostmortemsGetPostmortemByIncidentRequest,
        PostmortemsGetPostmortemByIncidentRequestTypedDict,
        PostmortemsGetPostmortemByIncidentResponse,
        PostmortemsGetPostmortemByIncidentResponseTypedDict,
    )
    from .postmortems_updatepostmortembyincidentop import (
        PostmortemsUpdatePostmortemByIncidentRequest,
        PostmortemsUpdatePostmortemByIncidentRequestTypedDict,
        PostmortemsUpdatePostmortemByIncidentResponse,
        PostmortemsUpdatePostmortemByIncidentResponseTypedDict,
    )
    from .rotations_createrotationop import (
        RotationsCreateRotationRequest,
        RotationsCreateRotationRequestTypedDict,
        RotationsCreateRotationResponse,
        RotationsCreateRotationResponseTypedDict,
    )
    from .rotations_deleterotationop import (
        RotationsDeleteRotationRequest,
        RotationsDeleteRotationRequestTypedDict,
        RotationsDeleteRotationResponseBody,
        RotationsDeleteRotationResponseBodyTypedDict,
    )
    from .rotations_getrotationparticipantsop import (
        RotationsGetRotationParticipantsRequest,
        RotationsGetRotationParticipantsRequestTypedDict,
        RotationsGetRotationParticipantsResponse,
        RotationsGetRotationParticipantsResponseTypedDict,
    )
    from .rotations_getschedulerotationbyidop import (
        RotationsGetScheduleRotationByIDRequest,
        RotationsGetScheduleRotationByIDRequestTypedDict,
        RotationsGetScheduleRotationByIDResponse,
        RotationsGetScheduleRotationByIDResponseTypedDict,
    )
    from .rotations_getschedulerotationsop import (
        RotationsGetScheduleRotationsRequest,
        RotationsGetScheduleRotationsRequestTypedDict,
        RotationsGetScheduleRotationsResponse,
        RotationsGetScheduleRotationsResponseTypedDict,
    )
    from .rotations_updaterotationop import (
        RotationsUpdateRotationRequest,
        RotationsUpdateRotationRequestTypedDict,
        RotationsUpdateRotationResponse,
        RotationsUpdateRotationResponseTypedDict,
    )
    from .rotations_updaterotationparticipantsop import (
        RotationsUpdateRotationParticipantsRequest,
        RotationsUpdateRotationParticipantsRequestTypedDict,
        RotationsUpdateRotationParticipantsResponse,
        RotationsUpdateRotationParticipantsResponseTypedDict,
    )
    from .routingrules_createorupdateroutingrulesop import (
        RoutingRulesCreateOrUpdateRoutingRulesData,
        RoutingRulesCreateOrUpdateRoutingRulesDataTypedDict,
        RoutingRulesCreateOrUpdateRoutingRulesRequest,
        RoutingRulesCreateOrUpdateRoutingRulesRequestTypedDict,
        RoutingRulesCreateOrUpdateRoutingRulesResponse,
        RoutingRulesCreateOrUpdateRoutingRulesResponseTypedDict,
    )
    from .routingrules_getroutingrulesop import (
        RoutingRulesGetRoutingRulesData,
        RoutingRulesGetRoutingRulesDataTypedDict,
        RoutingRulesGetRoutingRulesRequest,
        RoutingRulesGetRoutingRulesRequestTypedDict,
        RoutingRulesGetRoutingRulesResponse,
        RoutingRulesGetRoutingRulesResponseTypedDict,
    )
    from .runbooks_attachrunbooksop import (
        RunbooksAttachRunbooksRequest,
        RunbooksAttachRunbooksRequestTypedDict,
        RunbooksAttachRunbooksResponse,
        RunbooksAttachRunbooksResponseTypedDict,
    )
    from .runbooks_createrunbookop import (
        RunbooksCreateRunbookResponse,
        RunbooksCreateRunbookResponseTypedDict,
    )
    from .runbooks_getallrunbooksbyteamop import (
        RunbooksGetAllRunbooksByTeamResponse,
        RunbooksGetAllRunbooksByTeamResponseTypedDict,
    )
    from .runbooks_getrunbookbyidop import (
        RunbooksGetRunbookByIDRequest,
        RunbooksGetRunbookByIDRequestTypedDict,
        RunbooksGetRunbookByIDResponse,
        RunbooksGetRunbookByIDResponseTypedDict,
    )
    from .runbooks_removerunbookop import (
        RunbooksRemoveRunbookRequest,
        RunbooksRemoveRunbookRequestTypedDict,
        RunbooksRemoveRunbookResponseBody,
        RunbooksRemoveRunbookResponseBodyTypedDict,
    )
    from .runbooks_updaterunbookop import (
        RunbooksUpdateRunbookRequest,
        RunbooksUpdateRunbookRequestTypedDict,
        RunbooksUpdateRunbookResponse,
        RunbooksUpdateRunbookResponseTypedDict,
    )
    from .schedules_changetimezoneop import (
        SchedulesChangeTimezoneRequest,
        SchedulesChangeTimezoneRequestBody,
        SchedulesChangeTimezoneRequestBodyTypedDict,
        SchedulesChangeTimezoneRequestTypedDict,
        SchedulesChangeTimezoneResponse,
        SchedulesChangeTimezoneResponseTypedDict,
    )
    from .schedules_clonescheduleop import (
        SchedulesCloneScheduleRequest,
        SchedulesCloneScheduleRequestBody,
        SchedulesCloneScheduleRequestBodyTypedDict,
        SchedulesCloneScheduleRequestTypedDict,
        SchedulesCloneScheduleResponse,
        SchedulesCloneScheduleResponseTypedDict,
    )
    from .schedules_createscheduleop import (
        SchedulesCreateScheduleResponse,
        SchedulesCreateScheduleResponseTypedDict,
    )
    from .schedules_deletescheduleop import (
        SchedulesDeleteScheduleRequest,
        SchedulesDeleteScheduleRequestTypedDict,
        SchedulesDeleteScheduleResponseBody,
        SchedulesDeleteScheduleResponseBodyTypedDict,
    )
    from .schedules_getschedulebyidop import (
        SchedulesGetScheduleByIDRequest,
        SchedulesGetScheduleByIDRequestTypedDict,
        SchedulesGetScheduleByIDResponse,
        SchedulesGetScheduleByIDResponseTypedDict,
    )
    from .schedules_listschedulesop import (
        SchedulesListSchedulesRequest,
        SchedulesListSchedulesRequestTypedDict,
        SchedulesListSchedulesResponse,
        SchedulesListSchedulesResponseBody,
        SchedulesListSchedulesResponseBodyTypedDict,
        SchedulesListSchedulesResponseTypedDict,
    )
    from .schedules_pauseresumescheduleop import (
        Action,
        SchedulesPauseresumeScheduleRequest,
        SchedulesPauseresumeScheduleRequestBody,
        SchedulesPauseresumeScheduleRequestBodyTypedDict,
        SchedulesPauseresumeScheduleRequestTypedDict,
        SchedulesPauseresumeScheduleResponse,
        SchedulesPauseresumeScheduleResponseTypedDict,
    )
    from .schedules_updatescheduleop import (
        SchedulesUpdateScheduleRequest,
        SchedulesUpdateScheduleRequestTypedDict,
        SchedulesUpdateScheduleResponse,
        SchedulesUpdateScheduleResponseTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .services_createorupdateaptaconfigop import (
        ServicesCreateOrUpdateAPTAConfigData,
        ServicesCreateOrUpdateAPTAConfigDataTypedDict,
        ServicesCreateOrUpdateAPTAConfigRequest,
        ServicesCreateOrUpdateAPTAConfigRequestTypedDict,
        ServicesCreateOrUpdateAPTAConfigResponse,
        ServicesCreateOrUpdateAPTAConfigResponseTypedDict,
    )
    from .services_createorupdateiagconfigop import (
        ServicesCreateOrUpdateIAGConfigData,
        ServicesCreateOrUpdateIAGConfigDataTypedDict,
        ServicesCreateOrUpdateIAGConfigRequest,
        ServicesCreateOrUpdateIAGConfigRequestTypedDict,
        ServicesCreateOrUpdateIAGConfigResponse,
        ServicesCreateOrUpdateIAGConfigResponseTypedDict,
    )
    from .services_createserviceop import (
        ServicesCreateServiceBody,
        ServicesCreateServiceBodyTypedDict,
        ServicesCreateServiceRequest,
        ServicesCreateServiceRequestTypedDict,
        ServicesCreateServiceResponse,
        ServicesCreateServiceResponseTypedDict,
    )
    from .services_delayednotificationconfigop import (
        ServicesDelayedNotificationConfigRequest,
        ServicesDelayedNotificationConfigRequestTypedDict,
        ServicesDelayedNotificationConfigResponse,
        ServicesDelayedNotificationConfigResponseTypedDict,
    )
    from .services_deleteserviceop import (
        ServicesDeleteServiceRequest,
        ServicesDeleteServiceRequestTypedDict,
        ServicesDeleteServiceResponseBody,
        ServicesDeleteServiceResponseBodyTypedDict,
    )
    from .services_getservicebyidop import (
        ServicesGetServiceByIDRequest,
        ServicesGetServiceByIDRequestTypedDict,
        ServicesGetServiceByIDResponse,
        ServicesGetServiceByIDResponseTypedDict,
    )
    from .services_getservicesbynameop import (
        ServicesGetServicesByNameRequest,
        ServicesGetServicesByNameRequestTypedDict,
        ServicesGetServicesByNameResponse,
        ServicesGetServicesByNameResponseTypedDict,
    )
    from .services_getservicesop import (
        ServicesGetServicesRequest,
        ServicesGetServicesRequestTypedDict,
        ServicesGetServicesResponse,
        ServicesGetServicesResponseTypedDict,
    )
    from .services_updateserviceop import (
        ServicesUpdateServiceRequest,
        ServicesUpdateServiceRequestTypedDict,
        ServicesUpdateServiceResponse,
        ServicesUpdateServiceResponseTypedDict,
    )
    from .slo_createsloop import (
        SLOCreateSLOData,
        SLOCreateSLODataTypedDict,
        SLOCreateSLOResponse,
        SLOCreateSLOResponseTypedDict,
    )
    from .slo_getallslosop import (
        SLOGetAllSLOsData,
        SLOGetAllSLOsDataTypedDict,
        SLOGetAllSLOsMeta,
        SLOGetAllSLOsMetaTypedDict,
        SLOGetAllSLOsRequest,
        SLOGetAllSLOsRequestTypedDict,
        SLOGetAllSLOsResponse,
        SLOGetAllSLOsResponseTypedDict,
    )
    from .slo_getslobyidop import (
        SLOGetSLOByIDRequest,
        SLOGetSLOByIDRequestTypedDict,
        SLOGetSLOByIDResponse,
        SLOGetSLOByIDResponseTypedDict,
    )
    from .slo_marksloaffectedop import (
        SLOMarkSLOAffectedData,
        SLOMarkSLOAffectedDataTypedDict,
        SLOMarkSLOAffectedRequest,
        SLOMarkSLOAffectedRequestTypedDict,
        SLOMarkSLOAffectedResponse,
        SLOMarkSLOAffectedResponseTypedDict,
    )
    from .slo_markslofalsepositiveop import (
        SLOMarkSLOFalsePositiveData,
        SLOMarkSLOFalsePositiveDataTypedDict,
        SLOMarkSLOFalsePositiveRequest,
        SLOMarkSLOFalsePositiveRequestBody,
        SLOMarkSLOFalsePositiveRequestBodyTypedDict,
        SLOMarkSLOFalsePositiveRequestTypedDict,
        SLOMarkSLOFalsePositiveResponse,
        SLOMarkSLOFalsePositiveResponseTypedDict,
    )
    from .slo_removesloop import (
        SLORemoveSLORequest,
        SLORemoveSLORequestTypedDict,
        SLORemoveSLOResponse,
        SLORemoveSLOResponseTypedDict,
    )
    from .slo_updatesloop import (
        SLOUpdateSLOData,
        SLOUpdateSLODataTypedDict,
        SLOUpdateSLORequest,
        SLOUpdateSLORequestTypedDict,
        SLOUpdateSLOResponse,
        SLOUpdateSLOResponseTypedDict,
    )
    from .snoozenotifications_snoozeincidentnotificationsop import (
        SnoozeNotificationsSnoozeIncidentNotificationsRequest,
        SnoozeNotificationsSnoozeIncidentNotificationsRequestTypedDict,
        SnoozeNotificationsSnoozeIncidentNotificationsResponse,
        SnoozeNotificationsSnoozeIncidentNotificationsResponseTypedDict,
    )
    from .snoozenotifications_unsnoozeincidentnotificationsop import (
        SnoozeNotificationsUnsnoozeIncidentNotificationsRequest,
        SnoozeNotificationsUnsnoozeIncidentNotificationsRequestTypedDict,
        SnoozeNotificationsUnsnoozeIncidentNotificationsResponse,
        SnoozeNotificationsUnsnoozeIncidentNotificationsResponseTypedDict,
    )
    from .squads_createsquadop import (
        SquadsCreateSquadResponse,
        SquadsCreateSquadResponseTypedDict,
    )
    from .squads_deletesquadop import (
        SquadsDeleteSquadRequest,
        SquadsDeleteSquadRequestTypedDict,
        SquadsDeleteSquadResponseBody,
        SquadsDeleteSquadResponseBodyTypedDict,
    )
    from .squads_getallsquadsop import (
        SquadsGetAllSquadsRequest,
        SquadsGetAllSquadsRequestTypedDict,
        SquadsGetAllSquadsResponse,
        SquadsGetAllSquadsResponseTypedDict,
    )
    from .squads_getsquadbyidop import (
        SquadsGetSquadByIDRequest,
        SquadsGetSquadByIDRequestTypedDict,
        SquadsGetSquadByIDResponse,
        SquadsGetSquadByIDResponseTypedDict,
    )
    from .squads_removesquadmemberop import (
        SquadsRemoveSquadMemberRequest,
        SquadsRemoveSquadMemberRequestTypedDict,
    )
    from .squads_updatesquadmemberop import (
        SquadsUpdateSquadMemberRequest,
        SquadsUpdateSquadMemberRequestTypedDict,
    )
    from .squads_updatesquadnameop import (
        SquadsUpdateSquadNameRequest,
        SquadsUpdateSquadNameRequestTypedDict,
        SquadsUpdateSquadNameResponse,
        SquadsUpdateSquadNameResponseTypedDict,
    )
    from .squads_updatesquadop import (
        SquadsUpdateSquadRequest,
        SquadsUpdateSquadRequestTypedDict,
        SquadsUpdateSquadResponse,
        SquadsUpdateSquadResponseTypedDict,
    )
    from .statuspages_createstatuspageop import (
        StatusPagesCreateStatusPageResponse,
        StatusPagesCreateStatusPageResponseTypedDict,
    )
    from .statuspages_deletestatuspagebyidop import (
        StatusPagesDeleteStatusPageByIDRequest,
        StatusPagesDeleteStatusPageByIDRequestTypedDict,
        StatusPagesDeleteStatusPageByIDResponse,
        StatusPagesDeleteStatusPageByIDResponseTypedDict,
    )
    from .statuspages_getstatuspagebyidop import (
        StatusPagesGetStatusPageByIDRequest,
        StatusPagesGetStatusPageByIDRequestTypedDict,
        StatusPagesGetStatusPageByIDResponse,
        StatusPagesGetStatusPageByIDResponseTypedDict,
    )
    from .statuspages_liststatuspagesop import (
        StatusPagesListStatusPagesRequest,
        StatusPagesListStatusPagesRequestTypedDict,
        StatusPagesListStatusPagesResponse,
        StatusPagesListStatusPagesResponseTypedDict,
    )
    from .statuspages_liststatuspagestatusesop import (
        StatusPagesListStatusPageStatusesRequest,
        StatusPagesListStatusPageStatusesRequestTypedDict,
        StatusPagesListStatusPageStatusesResponse,
        StatusPagesListStatusPageStatusesResponseTypedDict,
    )
    from .statuspages_listsubscribersop import (
        StatusPagesListSubscribersRequest,
        StatusPagesListSubscribersRequestTypedDict,
    )
    from .statuspages_updatestatuspagebyidop import (
        StatusPagesUpdateStatusPageByIDRequest,
        StatusPagesUpdateStatusPageByIDRequestTypedDict,
        StatusPagesUpdateStatusPageByIDResponse,
        StatusPagesUpdateStatusPageByIDResponseTypedDict,
    )
    from .suppressionrules_createorupdatesuppressionrulesop import (
        SuppressionRulesCreateOrUpdateSuppressionRulesRequest,
        SuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict,
        SuppressionRulesCreateOrUpdateSuppressionRulesResponse,
        SuppressionRulesCreateOrUpdateSuppressionRulesResponseTypedDict,
    )
    from .suppressionrules_getsuppressionrulesop import (
        SuppressionRulesGetSuppressionRulesData,
        SuppressionRulesGetSuppressionRulesDataTypedDict,
        SuppressionRulesGetSuppressionRulesRequest,
        SuppressionRulesGetSuppressionRulesRequestTypedDict,
        SuppressionRulesGetSuppressionRulesResponse,
        SuppressionRulesGetSuppressionRulesResponseTypedDict,
    )
    from .taggingrules_createorupdatetaggingrulesop import (
        TaggingRulesCreateOrUpdateTaggingRulesData,
        TaggingRulesCreateOrUpdateTaggingRulesDataTypedDict,
        TaggingRulesCreateOrUpdateTaggingRulesRequest,
        TaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict,
        TaggingRulesCreateOrUpdateTaggingRulesResponse,
        TaggingRulesCreateOrUpdateTaggingRulesResponseTypedDict,
    )
    from .taggingrules_gettaggingrulesop import (
        TaggingRulesGetTaggingRulesData,
        TaggingRulesGetTaggingRulesDataTypedDict,
        TaggingRulesGetTaggingRulesRequest,
        TaggingRulesGetTaggingRulesRequestTypedDict,
        TaggingRulesGetTaggingRulesResponse,
        TaggingRulesGetTaggingRulesResponseTypedDict,
    )
    from .tags_appendtagop import (
        TagsAppendTagRequest,
        TagsAppendTagRequestTypedDict,
        TagsAppendTagResponse,
        TagsAppendTagResponseTypedDict,
    )
    from .tags_updatetagop import (
        TagsUpdateTagRequest,
        TagsUpdateTagRequestTypedDict,
        TagsUpdateTagResponse,
        TagsUpdateTagResponseTypedDict,
    )
    from .teams_addbulkteammemberop import (
        TeamsAddBulkTeamMemberData,
        TeamsAddBulkTeamMemberDataTypedDict,
        TeamsAddBulkTeamMemberMember,
        TeamsAddBulkTeamMemberMemberTypedDict,
        TeamsAddBulkTeamMemberRequest,
        TeamsAddBulkTeamMemberRequestTypedDict,
        TeamsAddBulkTeamMemberResponse,
        TeamsAddBulkTeamMemberResponseTypedDict,
    )
    from .teams_addteammemberop import (
        TeamsAddTeamMemberRequest,
        TeamsAddTeamMemberRequestTypedDict,
        TeamsAddTeamMemberResponse,
        TeamsAddTeamMemberResponseTypedDict,
    )
    from .teams_createteamop import (
        TeamsCreateTeamResponse,
        TeamsCreateTeamResponseTypedDict,
    )
    from .teams_createteamroleop import (
        TeamsCreateTeamRoleRequest,
        TeamsCreateTeamRoleRequestTypedDict,
        TeamsCreateTeamRoleResponse,
        TeamsCreateTeamRoleResponseTypedDict,
    )
    from .teams_getallteammembersop import (
        TeamsGetAllTeamMembersRequest,
        TeamsGetAllTeamMembersRequestTypedDict,
        TeamsGetAllTeamMembersResponse,
        TeamsGetAllTeamMembersResponseTypedDict,
    )
    from .teams_getallteamrolesop import (
        TeamsGetAllTeamRolesRequest,
        TeamsGetAllTeamRolesRequestTypedDict,
        TeamsGetAllTeamRolesResponse,
        TeamsGetAllTeamRolesResponseTypedDict,
    )
    from .teams_getallteamsop import (
        TeamsGetAllTeamsResponse,
        TeamsGetAllTeamsResponseTypedDict,
    )
    from .teams_getteambyidop import (
        TeamsGetTeamByIDRequest,
        TeamsGetTeamByIDRequestTypedDict,
        TeamsGetTeamByIDResponse,
        TeamsGetTeamByIDResponseTypedDict,
    )
    from .teams_removeteammemberop import (
        TeamsRemoveTeamMemberRequest,
        TeamsRemoveTeamMemberRequestTypedDict,
        TeamsRemoveTeamMemberResponseBody,
        TeamsRemoveTeamMemberResponseBodyTypedDict,
    )
    from .teams_removeteamop import (
        TeamsRemoveTeamRequest,
        TeamsRemoveTeamRequestTypedDict,
        TeamsRemoveTeamResponseBody,
        TeamsRemoveTeamResponseBodyTypedDict,
    )
    from .teams_removeteamroleop import (
        TeamsRemoveTeamRoleRequest,
        TeamsRemoveTeamRoleRequestTypedDict,
        TeamsRemoveTeamRoleResponseBody,
        TeamsRemoveTeamRoleResponseBodyTypedDict,
    )
    from .teams_updateteammemberop import (
        TeamsUpdateTeamMemberRequest,
        TeamsUpdateTeamMemberRequestTypedDict,
        TeamsUpdateTeamMemberResponse,
        TeamsUpdateTeamMemberResponseTypedDict,
    )
    from .teams_updateteamop import (
        TeamsUpdateTeamRequest,
        TeamsUpdateTeamRequestTypedDict,
        TeamsUpdateTeamResponse,
        TeamsUpdateTeamResponseTypedDict,
    )
    from .teams_updateteamroleop import (
        TeamsUpdateTeamRoleRequest,
        TeamsUpdateTeamRoleRequestTypedDict,
        TeamsUpdateTeamRoleResponse,
        TeamsUpdateTeamRoleResponseTypedDict,
    )
    from .users_adduserop import UsersAddUserResponse, UsersAddUserResponseTypedDict
    from .users_createtokenop import (
        UsersCreateTokenRequest,
        UsersCreateTokenRequestTypedDict,
        UsersCreateTokenResponse,
        UsersCreateTokenResponseTypedDict,
    )
    from .users_deleteuserop import (
        UsersDeleteUserData,
        UsersDeleteUserDataTypedDict,
        UsersDeleteUserRequest,
        UsersDeleteUserRequestTypedDict,
        UsersDeleteUserResponse,
        UsersDeleteUserResponseTypedDict,
    )
    from .users_getalltokensop import (
        UsersGetAllTokensResponse,
        UsersGetAllTokensResponseTypedDict,
    )
    from .users_getallusersop import (
        UsersGetAllUsersResponse,
        UsersGetAllUsersResponseTypedDict,
    )
    from .users_getuserbyidop import (
        UsersGetUserByIDRequest,
        UsersGetUserByIDRequestTypedDict,
        UsersGetUserByIDResponse,
        UsersGetUserByIDResponseTypedDict,
    )
    from .users_getuserrolesop import (
        UsersGetUserRolesResponse,
        UsersGetUserRolesResponseTypedDict,
    )
    from .users_removetokenop import (
        UsersRemoveTokenRequest,
        UsersRemoveTokenRequestTypedDict,
        UsersRemoveTokenResponseBody,
        UsersRemoveTokenResponseBodyTypedDict,
    )
    from .users_removeuserfromorgop import (
        UsersRemoveUserFromOrgRequest,
        UsersRemoveUserFromOrgRequestTypedDict,
        UsersRemoveUserFromOrgResponseBody,
        UsersRemoveUserFromOrgResponseBodyTypedDict,
    )
    from .users_updateorglevelpermissionsop import (
        UsersUpdateOrgLevelPermissionsResponse,
        UsersUpdateOrgLevelPermissionsResponseTypedDict,
    )
    from .users_updateuserbyidop import (
        UsersUpdateUserByIDRequest,
        UsersUpdateUserByIDRequestTypedDict,
        UsersUpdateUserByIDResponse,
        UsersUpdateUserByIDResponseTypedDict,
    )
    from .v3_analytics_analyticsresponse import (
        V3AnalyticsAnalyticsResponse,
        V3AnalyticsAnalyticsResponseTypedDict,
    )
    from .v3_auditlogs_actor import V3AuditLogsActor, V3AuditLogsActorTypedDict
    from .v3_auditlogs_auditlogidresponse import (
        V3AuditLogsAuditLogIDResponse,
        V3AuditLogsAuditLogIDResponseMeta,
        V3AuditLogsAuditLogIDResponseMetaTypedDict,
        V3AuditLogsAuditLogIDResponseTypedDict,
    )
    from .v3_auditlogs_auditlogresponse import (
        V3AuditLogsAuditLogResponse,
        V3AuditLogsAuditLogResponseTypedDict,
    )
    from .v3_auditlogs_auditlogsexporthistoryresponse import (
        V3AuditLogsAuditLogsExportHistoryResponse,
        V3AuditLogsAuditLogsExportHistoryResponseTypedDict,
    )
    from .v3_auditlogs_exportauditlogsrequest import (
        ExportType,
        Filters,
        FiltersTypedDict,
        V3AuditLogsExportAuditLogsRequest,
        V3AuditLogsExportAuditLogsRequestTypedDict,
    )
    from .v3_auditlogs_exportauditlogsresponse import (
        V3AuditLogsExportAuditLogsResponse,
        V3AuditLogsExportAuditLogsResponseData,
        V3AuditLogsExportAuditLogsResponseDataTypedDict,
        V3AuditLogsExportAuditLogsResponseTypedDict,
    )
    from .v3_auditlogs_filters import V3AuditLogsFilters, V3AuditLogsFiltersTypedDict
    from .v3_auditlogs_getauditlogbyidresponse import (
        V3AuditLogsGetAuditLogByIDResponse,
        V3AuditLogsGetAuditLogByIDResponseTypedDict,
    )
    from .v3_auditlogs_getauditlogexporthistorybyidresponse import (
        V3AuditLogsGetAuditLogExportHistoryByIDResponse,
        V3AuditLogsGetAuditLogExportHistoryByIDResponseTypedDict,
    )
    from .v3_auditlogs_listauditlogsexporthistoryresponse import (
        V3AuditLogsListAuditLogsExportHistoryResponse,
        V3AuditLogsListAuditLogsExportHistoryResponseMetadata,
        V3AuditLogsListAuditLogsExportHistoryResponseMetadataTypedDict,
        V3AuditLogsListAuditLogsExportHistoryResponseTypedDict,
    )
    from .v3_auditlogs_listauditlogsresponse import (
        V3AuditLogsListAuditLogsResponse,
        V3AuditLogsListAuditLogsResponseMetadata,
        V3AuditLogsListAuditLogsResponseMetadataTypedDict,
        V3AuditLogsListAuditLogsResponseTypedDict,
    )
    from .v3_auditlogs_team import V3AuditLogsTeam, V3AuditLogsTeamTypedDict
    from .v3_escalationpolicies_createescalationpolicyrequest import (
        V3EscalationPoliciesCreateEscalationPolicyRequest,
        V3EscalationPoliciesCreateEscalationPolicyRequestTypedDict,
    )
    from .v3_escalationpolicies_escalationentity import (
        V3EscalationPoliciesEscalationEntity,
        V3EscalationPoliciesEscalationEntityType,
        V3EscalationPoliciesEscalationEntityTypedDict,
    )
    from .v3_escalationpolicies_escalationpolicyresponse import (
        V3EscalationPoliciesEscalationPolicyResponse,
        V3EscalationPoliciesEscalationPolicyResponseTypedDict,
    )
    from .v3_escalationpolicies_escalationpolicyrule import (
        V3EscalationPoliciesEscalationPolicyRule,
        V3EscalationPoliciesEscalationPolicyRuleTypedDict,
    )
    from .v3_escalationpolicies_incidentreminderrule import (
        V3EscalationPoliciesIncidentReminderRule,
        V3EscalationPoliciesIncidentReminderRuleTypedDict,
    )
    from .v3_export_exportresponse import (
        V3ExportExportResponse,
        V3ExportExportResponseTypedDict,
    )
    from .v3_extensions_msteams_channelconfiguration import (
        V3ExtensionsMSTeamsChannelConfiguration,
        V3ExtensionsMSTeamsChannelConfigurationTypedDict,
    )
    from .v3_extensions_msteams_connectedteams import (
        V3ExtensionsMSTeamsConnectedTeams,
        V3ExtensionsMSTeamsConnectedTeamsTypedDict,
    )
    from .v3_extensions_msteams_createorupdatemsteamsconfigrequest import (
        V3ExtensionsMSTeamsCreateOrUpdateMSTeamsConfigRequest,
        V3ExtensionsMSTeamsCreateOrUpdateMSTeamsConfigRequestTypedDict,
    )
    from .v3_extensions_msteams_eventclass import (
        V3ExtensionsMSTeamsEventClass,
        V3ExtensionsMSTeamsEventClassEnum,
        V3ExtensionsMSTeamsEventClassTypedDict,
    )
    from .v3_extensions_msteams_incidentactionalertstate import (
        V3ExtensionsMSTeamsIncidentActionAlertState,
        V3ExtensionsMSTeamsIncidentActionAlertStateTypedDict,
    )
    from .v3_extensions_msteams_msteamsconfigresponse import (
        V3ExtensionsMSTeamsMSTeamsConfigResponse,
        V3ExtensionsMSTeamsMSTeamsConfigResponseTypedDict,
    )
    from .v3_extensions_msteams_squadcastservicemapping import (
        V3ExtensionsMSTeamsSquadCastServiceMapping,
        V3ExtensionsMSTeamsSquadCastServiceMappingTypedDict,
    )
    from .v3_extensions_msteams_triggers import (
        V3ExtensionsMSTeamsTriggers,
        V3ExtensionsMSTeamsTriggersTypedDict,
    )
    from .v3_extensions_webhooks_getallwebhooksresponse import (
        V3ExtensionsWebhooksGetAllWebhooksResponse,
        V3ExtensionsWebhooksGetAllWebhooksResponseData,
        V3ExtensionsWebhooksGetAllWebhooksResponseDataTypedDict,
        V3ExtensionsWebhooksGetAllWebhooksResponseMeta,
        V3ExtensionsWebhooksGetAllWebhooksResponseMetaTypedDict,
        V3ExtensionsWebhooksGetAllWebhooksResponseTypedDict,
    )
    from .v3_extensions_webhooks_webhook import (
        V3ExtensionsWebhooksWebhook,
        V3ExtensionsWebhooksWebhookHeader,
        V3ExtensionsWebhooksWebhookHeaderTypedDict,
        V3ExtensionsWebhooksWebhookTypedDict,
    )
    from .v3_extensions_webhooks_webhookfilter import (
        V3ExtensionsWebhooksWebhookFilter,
        V3ExtensionsWebhooksWebhookFilterTypedDict,
    )
    from .v3_extensions_webhooks_webhookfiltercondition import (
        V3ExtensionsWebhooksWebhookFilterCondition,
        V3ExtensionsWebhooksWebhookFilterConditionTypedDict,
    )
    from .v3_extensions_webhooks_webhooklistitem import (
        V3ExtensionsWebhooksWebhookListItem,
        V3ExtensionsWebhooksWebhookListItemTypedDict,
    )
    from .v3_extensions_webhooks_webhookresponse import (
        V3ExtensionsWebhooksWebhookResponse,
        V3ExtensionsWebhooksWebhookResponseHeader,
        V3ExtensionsWebhooksWebhookResponseHeaderTypedDict,
        V3ExtensionsWebhooksWebhookResponseTypedDict,
    )
    from .v3_extensions_webhooks_webhooktrigger import (
        V3ExtensionsWebhooksWebhookTrigger,
        V3ExtensionsWebhooksWebhookTriggerTypedDict,
    )
    from .v3_extensions_webhooks_webhookurl import (
        V3ExtensionsWebhooksWebhookURL,
        V3ExtensionsWebhooksWebhookURLTypedDict,
    )
    from .v3_globaleventrules_createdglobaleventruleresponse import (
        V3GlobalEventRulesCreatedGlobalEventRuleResponse,
        V3GlobalEventRulesCreatedGlobalEventRuleResponseTypedDict,
    )
    from .v3_globaleventrules_createglobaleventrulerequest import (
        V3GlobalEventRulesCreateGlobalEventRuleRequest,
        V3GlobalEventRulesCreateGlobalEventRuleRequestTypedDict,
    )
    from .v3_globaleventrules_createorupdaterulerequest import (
        V3GlobalEventRulesCreateOrUpdateRuleRequest,
        V3GlobalEventRulesCreateOrUpdateRuleRequestTypedDict,
    )
    from .v3_globaleventrules_createrulesetrequest import (
        V3GlobalEventRulesCreateRulesetRequest,
        V3GlobalEventRulesCreateRulesetRequestTypedDict,
    )
    from .v3_globaleventrules_entityowner import (
        V3GlobalEventRulesEntityOwner,
        V3GlobalEventRulesEntityOwnerType,
        V3GlobalEventRulesEntityOwnerTypedDict,
    )
    from .v3_globaleventrules_entityownerupdate import (
        V3GlobalEventRulesEntityOwnerUpdate,
        V3GlobalEventRulesEntityOwnerUpdateType,
        V3GlobalEventRulesEntityOwnerUpdateTypedDict,
    )
    from .v3_globaleventrules_globaleventruleinlist import (
        V3GlobalEventRulesGlobalEventRuleInList,
        V3GlobalEventRulesGlobalEventRuleInListTypedDict,
    )
    from .v3_globaleventrules_globaleventruleresponse import (
        V3GlobalEventRulesGlobalEventRuleResponse,
        V3GlobalEventRulesGlobalEventRuleResponseTypedDict,
    )
    from .v3_globaleventrules_orderingresponse import (
        V3GlobalEventRulesOrderingResponse,
        V3GlobalEventRulesOrderingResponseTypedDict,
    )
    from .v3_globaleventrules_reorderrulerequest import (
        V3GlobalEventRulesReorderRuleRequest,
        V3GlobalEventRulesReorderRuleRequestTypedDict,
    )
    from .v3_globaleventrules_reorderrulesetrequest import (
        V3GlobalEventRulesReorderRulesetRequest,
        V3GlobalEventRulesReorderRulesetRequestTypedDict,
    )
    from .v3_globaleventrules_ruleaction import (
        V3GlobalEventRulesRuleAction,
        V3GlobalEventRulesRuleActionTypedDict,
    )
    from .v3_globaleventrules_ruleactionupdate import (
        V3GlobalEventRulesRuleActionUpdate,
        V3GlobalEventRulesRuleActionUpdateTypedDict,
    )
    from .v3_globaleventrules_ruleset import (
        V3GlobalEventRulesRuleset,
        V3GlobalEventRulesRulesetTypedDict,
    )
    from .v3_globaleventrules_rulesetresponse import (
        V3GlobalEventRulesRulesetResponse,
        V3GlobalEventRulesRulesetResponseTypedDict,
    )
    from .v3_globaleventrules_rulesetruleresponse import (
        V3GlobalEventRulesRulesetRuleResponse,
        V3GlobalEventRulesRulesetRuleResponseTypedDict,
    )
    from .v3_globaleventrules_updateglobaleventrulerequest import (
        V3GlobalEventRulesUpdateGlobalEventRuleRequest,
        V3GlobalEventRulesUpdateGlobalEventRuleRequestTypedDict,
    )
    from .v3_globaleventrules_updaterulerequest import (
        V3GlobalEventRulesUpdateRuleRequest,
        V3GlobalEventRulesUpdateRuleRequestTypedDict,
    )
    from .v3_globaleventrules_updaterulesetrequest import (
        V3GlobalEventRulesUpdateRulesetRequest,
        V3GlobalEventRulesUpdateRulesetRequestTypedDict,
    )
    from .v3_globaloncallreminderrules_createglobaloncallreminderrulesrequest import (
        V3GlobalOncallReminderRulesCreateGlobalOncallReminderRulesRequest,
        V3GlobalOncallReminderRulesCreateGlobalOncallReminderRulesRequestTypedDict,
    )
    from .v3_globaloncallreminderrules_globaloncallreminderruleresponse import (
        V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse,
        V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict,
    )
    from .v3_globaloncallreminderrules_rule import (
        V3GlobalOncallReminderRulesRule,
        V3GlobalOncallReminderRulesRuleTypedDict,
    )
    from .v3_globaloncallreminderrules_updateglobaloncallreminderrulesrequest import (
        V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest,
        V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict,
    )
    from .v3_incidents_additionalresponderdetails import (
        V3IncidentsAdditionalResponderDetails,
        V3IncidentsAdditionalResponderDetailsTypedDict,
    )
    from .v3_incidents_additionalresponders_addadditionalrespondersrequest import (
        AdditionalResponder,
        AdditionalResponderTypedDict,
        V3IncidentsAdditionalRespondersAddAdditionalRespondersRequest,
        V3IncidentsAdditionalRespondersAddAdditionalRespondersRequestTypedDict,
    )
    from .v3_incidents_additionalresponders_additionalresponder import (
        V3IncidentsAdditionalRespondersAdditionalResponder,
        V3IncidentsAdditionalRespondersAdditionalResponderTypedDict,
    )
    from .v3_incidents_additionalresponders_additionalresponderresponse import (
        V3IncidentsAdditionalRespondersAdditionalResponderResponse,
        V3IncidentsAdditionalRespondersAdditionalResponderResponseTypedDict,
    )
    from .v3_incidents_analytics import (
        V3IncidentsAnalytics,
        V3IncidentsAnalyticsTypedDict,
    )
    from .v3_incidents_analyticsmetrics import (
        V3IncidentsAnalyticsMetrics,
        V3IncidentsAnalyticsMetricsTypedDict,
    )
    from .v3_incidents_apta_messageresponse import (
        V3IncidentsAptaMessageResponse,
        V3IncidentsAptaMessageResponseTypedDict,
    )
    from .v3_incidents_assignedto import (
        V3IncidentsAssignedTo,
        V3IncidentsAssignedToTypedDict,
    )
    from .v3_incidents_assignto import V3IncidentsAssignTo, V3IncidentsAssignToTypedDict
    from .v3_incidents_bulkincidentidsrequest import (
        V3IncidentsBulkIncidentIDsRequest,
        V3IncidentsBulkIncidentIDsRequestTypedDict,
    )
    from .v3_incidents_bulkincidentspriorityupdaterequest import (
        V3IncidentsBulkIncidentsPriorityUpdateRequest,
        V3IncidentsBulkIncidentsPriorityUpdateRequestTypedDict,
    )
    from .v3_incidents_communicationcards_archiveslackchannelrequest import (
        V3IncidentsCommunicationCardsArchiveSlackChannelRequest,
        V3IncidentsCommunicationCardsArchiveSlackChannelRequestTypedDict,
    )
    from .v3_incidents_communicationcards_communicationcardresponse import (
        V3IncidentsCommunicationCardsCommunicationCardResponse,
        V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict,
    )
    from .v3_incidents_communicationcards_createcommunicationcardrequest import (
        V3IncidentsCommunicationCardsCreateCommunicationCardRequest,
        V3IncidentsCommunicationCardsCreateCommunicationCardRequestTypedDict,
    )
    from .v3_incidents_communicationcards_createslackchannelrequest import (
        V3IncidentsCommunicationCardsCreateSlackChannelRequest,
        V3IncidentsCommunicationCardsCreateSlackChannelRequestTypedDict,
    )
    from .v3_incidents_communicationcards_updatecommunicationcardrequest import (
        V3IncidentsCommunicationCardsUpdateCommunicationCardRequest,
        V3IncidentsCommunicationCardsUpdateCommunicationCardRequestTypedDict,
    )
    from .v3_incidents_dedupdata import (
        V3IncidentsDedupData,
        V3IncidentsDedupDataTypedDict,
    )
    from .v3_incidents_exportformat import V3IncidentsExportFormat
    from .v3_incidents_exportincidentsfilter import (
        V3IncidentsExportIncidentsFilter,
        V3IncidentsExportIncidentsFilterTypedDict,
    )
    from .v3_incidents_incidentactions_circlecierrormeta import (
        V3IncidentsIncidentActionsCircleCIErrorMeta,
        V3IncidentsIncidentActionsCircleCIErrorMetaTypedDict,
    )
    from .v3_incidents_incidentactions_circlecirebuildresponse import (
        BuildParameters,
        BuildParametersTypedDict,
        CircleciResponse,
        CircleciResponseTypedDict,
        Previous,
        PreviousSuccessfulBuild,
        PreviousSuccessfulBuildTypedDict,
        PreviousTypedDict,
        V3IncidentsIncidentActionsCircleCIRebuildResponse,
        V3IncidentsIncidentActionsCircleCIRebuildResponseTypedDict,
    )
    from .v3_incidents_incidentactions_rebuildcircleciprojectrequest import (
        V3IncidentsIncidentActionsRebuildCircleCIProjectRequest,
        V3IncidentsIncidentActionsRebuildCircleCIProjectRequestTypedDict,
    )
    from .v3_incidents_incidentactions_webhookactionresponse import (
        URL,
        URLTypedDict,
        V3IncidentsIncidentActionsWebhookActionResponse,
        V3IncidentsIncidentActionsWebhookActionResponseHeader,
        V3IncidentsIncidentActionsWebhookActionResponseHeaderTypedDict,
        V3IncidentsIncidentActionsWebhookActionResponseTypedDict,
    )
    from .v3_incidents_incidenteventresponse import (
        DeduplicationReason,
        DeduplicationReasonTypedDict,
        Payload,
        PayloadTypedDict,
        V3IncidentsIncidentEventResponse,
        V3IncidentsIncidentEventResponseTags,
        V3IncidentsIncidentEventResponseTagsTypedDict,
        V3IncidentsIncidentEventResponseTypedDict,
    )
    from .v3_incidents_incidentexportasyncrequest import (
        V3IncidentsIncidentExportAsyncRequest,
        V3IncidentsIncidentExportAsyncRequestTypedDict,
    )
    from .v3_incidents_incidentexportasyncresponse import (
        V3IncidentsIncidentExportAsyncResponse,
        V3IncidentsIncidentExportAsyncResponseTypedDict,
    )
    from .v3_incidents_incidentexportrequest_is_starred import (
        V3IncidentsIncidentExportRequestIsStarred,
    )
    from .v3_incidents_incidentexportrequest_notes import (
        V3IncidentsIncidentExportRequestNotes,
    )
    from .v3_incidents_incidentexportrequest_retrospectives import (
        V3IncidentsIncidentExportRequestRetrospectives,
    )
    from .v3_incidents_incidentexportrequest_slo_affecting import (
        V3IncidentsIncidentExportRequestSloAffecting,
    )
    from .v3_incidents_incidentexportrequest_sort_by import (
        V3IncidentsIncidentExportRequestSortBy,
    )
    from .v3_incidents_incidentpriority import V3IncidentsIncidentPriority
    from .v3_incidents_incidentpriorityupdaterequest import (
        V3IncidentsIncidentPriorityUpdateRequest,
        V3IncidentsIncidentPriorityUpdateRequestTypedDict,
    )
    from .v3_incidents_incidentpriorityupdateresponse import (
        V3IncidentsIncidentPriorityUpdateResponse,
        V3IncidentsIncidentPriorityUpdateResponseTypedDict,
    )
    from .v3_incidents_incidentresponse import (
        V3IncidentsIncidentResponse,
        V3IncidentsIncidentResponseRetriggerPolicy,
        V3IncidentsIncidentResponseRetriggerPolicyTypedDict,
        V3IncidentsIncidentResponseTags,
        V3IncidentsIncidentResponseTagsTypedDict,
        V3IncidentsIncidentResponseTypedDict,
    )
    from .v3_incidents_ingestionstatusrequest import (
        V3IncidentsIngestionStatusRequest,
        V3IncidentsIngestionStatusRequestTypedDict,
    )
    from .v3_incidents_logs import (
        V3IncidentsLogs,
        V3IncidentsLogsAdditionalInfo,
        V3IncidentsLogsAdditionalInfoTypedDict,
        V3IncidentsLogsTypedDict,
    )
    from .v3_incidents_mergeincidententityreference import (
        V3IncidentsMergeIncidentEntityReference,
        V3IncidentsMergeIncidentEntityReferenceTypedDict,
    )
    from .v3_incidents_notes_createnoterequest import (
        V3IncidentsNotesCreateNoteRequest,
        V3IncidentsNotesCreateNoteRequestTypedDict,
    )
    from .v3_incidents_notes_noteresponse import (
        User,
        UserTypedDict,
        V3IncidentsNotesNoteResponse,
        V3IncidentsNotesNoteResponseTypedDict,
    )
    from .v3_incidents_notes_updatenoterequest import (
        V3IncidentsNotesUpdateNoteRequest,
        V3IncidentsNotesUpdateNoteRequestTypedDict,
    )
    from .v3_incidents_notificationdelaypolicy import (
        V3IncidentsNotificationDelayPolicy,
        V3IncidentsNotificationDelayPolicyTypedDict,
    )
    from .v3_incidents_pinnedmessage import (
        V3IncidentsPinnedMessage,
        V3IncidentsPinnedMessageTypedDict,
    )
    from .v3_incidents_postmortems_createpostmortemrequest import (
        V3IncidentsPostmortemsCreatePostmortemRequest,
        V3IncidentsPostmortemsCreatePostmortemRequestTypedDict,
    )
    from .v3_incidents_postmortems_postmortemattachmentrequest import (
        V3IncidentsPostmortemsPostmortemAttachmentRequest,
        V3IncidentsPostmortemsPostmortemAttachmentRequestTypedDict,
    )
    from .v3_incidents_postmortems_postmortemfollowup import (
        V3IncidentsPostmortemsPostmortemFollowUp,
        V3IncidentsPostmortemsPostmortemFollowUpTypedDict,
    )
    from .v3_incidents_postmortems_postmortemlistresult import (
        V3IncidentsPostmortemsPostmortemListResult,
        V3IncidentsPostmortemsPostmortemListResultIncident,
        V3IncidentsPostmortemsPostmortemListResultIncidentTypedDict,
        V3IncidentsPostmortemsPostmortemListResultTypedDict,
    )
    from .v3_incidents_postmortems_postmortemresponse import (
        V3IncidentsPostmortemsPostmortemResponse,
        V3IncidentsPostmortemsPostmortemResponseIncident,
        V3IncidentsPostmortemsPostmortemResponseIncidentTypedDict,
        V3IncidentsPostmortemsPostmortemResponseTypedDict,
    )
    from .v3_incidents_postmortems_postmortemstatus import (
        V3IncidentsPostmortemsPostmortemStatus,
    )
    from .v3_incidents_postmortems_totalpostmortemcount import (
        V3IncidentsPostmortemsTotalPostmortemCount,
        V3IncidentsPostmortemsTotalPostmortemCountTypedDict,
    )
    from .v3_incidents_postmortems_updatepostmortemrequest import (
        V3IncidentsPostmortemsUpdatePostmortemRequest,
        V3IncidentsPostmortemsUpdatePostmortemRequestTypedDict,
    )
    from .v3_incidents_reassignincidentrequest import (
        ReassignTo,
        ReassignToTypedDict,
        V3IncidentsReassignIncidentRequest,
        V3IncidentsReassignIncidentRequestTypedDict,
    )
    from .v3_incidents_relevantpeoplelog import (
        V3IncidentsRelevantPeopleLog,
        V3IncidentsRelevantPeopleLogTypedDict,
    )
    from .v3_incidents_resolveincidentrequest import (
        ResolutionReason,
        ResolutionReasonTypedDict,
        V3IncidentsResolveIncidentRequest,
        V3IncidentsResolveIncidentRequestTypedDict,
    )
    from .v3_incidents_responsenote import (
        V3IncidentsResponseNote,
        V3IncidentsResponseNoteTypedDict,
    )
    from .v3_incidents_runbooks_attachrunbooksrequest import (
        V3IncidentsRunbooksAttachRunbooksRequest,
        V3IncidentsRunbooksAttachRunbooksRequestTypedDict,
    )
    from .v3_incidents_runbooks_runbookresponse import (
        Step,
        StepTypedDict,
        V3IncidentsRunbooksRunbookResponse,
        V3IncidentsRunbooksRunbookResponseTypedDict,
    )
    from .v3_incidents_serviceownerfilter import (
        V3IncidentsServiceOwnerFilter,
        V3IncidentsServiceOwnerFilterTypedDict,
    )
    from .v3_incidents_snoozedetails import (
        V3IncidentsSnoozeDetails,
        V3IncidentsSnoozeDetailsTypedDict,
    )
    from .v3_incidents_snoozenotifications_reassignto import (
        V3IncidentsSnoozeNotificationsReassignTo,
        V3IncidentsSnoozeNotificationsReassignToTypedDict,
    )
    from .v3_incidents_snoozenotifications_snoozeincidentrequest import (
        V3IncidentsSnoozeNotificationsSnoozeIncidentRequest,
        V3IncidentsSnoozeNotificationsSnoozeIncidentRequestTypedDict,
    )
    from .v3_incidents_snoozenotifications_snoozeincidentresponse import (
        V3IncidentsSnoozeNotificationsSnoozeIncidentResponse,
        V3IncidentsSnoozeNotificationsSnoozeIncidentResponseTypedDict,
    )
    from .v3_incidents_snoozenotifications_unsnoozeincidentrequest import (
        V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequest,
        V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequestTypedDict,
    )
    from .v3_incidents_snoozenotifications_unsnoozeincidentresponse import (
        V3IncidentsSnoozeNotificationsUnsnoozeIncidentResponse,
        V3IncidentsSnoozeNotificationsUnsnoozeIncidentResponseTypedDict,
    )
    from .v3_incidents_tags_additionalresponderdetails import (
        V3IncidentsTagsAdditionalResponderDetails,
        V3IncidentsTagsAdditionalResponderDetailsTypedDict,
    )
    from .v3_incidents_tags_analytics import (
        V3IncidentsTagsAnalytics,
        V3IncidentsTagsAnalyticsTypedDict,
    )
    from .v3_incidents_tags_analyticsmetrics import (
        V3IncidentsTagsAnalyticsMetrics,
        V3IncidentsTagsAnalyticsMetricsTypedDict,
    )
    from .v3_incidents_tags_appendtagrequest import (
        V3IncidentsTagsAppendTagRequest,
        V3IncidentsTagsAppendTagRequestTags,
        V3IncidentsTagsAppendTagRequestTagsTypedDict,
        V3IncidentsTagsAppendTagRequestTypedDict,
    )
    from .v3_incidents_tags_assignedto import (
        V3IncidentsTagsAssignedTo,
        V3IncidentsTagsAssignedToTypedDict,
    )
    from .v3_incidents_tags_assignto import (
        V3IncidentsTagsAssignTo,
        V3IncidentsTagsAssignToTypedDict,
    )
    from .v3_incidents_tags_dedupdata import (
        V3IncidentsTagsDedupData,
        V3IncidentsTagsDedupDataTypedDict,
    )
    from .v3_incidents_tags_incidentfortagsresponse import (
        V3IncidentsTagsIncidentForTagsResponse,
        V3IncidentsTagsIncidentForTagsResponseRetriggerPolicy,
        V3IncidentsTagsIncidentForTagsResponseRetriggerPolicyTypedDict,
        V3IncidentsTagsIncidentForTagsResponseTags,
        V3IncidentsTagsIncidentForTagsResponseTagsTypedDict,
        V3IncidentsTagsIncidentForTagsResponseTypedDict,
    )
    from .v3_incidents_tags_incidentpriority import V3IncidentsTagsIncidentPriority
    from .v3_incidents_tags_logs import (
        V3IncidentsTagsLogs,
        V3IncidentsTagsLogsAdditionalInfo,
        V3IncidentsTagsLogsAdditionalInfoTypedDict,
        V3IncidentsTagsLogsTypedDict,
    )
    from .v3_incidents_tags_mergeincidententityreference import (
        V3IncidentsTagsMergeIncidentEntityReference,
        V3IncidentsTagsMergeIncidentEntityReferenceTypedDict,
    )
    from .v3_incidents_tags_notificationdelaypolicy import (
        V3IncidentsTagsNotificationDelayPolicy,
        V3IncidentsTagsNotificationDelayPolicyTypedDict,
    )
    from .v3_incidents_tags_pinnedmessage import (
        V3IncidentsTagsPinnedMessage,
        V3IncidentsTagsPinnedMessageTypedDict,
    )
    from .v3_incidents_tags_relevantpeoplelog import (
        V3IncidentsTagsRelevantPeopleLog,
        V3IncidentsTagsRelevantPeopleLogTypedDict,
    )
    from .v3_incidents_tags_responsenote import (
        V3IncidentsTagsResponseNote,
        V3IncidentsTagsResponseNoteTypedDict,
    )
    from .v3_incidents_tags_snoozedetails import (
        V3IncidentsTagsSnoozeDetails,
        V3IncidentsTagsSnoozeDetailsTypedDict,
    )
    from .v3_incidents_tags_updatetagrequest import (
        V3IncidentsTagsUpdateTagRequest,
        V3IncidentsTagsUpdateTagRequestTags,
        V3IncidentsTagsUpdateTagRequestTagsTypedDict,
        V3IncidentsTagsUpdateTagRequestTypedDict,
    )
    from .v3_runbooks_createrunbookrequest import (
        V3RunbooksCreateRunbookRequest,
        V3RunbooksCreateRunbookRequestTypedDict,
    )
    from .v3_runbooks_runbookresponse import (
        V3RunbooksRunbookResponse,
        V3RunbooksRunbookResponseTypedDict,
    )
    from .v3_runbooks_step import V3RunbooksStep, V3RunbooksStepTypedDict
    from .v3_runbooks_updaterunbookrequest import (
        V3RunbooksUpdateRunbookRequest,
        V3RunbooksUpdateRunbookRequestTypedDict,
    )
    from .v3_runbooks_updationinfo import (
        V3RunbooksUpdationInfo,
        V3RunbooksUpdationInfoTypedDict,
    )
    from .v3_services_aptaconfig import (
        V3ServicesAPTAConfig,
        V3ServicesAPTAConfigTypedDict,
    )
    from .v3_services_aptaconfigrequest import (
        V3ServicesAPTAConfigRequest,
        V3ServicesAPTAConfigRequestTypedDict,
    )
    from .v3_services_createservicerequest import (
        V3ServicesCreateServiceRequest,
        V3ServicesCreateServiceRequestTypedDict,
    )
    from .v3_services_dedupinitconfig import (
        V3ServicesDedupInitConfig,
        V3ServicesDedupInitConfigTimeUnit,
        V3ServicesDedupInitConfigTypedDict,
    )
    from .v3_services_deduplicationrules_creatededuplicationrulesrequest import (
        V3ServicesDeduplicationRulesCreateDeduplicationRulesRequest,
        V3ServicesDeduplicationRulesCreateDeduplicationRulesRequestTypedDict,
    )
    from .v3_services_deduplicationrules_deduplicationrule import (
        V3ServicesDeduplicationRulesDeduplicationRule,
        V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit,
        V3ServicesDeduplicationRulesDeduplicationRuleTypedDict,
    )
    from .v3_services_deduplicationrules_deduplicationruleresponse import (
        V3ServicesDeduplicationRulesDeduplicationRuleResponse,
        V3ServicesDeduplicationRulesDeduplicationRuleResponseTimeUnit,
        V3ServicesDeduplicationRulesDeduplicationRuleResponseTypedDict,
    )
    from .v3_services_deduplicationrules_expressionbranch import (
        V3ServicesDeduplicationRulesExpressionBranch,
        V3ServicesDeduplicationRulesExpressionBranchOp,
        V3ServicesDeduplicationRulesExpressionBranchRHS,
        V3ServicesDeduplicationRulesExpressionBranchRHSTypedDict,
        V3ServicesDeduplicationRulesExpressionBranchTypedDict,
    )
    from .v3_services_dependencies_createorupdatedependenciesrequest import (
        V3ServicesDependenciesCreateOrUpdateDependenciesRequest,
        V3ServicesDependenciesCreateOrUpdateDependenciesRequestTypedDict,
    )
    from .v3_services_escalationpolicybasic import (
        V3ServicesEscalationPolicyBasic,
        V3ServicesEscalationPolicyBasicTypedDict,
    )
    from .v3_services_extensions_slackextensionresponse import (
        V3ServicesExtensionsSlackExtensionResponse,
        V3ServicesExtensionsSlackExtensionResponseTypedDict,
    )
    from .v3_services_extensions_updateslackextensionrequest import (
        V3ServicesExtensionsUpdateSlackExtensionRequest,
        V3ServicesExtensionsUpdateSlackExtensionRequestTypedDict,
    )
    from .v3_services_iagconfig import V3ServicesIAGConfig, V3ServicesIAGConfigTypedDict
    from .v3_services_iagconfigrequest import (
        V3ServicesIAGConfigRequest,
        V3ServicesIAGConfigRequestTypedDict,
    )
    from .v3_services_jiracloudextension import (
        V3ServicesJiraCloudExtension,
        V3ServicesJiraCloudExtensionTypedDict,
    )
    from .v3_services_jiraissuetype import (
        V3ServicesJiraIssueType,
        V3ServicesJiraIssueTypeTypedDict,
    )
    from .v3_services_jiraproject import (
        V3ServicesJiraProject,
        V3ServicesJiraProjectTypedDict,
    )
    from .v3_services_jirastatus import (
        V3ServicesJiraStatus,
        V3ServicesJiraStatusTypedDict,
    )
    from .v3_services_jirastatusmap import (
        V3ServicesJiraStatusMap,
        V3ServicesJiraStatusMapTypedDict,
    )
    from .v3_services_maintenancemode_createorupdatemaintenancemoderequest import (
        V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest,
        V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict,
    )
    from .v3_services_maintenancemode_maintenancemoderesponse import (
        V3ServicesMaintenanceModeMaintenanceModeResponse,
        V3ServicesMaintenanceModeMaintenanceModeResponseTypedDict,
    )
    from .v3_services_maintenancemode_servicemaintenance import (
        V3ServicesMaintenanceModeServiceMaintenance,
        V3ServicesMaintenanceModeServiceMaintenanceTypedDict,
    )
    from .v3_services_notificationdelayconfig import (
        V3ServicesNotificationDelayConfig,
        V3ServicesNotificationDelayConfigAssignedTo,
        V3ServicesNotificationDelayConfigAssignedToTypedDict,
        V3ServicesNotificationDelayConfigCustomTimeslots,
        V3ServicesNotificationDelayConfigCustomTimeslotsTypedDict,
        V3ServicesNotificationDelayConfigFixedTimeslotConfig,
        V3ServicesNotificationDelayConfigFixedTimeslotConfigTypedDict,
        V3ServicesNotificationDelayConfigTypedDict,
    )
    from .v3_services_notificationdelayconfigrequest import (
        V3ServicesNotificationDelayConfigRequest,
        V3ServicesNotificationDelayConfigRequestAssignedTo,
        V3ServicesNotificationDelayConfigRequestAssignedToTypedDict,
        V3ServicesNotificationDelayConfigRequestCustomTimeslots,
        V3ServicesNotificationDelayConfigRequestCustomTimeslotsTypedDict,
        V3ServicesNotificationDelayConfigRequestFixedTimeslotConfig,
        V3ServicesNotificationDelayConfigRequestFixedTimeslotConfigTypedDict,
        V3ServicesNotificationDelayConfigRequestTypedDict,
    )
    from .v3_services_overlay_customcontent import (
        V3ServicesOverlayCustomContent,
        V3ServicesOverlayCustomContentTypedDict,
    )
    from .v3_services_overlay_customcontentoverlayresponse import (
        V3ServicesOverlayCustomContentOverlayResponse,
        V3ServicesOverlayCustomContentOverlayResponseOverlayTemplateType,
        V3ServicesOverlayCustomContentOverlayResponseTypedDict,
    )
    from .v3_services_overlay_dedupkeyoverlay import (
        V3ServicesOverlayDedupKeyOverlay,
        V3ServicesOverlayDedupKeyOverlayTypedDict,
    )
    from .v3_services_overlay_optinforkeybaseddeduplicationrequest import (
        V3ServicesOverlayOptInForKeyBasedDeduplicationRequest,
        V3ServicesOverlayOptInForKeyBasedDeduplicationRequestTypedDict,
    )
    from .v3_services_overlay_overlayresponse import (
        V3ServicesOverlayOverlayResponse,
        V3ServicesOverlayOverlayResponseOverlayTemplateType,
        V3ServicesOverlayOverlayResponseTypedDict,
    )
    from .v3_services_overlay_rendercustomcontentoverlayrequest import (
        V3ServicesOverlayRenderCustomContentOverlayRequest,
        V3ServicesOverlayRenderCustomContentOverlayRequestTypedDict,
    )
    from .v3_services_overlay_renderdedupkeytemplaterequest import (
        V3ServicesOverlayRenderDedupKeyTemplateRequest,
        V3ServicesOverlayRenderDedupKeyTemplateRequestTypedDict,
    )
    from .v3_services_overlay_updatecustomcontenttemplateoverlayrequest import (
        DescriptionOverlay,
        DescriptionOverlayTypedDict,
        MessageOverlay,
        MessageOverlayTypedDict,
        V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest,
        V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict,
    )
    from .v3_services_overlay_updatededupkeyoverlayrequest import (
        DedupKeyOverlay,
        DedupKeyOverlayTypedDict,
        V3ServicesOverlayUpdateDedupKeyOverlayRequest,
        V3ServicesOverlayUpdateDedupKeyOverlayRequestTypedDict,
    )
    from .v3_services_routingrules_createorupdateroutingrulesrequest import (
        V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequest,
        V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequestTypedDict,
    )
    from .v3_services_routingrules_expressionbranch import (
        V3ServicesRoutingRulesExpressionBranch,
        V3ServicesRoutingRulesExpressionBranchOp,
        V3ServicesRoutingRulesExpressionBranchRHS,
        V3ServicesRoutingRulesExpressionBranchRHSTypedDict,
        V3ServicesRoutingRulesExpressionBranchTypedDict,
    )
    from .v3_services_routingrules_routingrule import (
        V3ServicesRoutingRulesRoutingRule,
        V3ServicesRoutingRulesRoutingRuleEntityType,
        V3ServicesRoutingRulesRoutingRuleRouteTo,
        V3ServicesRoutingRulesRoutingRuleRouteToTypedDict,
        V3ServicesRoutingRulesRoutingRuleTypedDict,
    )
    from .v3_services_routingrules_routingruleresponse import (
        V3ServicesRoutingRulesRoutingRuleResponse,
        V3ServicesRoutingRulesRoutingRuleResponseEntityType,
        V3ServicesRoutingRulesRoutingRuleResponseRouteTo,
        V3ServicesRoutingRulesRoutingRuleResponseRouteToTypedDict,
        V3ServicesRoutingRulesRoutingRuleResponseTypedDict,
    )
    from .v3_services_servicemaintainer import (
        V3ServicesServiceMaintainer,
        V3ServicesServiceMaintainerType,
        V3ServicesServiceMaintainerTypedDict,
    )
    from .v3_services_serviceresponse import (
        Config,
        ConfigTypedDict,
        V3ServicesServiceResponse,
        V3ServicesServiceResponseTypedDict,
    )
    from .v3_services_serviceslack import (
        V3ServicesServiceSlack,
        V3ServicesServiceSlackTypedDict,
    )
    from .v3_services_servicetag import (
        V3ServicesServiceTag,
        V3ServicesServiceTagTypedDict,
    )
    from .v3_services_suppressionrules_basicexpression import (
        V3ServicesSuppressionRulesBasicExpression,
        V3ServicesSuppressionRulesBasicExpressionTypedDict,
    )
    from .v3_services_suppressionrules_createorupdatesuppressionrulesrequest import (
        V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequest,
        V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict,
    )
    from .v3_services_suppressionrules_customrepetition import (
        V3ServicesSuppressionRulesCustomRepetition,
        V3ServicesSuppressionRulesCustomRepetitionTypedDict,
    )
    from .v3_services_suppressionrules_suppressionrule import (
        V3ServicesSuppressionRulesSuppressionRule,
        V3ServicesSuppressionRulesSuppressionRuleTypedDict,
    )
    from .v3_services_suppressionrules_suppressionruleresponse import (
        V3ServicesSuppressionRulesSuppressionRuleResponse,
        V3ServicesSuppressionRulesSuppressionRuleResponseTypedDict,
    )
    from .v3_services_suppressionrules_suppressionrulescontainerresponse import (
        V3ServicesSuppressionRulesSuppressionRulesContainerResponse,
        V3ServicesSuppressionRulesSuppressionRulesContainerResponseTypedDict,
    )
    from .v3_services_suppressionrules_timeslot import (
        V3ServicesSuppressionRulesTimeslot,
        V3ServicesSuppressionRulesTimeslotTypedDict,
    )
    from .v3_services_taggingrules_createorupdatetaggingrulesrequest import (
        V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest,
        V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict,
    )
    from .v3_services_taggingrules_expressionbranch import (
        V3ServicesTaggingRulesExpressionBranch,
        V3ServicesTaggingRulesExpressionBranchOp,
        V3ServicesTaggingRulesExpressionBranchRHS,
        V3ServicesTaggingRulesExpressionBranchRHSTypedDict,
        V3ServicesTaggingRulesExpressionBranchTypedDict,
    )
    from .v3_services_taggingrules_tagconfigobject import (
        V3ServicesTaggingRulesTagConfigObject,
        V3ServicesTaggingRulesTagConfigObjectTypedDict,
    )
    from .v3_services_taggingrules_taggingruleresponse import (
        V3ServicesTaggingRulesTaggingRuleResponse,
        V3ServicesTaggingRulesTaggingRuleResponseTypedDict,
    )
    from .v3_services_taggingrules_tagrule import (
        V3ServicesTaggingRulesTagRule,
        V3ServicesTaggingRulesTagRuleTypedDict,
    )
    from .v3_services_taggingrules_tagsobject import (
        V3ServicesTaggingRulesTagsObject,
        V3ServicesTaggingRulesTagsObjectTypedDict,
    )
    from .v3_services_updateservicerequest import (
        V3ServicesUpdateServiceRequest,
        V3ServicesUpdateServiceRequestTypedDict,
    )
    from .v3_slo_createslorequest import (
        V3SLOCreateSLORequest,
        V3SLOCreateSLORequestTags,
        V3SLOCreateSLORequestTagsTypedDict,
        V3SLOCreateSLORequestTypedDict,
    )
    from .v3_slo_marksloaffectedrequest import (
        V3SLOMarkSLOAffectedRequest,
        V3SLOMarkSLOAffectedRequestTypedDict,
    )
    from .v3_slo_slo import (
        V3SLOSLOTags,
        V3SLOSLOTagsTypedDict,
        V3SloSlo,
        V3SloSloTypedDict,
    )
    from .v3_slo_sloaction import V3SLOSLOAction, V3SLOSLOActionTypedDict
    from .v3_slo_sloactiontype import V3SLOSLOActionType
    from .v3_slo_slodetailedresponse import (
        V3SLOSLODetailedResponse,
        V3SLOSLODetailedResponseTags,
        V3SLOSLODetailedResponseTagsTypedDict,
        V3SLOSLODetailedResponseTypedDict,
    )
    from .v3_slo_slomonitoringcheck import (
        V3SLOSLOMonitoringCheck,
        V3SLOSLOMonitoringCheckTypedDict,
    )
    from .v3_slo_sloownertype import V3SLOSLOOwnerType
    from .v3_slo_sloresponse import (
        V3SLOSLOResponse,
        V3SLOSLOResponseTags,
        V3SLOSLOResponseTagsTypedDict,
        V3SLOSLOResponseTypedDict,
    )
    from .v3_slo_sloviolatingincidentresponse import (
        V3SLOSLOViolatingIncidentResponse,
        V3SLOSLOViolatingIncidentResponseTypedDict,
    )
    from .v3_slo_slowithinsightsresponse import (
        Insights,
        InsightsTypedDict,
        V3SLOSLOWithInsightsResponse,
        V3SLOSLOWithInsightsResponseTypedDict,
    )
    from .v3_slo_timeintervaltype import V3SLOTimeIntervalType
    from .v3_teams_abilities import (
        EscalationPolicies,
        EscalationPoliciesTypedDict,
        Ger,
        GerTypedDict,
        GlobalOncallReminderRules,
        GlobalOncallReminderRulesTypedDict,
        Postmortems,
        PostmortemsTypedDict,
        RoutingNumbers,
        RoutingNumbersTypedDict,
        Runbooks,
        RunbooksTypedDict,
        Schedules,
        SchedulesTypedDict,
        Services,
        ServicesTypedDict,
        Slos,
        SlosTypedDict,
        Squads,
        SquadsTypedDict,
        StakeholderGroups,
        StakeholderGroupsTypedDict,
        StatusPages,
        StatusPagesTypedDict,
        TeamAnalytics,
        TeamAnalyticsTypedDict,
        V3TeamsAbilities,
        V3TeamsAbilitiesTypedDict,
        Webforms,
        WebformsTypedDict,
        Workflows,
        WorkflowsTypedDict,
    )
    from .v3_teams_addbulkteammemberrequest import (
        V3TeamsAddBulkTeamMemberRequest,
        V3TeamsAddBulkTeamMemberRequestMember,
        V3TeamsAddBulkTeamMemberRequestMemberTypedDict,
        V3TeamsAddBulkTeamMemberRequestTypedDict,
    )
    from .v3_teams_addteammemberrequest import (
        V3TeamsAddTeamMemberRequest,
        V3TeamsAddTeamMemberRequestTypedDict,
    )
    from .v3_teams_createteamrequest import (
        V3TeamsCreateTeamRequest,
        V3TeamsCreateTeamRequestTypedDict,
    )
    from .v3_teams_createteamrolerequest import (
        V3TeamsCreateTeamRoleRequest,
        V3TeamsCreateTeamRoleRequestTypedDict,
    )
    from .v3_teams_teambaseresponse import (
        V3TeamsTeamBaseResponse,
        V3TeamsTeamBaseResponseTypedDict,
    )
    from .v3_teams_teammember import V3TeamsTeamMember, V3TeamsTeamMemberTypedDict
    from .v3_teams_teammemberresponse import (
        V3TeamsTeamMemberResponse,
        V3TeamsTeamMemberResponseTypedDict,
    )
    from .v3_teams_teamresponse import (
        Organization,
        OrganizationTypedDict,
        V3TeamsTeamResponse,
        V3TeamsTeamResponseTypedDict,
    )
    from .v3_teams_teamrole import V3TeamsTeamRole, V3TeamsTeamRoleTypedDict
    from .v3_teams_teamroleresponse import (
        V3TeamsTeamRoleResponse,
        V3TeamsTeamRoleResponseTypedDict,
    )
    from .v3_teams_updateteammemberrequest import (
        V3TeamsUpdateTeamMemberRequest,
        V3TeamsUpdateTeamMemberRequestTypedDict,
    )
    from .v3_teams_updateteamrequest import (
        V3TeamsUpdateTeamRequest,
        V3TeamsUpdateTeamRequestMember,
        V3TeamsUpdateTeamRequestMemberTypedDict,
        V3TeamsUpdateTeamRequestTypedDict,
    )
    from .v3_teams_updateteamrolerequest import (
        V3TeamsUpdateTeamRoleRequest,
        V3TeamsUpdateTeamRoleRequestTypedDict,
    )
    from .v3_users_adduserrequest import (
        V3UsersAddUserRequest,
        V3UsersAddUserRequestRole,
        V3UsersAddUserRequestTypedDict,
    )
    from .v3_users_apitokenresponse import (
        V3UsersAPITokenResponse,
        V3UsersAPITokenResponseTypedDict,
    )
    from .v3_users_contact import V3UsersContact, V3UsersContactTypedDict
    from .v3_users_globalrbacabilityname import V3UsersGlobalRBACAbilityName
    from .v3_users_notificationrule import (
        V3UsersNotificationRule,
        V3UsersNotificationRuleTypedDict,
    )
    from .v3_users_updateuserabilitiesrequest import (
        V3UsersUpdateUserAbilitiesRequest,
        V3UsersUpdateUserAbilitiesRequestData,
        V3UsersUpdateUserAbilitiesRequestDataTypedDict,
        V3UsersUpdateUserAbilitiesRequestTypedDict,
    )
    from .v3_users_updateuserrequest import (
        V3UsersUpdateUserRequest,
        V3UsersUpdateUserRequestRole,
        V3UsersUpdateUserRequestTypedDict,
    )
    from .v3_users_userresponse import V3UsersUserResponse, V3UsersUserResponseTypedDict
    from .v3_users_userroleresponse import (
        V3UsersUserRoleResponse,
        V3UsersUserRoleResponseTypedDict,
    )
    from .v3_webforms_createorupdatewebformrequest import (
        V3WebformsCreateOrUpdateWebformRequest,
        V3WebformsCreateOrUpdateWebformRequestTags,
        V3WebformsCreateOrUpdateWebformRequestTagsTypedDict,
        V3WebformsCreateOrUpdateWebformRequestTypedDict,
    )
    from .v3_webforms_recaptchasecrets import (
        V3WebformsRecaptchaSecrets,
        V3WebformsRecaptchaSecretsTypedDict,
    )
    from .v3_webforms_webformresponse import (
        V3WebformsWebformResponse,
        V3WebformsWebformResponseTags,
        V3WebformsWebformResponseTagsTypedDict,
        V3WebformsWebformResponseTypedDict,
    )
    from .v3_webforms_wfinputfield import (
        V3WebformsWFInputField,
        V3WebformsWFInputFieldTypedDict,
    )
    from .v3_webforms_wfservice import V3WebformsWFService, V3WebformsWFServiceTypedDict
    from .v3_workflows_actionrequest import (
        V3WorkflowsActionRequest,
        V3WorkflowsActionRequestData,
        V3WorkflowsActionRequestDataTypedDict,
        V3WorkflowsActionRequestName,
        V3WorkflowsActionRequestSqAttachRunbooks,
        V3WorkflowsActionRequestSqAttachRunbooksTypedDict,
        V3WorkflowsActionRequestTypedDict,
    )
    from .v3_workflows_actionrequestupdate import (
        V3WorkflowsActionRequestUpdate,
        V3WorkflowsActionRequestUpdateData,
        V3WorkflowsActionRequestUpdateDataTypedDict,
        V3WorkflowsActionRequestUpdateName,
        V3WorkflowsActionRequestUpdateSqAttachRunbooks,
        V3WorkflowsActionRequestUpdateSqAttachRunbooksTypedDict,
        V3WorkflowsActionRequestUpdateTypedDict,
    )
    from .v3_workflows_actionresponse import (
        V3WorkflowsActionResponse,
        V3WorkflowsActionResponseData,
        V3WorkflowsActionResponseDataTypedDict,
        V3WorkflowsActionResponseName,
        V3WorkflowsActionResponseSqAttachRunbooks,
        V3WorkflowsActionResponseSqAttachRunbooksTypedDict,
        V3WorkflowsActionResponseTypedDict,
    )
    from .v3_workflows_bulkenabledisableworkflowsrequest import (
        V3WorkflowsBulkEnableDisableWorkflowsRequest,
        V3WorkflowsBulkEnableDisableWorkflowsRequestTypedDict,
    )
    from .v3_workflows_communicationchannel import (
        V3WorkflowsCommunicationChannel,
        V3WorkflowsCommunicationChannelType,
        V3WorkflowsCommunicationChannelTypedDict,
    )
    from .v3_workflows_componentandimpact import (
        V3WorkflowsComponentAndImpact,
        V3WorkflowsComponentAndImpactTypedDict,
    )
    from .v3_workflows_createworkflowfilter import (
        Entity,
        EntityTypedDict,
        V3WorkflowsCreateWorkflowFilter,
        V3WorkflowsCreateWorkflowFilterTypedDict,
    )
    from .v3_workflows_createworkflowrequest import (
        V3WorkflowsCreateWorkflowRequest,
        V3WorkflowsCreateWorkflowRequestOwnerType,
        V3WorkflowsCreateWorkflowRequestTypedDict,
    )
    from .v3_workflows_createworkflowrequestupdate import (
        V3WorkflowsCreateWorkflowRequestUpdate,
        V3WorkflowsCreateWorkflowRequestUpdateOwnerType,
        V3WorkflowsCreateWorkflowRequestUpdateTypedDict,
    )
    from .v3_workflows_enabledisableworkflowrequest import (
        V3WorkflowsEnableDisableWorkflowRequest,
        V3WorkflowsEnableDisableWorkflowRequestTypedDict,
    )
    from .v3_workflows_entityowner import (
        V3WorkflowsEntityOwner,
        V3WorkflowsEntityOwnerTypedDict,
    )
    from .v3_workflows_entityownerupdate import (
        V3WorkflowsEntityOwnerUpdate,
        V3WorkflowsEntityOwnerUpdateTypedDict,
    )
    from .v3_workflows_getworkflowactionbyidresponse import (
        V3WorkflowsGetWorkflowActionByIDResponse,
        V3WorkflowsGetWorkflowActionByIDResponseTypedDict,
    )
    from .v3_workflows_getworkflowbyidresponse import (
        V3WorkflowsGetWorkflowByIDResponse,
        V3WorkflowsGetWorkflowByIDResponseTypedDict,
    )
    from .v3_workflows_getworkflowlogsresponse import (
        StatusEnum,
        V3WorkflowsGetWorkflowLogsResponse,
        V3WorkflowsGetWorkflowLogsResponseData,
        V3WorkflowsGetWorkflowLogsResponseDataTypedDict,
        V3WorkflowsGetWorkflowLogsResponseMeta,
        V3WorkflowsGetWorkflowLogsResponseMetaTypedDict,
        V3WorkflowsGetWorkflowLogsResponseTypedDict,
    )
    from .v3_workflows_issuestatusandmessage import (
        V3WorkflowsIssueStatusAndMessage,
        V3WorkflowsIssueStatusAndMessageTypedDict,
    )
    from .v3_workflows_jiracreateticket import (
        V3WorkflowsJiraCreateTicket,
        V3WorkflowsJiraCreateTicketData,
        V3WorkflowsJiraCreateTicketDataTypedDict,
        V3WorkflowsJiraCreateTicketName,
        V3WorkflowsJiraCreateTicketTypedDict,
    )
    from .v3_workflows_jiracreateticketupdate import (
        V3WorkflowsJiraCreateTicketUpdate,
        V3WorkflowsJiraCreateTicketUpdateData,
        V3WorkflowsJiraCreateTicketUpdateDataTypedDict,
        V3WorkflowsJiraCreateTicketUpdateName,
        V3WorkflowsJiraCreateTicketUpdateTypedDict,
    )
    from .v3_workflows_listworkflowapiresponse import (
        ACL,
        ACLTypedDict,
        V3WorkflowsListWorkflowAPIResponse,
        V3WorkflowsListWorkflowAPIResponseMeta,
        V3WorkflowsListWorkflowAPIResponseMetaTypedDict,
        V3WorkflowsListWorkflowAPIResponseTypedDict,
    )
    from .v3_workflows_msteamscreatemeetinglink import (
        V3WorkflowsMsTeamsCreateMeetingLink,
        V3WorkflowsMsTeamsCreateMeetingLinkName,
        V3WorkflowsMsTeamsCreateMeetingLinkTypedDict,
    )
    from .v3_workflows_msteamscreatemeetinglinkupdate import (
        V3WorkflowsMsTeamsCreateMeetingLinkUpdate,
        V3WorkflowsMsTeamsCreateMeetingLinkUpdateName,
        V3WorkflowsMsTeamsCreateMeetingLinkUpdateTypedDict,
    )
    from .v3_workflows_msteamsmessagechannel import (
        V3WorkflowsMsTeamsMessageChannel,
        V3WorkflowsMsTeamsMessageChannelData,
        V3WorkflowsMsTeamsMessageChannelDataTypedDict,
        V3WorkflowsMsTeamsMessageChannelName,
        V3WorkflowsMsTeamsMessageChannelTypedDict,
    )
    from .v3_workflows_msteamsmessagechannelupdate import (
        V3WorkflowsMsTeamsMessageChannelUpdate,
        V3WorkflowsMsTeamsMessageChannelUpdateData,
        V3WorkflowsMsTeamsMessageChannelUpdateDataTypedDict,
        V3WorkflowsMsTeamsMessageChannelUpdateName,
        V3WorkflowsMsTeamsMessageChannelUpdateTypedDict,
    )
    from .v3_workflows_msteamsmessageuser import (
        V3WorkflowsMsTeamsMessageUser,
        V3WorkflowsMsTeamsMessageUserData,
        V3WorkflowsMsTeamsMessageUserDataTypedDict,
        V3WorkflowsMsTeamsMessageUserName,
        V3WorkflowsMsTeamsMessageUserTypedDict,
    )
    from .v3_workflows_msteamsmessageuserupdate import (
        V3WorkflowsMsTeamsMessageUserUpdate,
        V3WorkflowsMsTeamsMessageUserUpdateData,
        V3WorkflowsMsTeamsMessageUserUpdateDataTypedDict,
        V3WorkflowsMsTeamsMessageUserUpdateName,
        V3WorkflowsMsTeamsMessageUserUpdateTypedDict,
    )
    from .v3_workflows_runbookresponse import (
        V3WorkflowsRunbookResponse,
        V3WorkflowsRunbookResponseTypedDict,
    )
    from .v3_workflows_slackarchivechannel import (
        V3WorkflowsSlackArchiveChannel,
        V3WorkflowsSlackArchiveChannelName,
        V3WorkflowsSlackArchiveChannelTypedDict,
    )
    from .v3_workflows_slackarchivechannelupdate import (
        V3WorkflowsSlackArchiveChannelUpdate,
        V3WorkflowsSlackArchiveChannelUpdateName,
        V3WorkflowsSlackArchiveChannelUpdateTypedDict,
    )
    from .v3_workflows_slackcreateincidentchannel import (
        V3WorkflowsSlackCreateIncidentChannel,
        V3WorkflowsSlackCreateIncidentChannelData,
        V3WorkflowsSlackCreateIncidentChannelDataTypedDict,
        V3WorkflowsSlackCreateIncidentChannelName,
        V3WorkflowsSlackCreateIncidentChannelTypedDict,
    )
    from .v3_workflows_slackcreateincidentchannelupdate import (
        V3WorkflowsSlackCreateIncidentChannelUpdate,
        V3WorkflowsSlackCreateIncidentChannelUpdateData,
        V3WorkflowsSlackCreateIncidentChannelUpdateDataTypedDict,
        V3WorkflowsSlackCreateIncidentChannelUpdateName,
        V3WorkflowsSlackCreateIncidentChannelUpdateTypedDict,
    )
    from .v3_workflows_slackmessagechannel import (
        V3WorkflowsSlackMessageChannel,
        V3WorkflowsSlackMessageChannelData,
        V3WorkflowsSlackMessageChannelDataTypedDict,
        V3WorkflowsSlackMessageChannelName,
        V3WorkflowsSlackMessageChannelTypedDict,
    )
    from .v3_workflows_slackmessagechannelupdate import (
        V3WorkflowsSlackMessageChannelUpdate,
        V3WorkflowsSlackMessageChannelUpdateData,
        V3WorkflowsSlackMessageChannelUpdateDataTypedDict,
        V3WorkflowsSlackMessageChannelUpdateName,
        V3WorkflowsSlackMessageChannelUpdateTypedDict,
    )
    from .v3_workflows_slackmessageuser import (
        V3WorkflowsSlackMessageUser,
        V3WorkflowsSlackMessageUserData,
        V3WorkflowsSlackMessageUserDataTypedDict,
        V3WorkflowsSlackMessageUserName,
        V3WorkflowsSlackMessageUserTypedDict,
    )
    from .v3_workflows_slackmessageuserupdate import (
        V3WorkflowsSlackMessageUserUpdate,
        V3WorkflowsSlackMessageUserUpdateData,
        V3WorkflowsSlackMessageUserUpdateDataTypedDict,
        V3WorkflowsSlackMessageUserUpdateName,
        V3WorkflowsSlackMessageUserUpdateTypedDict,
    )
    from .v3_workflows_sqaddcommunicationchannel import (
        V3WorkflowsSqAddCommunicationChannel,
        V3WorkflowsSqAddCommunicationChannelData,
        V3WorkflowsSqAddCommunicationChannelDataTypedDict,
        V3WorkflowsSqAddCommunicationChannelName,
        V3WorkflowsSqAddCommunicationChannelTypedDict,
    )
    from .v3_workflows_sqaddcommunicationchannelupdate import (
        V3WorkflowsSqAddCommunicationChannelUpdate,
        V3WorkflowsSqAddCommunicationChannelUpdateData,
        V3WorkflowsSqAddCommunicationChannelUpdateDataTypedDict,
        V3WorkflowsSqAddCommunicationChannelUpdateName,
        V3WorkflowsSqAddCommunicationChannelUpdateTypedDict,
    )
    from .v3_workflows_sqaddincidentnote import (
        V3WorkflowsSqAddIncidentNote,
        V3WorkflowsSqAddIncidentNoteData,
        V3WorkflowsSqAddIncidentNoteDataTypedDict,
        V3WorkflowsSqAddIncidentNoteName,
        V3WorkflowsSqAddIncidentNoteTypedDict,
    )
    from .v3_workflows_sqaddincidentnoteupdate import (
        V3WorkflowsSqAddIncidentNoteUpdate,
        V3WorkflowsSqAddIncidentNoteUpdateData,
        V3WorkflowsSqAddIncidentNoteUpdateDataTypedDict,
        V3WorkflowsSqAddIncidentNoteUpdateName,
        V3WorkflowsSqAddIncidentNoteUpdateTypedDict,
    )
    from .v3_workflows_sqcreatestatuspageissue import (
        V3WorkflowsSqCreateStatusPageIssue,
        V3WorkflowsSqCreateStatusPageIssueData,
        V3WorkflowsSqCreateStatusPageIssueDataTypedDict,
        V3WorkflowsSqCreateStatusPageIssueName,
        V3WorkflowsSqCreateStatusPageIssueTypedDict,
    )
    from .v3_workflows_sqcreatestatuspageissueupdate import (
        V3WorkflowsSqCreateStatusPageIssueUpdate,
        V3WorkflowsSqCreateStatusPageIssueUpdateData,
        V3WorkflowsSqCreateStatusPageIssueUpdateDataTypedDict,
        V3WorkflowsSqCreateStatusPageIssueUpdateName,
        V3WorkflowsSqCreateStatusPageIssueUpdateTypedDict,
    )
    from .v3_workflows_sqmakehttpcall import (
        V3WorkflowsSqMakeHTTPCall,
        V3WorkflowsSqMakeHTTPCallData,
        V3WorkflowsSqMakeHTTPCallDataTypedDict,
        V3WorkflowsSqMakeHTTPCallHeader,
        V3WorkflowsSqMakeHTTPCallHeaderTypedDict,
        V3WorkflowsSqMakeHTTPCallMethod,
        V3WorkflowsSqMakeHTTPCallName,
        V3WorkflowsSqMakeHTTPCallTypedDict,
    )
    from .v3_workflows_sqmakehttpcallupdate import (
        V3WorkflowsSqMakeHTTPCallUpdate,
        V3WorkflowsSqMakeHTTPCallUpdateData,
        V3WorkflowsSqMakeHTTPCallUpdateDataTypedDict,
        V3WorkflowsSqMakeHTTPCallUpdateHeader,
        V3WorkflowsSqMakeHTTPCallUpdateHeaderTypedDict,
        V3WorkflowsSqMakeHTTPCallUpdateMethod,
        V3WorkflowsSqMakeHTTPCallUpdateName,
        V3WorkflowsSqMakeHTTPCallUpdateTypedDict,
    )
    from .v3_workflows_sqmarkincidentsloaffecting import (
        V3WorkflowsSqMarkIncidentSLOAffecting,
        V3WorkflowsSqMarkIncidentSLOAffectingData,
        V3WorkflowsSqMarkIncidentSLOAffectingDataTypedDict,
        V3WorkflowsSqMarkIncidentSLOAffectingName,
        V3WorkflowsSqMarkIncidentSLOAffectingTypedDict,
    )
    from .v3_workflows_sqmarkincidentsloaffectingupdate import (
        V3WorkflowsSqMarkIncidentSLOAffectingUpdate,
        V3WorkflowsSqMarkIncidentSLOAffectingUpdateData,
        V3WorkflowsSqMarkIncidentSLOAffectingUpdateDataTypedDict,
        V3WorkflowsSqMarkIncidentSLOAffectingUpdateName,
        V3WorkflowsSqMarkIncidentSLOAffectingUpdateTypedDict,
    )
    from .v3_workflows_sqsendemail import (
        V3WorkflowsSqSendEmail,
        V3WorkflowsSqSendEmailData,
        V3WorkflowsSqSendEmailDataTypedDict,
        V3WorkflowsSqSendEmailName,
        V3WorkflowsSqSendEmailTypedDict,
    )
    from .v3_workflows_sqsendemailupdate import (
        V3WorkflowsSqSendEmailUpdate,
        V3WorkflowsSqSendEmailUpdateData,
        V3WorkflowsSqSendEmailUpdateDataTypedDict,
        V3WorkflowsSqSendEmailUpdateName,
        V3WorkflowsSqSendEmailUpdateTypedDict,
    )
    from .v3_workflows_sqtriggermanualwebhook import (
        V3WorkflowsSqTriggerManualWebhook,
        V3WorkflowsSqTriggerManualWebhookData,
        V3WorkflowsSqTriggerManualWebhookDataTypedDict,
        V3WorkflowsSqTriggerManualWebhookName,
        V3WorkflowsSqTriggerManualWebhookTypedDict,
    )
    from .v3_workflows_sqtriggermanualwebhookupdate import (
        V3WorkflowsSqTriggerManualWebhookUpdate,
        V3WorkflowsSqTriggerManualWebhookUpdateData,
        V3WorkflowsSqTriggerManualWebhookUpdateDataTypedDict,
        V3WorkflowsSqTriggerManualWebhookUpdateName,
        V3WorkflowsSqTriggerManualWebhookUpdateTypedDict,
    )
    from .v3_workflows_tag import V3WorkflowsTag, V3WorkflowsTagTypedDict
    from .v3_workflows_updateactionsorderrequest import (
        V3WorkflowsUpdateActionsOrderRequest,
        V3WorkflowsUpdateActionsOrderRequestTypedDict,
    )
    from .v3_workflows_updateactionsorderresponse import (
        V3WorkflowsUpdateActionsOrderResponse,
        V3WorkflowsUpdateActionsOrderResponseData,
        V3WorkflowsUpdateActionsOrderResponseDataTypedDict,
        V3WorkflowsUpdateActionsOrderResponseTypedDict,
    )
    from .v3_workflows_updateincidentpriority import (
        V3WorkflowsUpdateIncidentPriority,
        V3WorkflowsUpdateIncidentPriorityData,
        V3WorkflowsUpdateIncidentPriorityDataTypedDict,
        V3WorkflowsUpdateIncidentPriorityName,
        V3WorkflowsUpdateIncidentPriorityPriority,
        V3WorkflowsUpdateIncidentPriorityTypedDict,
    )
    from .v3_workflows_updateincidentpriorityupdate import (
        V3WorkflowsUpdateIncidentPriorityUpdate,
        V3WorkflowsUpdateIncidentPriorityUpdateData,
        V3WorkflowsUpdateIncidentPriorityUpdateDataTypedDict,
        V3WorkflowsUpdateIncidentPriorityUpdateName,
        V3WorkflowsUpdateIncidentPriorityUpdatePriority,
        V3WorkflowsUpdateIncidentPriorityUpdateTypedDict,
    )
    from .v3_workflows_updateworkflowapiresponse import (
        V3WorkflowsUpdateWorkflowAPIResponse,
        V3WorkflowsUpdateWorkflowAPIResponseTypedDict,
    )
    from .v3_workflows_workflowapiresponse import (
        V3WorkflowsWorkflowAPIResponse,
        V3WorkflowsWorkflowAPIResponseTypedDict,
    )
    from .v3_workflows_workflowfilters import (
        Condition,
        V3WorkflowsWorkflowFilters,
        V3WorkflowsWorkflowFiltersTypedDict,
    )
    from .v3_workflows_workflowtrigger import V3WorkflowsWorkflowTrigger
    from .v4_changetimezoneresponse import (
        V4ChangeTimezoneResponse,
        V4ChangeTimezoneResponseTypedDict,
    )
    from .v4_createrotationrequest import (
        V4CreateRotationRequest,
        V4CreateRotationRequestTypedDict,
    )
    from .v4_createscheduleoverriderequest import (
        V4CreateScheduleOverrideRequest,
        V4CreateScheduleOverrideRequestTypedDict,
    )
    from .v4_createschedulerequest import (
        V4CreateScheduleRequest,
        V4CreateScheduleRequestOwnerType,
        V4CreateScheduleRequestTypedDict,
    )
    from .v4_getrotationparticipantsresponse import (
        V4GetRotationParticipantsResponse,
        V4GetRotationParticipantsResponseTypedDict,
    )
    from .v4_icallinkresponse import V4ICalLinkResponse, V4ICalLinkResponseTypedDict
    from .v4_overrideparticipantgroup import (
        V4OverrideParticipantGroup,
        V4OverrideParticipantGroupTypedDict,
    )
    from .v4_overrideresponse import V4OverrideResponse, V4OverrideResponseTypedDict
    from .v4_participant import V4Participant, V4ParticipantTypedDict
    from .v4_participantgroup import V4ParticipantGroup, V4ParticipantGroupTypedDict
    from .v4_pauseresumescheduleresponse import (
        V4PauseResumeScheduleResponse,
        V4PauseResumeScheduleResponseTypedDict,
    )
    from .v4_rotationparticipantsresponse import (
        V4RotationParticipantsResponse,
        V4RotationParticipantsResponseTypedDict,
    )
    from .v4_rotationresponse import V4RotationResponse, V4RotationResponseTypedDict
    from .v4_scheduleresponse import (
        V4ScheduleResponse,
        V4ScheduleResponseOwnerType,
        V4ScheduleResponseTypedDict,
    )
    from .v4_shifttimeslot import V4ShiftTimeSlot, V4ShiftTimeSlotTypedDict
    from .v4_squads_createsquadrequest import (
        V4SquadsCreateSquadRequest,
        V4SquadsCreateSquadRequestTypedDict,
    )
    from .v4_squads_createsquadresponse import (
        V4SquadsCreateSquadResponse,
        V4SquadsCreateSquadResponseTypedDict,
    )
    from .v4_squads_removesquadmemberresponse import (
        V4SquadsRemoveSquadMemberResponse,
        V4SquadsRemoveSquadMemberResponseTypedDict,
    )
    from .v4_squads_squadmember import V4SquadsSquadMember, V4SquadsSquadMemberTypedDict
    from .v4_squads_squadresponse import (
        V4SquadsSquadResponse,
        V4SquadsSquadResponseTypedDict,
    )
    from .v4_squads_updatesquadmemberrequest import (
        V4SquadsUpdateSquadMemberRequest,
        V4SquadsUpdateSquadMemberRequestTypedDict,
    )
    from .v4_squads_updatesquadmemberresponse import (
        V4SquadsUpdateSquadMemberResponse,
        V4SquadsUpdateSquadMemberResponseTypedDict,
    )
    from .v4_squads_updatesquadnamerequest import (
        V4SquadsUpdateSquadNameRequest,
        V4SquadsUpdateSquadNameRequestTypedDict,
    )
    from .v4_squads_updatesquadnameresponse import (
        V4SquadsUpdateSquadNameResponse,
        V4SquadsUpdateSquadNameResponseTypedDict,
    )
    from .v4_squads_updatesquadrequest import (
        V4SquadsUpdateSquadRequest,
        V4SquadsUpdateSquadRequestTypedDict,
    )
    from .v4_statuspages_componentgroups_component import (
        V4StatusPagesComponentGroupsComponent,
        V4StatusPagesComponentGroupsComponentTypedDict,
    )
    from .v4_statuspages_componentgroups_componentgroupresponse import (
        V4StatusPagesComponentGroupsComponentGroupResponse,
        V4StatusPagesComponentGroupsComponentGroupResponseTypedDict,
    )
    from .v4_statuspages_componentgroups_componentstatus import (
        V4StatusPagesComponentGroupsComponentStatus,
        V4StatusPagesComponentGroupsComponentStatusTypedDict,
    )
    from .v4_statuspages_componentgroups_createcomponentgrouprequest import (
        V4StatusPagesComponentGroupsCreateComponentGroupRequest,
        V4StatusPagesComponentGroupsCreateComponentGroupRequestTypedDict,
    )
    from .v4_statuspages_componentgroups_createcomponentgroupresponse import (
        V4StatusPagesComponentGroupsCreateComponentGroupResponse,
        V4StatusPagesComponentGroupsCreateComponentGroupResponseTypedDict,
    )
    from .v4_statuspages_componentgroups_deletecomponentgroupbyidresponse import (
        V4StatusPagesComponentGroupsDeleteComponentGroupByIDResponse,
        V4StatusPagesComponentGroupsDeleteComponentGroupByIDResponseTypedDict,
    )
    from .v4_statuspages_componentgroups_getcomponentgroupbyidresponse import (
        V4StatusPagesComponentGroupsGetComponentGroupByIDResponse,
        V4StatusPagesComponentGroupsGetComponentGroupByIDResponseTypedDict,
    )
    from .v4_statuspages_components_component import (
        V4StatusPagesComponentsComponent,
        V4StatusPagesComponentsComponentTypedDict,
    )
    from .v4_statuspages_components_componentstatus import (
        V4StatusPagesComponentsComponentStatus,
        V4StatusPagesComponentsComponentStatusTypedDict,
    )
    from .v4_statuspages_components_createcomponentrequest import (
        V4StatusPagesComponentsCreateComponentRequest,
        V4StatusPagesComponentsCreateComponentRequestTypedDict,
    )
    from .v4_statuspages_components_createcomponentresponse import (
        V4StatusPagesComponentsCreateComponentResponse,
        V4StatusPagesComponentsCreateComponentResponseTypedDict,
    )
    from .v4_statuspages_components_deletecomponentbyidresponse import (
        V4StatusPagesComponentsDeleteComponentByIDResponse,
        V4StatusPagesComponentsDeleteComponentByIDResponseTypedDict,
    )
    from .v4_statuspages_components_getcomponentbyidresponse import (
        V4StatusPagesComponentsGetComponentByIDResponse,
        V4StatusPagesComponentsGetComponentByIDResponseTypedDict,
    )
    from .v4_statuspages_components_listcomponentsresponse import (
        V4StatusPagesComponentsListComponentsResponse,
        V4StatusPagesComponentsListComponentsResponseTypedDict,
    )
    from .v4_statuspages_components_updatecomponentbyidrequest import (
        V4StatusPagesComponentsUpdateComponentByIDRequest,
        V4StatusPagesComponentsUpdateComponentByIDRequestTypedDict,
    )
    from .v4_statuspages_components_updatecomponentbyidresponse import (
        V4StatusPagesComponentsUpdateComponentByIDResponse,
        V4StatusPagesComponentsUpdateComponentByIDResponseTypedDict,
    )
    from .v4_statuspages_createstatuspagerequest import (
        V4StatusPagesCreateStatusPageRequest,
        V4StatusPagesCreateStatusPageRequestOwnerType,
        V4StatusPagesCreateStatusPageRequestTypedDict,
    )
    from .v4_statuspages_createstatuspageresponse import (
        V4StatusPagesCreateStatusPageResponse,
        V4StatusPagesCreateStatusPageResponseTypedDict,
    )
    from .v4_statuspages_deletestatuspagebyidresponse import (
        V4StatusPagesDeleteStatusPageByIDResponse,
        V4StatusPagesDeleteStatusPageByIDResponseTypedDict,
    )
    from .v4_statuspages_getstatuspagebyidresponse import (
        V4StatusPagesGetStatusPageByIDResponse,
        V4StatusPagesGetStatusPageByIDResponseThemeColor,
        V4StatusPagesGetStatusPageByIDResponseThemeColorTypedDict,
        V4StatusPagesGetStatusPageByIDResponseTypedDict,
    )
    from .v4_statuspages_issues_componentstatus import (
        V4StatusPagesIssuesComponentStatus,
        V4StatusPagesIssuesComponentStatusTypedDict,
    )
    from .v4_statuspages_issues_createissuerequest import (
        V4StatusPagesIssuesCreateIssueRequest,
        V4StatusPagesIssuesCreateIssueRequestComponent,
        V4StatusPagesIssuesCreateIssueRequestComponentTypedDict,
        V4StatusPagesIssuesCreateIssueRequestIssue,
        V4StatusPagesIssuesCreateIssueRequestIssueTypedDict,
        V4StatusPagesIssuesCreateIssueRequestStateMessage,
        V4StatusPagesIssuesCreateIssueRequestStateMessageTypedDict,
        V4StatusPagesIssuesCreateIssueRequestTypedDict,
    )
    from .v4_statuspages_issues_createissueresponse import (
        V4StatusPagesIssuesCreateIssueResponse,
        V4StatusPagesIssuesCreateIssueResponseTypedDict,
    )
    from .v4_statuspages_issues_deleteissuebyidresponse import (
        V4StatusPagesIssuesDeleteIssueByIDResponse,
        V4StatusPagesIssuesDeleteIssueByIDResponseTypedDict,
    )
    from .v4_statuspages_issues_getissuebyidresponse import (
        V4StatusPagesIssuesGetIssueByIDResponse,
        V4StatusPagesIssuesGetIssueByIDResponseTypedDict,
    )
    from .v4_statuspages_issues_issue import (
        V4StatusPagesIssuesIssue,
        V4StatusPagesIssuesIssueTypedDict,
    )
    from .v4_statuspages_issues_issuecomponent import (
        V4StatusPagesIssuesIssueComponent,
        V4StatusPagesIssuesIssueComponentTypedDict,
    )
    from .v4_statuspages_issues_issuecomponentdetail import (
        V4StatusPagesIssuesIssueComponentDetail,
        V4StatusPagesIssuesIssueComponentDetailTypedDict,
    )
    from .v4_statuspages_issues_issuedetail import (
        V4StatusPagesIssuesIssueDetail,
        V4StatusPagesIssuesIssueDetailTypedDict,
    )
    from .v4_statuspages_issues_issuestate import (
        V4StatusPagesIssuesIssueState,
        V4StatusPagesIssuesIssueStateTypedDict,
    )
    from .v4_statuspages_issues_issuestatemessage import (
        V4StatusPagesIssuesIssueStateMessage,
        V4StatusPagesIssuesIssueStateMessageTypedDict,
    )
    from .v4_statuspages_issues_listissuesresponse import (
        V4StatusPagesIssuesListIssuesResponse,
        V4StatusPagesIssuesListIssuesResponseMeta,
        V4StatusPagesIssuesListIssuesResponseMetaTypedDict,
        V4StatusPagesIssuesListIssuesResponseTypedDict,
    )
    from .v4_statuspages_issues_liststatuspageissuestatesresponse import (
        V4StatusPagesIssuesListStatusPageIssueStatesResponse,
        V4StatusPagesIssuesListStatusPageIssueStatesResponseTypedDict,
    )
    from .v4_statuspages_issues_updateissuerequest import (
        V4StatusPagesIssuesUpdateIssueRequest,
        V4StatusPagesIssuesUpdateIssueRequestComponent,
        V4StatusPagesIssuesUpdateIssueRequestComponentTypedDict,
        V4StatusPagesIssuesUpdateIssueRequestIssue,
        V4StatusPagesIssuesUpdateIssueRequestIssueTypedDict,
        V4StatusPagesIssuesUpdateIssueRequestStateMessage,
        V4StatusPagesIssuesUpdateIssueRequestStateMessageTypedDict,
        V4StatusPagesIssuesUpdateIssueRequestTypedDict,
    )
    from .v4_statuspages_issues_updateissueresponse import (
        V4StatusPagesIssuesUpdateIssueResponse,
        V4StatusPagesIssuesUpdateIssueResponseTypedDict,
    )
    from .v4_statuspages_liststatuspagesresponse import (
        V4StatusPagesListStatusPagesResponse,
        V4StatusPagesListStatusPagesResponseMeta,
        V4StatusPagesListStatusPagesResponseMetaTypedDict,
        V4StatusPagesListStatusPagesResponseTypedDict,
    )
    from .v4_statuspages_listsubscribersresponse import (
        V4StatusPagesListSubscribersResponse,
        V4StatusPagesListSubscribersResponseTypedDict,
    )
    from .v4_statuspages_listsubscribersresponsemeta import (
        V4StatusPagesListSubscribersResponseMeta,
        V4StatusPagesListSubscribersResponseMetaTypedDict,
    )
    from .v4_statuspages_maintenances_createmaintenancerequest import (
        V4StatusPagesMaintenancesCreateMaintenanceRequest,
        V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict,
    )
    from .v4_statuspages_maintenances_createmaintenanceresponse import (
        V4StatusPagesMaintenancesCreateMaintenanceResponse,
        V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict,
    )
    from .v4_statuspages_maintenances_deletemaintenancebyidresponse import (
        V4StatusPagesMaintenancesDeleteMaintenanceByIDResponse,
        V4StatusPagesMaintenancesDeleteMaintenanceByIDResponseTypedDict,
    )
    from .v4_statuspages_maintenances_getmaintenancebyidresponse import (
        V4StatusPagesMaintenancesGetMaintenanceByIDResponse,
        V4StatusPagesMaintenancesGetMaintenanceByIDResponseTypedDict,
    )
    from .v4_statuspages_maintenances_listmaintenancesresponse import (
        V4StatusPagesMaintenancesListMaintenancesResponse,
        V4StatusPagesMaintenancesListMaintenancesResponseMeta,
        V4StatusPagesMaintenancesListMaintenancesResponseMetaTypedDict,
        V4StatusPagesMaintenancesListMaintenancesResponseTypedDict,
    )
    from .v4_statuspages_maintenances_maintenance import (
        V4StatusPagesMaintenancesMaintenance,
        V4StatusPagesMaintenancesMaintenanceComponent,
        V4StatusPagesMaintenancesMaintenanceComponentTypedDict,
        V4StatusPagesMaintenancesMaintenanceTypedDict,
    )
    from .v4_statuspages_maintenances_updatemaintenancebyidrequest import (
        V4StatusPagesMaintenancesUpdateMaintenanceByIDRequest,
        V4StatusPagesMaintenancesUpdateMaintenanceByIDRequestTypedDict,
    )
    from .v4_statuspages_maintenances_updatemaintenancebyidresponse import (
        V4StatusPagesMaintenancesUpdateMaintenanceByIDResponse,
        V4StatusPagesMaintenancesUpdateMaintenanceByIDResponseTypedDict,
    )
    from .v4_statuspages_newstatuspagecomponent import (
        V4StatusPagesNewStatusPageComponent,
        V4StatusPagesNewStatusPageComponentType,
        V4StatusPagesNewStatusPageComponentTypedDict,
    )
    from .v4_statuspages_newstatuspagecomponentlist import (
        V4StatusPagesNewStatusPageComponentList,
        V4StatusPagesNewStatusPageComponentListType,
        V4StatusPagesNewStatusPageComponentListTypedDict,
    )
    from .v4_statuspages_newstatuspagethemecolor import (
        V4StatusPagesNewStatusPageThemeColor,
        V4StatusPagesNewStatusPageThemeColorTypedDict,
    )
    from .v4_statuspages_statuspage import (
        StatusMaintenance,
        StatusMaintenanceTypedDict,
        V4StatusPagesStatusPage,
        V4StatusPagesStatusPageComponent,
        V4StatusPagesStatusPageComponentTypedDict,
        V4StatusPagesStatusPageStatus,
        V4StatusPagesStatusPageStatusTypedDict,
        V4StatusPagesStatusPageTypedDict,
    )
    from .v4_statuspages_statuspagestatusesresponse import (
        V4StatusPagesStatusPageStatusesResponse,
        V4StatusPagesStatusPageStatusesResponseTypedDict,
    )
    from .v4_statuspages_statuspagesubscriber import (
        V4StatusPagesStatusPageSubscriber,
        V4StatusPagesStatusPageSubscriberTypedDict,
    )
    from .v4_statuspages_statuspagesubscribercomponent import (
        V4StatusPagesStatusPageSubscriberComponent,
        V4StatusPagesStatusPageSubscriberComponentTypedDict,
    )
    from .v4_statuspages_totalsubscriberscount import (
        V4StatusPagesTotalSubscribersCount,
        V4StatusPagesTotalSubscribersCountTypedDict,
    )
    from .v4_statuspages_updatestatuspagebyidrequest import (
        V4StatusPagesUpdateStatusPageByIDRequest,
        V4StatusPagesUpdateStatusPageByIDRequestComponent1,
        V4StatusPagesUpdateStatusPageByIDRequestComponent1TypedDict,
        V4StatusPagesUpdateStatusPageByIDRequestComponent2,
        V4StatusPagesUpdateStatusPageByIDRequestComponent2TypedDict,
        V4StatusPagesUpdateStatusPageByIDRequestThemeColor,
        V4StatusPagesUpdateStatusPageByIDRequestThemeColorTypedDict,
        V4StatusPagesUpdateStatusPageByIDRequestTypedDict,
    )
    from .v4_statuspages_updatestatuspagebyidresponse import (
        V4StatusPagesUpdateStatusPageByIDResponse,
        V4StatusPagesUpdateStatusPageByIDResponseThemeColor,
        V4StatusPagesUpdateStatusPageByIDResponseThemeColorTypedDict,
        V4StatusPagesUpdateStatusPageByIDResponseTypedDict,
    )
    from .v4_tag import V4Tag, V4TagTypedDict
    from .v4_updaterotationparticipantsrequest import (
        V4UpdateRotationParticipantsRequest,
        V4UpdateRotationParticipantsRequestTypedDict,
    )
    from .v4_updaterotationrequest import (
        V4UpdateRotationRequest,
        V4UpdateRotationRequestTypedDict,
    )
    from .v4_updatescheduleoverriderequest import (
        V4UpdateScheduleOverrideRequest,
        V4UpdateScheduleOverrideRequestTypedDict,
    )
    from .v4_updateschedulerequest import (
        V4UpdateScheduleRequest,
        V4UpdateScheduleRequestOwnerType,
        V4UpdateScheduleRequestTypedDict,
    )
    from .webforms_createwebformop import (
        WebformsCreateWebformData,
        WebformsCreateWebformDataTypedDict,
        WebformsCreateWebformResponse,
        WebformsCreateWebformResponseTypedDict,
    )
    from .webforms_getallwebformsop import (
        WebformsGetAllWebformsMeta,
        WebformsGetAllWebformsMetaTypedDict,
        WebformsGetAllWebformsRequest,
        WebformsGetAllWebformsRequestTypedDict,
        WebformsGetAllWebformsResponse,
        WebformsGetAllWebformsResponseBody,
        WebformsGetAllWebformsResponseBodyTypedDict,
        WebformsGetAllWebformsResponseTypedDict,
    )
    from .webforms_getwebformbyidop import (
        WebformsGetWebformByIDRequest,
        WebformsGetWebformByIDRequestTypedDict,
        WebformsGetWebformByIDResponse,
        WebformsGetWebformByIDResponseTypedDict,
    )
    from .webforms_removewebformop import (
        WebformsRemoveWebformRequest,
        WebformsRemoveWebformRequestTypedDict,
        WebformsRemoveWebformResponse,
        WebformsRemoveWebformResponseTypedDict,
    )
    from .webforms_updatewebformop import (
        WebformsUpdateWebformRequest,
        WebformsUpdateWebformRequestTypedDict,
        WebformsUpdateWebformResponse,
        WebformsUpdateWebformResponseTypedDict,
    )
    from .webhooks_createwebhookop import (
        WebhooksCreateWebhookBody,
        WebhooksCreateWebhookBodyTypedDict,
        WebhooksCreateWebhookResponse,
        WebhooksCreateWebhookResponseTypedDict,
    )
    from .webhooks_deletewebhookop import (
        WebhooksDeleteWebhookRequest,
        WebhooksDeleteWebhookRequestTypedDict,
        WebhooksDeleteWebhookResponseBody,
        WebhooksDeleteWebhookResponseBodyTypedDict,
    )
    from .webhooks_getallwebhooksop import (
        WebhooksGetAllWebhooksRequest,
        WebhooksGetAllWebhooksRequestTypedDict,
    )
    from .webhooks_getwebhookbyidop import (
        WebhooksGetWebhookByIDRequest,
        WebhooksGetWebhookByIDRequestTypedDict,
        WebhooksGetWebhookByIDResponse,
        WebhooksGetWebhookByIDResponseTypedDict,
    )
    from .webhooks_updatewebhookop import (
        WebhooksUpdateWebhookRequest,
        WebhooksUpdateWebhookRequestTypedDict,
        WebhooksUpdateWebhookResponse,
        WebhooksUpdateWebhookResponseTypedDict,
    )
    from .workflows_bulkenabledisableworkflowsop import (
        WorkflowsBulkEnabledisableWorkflowsResponseBody,
        WorkflowsBulkEnabledisableWorkflowsResponseBodyTypedDict,
    )
    from .workflows_createactionop import (
        WorkflowsCreateActionRequest,
        WorkflowsCreateActionRequestTypedDict,
        WorkflowsCreateActionResponse,
        WorkflowsCreateActionResponseTypedDict,
    )
    from .workflows_createworkflowop import (
        WorkflowsCreateWorkflowResponse,
        WorkflowsCreateWorkflowResponseTypedDict,
    )
    from .workflows_deleteworkflowactionop import (
        WorkflowsDeleteWorkflowActionRequest,
        WorkflowsDeleteWorkflowActionRequestTypedDict,
        WorkflowsDeleteWorkflowActionResponseBody,
        WorkflowsDeleteWorkflowActionResponseBodyTypedDict,
    )
    from .workflows_deleteworkflowop import (
        WorkflowsDeleteWorkflowRequest,
        WorkflowsDeleteWorkflowRequestTypedDict,
        WorkflowsDeleteWorkflowResponseBody,
        WorkflowsDeleteWorkflowResponseBodyTypedDict,
    )
    from .workflows_enabledisableworkflowop import (
        WorkflowsEnabledisableWorkflowRequest,
        WorkflowsEnabledisableWorkflowRequestTypedDict,
        WorkflowsEnabledisableWorkflowResponseBody,
        WorkflowsEnabledisableWorkflowResponseBodyTypedDict,
    )
    from .workflows_getworkflowactionbyidop import (
        WorkflowsGetWorkflowActionByIDRequest,
        WorkflowsGetWorkflowActionByIDRequestTypedDict,
        WorkflowsGetWorkflowActionByIDResponse,
        WorkflowsGetWorkflowActionByIDResponseTypedDict,
    )
    from .workflows_getworkflowbyidop import (
        WorkflowsGetWorkflowByIDRequest,
        WorkflowsGetWorkflowByIDRequestTypedDict,
    )
    from .workflows_getworkflowlogsop import (
        WorkflowsGetWorkflowLogsRequest,
        WorkflowsGetWorkflowLogsRequestTypedDict,
        WorkflowsGetWorkflowLogsResponse,
        WorkflowsGetWorkflowLogsResponseTypedDict,
    )
    from .workflows_listworkflowsop import (
        WorkflowsListWorkflowsRequest,
        WorkflowsListWorkflowsRequestTypedDict,
        WorkflowsListWorkflowsResponse,
        WorkflowsListWorkflowsResponseTypedDict,
    )
    from .workflows_updateactionsorderop import (
        WorkflowsUpdateActionsOrderRequest,
        WorkflowsUpdateActionsOrderRequestTypedDict,
    )
    from .workflows_updateworkflowactionop import (
        WorkflowsUpdateWorkflowActionRequest,
        WorkflowsUpdateWorkflowActionRequestTypedDict,
    )
    from .workflows_updateworkflowop import (
        WorkflowsUpdateWorkflowRequest,
        WorkflowsUpdateWorkflowRequestTypedDict,
        WorkflowsUpdateWorkflowResponse,
        WorkflowsUpdateWorkflowResponseTypedDict,
    )

__all__ = [
    "ACL",
    "ACLTypedDict",
    "Abilities",
    "AbilitiesTypedDict",
    "Action",
    "AdditionalResponder",
    "AdditionalResponderTypedDict",
    "AdditionalRespondersAddAdditionalRespondersRequest",
    "AdditionalRespondersAddAdditionalRespondersRequestTypedDict",
    "AdditionalRespondersAddAdditionalRespondersResponse",
    "AdditionalRespondersAddAdditionalRespondersResponseTypedDict",
    "AdditionalRespondersGetAdditionalRespondersRequest",
    "AdditionalRespondersGetAdditionalRespondersRequestTypedDict",
    "AdditionalRespondersGetAdditionalRespondersResponse",
    "AdditionalRespondersGetAdditionalRespondersResponseTypedDict",
    "AdditionalRespondersRemoveAdditionalRespondersRequest",
    "AdditionalRespondersRemoveAdditionalRespondersRequestTypedDict",
    "AdditionalRespondersRemoveAdditionalRespondersResponseBody",
    "AdditionalRespondersRemoveAdditionalRespondersResponseBodyTypedDict",
    "AnalyticsGetOrgAnalyticsRequest",
    "AnalyticsGetOrgAnalyticsRequestTypedDict",
    "AnalyticsGetOrgAnalyticsResponse",
    "AnalyticsGetOrgAnalyticsResponseTypedDict",
    "AnalyticsGetTeamAnalyticsRequest",
    "AnalyticsGetTeamAnalyticsRequestTypedDict",
    "AnalyticsGetTeamAnalyticsResponse",
    "AnalyticsGetTeamAnalyticsResponseTypedDict",
    "AptaMarkAsNotTransientRequest",
    "AptaMarkAsNotTransientRequestTypedDict",
    "AptaMarkAsNotTransientResponse",
    "AptaMarkAsNotTransientResponseTypedDict",
    "AptaMarkAsTransientRequest",
    "AptaMarkAsTransientRequestTypedDict",
    "AptaMarkAsTransientResponse",
    "AptaMarkAsTransientResponseTypedDict",
    "AuditLogsGetAuditLogByIDRequest",
    "AuditLogsGetAuditLogByIDRequestTypedDict",
    "AuditLogsGetAuditLogsExportHistoryByIDRequest",
    "AuditLogsGetAuditLogsExportHistoryByIDRequestTypedDict",
    "AuditLogsListAuditLogsExportHistoryRequest",
    "AuditLogsListAuditLogsExportHistoryRequestTypedDict",
    "AuditLogsListAuditLogsExportHistoryResponse",
    "AuditLogsListAuditLogsExportHistoryResponseTypedDict",
    "AuditLogsListAuditLogsRequest",
    "AuditLogsListAuditLogsRequestTypedDict",
    "AuditLogsListAuditLogsResponse",
    "AuditLogsListAuditLogsResponseTypedDict",
    "BuildParameters",
    "BuildParametersTypedDict",
    "CircleciResponse",
    "CircleciResponseTypedDict",
    "Client",
    "CommonV3EntityOwner",
    "CommonV3EntityOwnerTypedDict",
    "CommonV3ErrorMeta",
    "CommonV3ErrorMetaTypedDict",
    "CommonV3RBACEntityPermission",
    "CommonV3RBACEntityPermissionTypedDict",
    "CommonV3RBACOwner",
    "CommonV3RBACOwnerType",
    "CommonV3RBACOwnerTypedDict",
    "CommonV4PageInfo",
    "CommonV4PageInfoTypedDict",
    "CommunicationCardsArchiveSlackChannelResponse",
    "CommunicationCardsArchiveSlackChannelResponseTypedDict",
    "CommunicationCardsCreateCommunicationCardRequest",
    "CommunicationCardsCreateCommunicationCardRequestTypedDict",
    "CommunicationCardsCreateCommunicationCardResponse",
    "CommunicationCardsCreateCommunicationCardResponseTypedDict",
    "CommunicationCardsCreateSlackChannelInCommunicationCardResponse",
    "CommunicationCardsCreateSlackChannelInCommunicationCardResponseTypedDict",
    "CommunicationCardsDeleteCommunicationCardRequest",
    "CommunicationCardsDeleteCommunicationCardRequestTypedDict",
    "CommunicationCardsDeleteCommunicationCardResponse",
    "CommunicationCardsDeleteCommunicationCardResponseTypedDict",
    "CommunicationCardsGetAllCommunicationCardRequest",
    "CommunicationCardsGetAllCommunicationCardRequestTypedDict",
    "CommunicationCardsGetAllCommunicationCardResponse",
    "CommunicationCardsGetAllCommunicationCardResponseTypedDict",
    "CommunicationCardsUpdateCommunicationCardRequest",
    "CommunicationCardsUpdateCommunicationCardRequestTypedDict",
    "CommunicationCardsUpdateCommunicationCardResponse",
    "CommunicationCardsUpdateCommunicationCardResponseTypedDict",
    "ComponentGroupsCreateComponentGroupRequest",
    "ComponentGroupsCreateComponentGroupRequestTypedDict",
    "ComponentGroupsCreateComponentGroupResponse",
    "ComponentGroupsCreateComponentGroupResponseTypedDict",
    "ComponentGroupsDeleteComponentGroupByIDRequest",
    "ComponentGroupsDeleteComponentGroupByIDRequestTypedDict",
    "ComponentGroupsDeleteComponentGroupByIDResponse",
    "ComponentGroupsDeleteComponentGroupByIDResponseTypedDict",
    "ComponentGroupsGetComponentGroupByIDRequest",
    "ComponentGroupsGetComponentGroupByIDRequestTypedDict",
    "ComponentGroupsGetComponentGroupByIDResponse",
    "ComponentGroupsGetComponentGroupByIDResponseTypedDict",
    "ComponentGroupsListComponentGroupsRequest",
    "ComponentGroupsListComponentGroupsRequestTypedDict",
    "ComponentGroupsListComponentGroupsResponse",
    "ComponentGroupsListComponentGroupsResponseTypedDict",
    "ComponentsCreateComponentRequest",
    "ComponentsCreateComponentRequestTypedDict",
    "ComponentsCreateComponentResponse",
    "ComponentsCreateComponentResponseTypedDict",
    "ComponentsDeleteComponentByIDRequest",
    "ComponentsDeleteComponentByIDRequestTypedDict",
    "ComponentsDeleteComponentByIDResponse",
    "ComponentsDeleteComponentByIDResponseTypedDict",
    "ComponentsGetComponentByIDRequest",
    "ComponentsGetComponentByIDRequestTypedDict",
    "ComponentsGetComponentByIDResponse",
    "ComponentsGetComponentByIDResponseTypedDict",
    "ComponentsListComponentsRequest",
    "ComponentsListComponentsRequestTypedDict",
    "ComponentsListComponentsResponse",
    "ComponentsListComponentsResponseTypedDict",
    "ComponentsUpdateComponentByIDRequest",
    "ComponentsUpdateComponentByIDRequestTypedDict",
    "ComponentsUpdateComponentByIDResponse",
    "ComponentsUpdateComponentByIDResponseTypedDict",
    "Condition",
    "Config",
    "ConfigTypedDict",
    "DedupKeyOverlay",
    "DedupKeyOverlayTypedDict",
    "DeduplicationReason",
    "DeduplicationReasonTypedDict",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesData",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesDataTypedDict",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesRequest",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesRequestTypedDict",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesResponse",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesResponseTypedDict",
    "DeduplicationRulesGetDeduplicationRulesData",
    "DeduplicationRulesGetDeduplicationRulesDataTypedDict",
    "DeduplicationRulesGetDeduplicationRulesRequest",
    "DeduplicationRulesGetDeduplicationRulesRequestTypedDict",
    "DeduplicationRulesGetDeduplicationRulesResponse",
    "DeduplicationRulesGetDeduplicationRulesResponseTypedDict",
    "DependenciesCreateOrUpdateDependenciesData",
    "DependenciesCreateOrUpdateDependenciesDataTypedDict",
    "DependenciesCreateOrUpdateDependenciesRequest",
    "DependenciesCreateOrUpdateDependenciesRequestTypedDict",
    "DependenciesCreateOrUpdateDependenciesResponse",
    "DependenciesCreateOrUpdateDependenciesResponseTypedDict",
    "DescriptionOverlay",
    "DescriptionOverlayTypedDict",
    "Detail",
    "DetailTypedDict",
    "Entity",
    "EntityTypedDict",
    "Error",
    "ErrorTypedDict",
    "EscalationPolicies",
    "EscalationPoliciesCreateEscalationPoliciesResponse",
    "EscalationPoliciesCreateEscalationPoliciesResponseTypedDict",
    "EscalationPoliciesGetEscalationPolicyByIDRequest",
    "EscalationPoliciesGetEscalationPolicyByIDRequestTypedDict",
    "EscalationPoliciesGetEscalationPolicyByIDResponse",
    "EscalationPoliciesGetEscalationPolicyByIDResponseTypedDict",
    "EscalationPoliciesGetEscalationPolicyByTeamMeta",
    "EscalationPoliciesGetEscalationPolicyByTeamMetaTypedDict",
    "EscalationPoliciesGetEscalationPolicyByTeamRequest",
    "EscalationPoliciesGetEscalationPolicyByTeamRequestTypedDict",
    "EscalationPoliciesGetEscalationPolicyByTeamResponse",
    "EscalationPoliciesGetEscalationPolicyByTeamResponseBody",
    "EscalationPoliciesGetEscalationPolicyByTeamResponseBodyTypedDict",
    "EscalationPoliciesGetEscalationPolicyByTeamResponseTypedDict",
    "EscalationPoliciesRemoveEscalationPolicyRequest",
    "EscalationPoliciesRemoveEscalationPolicyRequestTypedDict",
    "EscalationPoliciesRemoveEscalationPolicyResponseBody",
    "EscalationPoliciesRemoveEscalationPolicyResponseBodyTypedDict",
    "EscalationPoliciesTypedDict",
    "EscalationPoliciesUpdateEscalationPolicyRequest",
    "EscalationPoliciesUpdateEscalationPolicyRequestTypedDict",
    "EscalationPoliciesUpdateEscalationPolicyResponse",
    "EscalationPoliciesUpdateEscalationPolicyResponseTypedDict",
    "ExportCreateScheduleIcalLinkRequest",
    "ExportCreateScheduleIcalLinkRequestBody",
    "ExportCreateScheduleIcalLinkRequestBodyTypedDict",
    "ExportCreateScheduleIcalLinkRequestTypedDict",
    "ExportCreateScheduleIcalLinkResponse",
    "ExportCreateScheduleIcalLinkResponseTypedDict",
    "ExportDeleteIcalLinkRequest",
    "ExportDeleteIcalLinkRequestTypedDict",
    "ExportDeleteIcalLinkResponseBody",
    "ExportDeleteIcalLinkResponseBodyTypedDict",
    "ExportGetExportDetailsRequest",
    "ExportGetExportDetailsRequestTypedDict",
    "ExportGetExportDetailsResponse",
    "ExportGetExportDetailsResponseTypedDict",
    "ExportGetScheduleIcalLinkRequest",
    "ExportGetScheduleIcalLinkRequestTypedDict",
    "ExportGetScheduleIcalLinkResponse",
    "ExportGetScheduleIcalLinkResponseTypedDict",
    "ExportRefreshScheduleIcalLinkRequest",
    "ExportRefreshScheduleIcalLinkRequestBody",
    "ExportRefreshScheduleIcalLinkRequestBodyTypedDict",
    "ExportRefreshScheduleIcalLinkRequestTypedDict",
    "ExportRefreshScheduleIcalLinkResponse",
    "ExportRefreshScheduleIcalLinkResponseTypedDict",
    "ExportType",
    "ExtensionsUpdateSlackExtensionRequest",
    "ExtensionsUpdateSlackExtensionRequestTypedDict",
    "ExtensionsUpdateSlackExtensionResponse",
    "ExtensionsUpdateSlackExtensionResponseTypedDict",
    "Filters",
    "FiltersTypedDict",
    "Ger",
    "GerTypedDict",
    "GlobalEventRulesCreateGlobalEventRuleResponse",
    "GlobalEventRulesCreateGlobalEventRuleResponseTypedDict",
    "GlobalEventRulesCreateRuleRequest",
    "GlobalEventRulesCreateRuleRequestTypedDict",
    "GlobalEventRulesCreateRuleResponse",
    "GlobalEventRulesCreateRuleResponseTypedDict",
    "GlobalEventRulesCreateRulesetRequest",
    "GlobalEventRulesCreateRulesetRequestTypedDict",
    "GlobalEventRulesCreateRulesetResponse",
    "GlobalEventRulesCreateRulesetResponseTypedDict",
    "GlobalEventRulesDeleteGerRulesetRequest",
    "GlobalEventRulesDeleteGerRulesetRequestTypedDict",
    "GlobalEventRulesDeleteGerRulesetResponseBody",
    "GlobalEventRulesDeleteGerRulesetResponseBodyTypedDict",
    "GlobalEventRulesDeleteGlobalEventRuleByIDRequest",
    "GlobalEventRulesDeleteGlobalEventRuleByIDRequestTypedDict",
    "GlobalEventRulesDeleteGlobalEventRuleByIDResponseBody",
    "GlobalEventRulesDeleteGlobalEventRuleByIDResponseBodyTypedDict",
    "GlobalEventRulesDeleteRuleByIDRequest",
    "GlobalEventRulesDeleteRuleByIDRequestTypedDict",
    "GlobalEventRulesDeleteRuleByIDResponseBody",
    "GlobalEventRulesDeleteRuleByIDResponseBodyTypedDict",
    "GlobalEventRulesGetGlobalEventRuleByIDRequest",
    "GlobalEventRulesGetGlobalEventRuleByIDRequestTypedDict",
    "GlobalEventRulesGetGlobalEventRuleByIDResponse",
    "GlobalEventRulesGetGlobalEventRuleByIDResponseTypedDict",
    "GlobalEventRulesGetRuleByIDRequest",
    "GlobalEventRulesGetRuleByIDRequestTypedDict",
    "GlobalEventRulesGetRuleByIDResponse",
    "GlobalEventRulesGetRuleByIDResponseTypedDict",
    "GlobalEventRulesGetRulesetRequest",
    "GlobalEventRulesGetRulesetRequestTypedDict",
    "GlobalEventRulesGetRulesetResponse",
    "GlobalEventRulesGetRulesetResponseTypedDict",
    "GlobalEventRulesListGlobalEventRulesMeta",
    "GlobalEventRulesListGlobalEventRulesMetaTypedDict",
    "GlobalEventRulesListGlobalEventRulesRequest",
    "GlobalEventRulesListGlobalEventRulesRequestTypedDict",
    "GlobalEventRulesListGlobalEventRulesResponse",
    "GlobalEventRulesListGlobalEventRulesResponseBody",
    "GlobalEventRulesListGlobalEventRulesResponseBodyTypedDict",
    "GlobalEventRulesListGlobalEventRulesResponseTypedDict",
    "GlobalEventRulesListRulesetRulesMeta",
    "GlobalEventRulesListRulesetRulesMetaTypedDict",
    "GlobalEventRulesListRulesetRulesRequest",
    "GlobalEventRulesListRulesetRulesRequestTypedDict",
    "GlobalEventRulesListRulesetRulesResponse",
    "GlobalEventRulesListRulesetRulesResponseBody",
    "GlobalEventRulesListRulesetRulesResponseBodyTypedDict",
    "GlobalEventRulesListRulesetRulesResponseTypedDict",
    "GlobalEventRulesReorderRulesetByIndexRequest",
    "GlobalEventRulesReorderRulesetByIndexRequestTypedDict",
    "GlobalEventRulesReorderRulesetByIndexResponse",
    "GlobalEventRulesReorderRulesetByIndexResponseTypedDict",
    "GlobalEventRulesReorderRulesetRequest",
    "GlobalEventRulesReorderRulesetRequestTypedDict",
    "GlobalEventRulesReorderRulesetResponse",
    "GlobalEventRulesReorderRulesetResponseTypedDict",
    "GlobalEventRulesUpdateGlobalEventRuleByIDRequest",
    "GlobalEventRulesUpdateGlobalEventRuleByIDRequestTypedDict",
    "GlobalEventRulesUpdateGlobalEventRuleByIDResponse",
    "GlobalEventRulesUpdateGlobalEventRuleByIDResponseTypedDict",
    "GlobalEventRulesUpdateRuleByIDRequest",
    "GlobalEventRulesUpdateRuleByIDRequestTypedDict",
    "GlobalEventRulesUpdateRuleByIDResponse",
    "GlobalEventRulesUpdateRuleByIDResponseTypedDict",
    "GlobalEventRulesUpdateRulesetRequest",
    "GlobalEventRulesUpdateRulesetRequestTypedDict",
    "GlobalEventRulesUpdateRulesetResponse",
    "GlobalEventRulesUpdateRulesetResponseTypedDict",
    "GlobalOncallReminderRules",
    "GlobalOncallReminderRulesCreateGlobalOncallReminderRulesResponse",
    "GlobalOncallReminderRulesCreateGlobalOncallReminderRulesResponseTypedDict",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequest",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequestTypedDict",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBody",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBodyTypedDict",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequest",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequestTypedDict",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponse",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponseTypedDict",
    "GlobalOncallReminderRulesTypedDict",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponse",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponseTypedDict",
    "IncidentActionsCreateATicketOnJiraCloudRequest",
    "IncidentActionsCreateATicketOnJiraCloudRequestTypedDict",
    "IncidentActionsCreateATicketOnJiraCloudResponse",
    "IncidentActionsCreateATicketOnJiraCloudResponseTypedDict",
    "IncidentActionsCreateATicketOnJiraServerRequest",
    "IncidentActionsCreateATicketOnJiraServerRequestTypedDict",
    "IncidentActionsCreateATicketOnJiraServerResponse",
    "IncidentActionsCreateATicketOnJiraServerResponseTypedDict",
    "IncidentActionsCreateAnIncidentInServicenowRequest",
    "IncidentActionsCreateAnIncidentInServicenowRequestTypedDict",
    "IncidentActionsCreateAnIncidentInServicenowResponse",
    "IncidentActionsCreateAnIncidentInServicenowResponseTypedDict",
    "IncidentActionsRebuildAProjectInCircleciMeta",
    "IncidentActionsRebuildAProjectInCircleciMetaTypedDict",
    "IncidentActionsRebuildAProjectInCircleciRequest",
    "IncidentActionsRebuildAProjectInCircleciRequestTypedDict",
    "IncidentActionsRebuildAProjectInCircleciResponse",
    "IncidentActionsRebuildAProjectInCircleciResponseTypedDict",
    "IncidentActionsTriggerAWebhookManuallyRequest",
    "IncidentActionsTriggerAWebhookManuallyRequestTypedDict",
    "IncidentActionsTriggerAWebhookManuallyResponse",
    "IncidentActionsTriggerAWebhookManuallyResponseTypedDict",
    "IncidentsAcknowledgeIncidentRequest",
    "IncidentsAcknowledgeIncidentRequestTypedDict",
    "IncidentsAcknowledgeIncidentResponse",
    "IncidentsAcknowledgeIncidentResponseTypedDict",
    "IncidentsBulkAcknowledgeIncidentsResponse",
    "IncidentsBulkAcknowledgeIncidentsResponseTypedDict",
    "IncidentsBulkIncidentsPriorityUpdateResponseBody",
    "IncidentsBulkIncidentsPriorityUpdateResponseBodyTypedDict",
    "IncidentsBulkResolveIncidentsResponse",
    "IncidentsBulkResolveIncidentsResponseTypedDict",
    "IncidentsGetIncidentByIDRequest",
    "IncidentsGetIncidentByIDRequestTypedDict",
    "IncidentsGetIncidentByIDResponse",
    "IncidentsGetIncidentByIDResponseTypedDict",
    "IncidentsGetIncidentEventsData",
    "IncidentsGetIncidentEventsDataTypedDict",
    "IncidentsGetIncidentEventsMeta",
    "IncidentsGetIncidentEventsMetaTypedDict",
    "IncidentsGetIncidentEventsRequest",
    "IncidentsGetIncidentEventsRequestTypedDict",
    "IncidentsGetIncidentEventsResponse",
    "IncidentsGetIncidentEventsResponseTypedDict",
    "IncidentsGetIncidentsStatusByRequestidsMeta",
    "IncidentsGetIncidentsStatusByRequestidsMetaTypedDict",
    "IncidentsGetIncidentsStatusByRequestidsResponse",
    "IncidentsGetIncidentsStatusByRequestidsResponseTypedDict",
    "IncidentsIncidentExportAsyncBody",
    "IncidentsIncidentExportAsyncBodyTypedDict",
    "IncidentsIncidentExportAsyncResponseBody",
    "IncidentsIncidentExportAsyncResponseBodyTypedDict",
    "IncidentsIncidentExportRequest",
    "IncidentsIncidentExportRequestTypedDict",
    "IncidentsIncidentPriorityUpdateRequest",
    "IncidentsIncidentPriorityUpdateRequestTypedDict",
    "IncidentsIncidentPriorityUpdateResponse",
    "IncidentsIncidentPriorityUpdateResponseTypedDict",
    "IncidentsMarkIncidentSloFalsePositiveRequest",
    "IncidentsMarkIncidentSloFalsePositiveRequestTypedDict",
    "IncidentsMarkIncidentSloFalsePositiveResponse",
    "IncidentsMarkIncidentSloFalsePositiveResponseTypedDict",
    "IncidentsReassignIncidentRequest",
    "IncidentsReassignIncidentRequestTypedDict",
    "IncidentsReassignIncidentResponse",
    "IncidentsReassignIncidentResponseTypedDict",
    "IncidentsResolveIncidentRequest",
    "IncidentsResolveIncidentRequestTypedDict",
    "IncidentsResolveIncidentResponse",
    "IncidentsResolveIncidentResponseTypedDict",
    "Insights",
    "InsightsTypedDict",
    "IssuesCreateIssueRequest",
    "IssuesCreateIssueRequestTypedDict",
    "IssuesCreateIssueResponse",
    "IssuesCreateIssueResponseTypedDict",
    "IssuesDeleteIssueByIDRequest",
    "IssuesDeleteIssueByIDRequestTypedDict",
    "IssuesDeleteIssueByIDResponse",
    "IssuesDeleteIssueByIDResponseTypedDict",
    "IssuesGetIssueByIDRequest",
    "IssuesGetIssueByIDRequestTypedDict",
    "IssuesGetIssueByIDResponse",
    "IssuesGetIssueByIDResponseTypedDict",
    "IssuesListIssuesRequest",
    "IssuesListIssuesRequestTypedDict",
    "IssuesListStatusPageIssueStatesRequest",
    "IssuesListStatusPageIssueStatesRequestTypedDict",
    "IssuesListStatusPageIssueStatesResponse",
    "IssuesListStatusPageIssueStatesResponseTypedDict",
    "IssuesUpdateIssueRequest",
    "IssuesUpdateIssueRequestTypedDict",
    "IssuesUpdateIssueResponse",
    "IssuesUpdateIssueResponseTypedDict",
    "MSTeamsCreateOrUpdateMsteamsConfigurationResponse",
    "MSTeamsCreateOrUpdateMsteamsConfigurationResponseTypedDict",
    "MSTeamsGetMsteamsConfigResponse",
    "MSTeamsGetMsteamsConfigResponseTypedDict",
    "MaintenanceModeCreateOrUpdateMaintenanceModeRequest",
    "MaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict",
    "MaintenanceModeCreateOrUpdateMaintenanceModeResponse",
    "MaintenanceModeCreateOrUpdateMaintenanceModeResponseTypedDict",
    "MaintenanceModeGetMaintenanceModeRequest",
    "MaintenanceModeGetMaintenanceModeRequestTypedDict",
    "MaintenanceModeGetMaintenanceModeResponse",
    "MaintenanceModeGetMaintenanceModeResponseTypedDict",
    "MaintenancesCreateMaintenanceRequest",
    "MaintenancesCreateMaintenanceRequestTypedDict",
    "MaintenancesCreateMaintenanceResponse",
    "MaintenancesCreateMaintenanceResponseTypedDict",
    "MaintenancesDeleteMaintenanceByIDRequest",
    "MaintenancesDeleteMaintenanceByIDRequestTypedDict",
    "MaintenancesDeleteMaintenanceByIDResponse",
    "MaintenancesDeleteMaintenanceByIDResponseTypedDict",
    "MaintenancesGetMaintenanceByIDRequest",
    "MaintenancesGetMaintenanceByIDRequestTypedDict",
    "MaintenancesGetMaintenanceByIDResponse",
    "MaintenancesGetMaintenanceByIDResponseTypedDict",
    "MaintenancesListMaintenancesRequest",
    "MaintenancesListMaintenancesRequestTypedDict",
    "MaintenancesUpdateMaintenanceByIDRequest",
    "MaintenancesUpdateMaintenanceByIDRequestTypedDict",
    "MaintenancesUpdateMaintenanceByIDResponse",
    "MaintenancesUpdateMaintenanceByIDResponseTypedDict",
    "MessageOverlay",
    "MessageOverlayTypedDict",
    "NotesCreateNotesBody",
    "NotesCreateNotesBodyTypedDict",
    "NotesCreateNotesRequest",
    "NotesCreateNotesRequestTypedDict",
    "NotesCreateNotesResponse",
    "NotesCreateNotesResponseTypedDict",
    "NotesDeleteNoteRequest",
    "NotesDeleteNoteRequestTypedDict",
    "NotesDeleteNoteResponseBody",
    "NotesDeleteNoteResponseBodyTypedDict",
    "NotesGetAllNotesRequest",
    "NotesGetAllNotesRequestTypedDict",
    "NotesGetAllNotesResponse",
    "NotesGetAllNotesResponseTypedDict",
    "NotesUpdateNoteRequest",
    "NotesUpdateNoteRequestTypedDict",
    "NotesUpdateNoteResponse",
    "NotesUpdateNoteResponseTypedDict",
    "Organization",
    "OrganizationTypedDict",
    "OverlayCreateOrUpdateNotificationTemplateOverlayRequest",
    "OverlayCreateOrUpdateNotificationTemplateOverlayRequestTypedDict",
    "OverlayCreateOrUpdateNotificationTemplateOverlayResponse",
    "OverlayCreateOrUpdateNotificationTemplateOverlayResponseTypedDict",
    "OverlayDeleteDedupKeyOverlayRequest",
    "OverlayDeleteDedupKeyOverlayRequestTypedDict",
    "OverlayDeleteDedupKeyOverlayResponseBody",
    "OverlayDeleteDedupKeyOverlayResponseBodyTypedDict",
    "OverlayDeleteNotificationTemplateOverlayRequest",
    "OverlayDeleteNotificationTemplateOverlayRequestTypedDict",
    "OverlayDeleteNotificationTemplateOverlayResponseBody",
    "OverlayDeleteNotificationTemplateOverlayResponseBodyTypedDict",
    "OverlayGetAllCustomContentTemplateOverlayByServiceRequest",
    "OverlayGetAllCustomContentTemplateOverlayByServiceRequestTypedDict",
    "OverlayGetAllCustomContentTemplateOverlayByServiceResponse",
    "OverlayGetAllCustomContentTemplateOverlayByServiceResponseTypedDict",
    "OverlayGetAllDedupKeyOverlayByServiceRequest",
    "OverlayGetAllDedupKeyOverlayByServiceRequestTypedDict",
    "OverlayGetAllDedupKeyOverlayByServiceResponse",
    "OverlayGetAllDedupKeyOverlayByServiceResponseTypedDict",
    "OverlayGetCustomContentTemplateOverlayRequest",
    "OverlayGetCustomContentTemplateOverlayRequestTypedDict",
    "OverlayGetCustomContentTemplateOverlayResponse",
    "OverlayGetCustomContentTemplateOverlayResponseTypedDict",
    "OverlayGetDedupKeyOverlayForAlertSourceRequest",
    "OverlayGetDedupKeyOverlayForAlertSourceRequestTypedDict",
    "OverlayGetDedupKeyOverlayForAlertSourceResponse",
    "OverlayGetDedupKeyOverlayForAlertSourceResponseTypedDict",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceData",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceDataTypedDict",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceRequest",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceRequestTypedDict",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceResponse",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceResponseTypedDict",
    "OverlayOptinForKeyBasedDeduplicationForAServiceRequest",
    "OverlayOptinForKeyBasedDeduplicationForAServiceRequestTypedDict",
    "OverlayOptinForKeyBasedDeduplicationForAServiceResponse",
    "OverlayOptinForKeyBasedDeduplicationForAServiceResponseTypedDict",
    "OverlayRenderCustomContentOverlayRequest",
    "OverlayRenderCustomContentOverlayRequestTypedDict",
    "OverlayRenderCustomContentOverlayResponse",
    "OverlayRenderCustomContentOverlayResponseTypedDict",
    "OverlayRenderDedupKeyTemplateRequest",
    "OverlayRenderDedupKeyTemplateRequestTypedDict",
    "OverlayRenderDedupKeyTemplateResponse",
    "OverlayRenderDedupKeyTemplateResponseTypedDict",
    "OverlayUpdateDedupKeyOverlayRequest",
    "OverlayUpdateDedupKeyOverlayRequestTypedDict",
    "OverlayUpdateDedupKeyOverlayResponse",
    "OverlayUpdateDedupKeyOverlayResponseTypedDict",
    "OverridesCreateScheduleOverrideRequest",
    "OverridesCreateScheduleOverrideRequestTypedDict",
    "OverridesCreateScheduleOverrideResponse",
    "OverridesCreateScheduleOverrideResponseTypedDict",
    "OverridesDeleteScheduleOverrideRequest",
    "OverridesDeleteScheduleOverrideRequestTypedDict",
    "OverridesDeleteScheduleOverrideResponseBody",
    "OverridesDeleteScheduleOverrideResponseBodyTypedDict",
    "OverridesGetOverrideByIDRequest",
    "OverridesGetOverrideByIDRequestTypedDict",
    "OverridesGetOverrideByIDResponse",
    "OverridesGetOverrideByIDResponseTypedDict",
    "OverridesListOverridesRequest",
    "OverridesListOverridesRequestTypedDict",
    "OverridesListOverridesResponse",
    "OverridesListOverridesResponseTypedDict",
    "OverridesUpdateScheduleOverrideRequest",
    "OverridesUpdateScheduleOverrideRequestTypedDict",
    "OverridesUpdateScheduleOverrideResponse",
    "OverridesUpdateScheduleOverrideResponseTypedDict",
    "Payload",
    "PayloadTypedDict",
    "Postmortems",
    "PostmortemsCreatePostmortemBody",
    "PostmortemsCreatePostmortemBodyTypedDict",
    "PostmortemsCreatePostmortemRequest",
    "PostmortemsCreatePostmortemRequestTypedDict",
    "PostmortemsCreatePostmortemResponse",
    "PostmortemsCreatePostmortemResponseTypedDict",
    "PostmortemsDeletePostmortemByIncidentRequest",
    "PostmortemsDeletePostmortemByIncidentRequestTypedDict",
    "PostmortemsDeletePostmortemByIncidentResponse",
    "PostmortemsDeletePostmortemByIncidentResponseTypedDict",
    "PostmortemsGetAllPostmortemsData",
    "PostmortemsGetAllPostmortemsDataTypedDict",
    "PostmortemsGetAllPostmortemsRequest",
    "PostmortemsGetAllPostmortemsRequestTypedDict",
    "PostmortemsGetAllPostmortemsResponse",
    "PostmortemsGetAllPostmortemsResponseTypedDict",
    "PostmortemsGetPostmortemByIncidentRequest",
    "PostmortemsGetPostmortemByIncidentRequestTypedDict",
    "PostmortemsGetPostmortemByIncidentResponse",
    "PostmortemsGetPostmortemByIncidentResponseTypedDict",
    "PostmortemsTypedDict",
    "PostmortemsUpdatePostmortemByIncidentRequest",
    "PostmortemsUpdatePostmortemByIncidentRequestTypedDict",
    "PostmortemsUpdatePostmortemByIncidentResponse",
    "PostmortemsUpdatePostmortemByIncidentResponseTypedDict",
    "Previous",
    "PreviousSuccessfulBuild",
    "PreviousSuccessfulBuildTypedDict",
    "PreviousTypedDict",
    "ReassignTo",
    "ReassignToTypedDict",
    "RequestsStatus",
    "RequestsStatusTypedDict",
    "ResolutionReason",
    "ResolutionReasonTypedDict",
    "ResponseBody1",
    "ResponseBody1TypedDict",
    "ResponseBody2",
    "ResponseBody2TypedDict",
    "RotationsCreateRotationRequest",
    "RotationsCreateRotationRequestTypedDict",
    "RotationsCreateRotationResponse",
    "RotationsCreateRotationResponseTypedDict",
    "RotationsDeleteRotationRequest",
    "RotationsDeleteRotationRequestTypedDict",
    "RotationsDeleteRotationResponseBody",
    "RotationsDeleteRotationResponseBodyTypedDict",
    "RotationsGetRotationParticipantsRequest",
    "RotationsGetRotationParticipantsRequestTypedDict",
    "RotationsGetRotationParticipantsResponse",
    "RotationsGetRotationParticipantsResponseTypedDict",
    "RotationsGetScheduleRotationByIDRequest",
    "RotationsGetScheduleRotationByIDRequestTypedDict",
    "RotationsGetScheduleRotationByIDResponse",
    "RotationsGetScheduleRotationByIDResponseTypedDict",
    "RotationsGetScheduleRotationsRequest",
    "RotationsGetScheduleRotationsRequestTypedDict",
    "RotationsGetScheduleRotationsResponse",
    "RotationsGetScheduleRotationsResponseTypedDict",
    "RotationsUpdateRotationParticipantsRequest",
    "RotationsUpdateRotationParticipantsRequestTypedDict",
    "RotationsUpdateRotationParticipantsResponse",
    "RotationsUpdateRotationParticipantsResponseTypedDict",
    "RotationsUpdateRotationRequest",
    "RotationsUpdateRotationRequestTypedDict",
    "RotationsUpdateRotationResponse",
    "RotationsUpdateRotationResponseTypedDict",
    "RoutingNumbers",
    "RoutingNumbersTypedDict",
    "RoutingRulesCreateOrUpdateRoutingRulesData",
    "RoutingRulesCreateOrUpdateRoutingRulesDataTypedDict",
    "RoutingRulesCreateOrUpdateRoutingRulesRequest",
    "RoutingRulesCreateOrUpdateRoutingRulesRequestTypedDict",
    "RoutingRulesCreateOrUpdateRoutingRulesResponse",
    "RoutingRulesCreateOrUpdateRoutingRulesResponseTypedDict",
    "RoutingRulesGetRoutingRulesData",
    "RoutingRulesGetRoutingRulesDataTypedDict",
    "RoutingRulesGetRoutingRulesRequest",
    "RoutingRulesGetRoutingRulesRequestTypedDict",
    "RoutingRulesGetRoutingRulesResponse",
    "RoutingRulesGetRoutingRulesResponseTypedDict",
    "Runbooks",
    "RunbooksAttachRunbooksRequest",
    "RunbooksAttachRunbooksRequestTypedDict",
    "RunbooksAttachRunbooksResponse",
    "RunbooksAttachRunbooksResponseTypedDict",
    "RunbooksCreateRunbookResponse",
    "RunbooksCreateRunbookResponseTypedDict",
    "RunbooksGetAllRunbooksByTeamResponse",
    "RunbooksGetAllRunbooksByTeamResponseTypedDict",
    "RunbooksGetRunbookByIDRequest",
    "RunbooksGetRunbookByIDRequestTypedDict",
    "RunbooksGetRunbookByIDResponse",
    "RunbooksGetRunbookByIDResponseTypedDict",
    "RunbooksRemoveRunbookRequest",
    "RunbooksRemoveRunbookRequestTypedDict",
    "RunbooksRemoveRunbookResponseBody",
    "RunbooksRemoveRunbookResponseBodyTypedDict",
    "RunbooksTypedDict",
    "RunbooksUpdateRunbookRequest",
    "RunbooksUpdateRunbookRequestTypedDict",
    "RunbooksUpdateRunbookResponse",
    "RunbooksUpdateRunbookResponseTypedDict",
    "SLOCreateSLOData",
    "SLOCreateSLODataTypedDict",
    "SLOCreateSLOResponse",
    "SLOCreateSLOResponseTypedDict",
    "SLOGetAllSLOsData",
    "SLOGetAllSLOsDataTypedDict",
    "SLOGetAllSLOsMeta",
    "SLOGetAllSLOsMetaTypedDict",
    "SLOGetAllSLOsRequest",
    "SLOGetAllSLOsRequestTypedDict",
    "SLOGetAllSLOsResponse",
    "SLOGetAllSLOsResponseTypedDict",
    "SLOGetSLOByIDRequest",
    "SLOGetSLOByIDRequestTypedDict",
    "SLOGetSLOByIDResponse",
    "SLOGetSLOByIDResponseTypedDict",
    "SLOMarkSLOAffectedData",
    "SLOMarkSLOAffectedDataTypedDict",
    "SLOMarkSLOAffectedRequest",
    "SLOMarkSLOAffectedRequestTypedDict",
    "SLOMarkSLOAffectedResponse",
    "SLOMarkSLOAffectedResponseTypedDict",
    "SLOMarkSLOFalsePositiveData",
    "SLOMarkSLOFalsePositiveDataTypedDict",
    "SLOMarkSLOFalsePositiveRequest",
    "SLOMarkSLOFalsePositiveRequestBody",
    "SLOMarkSLOFalsePositiveRequestBodyTypedDict",
    "SLOMarkSLOFalsePositiveRequestTypedDict",
    "SLOMarkSLOFalsePositiveResponse",
    "SLOMarkSLOFalsePositiveResponseTypedDict",
    "SLORemoveSLORequest",
    "SLORemoveSLORequestTypedDict",
    "SLORemoveSLOResponse",
    "SLORemoveSLOResponseTypedDict",
    "SLOUpdateSLOData",
    "SLOUpdateSLODataTypedDict",
    "SLOUpdateSLORequest",
    "SLOUpdateSLORequestTypedDict",
    "SLOUpdateSLOResponse",
    "SLOUpdateSLOResponseTypedDict",
    "Schedules",
    "SchedulesChangeTimezoneRequest",
    "SchedulesChangeTimezoneRequestBody",
    "SchedulesChangeTimezoneRequestBodyTypedDict",
    "SchedulesChangeTimezoneRequestTypedDict",
    "SchedulesChangeTimezoneResponse",
    "SchedulesChangeTimezoneResponseTypedDict",
    "SchedulesCloneScheduleRequest",
    "SchedulesCloneScheduleRequestBody",
    "SchedulesCloneScheduleRequestBodyTypedDict",
    "SchedulesCloneScheduleRequestTypedDict",
    "SchedulesCloneScheduleResponse",
    "SchedulesCloneScheduleResponseTypedDict",
    "SchedulesCreateScheduleResponse",
    "SchedulesCreateScheduleResponseTypedDict",
    "SchedulesDeleteScheduleRequest",
    "SchedulesDeleteScheduleRequestTypedDict",
    "SchedulesDeleteScheduleResponseBody",
    "SchedulesDeleteScheduleResponseBodyTypedDict",
    "SchedulesGetScheduleByIDRequest",
    "SchedulesGetScheduleByIDRequestTypedDict",
    "SchedulesGetScheduleByIDResponse",
    "SchedulesGetScheduleByIDResponseTypedDict",
    "SchedulesListSchedulesRequest",
    "SchedulesListSchedulesRequestTypedDict",
    "SchedulesListSchedulesResponse",
    "SchedulesListSchedulesResponseBody",
    "SchedulesListSchedulesResponseBodyTypedDict",
    "SchedulesListSchedulesResponseTypedDict",
    "SchedulesPauseresumeScheduleRequest",
    "SchedulesPauseresumeScheduleRequestBody",
    "SchedulesPauseresumeScheduleRequestBodyTypedDict",
    "SchedulesPauseresumeScheduleRequestTypedDict",
    "SchedulesPauseresumeScheduleResponse",
    "SchedulesPauseresumeScheduleResponseTypedDict",
    "SchedulesTypedDict",
    "SchedulesUpdateScheduleRequest",
    "SchedulesUpdateScheduleRequestTypedDict",
    "SchedulesUpdateScheduleResponse",
    "SchedulesUpdateScheduleResponseTypedDict",
    "Security",
    "SecurityTypedDict",
    "Services",
    "ServicesCreateOrUpdateAPTAConfigData",
    "ServicesCreateOrUpdateAPTAConfigDataTypedDict",
    "ServicesCreateOrUpdateAPTAConfigRequest",
    "ServicesCreateOrUpdateAPTAConfigRequestTypedDict",
    "ServicesCreateOrUpdateAPTAConfigResponse",
    "ServicesCreateOrUpdateAPTAConfigResponseTypedDict",
    "ServicesCreateOrUpdateIAGConfigData",
    "ServicesCreateOrUpdateIAGConfigDataTypedDict",
    "ServicesCreateOrUpdateIAGConfigRequest",
    "ServicesCreateOrUpdateIAGConfigRequestTypedDict",
    "ServicesCreateOrUpdateIAGConfigResponse",
    "ServicesCreateOrUpdateIAGConfigResponseTypedDict",
    "ServicesCreateServiceBody",
    "ServicesCreateServiceBodyTypedDict",
    "ServicesCreateServiceRequest",
    "ServicesCreateServiceRequestTypedDict",
    "ServicesCreateServiceResponse",
    "ServicesCreateServiceResponseTypedDict",
    "ServicesDelayedNotificationConfigRequest",
    "ServicesDelayedNotificationConfigRequestTypedDict",
    "ServicesDelayedNotificationConfigResponse",
    "ServicesDelayedNotificationConfigResponseTypedDict",
    "ServicesDeleteServiceRequest",
    "ServicesDeleteServiceRequestTypedDict",
    "ServicesDeleteServiceResponseBody",
    "ServicesDeleteServiceResponseBodyTypedDict",
    "ServicesGetServiceByIDRequest",
    "ServicesGetServiceByIDRequestTypedDict",
    "ServicesGetServiceByIDResponse",
    "ServicesGetServiceByIDResponseTypedDict",
    "ServicesGetServicesByNameRequest",
    "ServicesGetServicesByNameRequestTypedDict",
    "ServicesGetServicesByNameResponse",
    "ServicesGetServicesByNameResponseTypedDict",
    "ServicesGetServicesRequest",
    "ServicesGetServicesRequestTypedDict",
    "ServicesGetServicesResponse",
    "ServicesGetServicesResponseTypedDict",
    "ServicesTypedDict",
    "ServicesUpdateServiceRequest",
    "ServicesUpdateServiceRequestTypedDict",
    "ServicesUpdateServiceResponse",
    "ServicesUpdateServiceResponseTypedDict",
    "Slos",
    "SlosTypedDict",
    "SnoozeNotificationsSnoozeIncidentNotificationsRequest",
    "SnoozeNotificationsSnoozeIncidentNotificationsRequestTypedDict",
    "SnoozeNotificationsSnoozeIncidentNotificationsResponse",
    "SnoozeNotificationsSnoozeIncidentNotificationsResponseTypedDict",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsRequest",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsRequestTypedDict",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsResponse",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsResponseTypedDict",
    "Squads",
    "SquadsCreateSquadResponse",
    "SquadsCreateSquadResponseTypedDict",
    "SquadsDeleteSquadRequest",
    "SquadsDeleteSquadRequestTypedDict",
    "SquadsDeleteSquadResponseBody",
    "SquadsDeleteSquadResponseBodyTypedDict",
    "SquadsGetAllSquadsRequest",
    "SquadsGetAllSquadsRequestTypedDict",
    "SquadsGetAllSquadsResponse",
    "SquadsGetAllSquadsResponseTypedDict",
    "SquadsGetSquadByIDRequest",
    "SquadsGetSquadByIDRequestTypedDict",
    "SquadsGetSquadByIDResponse",
    "SquadsGetSquadByIDResponseTypedDict",
    "SquadsRemoveSquadMemberRequest",
    "SquadsRemoveSquadMemberRequestTypedDict",
    "SquadsTypedDict",
    "SquadsUpdateSquadMemberRequest",
    "SquadsUpdateSquadMemberRequestTypedDict",
    "SquadsUpdateSquadNameRequest",
    "SquadsUpdateSquadNameRequestTypedDict",
    "SquadsUpdateSquadNameResponse",
    "SquadsUpdateSquadNameResponseTypedDict",
    "SquadsUpdateSquadRequest",
    "SquadsUpdateSquadRequestTypedDict",
    "SquadsUpdateSquadResponse",
    "SquadsUpdateSquadResponseTypedDict",
    "StakeholderGroups",
    "StakeholderGroupsTypedDict",
    "Status",
    "StatusEnum",
    "StatusMaintenance",
    "StatusMaintenanceTypedDict",
    "StatusPages",
    "StatusPagesCreateStatusPageResponse",
    "StatusPagesCreateStatusPageResponseTypedDict",
    "StatusPagesDeleteStatusPageByIDRequest",
    "StatusPagesDeleteStatusPageByIDRequestTypedDict",
    "StatusPagesDeleteStatusPageByIDResponse",
    "StatusPagesDeleteStatusPageByIDResponseTypedDict",
    "StatusPagesGetStatusPageByIDRequest",
    "StatusPagesGetStatusPageByIDRequestTypedDict",
    "StatusPagesGetStatusPageByIDResponse",
    "StatusPagesGetStatusPageByIDResponseTypedDict",
    "StatusPagesListStatusPageStatusesRequest",
    "StatusPagesListStatusPageStatusesRequestTypedDict",
    "StatusPagesListStatusPageStatusesResponse",
    "StatusPagesListStatusPageStatusesResponseTypedDict",
    "StatusPagesListStatusPagesRequest",
    "StatusPagesListStatusPagesRequestTypedDict",
    "StatusPagesListStatusPagesResponse",
    "StatusPagesListStatusPagesResponseTypedDict",
    "StatusPagesListSubscribersRequest",
    "StatusPagesListSubscribersRequestTypedDict",
    "StatusPagesTypedDict",
    "StatusPagesUpdateStatusPageByIDRequest",
    "StatusPagesUpdateStatusPageByIDRequestTypedDict",
    "StatusPagesUpdateStatusPageByIDResponse",
    "StatusPagesUpdateStatusPageByIDResponseTypedDict",
    "StatusTypedDict",
    "Step",
    "StepTypedDict",
    "SuppressionRulesCreateOrUpdateSuppressionRulesRequest",
    "SuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict",
    "SuppressionRulesCreateOrUpdateSuppressionRulesResponse",
    "SuppressionRulesCreateOrUpdateSuppressionRulesResponseTypedDict",
    "SuppressionRulesGetSuppressionRulesData",
    "SuppressionRulesGetSuppressionRulesDataTypedDict",
    "SuppressionRulesGetSuppressionRulesRequest",
    "SuppressionRulesGetSuppressionRulesRequestTypedDict",
    "SuppressionRulesGetSuppressionRulesResponse",
    "SuppressionRulesGetSuppressionRulesResponseTypedDict",
    "TaggingRulesCreateOrUpdateTaggingRulesData",
    "TaggingRulesCreateOrUpdateTaggingRulesDataTypedDict",
    "TaggingRulesCreateOrUpdateTaggingRulesRequest",
    "TaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict",
    "TaggingRulesCreateOrUpdateTaggingRulesResponse",
    "TaggingRulesCreateOrUpdateTaggingRulesResponseTypedDict",
    "TaggingRulesGetTaggingRulesData",
    "TaggingRulesGetTaggingRulesDataTypedDict",
    "TaggingRulesGetTaggingRulesRequest",
    "TaggingRulesGetTaggingRulesRequestTypedDict",
    "TaggingRulesGetTaggingRulesResponse",
    "TaggingRulesGetTaggingRulesResponseTypedDict",
    "TagsAppendTagRequest",
    "TagsAppendTagRequestTypedDict",
    "TagsAppendTagResponse",
    "TagsAppendTagResponseTypedDict",
    "TagsUpdateTagRequest",
    "TagsUpdateTagRequestTypedDict",
    "TagsUpdateTagResponse",
    "TagsUpdateTagResponseTypedDict",
    "TeamAnalytics",
    "TeamAnalyticsTypedDict",
    "TeamsAddBulkTeamMemberData",
    "TeamsAddBulkTeamMemberDataTypedDict",
    "TeamsAddBulkTeamMemberMember",
    "TeamsAddBulkTeamMemberMemberTypedDict",
    "TeamsAddBulkTeamMemberRequest",
    "TeamsAddBulkTeamMemberRequestTypedDict",
    "TeamsAddBulkTeamMemberResponse",
    "TeamsAddBulkTeamMemberResponseTypedDict",
    "TeamsAddTeamMemberRequest",
    "TeamsAddTeamMemberRequestTypedDict",
    "TeamsAddTeamMemberResponse",
    "TeamsAddTeamMemberResponseTypedDict",
    "TeamsCreateTeamResponse",
    "TeamsCreateTeamResponseTypedDict",
    "TeamsCreateTeamRoleRequest",
    "TeamsCreateTeamRoleRequestTypedDict",
    "TeamsCreateTeamRoleResponse",
    "TeamsCreateTeamRoleResponseTypedDict",
    "TeamsGetAllTeamMembersRequest",
    "TeamsGetAllTeamMembersRequestTypedDict",
    "TeamsGetAllTeamMembersResponse",
    "TeamsGetAllTeamMembersResponseTypedDict",
    "TeamsGetAllTeamRolesRequest",
    "TeamsGetAllTeamRolesRequestTypedDict",
    "TeamsGetAllTeamRolesResponse",
    "TeamsGetAllTeamRolesResponseTypedDict",
    "TeamsGetAllTeamsResponse",
    "TeamsGetAllTeamsResponseTypedDict",
    "TeamsGetTeamByIDRequest",
    "TeamsGetTeamByIDRequestTypedDict",
    "TeamsGetTeamByIDResponse",
    "TeamsGetTeamByIDResponseTypedDict",
    "TeamsRemoveTeamMemberRequest",
    "TeamsRemoveTeamMemberRequestTypedDict",
    "TeamsRemoveTeamMemberResponseBody",
    "TeamsRemoveTeamMemberResponseBodyTypedDict",
    "TeamsRemoveTeamRequest",
    "TeamsRemoveTeamRequestTypedDict",
    "TeamsRemoveTeamResponseBody",
    "TeamsRemoveTeamResponseBodyTypedDict",
    "TeamsRemoveTeamRoleRequest",
    "TeamsRemoveTeamRoleRequestTypedDict",
    "TeamsRemoveTeamRoleResponseBody",
    "TeamsRemoveTeamRoleResponseBodyTypedDict",
    "TeamsUpdateTeamMemberRequest",
    "TeamsUpdateTeamMemberRequestTypedDict",
    "TeamsUpdateTeamMemberResponse",
    "TeamsUpdateTeamMemberResponseTypedDict",
    "TeamsUpdateTeamRequest",
    "TeamsUpdateTeamRequestTypedDict",
    "TeamsUpdateTeamResponse",
    "TeamsUpdateTeamResponseTypedDict",
    "TeamsUpdateTeamRoleRequest",
    "TeamsUpdateTeamRoleRequestTypedDict",
    "TeamsUpdateTeamRoleResponse",
    "TeamsUpdateTeamRoleResponseTypedDict",
    "URL",
    "URLTypedDict",
    "User",
    "UserTypedDict",
    "UsersAddUserResponse",
    "UsersAddUserResponseTypedDict",
    "UsersCreateTokenRequest",
    "UsersCreateTokenRequestTypedDict",
    "UsersCreateTokenResponse",
    "UsersCreateTokenResponseTypedDict",
    "UsersDeleteUserData",
    "UsersDeleteUserDataTypedDict",
    "UsersDeleteUserRequest",
    "UsersDeleteUserRequestTypedDict",
    "UsersDeleteUserResponse",
    "UsersDeleteUserResponseTypedDict",
    "UsersGetAllTokensResponse",
    "UsersGetAllTokensResponseTypedDict",
    "UsersGetAllUsersResponse",
    "UsersGetAllUsersResponseTypedDict",
    "UsersGetUserByIDRequest",
    "UsersGetUserByIDRequestTypedDict",
    "UsersGetUserByIDResponse",
    "UsersGetUserByIDResponseTypedDict",
    "UsersGetUserRolesResponse",
    "UsersGetUserRolesResponseTypedDict",
    "UsersRemoveTokenRequest",
    "UsersRemoveTokenRequestTypedDict",
    "UsersRemoveTokenResponseBody",
    "UsersRemoveTokenResponseBodyTypedDict",
    "UsersRemoveUserFromOrgRequest",
    "UsersRemoveUserFromOrgRequestTypedDict",
    "UsersRemoveUserFromOrgResponseBody",
    "UsersRemoveUserFromOrgResponseBodyTypedDict",
    "UsersUpdateOrgLevelPermissionsResponse",
    "UsersUpdateOrgLevelPermissionsResponseTypedDict",
    "UsersUpdateUserByIDRequest",
    "UsersUpdateUserByIDRequestTypedDict",
    "UsersUpdateUserByIDResponse",
    "UsersUpdateUserByIDResponseTypedDict",
    "V3AnalyticsAnalyticsResponse",
    "V3AnalyticsAnalyticsResponseTypedDict",
    "V3AuditLogsActor",
    "V3AuditLogsActorTypedDict",
    "V3AuditLogsAuditLogIDResponse",
    "V3AuditLogsAuditLogIDResponseMeta",
    "V3AuditLogsAuditLogIDResponseMetaTypedDict",
    "V3AuditLogsAuditLogIDResponseTypedDict",
    "V3AuditLogsAuditLogResponse",
    "V3AuditLogsAuditLogResponseTypedDict",
    "V3AuditLogsAuditLogsExportHistoryResponse",
    "V3AuditLogsAuditLogsExportHistoryResponseTypedDict",
    "V3AuditLogsExportAuditLogsRequest",
    "V3AuditLogsExportAuditLogsRequestTypedDict",
    "V3AuditLogsExportAuditLogsResponse",
    "V3AuditLogsExportAuditLogsResponseData",
    "V3AuditLogsExportAuditLogsResponseDataTypedDict",
    "V3AuditLogsExportAuditLogsResponseTypedDict",
    "V3AuditLogsFilters",
    "V3AuditLogsFiltersTypedDict",
    "V3AuditLogsGetAuditLogByIDResponse",
    "V3AuditLogsGetAuditLogByIDResponseTypedDict",
    "V3AuditLogsGetAuditLogExportHistoryByIDResponse",
    "V3AuditLogsGetAuditLogExportHistoryByIDResponseTypedDict",
    "V3AuditLogsListAuditLogsExportHistoryResponse",
    "V3AuditLogsListAuditLogsExportHistoryResponseMetadata",
    "V3AuditLogsListAuditLogsExportHistoryResponseMetadataTypedDict",
    "V3AuditLogsListAuditLogsExportHistoryResponseTypedDict",
    "V3AuditLogsListAuditLogsResponse",
    "V3AuditLogsListAuditLogsResponseMetadata",
    "V3AuditLogsListAuditLogsResponseMetadataTypedDict",
    "V3AuditLogsListAuditLogsResponseTypedDict",
    "V3AuditLogsTeam",
    "V3AuditLogsTeamTypedDict",
    "V3EscalationPoliciesCreateEscalationPolicyRequest",
    "V3EscalationPoliciesCreateEscalationPolicyRequestTypedDict",
    "V3EscalationPoliciesEscalationEntity",
    "V3EscalationPoliciesEscalationEntityType",
    "V3EscalationPoliciesEscalationEntityTypedDict",
    "V3EscalationPoliciesEscalationPolicyResponse",
    "V3EscalationPoliciesEscalationPolicyResponseTypedDict",
    "V3EscalationPoliciesEscalationPolicyRule",
    "V3EscalationPoliciesEscalationPolicyRuleTypedDict",
    "V3EscalationPoliciesIncidentReminderRule",
    "V3EscalationPoliciesIncidentReminderRuleTypedDict",
    "V3ExportExportResponse",
    "V3ExportExportResponseTypedDict",
    "V3ExtensionsMSTeamsChannelConfiguration",
    "V3ExtensionsMSTeamsChannelConfigurationTypedDict",
    "V3ExtensionsMSTeamsConnectedTeams",
    "V3ExtensionsMSTeamsConnectedTeamsTypedDict",
    "V3ExtensionsMSTeamsCreateOrUpdateMSTeamsConfigRequest",
    "V3ExtensionsMSTeamsCreateOrUpdateMSTeamsConfigRequestTypedDict",
    "V3ExtensionsMSTeamsEventClass",
    "V3ExtensionsMSTeamsEventClassEnum",
    "V3ExtensionsMSTeamsEventClassTypedDict",
    "V3ExtensionsMSTeamsIncidentActionAlertState",
    "V3ExtensionsMSTeamsIncidentActionAlertStateTypedDict",
    "V3ExtensionsMSTeamsMSTeamsConfigResponse",
    "V3ExtensionsMSTeamsMSTeamsConfigResponseTypedDict",
    "V3ExtensionsMSTeamsSquadCastServiceMapping",
    "V3ExtensionsMSTeamsSquadCastServiceMappingTypedDict",
    "V3ExtensionsMSTeamsTriggers",
    "V3ExtensionsMSTeamsTriggersTypedDict",
    "V3ExtensionsWebhooksGetAllWebhooksResponse",
    "V3ExtensionsWebhooksGetAllWebhooksResponseData",
    "V3ExtensionsWebhooksGetAllWebhooksResponseDataTypedDict",
    "V3ExtensionsWebhooksGetAllWebhooksResponseMeta",
    "V3ExtensionsWebhooksGetAllWebhooksResponseMetaTypedDict",
    "V3ExtensionsWebhooksGetAllWebhooksResponseTypedDict",
    "V3ExtensionsWebhooksWebhook",
    "V3ExtensionsWebhooksWebhookFilter",
    "V3ExtensionsWebhooksWebhookFilterCondition",
    "V3ExtensionsWebhooksWebhookFilterConditionTypedDict",
    "V3ExtensionsWebhooksWebhookFilterTypedDict",
    "V3ExtensionsWebhooksWebhookHeader",
    "V3ExtensionsWebhooksWebhookHeaderTypedDict",
    "V3ExtensionsWebhooksWebhookListItem",
    "V3ExtensionsWebhooksWebhookListItemTypedDict",
    "V3ExtensionsWebhooksWebhookResponse",
    "V3ExtensionsWebhooksWebhookResponseHeader",
    "V3ExtensionsWebhooksWebhookResponseHeaderTypedDict",
    "V3ExtensionsWebhooksWebhookResponseTypedDict",
    "V3ExtensionsWebhooksWebhookTrigger",
    "V3ExtensionsWebhooksWebhookTriggerTypedDict",
    "V3ExtensionsWebhooksWebhookTypedDict",
    "V3ExtensionsWebhooksWebhookURL",
    "V3ExtensionsWebhooksWebhookURLTypedDict",
    "V3GlobalEventRulesCreateGlobalEventRuleRequest",
    "V3GlobalEventRulesCreateGlobalEventRuleRequestTypedDict",
    "V3GlobalEventRulesCreateOrUpdateRuleRequest",
    "V3GlobalEventRulesCreateOrUpdateRuleRequestTypedDict",
    "V3GlobalEventRulesCreateRulesetRequest",
    "V3GlobalEventRulesCreateRulesetRequestTypedDict",
    "V3GlobalEventRulesCreatedGlobalEventRuleResponse",
    "V3GlobalEventRulesCreatedGlobalEventRuleResponseTypedDict",
    "V3GlobalEventRulesEntityOwner",
    "V3GlobalEventRulesEntityOwnerType",
    "V3GlobalEventRulesEntityOwnerTypedDict",
    "V3GlobalEventRulesEntityOwnerUpdate",
    "V3GlobalEventRulesEntityOwnerUpdateType",
    "V3GlobalEventRulesEntityOwnerUpdateTypedDict",
    "V3GlobalEventRulesGlobalEventRuleInList",
    "V3GlobalEventRulesGlobalEventRuleInListTypedDict",
    "V3GlobalEventRulesGlobalEventRuleResponse",
    "V3GlobalEventRulesGlobalEventRuleResponseTypedDict",
    "V3GlobalEventRulesOrderingResponse",
    "V3GlobalEventRulesOrderingResponseTypedDict",
    "V3GlobalEventRulesReorderRuleRequest",
    "V3GlobalEventRulesReorderRuleRequestTypedDict",
    "V3GlobalEventRulesReorderRulesetRequest",
    "V3GlobalEventRulesReorderRulesetRequestTypedDict",
    "V3GlobalEventRulesRuleAction",
    "V3GlobalEventRulesRuleActionTypedDict",
    "V3GlobalEventRulesRuleActionUpdate",
    "V3GlobalEventRulesRuleActionUpdateTypedDict",
    "V3GlobalEventRulesRuleset",
    "V3GlobalEventRulesRulesetResponse",
    "V3GlobalEventRulesRulesetResponseTypedDict",
    "V3GlobalEventRulesRulesetRuleResponse",
    "V3GlobalEventRulesRulesetRuleResponseTypedDict",
    "V3GlobalEventRulesRulesetTypedDict",
    "V3GlobalEventRulesUpdateGlobalEventRuleRequest",
    "V3GlobalEventRulesUpdateGlobalEventRuleRequestTypedDict",
    "V3GlobalEventRulesUpdateRuleRequest",
    "V3GlobalEventRulesUpdateRuleRequestTypedDict",
    "V3GlobalEventRulesUpdateRulesetRequest",
    "V3GlobalEventRulesUpdateRulesetRequestTypedDict",
    "V3GlobalOncallReminderRulesCreateGlobalOncallReminderRulesRequest",
    "V3GlobalOncallReminderRulesCreateGlobalOncallReminderRulesRequestTypedDict",
    "V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse",
    "V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict",
    "V3GlobalOncallReminderRulesRule",
    "V3GlobalOncallReminderRulesRuleTypedDict",
    "V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest",
    "V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict",
    "V3IncidentsAdditionalResponderDetails",
    "V3IncidentsAdditionalResponderDetailsTypedDict",
    "V3IncidentsAdditionalRespondersAddAdditionalRespondersRequest",
    "V3IncidentsAdditionalRespondersAddAdditionalRespondersRequestTypedDict",
    "V3IncidentsAdditionalRespondersAdditionalResponder",
    "V3IncidentsAdditionalRespondersAdditionalResponderResponse",
    "V3IncidentsAdditionalRespondersAdditionalResponderResponseTypedDict",
    "V3IncidentsAdditionalRespondersAdditionalResponderTypedDict",
    "V3IncidentsAnalytics",
    "V3IncidentsAnalyticsMetrics",
    "V3IncidentsAnalyticsMetricsTypedDict",
    "V3IncidentsAnalyticsTypedDict",
    "V3IncidentsAptaMessageResponse",
    "V3IncidentsAptaMessageResponseTypedDict",
    "V3IncidentsAssignTo",
    "V3IncidentsAssignToTypedDict",
    "V3IncidentsAssignedTo",
    "V3IncidentsAssignedToTypedDict",
    "V3IncidentsBulkIncidentIDsRequest",
    "V3IncidentsBulkIncidentIDsRequestTypedDict",
    "V3IncidentsBulkIncidentsPriorityUpdateRequest",
    "V3IncidentsBulkIncidentsPriorityUpdateRequestTypedDict",
    "V3IncidentsCommunicationCardsArchiveSlackChannelRequest",
    "V3IncidentsCommunicationCardsArchiveSlackChannelRequestTypedDict",
    "V3IncidentsCommunicationCardsCommunicationCardResponse",
    "V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict",
    "V3IncidentsCommunicationCardsCreateCommunicationCardRequest",
    "V3IncidentsCommunicationCardsCreateCommunicationCardRequestTypedDict",
    "V3IncidentsCommunicationCardsCreateSlackChannelRequest",
    "V3IncidentsCommunicationCardsCreateSlackChannelRequestTypedDict",
    "V3IncidentsCommunicationCardsUpdateCommunicationCardRequest",
    "V3IncidentsCommunicationCardsUpdateCommunicationCardRequestTypedDict",
    "V3IncidentsDedupData",
    "V3IncidentsDedupDataTypedDict",
    "V3IncidentsExportFormat",
    "V3IncidentsExportIncidentsFilter",
    "V3IncidentsExportIncidentsFilterTypedDict",
    "V3IncidentsIncidentActionsCircleCIErrorMeta",
    "V3IncidentsIncidentActionsCircleCIErrorMetaTypedDict",
    "V3IncidentsIncidentActionsCircleCIRebuildResponse",
    "V3IncidentsIncidentActionsCircleCIRebuildResponseTypedDict",
    "V3IncidentsIncidentActionsRebuildCircleCIProjectRequest",
    "V3IncidentsIncidentActionsRebuildCircleCIProjectRequestTypedDict",
    "V3IncidentsIncidentActionsWebhookActionResponse",
    "V3IncidentsIncidentActionsWebhookActionResponseHeader",
    "V3IncidentsIncidentActionsWebhookActionResponseHeaderTypedDict",
    "V3IncidentsIncidentActionsWebhookActionResponseTypedDict",
    "V3IncidentsIncidentEventResponse",
    "V3IncidentsIncidentEventResponseTags",
    "V3IncidentsIncidentEventResponseTagsTypedDict",
    "V3IncidentsIncidentEventResponseTypedDict",
    "V3IncidentsIncidentExportAsyncRequest",
    "V3IncidentsIncidentExportAsyncRequestTypedDict",
    "V3IncidentsIncidentExportAsyncResponse",
    "V3IncidentsIncidentExportAsyncResponseTypedDict",
    "V3IncidentsIncidentExportRequestIsStarred",
    "V3IncidentsIncidentExportRequestNotes",
    "V3IncidentsIncidentExportRequestRetrospectives",
    "V3IncidentsIncidentExportRequestSloAffecting",
    "V3IncidentsIncidentExportRequestSortBy",
    "V3IncidentsIncidentPriority",
    "V3IncidentsIncidentPriorityUpdateRequest",
    "V3IncidentsIncidentPriorityUpdateRequestTypedDict",
    "V3IncidentsIncidentPriorityUpdateResponse",
    "V3IncidentsIncidentPriorityUpdateResponseTypedDict",
    "V3IncidentsIncidentResponse",
    "V3IncidentsIncidentResponseRetriggerPolicy",
    "V3IncidentsIncidentResponseRetriggerPolicyTypedDict",
    "V3IncidentsIncidentResponseTags",
    "V3IncidentsIncidentResponseTagsTypedDict",
    "V3IncidentsIncidentResponseTypedDict",
    "V3IncidentsIngestionStatusRequest",
    "V3IncidentsIngestionStatusRequestTypedDict",
    "V3IncidentsLogs",
    "V3IncidentsLogsAdditionalInfo",
    "V3IncidentsLogsAdditionalInfoTypedDict",
    "V3IncidentsLogsTypedDict",
    "V3IncidentsMergeIncidentEntityReference",
    "V3IncidentsMergeIncidentEntityReferenceTypedDict",
    "V3IncidentsNotesCreateNoteRequest",
    "V3IncidentsNotesCreateNoteRequestTypedDict",
    "V3IncidentsNotesNoteResponse",
    "V3IncidentsNotesNoteResponseTypedDict",
    "V3IncidentsNotesUpdateNoteRequest",
    "V3IncidentsNotesUpdateNoteRequestTypedDict",
    "V3IncidentsNotificationDelayPolicy",
    "V3IncidentsNotificationDelayPolicyTypedDict",
    "V3IncidentsPinnedMessage",
    "V3IncidentsPinnedMessageTypedDict",
    "V3IncidentsPostmortemsCreatePostmortemRequest",
    "V3IncidentsPostmortemsCreatePostmortemRequestTypedDict",
    "V3IncidentsPostmortemsPostmortemAttachmentRequest",
    "V3IncidentsPostmortemsPostmortemAttachmentRequestTypedDict",
    "V3IncidentsPostmortemsPostmortemFollowUp",
    "V3IncidentsPostmortemsPostmortemFollowUpTypedDict",
    "V3IncidentsPostmortemsPostmortemListResult",
    "V3IncidentsPostmortemsPostmortemListResultIncident",
    "V3IncidentsPostmortemsPostmortemListResultIncidentTypedDict",
    "V3IncidentsPostmortemsPostmortemListResultTypedDict",
    "V3IncidentsPostmortemsPostmortemResponse",
    "V3IncidentsPostmortemsPostmortemResponseIncident",
    "V3IncidentsPostmortemsPostmortemResponseIncidentTypedDict",
    "V3IncidentsPostmortemsPostmortemResponseTypedDict",
    "V3IncidentsPostmortemsPostmortemStatus",
    "V3IncidentsPostmortemsTotalPostmortemCount",
    "V3IncidentsPostmortemsTotalPostmortemCountTypedDict",
    "V3IncidentsPostmortemsUpdatePostmortemRequest",
    "V3IncidentsPostmortemsUpdatePostmortemRequestTypedDict",
    "V3IncidentsReassignIncidentRequest",
    "V3IncidentsReassignIncidentRequestTypedDict",
    "V3IncidentsRelevantPeopleLog",
    "V3IncidentsRelevantPeopleLogTypedDict",
    "V3IncidentsResolveIncidentRequest",
    "V3IncidentsResolveIncidentRequestTypedDict",
    "V3IncidentsResponseNote",
    "V3IncidentsResponseNoteTypedDict",
    "V3IncidentsRunbooksAttachRunbooksRequest",
    "V3IncidentsRunbooksAttachRunbooksRequestTypedDict",
    "V3IncidentsRunbooksRunbookResponse",
    "V3IncidentsRunbooksRunbookResponseTypedDict",
    "V3IncidentsServiceOwnerFilter",
    "V3IncidentsServiceOwnerFilterTypedDict",
    "V3IncidentsSnoozeDetails",
    "V3IncidentsSnoozeDetailsTypedDict",
    "V3IncidentsSnoozeNotificationsReassignTo",
    "V3IncidentsSnoozeNotificationsReassignToTypedDict",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentRequest",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentRequestTypedDict",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentResponse",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentResponseTypedDict",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequest",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequestTypedDict",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentResponse",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentResponseTypedDict",
    "V3IncidentsTagsAdditionalResponderDetails",
    "V3IncidentsTagsAdditionalResponderDetailsTypedDict",
    "V3IncidentsTagsAnalytics",
    "V3IncidentsTagsAnalyticsMetrics",
    "V3IncidentsTagsAnalyticsMetricsTypedDict",
    "V3IncidentsTagsAnalyticsTypedDict",
    "V3IncidentsTagsAppendTagRequest",
    "V3IncidentsTagsAppendTagRequestTags",
    "V3IncidentsTagsAppendTagRequestTagsTypedDict",
    "V3IncidentsTagsAppendTagRequestTypedDict",
    "V3IncidentsTagsAssignTo",
    "V3IncidentsTagsAssignToTypedDict",
    "V3IncidentsTagsAssignedTo",
    "V3IncidentsTagsAssignedToTypedDict",
    "V3IncidentsTagsDedupData",
    "V3IncidentsTagsDedupDataTypedDict",
    "V3IncidentsTagsIncidentForTagsResponse",
    "V3IncidentsTagsIncidentForTagsResponseRetriggerPolicy",
    "V3IncidentsTagsIncidentForTagsResponseRetriggerPolicyTypedDict",
    "V3IncidentsTagsIncidentForTagsResponseTags",
    "V3IncidentsTagsIncidentForTagsResponseTagsTypedDict",
    "V3IncidentsTagsIncidentForTagsResponseTypedDict",
    "V3IncidentsTagsIncidentPriority",
    "V3IncidentsTagsLogs",
    "V3IncidentsTagsLogsAdditionalInfo",
    "V3IncidentsTagsLogsAdditionalInfoTypedDict",
    "V3IncidentsTagsLogsTypedDict",
    "V3IncidentsTagsMergeIncidentEntityReference",
    "V3IncidentsTagsMergeIncidentEntityReferenceTypedDict",
    "V3IncidentsTagsNotificationDelayPolicy",
    "V3IncidentsTagsNotificationDelayPolicyTypedDict",
    "V3IncidentsTagsPinnedMessage",
    "V3IncidentsTagsPinnedMessageTypedDict",
    "V3IncidentsTagsRelevantPeopleLog",
    "V3IncidentsTagsRelevantPeopleLogTypedDict",
    "V3IncidentsTagsResponseNote",
    "V3IncidentsTagsResponseNoteTypedDict",
    "V3IncidentsTagsSnoozeDetails",
    "V3IncidentsTagsSnoozeDetailsTypedDict",
    "V3IncidentsTagsUpdateTagRequest",
    "V3IncidentsTagsUpdateTagRequestTags",
    "V3IncidentsTagsUpdateTagRequestTagsTypedDict",
    "V3IncidentsTagsUpdateTagRequestTypedDict",
    "V3RunbooksCreateRunbookRequest",
    "V3RunbooksCreateRunbookRequestTypedDict",
    "V3RunbooksRunbookResponse",
    "V3RunbooksRunbookResponseTypedDict",
    "V3RunbooksStep",
    "V3RunbooksStepTypedDict",
    "V3RunbooksUpdateRunbookRequest",
    "V3RunbooksUpdateRunbookRequestTypedDict",
    "V3RunbooksUpdationInfo",
    "V3RunbooksUpdationInfoTypedDict",
    "V3SLOCreateSLORequest",
    "V3SLOCreateSLORequestTags",
    "V3SLOCreateSLORequestTagsTypedDict",
    "V3SLOCreateSLORequestTypedDict",
    "V3SLOMarkSLOAffectedRequest",
    "V3SLOMarkSLOAffectedRequestTypedDict",
    "V3SLOSLOAction",
    "V3SLOSLOActionType",
    "V3SLOSLOActionTypedDict",
    "V3SLOSLODetailedResponse",
    "V3SLOSLODetailedResponseTags",
    "V3SLOSLODetailedResponseTagsTypedDict",
    "V3SLOSLODetailedResponseTypedDict",
    "V3SLOSLOMonitoringCheck",
    "V3SLOSLOMonitoringCheckTypedDict",
    "V3SLOSLOOwnerType",
    "V3SLOSLOResponse",
    "V3SLOSLOResponseTags",
    "V3SLOSLOResponseTagsTypedDict",
    "V3SLOSLOResponseTypedDict",
    "V3SLOSLOTags",
    "V3SLOSLOTagsTypedDict",
    "V3SLOSLOViolatingIncidentResponse",
    "V3SLOSLOViolatingIncidentResponseTypedDict",
    "V3SLOSLOWithInsightsResponse",
    "V3SLOSLOWithInsightsResponseTypedDict",
    "V3SLOTimeIntervalType",
    "V3ServicesAPTAConfig",
    "V3ServicesAPTAConfigRequest",
    "V3ServicesAPTAConfigRequestTypedDict",
    "V3ServicesAPTAConfigTypedDict",
    "V3ServicesCreateServiceRequest",
    "V3ServicesCreateServiceRequestTypedDict",
    "V3ServicesDedupInitConfig",
    "V3ServicesDedupInitConfigTimeUnit",
    "V3ServicesDedupInitConfigTypedDict",
    "V3ServicesDeduplicationRulesCreateDeduplicationRulesRequest",
    "V3ServicesDeduplicationRulesCreateDeduplicationRulesRequestTypedDict",
    "V3ServicesDeduplicationRulesDeduplicationRule",
    "V3ServicesDeduplicationRulesDeduplicationRuleResponse",
    "V3ServicesDeduplicationRulesDeduplicationRuleResponseTimeUnit",
    "V3ServicesDeduplicationRulesDeduplicationRuleResponseTypedDict",
    "V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit",
    "V3ServicesDeduplicationRulesDeduplicationRuleTypedDict",
    "V3ServicesDeduplicationRulesExpressionBranch",
    "V3ServicesDeduplicationRulesExpressionBranchOp",
    "V3ServicesDeduplicationRulesExpressionBranchRHS",
    "V3ServicesDeduplicationRulesExpressionBranchRHSTypedDict",
    "V3ServicesDeduplicationRulesExpressionBranchTypedDict",
    "V3ServicesDependenciesCreateOrUpdateDependenciesRequest",
    "V3ServicesDependenciesCreateOrUpdateDependenciesRequestTypedDict",
    "V3ServicesEscalationPolicyBasic",
    "V3ServicesEscalationPolicyBasicTypedDict",
    "V3ServicesExtensionsSlackExtensionResponse",
    "V3ServicesExtensionsSlackExtensionResponseTypedDict",
    "V3ServicesExtensionsUpdateSlackExtensionRequest",
    "V3ServicesExtensionsUpdateSlackExtensionRequestTypedDict",
    "V3ServicesIAGConfig",
    "V3ServicesIAGConfigRequest",
    "V3ServicesIAGConfigRequestTypedDict",
    "V3ServicesIAGConfigTypedDict",
    "V3ServicesJiraCloudExtension",
    "V3ServicesJiraCloudExtensionTypedDict",
    "V3ServicesJiraIssueType",
    "V3ServicesJiraIssueTypeTypedDict",
    "V3ServicesJiraProject",
    "V3ServicesJiraProjectTypedDict",
    "V3ServicesJiraStatus",
    "V3ServicesJiraStatusMap",
    "V3ServicesJiraStatusMapTypedDict",
    "V3ServicesJiraStatusTypedDict",
    "V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest",
    "V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict",
    "V3ServicesMaintenanceModeMaintenanceModeResponse",
    "V3ServicesMaintenanceModeMaintenanceModeResponseTypedDict",
    "V3ServicesMaintenanceModeServiceMaintenance",
    "V3ServicesMaintenanceModeServiceMaintenanceTypedDict",
    "V3ServicesNotificationDelayConfig",
    "V3ServicesNotificationDelayConfigAssignedTo",
    "V3ServicesNotificationDelayConfigAssignedToTypedDict",
    "V3ServicesNotificationDelayConfigCustomTimeslots",
    "V3ServicesNotificationDelayConfigCustomTimeslotsTypedDict",
    "V3ServicesNotificationDelayConfigFixedTimeslotConfig",
    "V3ServicesNotificationDelayConfigFixedTimeslotConfigTypedDict",
    "V3ServicesNotificationDelayConfigRequest",
    "V3ServicesNotificationDelayConfigRequestAssignedTo",
    "V3ServicesNotificationDelayConfigRequestAssignedToTypedDict",
    "V3ServicesNotificationDelayConfigRequestCustomTimeslots",
    "V3ServicesNotificationDelayConfigRequestCustomTimeslotsTypedDict",
    "V3ServicesNotificationDelayConfigRequestFixedTimeslotConfig",
    "V3ServicesNotificationDelayConfigRequestFixedTimeslotConfigTypedDict",
    "V3ServicesNotificationDelayConfigRequestTypedDict",
    "V3ServicesNotificationDelayConfigTypedDict",
    "V3ServicesOverlayCustomContent",
    "V3ServicesOverlayCustomContentOverlayResponse",
    "V3ServicesOverlayCustomContentOverlayResponseOverlayTemplateType",
    "V3ServicesOverlayCustomContentOverlayResponseTypedDict",
    "V3ServicesOverlayCustomContentTypedDict",
    "V3ServicesOverlayDedupKeyOverlay",
    "V3ServicesOverlayDedupKeyOverlayTypedDict",
    "V3ServicesOverlayOptInForKeyBasedDeduplicationRequest",
    "V3ServicesOverlayOptInForKeyBasedDeduplicationRequestTypedDict",
    "V3ServicesOverlayOverlayResponse",
    "V3ServicesOverlayOverlayResponseOverlayTemplateType",
    "V3ServicesOverlayOverlayResponseTypedDict",
    "V3ServicesOverlayRenderCustomContentOverlayRequest",
    "V3ServicesOverlayRenderCustomContentOverlayRequestTypedDict",
    "V3ServicesOverlayRenderDedupKeyTemplateRequest",
    "V3ServicesOverlayRenderDedupKeyTemplateRequestTypedDict",
    "V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest",
    "V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict",
    "V3ServicesOverlayUpdateDedupKeyOverlayRequest",
    "V3ServicesOverlayUpdateDedupKeyOverlayRequestTypedDict",
    "V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequest",
    "V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequestTypedDict",
    "V3ServicesRoutingRulesExpressionBranch",
    "V3ServicesRoutingRulesExpressionBranchOp",
    "V3ServicesRoutingRulesExpressionBranchRHS",
    "V3ServicesRoutingRulesExpressionBranchRHSTypedDict",
    "V3ServicesRoutingRulesExpressionBranchTypedDict",
    "V3ServicesRoutingRulesRoutingRule",
    "V3ServicesRoutingRulesRoutingRuleEntityType",
    "V3ServicesRoutingRulesRoutingRuleResponse",
    "V3ServicesRoutingRulesRoutingRuleResponseEntityType",
    "V3ServicesRoutingRulesRoutingRuleResponseRouteTo",
    "V3ServicesRoutingRulesRoutingRuleResponseRouteToTypedDict",
    "V3ServicesRoutingRulesRoutingRuleResponseTypedDict",
    "V3ServicesRoutingRulesRoutingRuleRouteTo",
    "V3ServicesRoutingRulesRoutingRuleRouteToTypedDict",
    "V3ServicesRoutingRulesRoutingRuleTypedDict",
    "V3ServicesServiceMaintainer",
    "V3ServicesServiceMaintainerType",
    "V3ServicesServiceMaintainerTypedDict",
    "V3ServicesServiceResponse",
    "V3ServicesServiceResponseTypedDict",
    "V3ServicesServiceSlack",
    "V3ServicesServiceSlackTypedDict",
    "V3ServicesServiceTag",
    "V3ServicesServiceTagTypedDict",
    "V3ServicesSuppressionRulesBasicExpression",
    "V3ServicesSuppressionRulesBasicExpressionTypedDict",
    "V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequest",
    "V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict",
    "V3ServicesSuppressionRulesCustomRepetition",
    "V3ServicesSuppressionRulesCustomRepetitionTypedDict",
    "V3ServicesSuppressionRulesSuppressionRule",
    "V3ServicesSuppressionRulesSuppressionRuleResponse",
    "V3ServicesSuppressionRulesSuppressionRuleResponseTypedDict",
    "V3ServicesSuppressionRulesSuppressionRuleTypedDict",
    "V3ServicesSuppressionRulesSuppressionRulesContainerResponse",
    "V3ServicesSuppressionRulesSuppressionRulesContainerResponseTypedDict",
    "V3ServicesSuppressionRulesTimeslot",
    "V3ServicesSuppressionRulesTimeslotTypedDict",
    "V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest",
    "V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict",
    "V3ServicesTaggingRulesExpressionBranch",
    "V3ServicesTaggingRulesExpressionBranchOp",
    "V3ServicesTaggingRulesExpressionBranchRHS",
    "V3ServicesTaggingRulesExpressionBranchRHSTypedDict",
    "V3ServicesTaggingRulesExpressionBranchTypedDict",
    "V3ServicesTaggingRulesTagConfigObject",
    "V3ServicesTaggingRulesTagConfigObjectTypedDict",
    "V3ServicesTaggingRulesTagRule",
    "V3ServicesTaggingRulesTagRuleTypedDict",
    "V3ServicesTaggingRulesTaggingRuleResponse",
    "V3ServicesTaggingRulesTaggingRuleResponseTypedDict",
    "V3ServicesTaggingRulesTagsObject",
    "V3ServicesTaggingRulesTagsObjectTypedDict",
    "V3ServicesUpdateServiceRequest",
    "V3ServicesUpdateServiceRequestTypedDict",
    "V3SloSlo",
    "V3SloSloTypedDict",
    "V3TeamsAbilities",
    "V3TeamsAbilitiesTypedDict",
    "V3TeamsAddBulkTeamMemberRequest",
    "V3TeamsAddBulkTeamMemberRequestMember",
    "V3TeamsAddBulkTeamMemberRequestMemberTypedDict",
    "V3TeamsAddBulkTeamMemberRequestTypedDict",
    "V3TeamsAddTeamMemberRequest",
    "V3TeamsAddTeamMemberRequestTypedDict",
    "V3TeamsCreateTeamRequest",
    "V3TeamsCreateTeamRequestTypedDict",
    "V3TeamsCreateTeamRoleRequest",
    "V3TeamsCreateTeamRoleRequestTypedDict",
    "V3TeamsTeamBaseResponse",
    "V3TeamsTeamBaseResponseTypedDict",
    "V3TeamsTeamMember",
    "V3TeamsTeamMemberResponse",
    "V3TeamsTeamMemberResponseTypedDict",
    "V3TeamsTeamMemberTypedDict",
    "V3TeamsTeamResponse",
    "V3TeamsTeamResponseTypedDict",
    "V3TeamsTeamRole",
    "V3TeamsTeamRoleResponse",
    "V3TeamsTeamRoleResponseTypedDict",
    "V3TeamsTeamRoleTypedDict",
    "V3TeamsUpdateTeamMemberRequest",
    "V3TeamsUpdateTeamMemberRequestTypedDict",
    "V3TeamsUpdateTeamRequest",
    "V3TeamsUpdateTeamRequestMember",
    "V3TeamsUpdateTeamRequestMemberTypedDict",
    "V3TeamsUpdateTeamRequestTypedDict",
    "V3TeamsUpdateTeamRoleRequest",
    "V3TeamsUpdateTeamRoleRequestTypedDict",
    "V3UsersAPITokenResponse",
    "V3UsersAPITokenResponseTypedDict",
    "V3UsersAddUserRequest",
    "V3UsersAddUserRequestRole",
    "V3UsersAddUserRequestTypedDict",
    "V3UsersContact",
    "V3UsersContactTypedDict",
    "V3UsersGlobalRBACAbilityName",
    "V3UsersNotificationRule",
    "V3UsersNotificationRuleTypedDict",
    "V3UsersUpdateUserAbilitiesRequest",
    "V3UsersUpdateUserAbilitiesRequestData",
    "V3UsersUpdateUserAbilitiesRequestDataTypedDict",
    "V3UsersUpdateUserAbilitiesRequestTypedDict",
    "V3UsersUpdateUserRequest",
    "V3UsersUpdateUserRequestRole",
    "V3UsersUpdateUserRequestTypedDict",
    "V3UsersUserResponse",
    "V3UsersUserResponseTypedDict",
    "V3UsersUserRoleResponse",
    "V3UsersUserRoleResponseTypedDict",
    "V3WebformsCreateOrUpdateWebformRequest",
    "V3WebformsCreateOrUpdateWebformRequestTags",
    "V3WebformsCreateOrUpdateWebformRequestTagsTypedDict",
    "V3WebformsCreateOrUpdateWebformRequestTypedDict",
    "V3WebformsRecaptchaSecrets",
    "V3WebformsRecaptchaSecretsTypedDict",
    "V3WebformsWFInputField",
    "V3WebformsWFInputFieldTypedDict",
    "V3WebformsWFService",
    "V3WebformsWFServiceTypedDict",
    "V3WebformsWebformResponse",
    "V3WebformsWebformResponseTags",
    "V3WebformsWebformResponseTagsTypedDict",
    "V3WebformsWebformResponseTypedDict",
    "V3WorkflowsActionRequest",
    "V3WorkflowsActionRequestData",
    "V3WorkflowsActionRequestDataTypedDict",
    "V3WorkflowsActionRequestName",
    "V3WorkflowsActionRequestSqAttachRunbooks",
    "V3WorkflowsActionRequestSqAttachRunbooksTypedDict",
    "V3WorkflowsActionRequestTypedDict",
    "V3WorkflowsActionRequestUpdate",
    "V3WorkflowsActionRequestUpdateData",
    "V3WorkflowsActionRequestUpdateDataTypedDict",
    "V3WorkflowsActionRequestUpdateName",
    "V3WorkflowsActionRequestUpdateSqAttachRunbooks",
    "V3WorkflowsActionRequestUpdateSqAttachRunbooksTypedDict",
    "V3WorkflowsActionRequestUpdateTypedDict",
    "V3WorkflowsActionResponse",
    "V3WorkflowsActionResponseData",
    "V3WorkflowsActionResponseDataTypedDict",
    "V3WorkflowsActionResponseName",
    "V3WorkflowsActionResponseSqAttachRunbooks",
    "V3WorkflowsActionResponseSqAttachRunbooksTypedDict",
    "V3WorkflowsActionResponseTypedDict",
    "V3WorkflowsBulkEnableDisableWorkflowsRequest",
    "V3WorkflowsBulkEnableDisableWorkflowsRequestTypedDict",
    "V3WorkflowsCommunicationChannel",
    "V3WorkflowsCommunicationChannelType",
    "V3WorkflowsCommunicationChannelTypedDict",
    "V3WorkflowsComponentAndImpact",
    "V3WorkflowsComponentAndImpactTypedDict",
    "V3WorkflowsCreateWorkflowFilter",
    "V3WorkflowsCreateWorkflowFilterTypedDict",
    "V3WorkflowsCreateWorkflowRequest",
    "V3WorkflowsCreateWorkflowRequestOwnerType",
    "V3WorkflowsCreateWorkflowRequestTypedDict",
    "V3WorkflowsCreateWorkflowRequestUpdate",
    "V3WorkflowsCreateWorkflowRequestUpdateOwnerType",
    "V3WorkflowsCreateWorkflowRequestUpdateTypedDict",
    "V3WorkflowsEnableDisableWorkflowRequest",
    "V3WorkflowsEnableDisableWorkflowRequestTypedDict",
    "V3WorkflowsEntityOwner",
    "V3WorkflowsEntityOwnerTypedDict",
    "V3WorkflowsEntityOwnerUpdate",
    "V3WorkflowsEntityOwnerUpdateTypedDict",
    "V3WorkflowsGetWorkflowActionByIDResponse",
    "V3WorkflowsGetWorkflowActionByIDResponseTypedDict",
    "V3WorkflowsGetWorkflowByIDResponse",
    "V3WorkflowsGetWorkflowByIDResponseTypedDict",
    "V3WorkflowsGetWorkflowLogsResponse",
    "V3WorkflowsGetWorkflowLogsResponseData",
    "V3WorkflowsGetWorkflowLogsResponseDataTypedDict",
    "V3WorkflowsGetWorkflowLogsResponseMeta",
    "V3WorkflowsGetWorkflowLogsResponseMetaTypedDict",
    "V3WorkflowsGetWorkflowLogsResponseTypedDict",
    "V3WorkflowsIssueStatusAndMessage",
    "V3WorkflowsIssueStatusAndMessageTypedDict",
    "V3WorkflowsJiraCreateTicket",
    "V3WorkflowsJiraCreateTicketData",
    "V3WorkflowsJiraCreateTicketDataTypedDict",
    "V3WorkflowsJiraCreateTicketName",
    "V3WorkflowsJiraCreateTicketTypedDict",
    "V3WorkflowsJiraCreateTicketUpdate",
    "V3WorkflowsJiraCreateTicketUpdateData",
    "V3WorkflowsJiraCreateTicketUpdateDataTypedDict",
    "V3WorkflowsJiraCreateTicketUpdateName",
    "V3WorkflowsJiraCreateTicketUpdateTypedDict",
    "V3WorkflowsListWorkflowAPIResponse",
    "V3WorkflowsListWorkflowAPIResponseMeta",
    "V3WorkflowsListWorkflowAPIResponseMetaTypedDict",
    "V3WorkflowsListWorkflowAPIResponseTypedDict",
    "V3WorkflowsMsTeamsCreateMeetingLink",
    "V3WorkflowsMsTeamsCreateMeetingLinkName",
    "V3WorkflowsMsTeamsCreateMeetingLinkTypedDict",
    "V3WorkflowsMsTeamsCreateMeetingLinkUpdate",
    "V3WorkflowsMsTeamsCreateMeetingLinkUpdateName",
    "V3WorkflowsMsTeamsCreateMeetingLinkUpdateTypedDict",
    "V3WorkflowsMsTeamsMessageChannel",
    "V3WorkflowsMsTeamsMessageChannelData",
    "V3WorkflowsMsTeamsMessageChannelDataTypedDict",
    "V3WorkflowsMsTeamsMessageChannelName",
    "V3WorkflowsMsTeamsMessageChannelTypedDict",
    "V3WorkflowsMsTeamsMessageChannelUpdate",
    "V3WorkflowsMsTeamsMessageChannelUpdateData",
    "V3WorkflowsMsTeamsMessageChannelUpdateDataTypedDict",
    "V3WorkflowsMsTeamsMessageChannelUpdateName",
    "V3WorkflowsMsTeamsMessageChannelUpdateTypedDict",
    "V3WorkflowsMsTeamsMessageUser",
    "V3WorkflowsMsTeamsMessageUserData",
    "V3WorkflowsMsTeamsMessageUserDataTypedDict",
    "V3WorkflowsMsTeamsMessageUserName",
    "V3WorkflowsMsTeamsMessageUserTypedDict",
    "V3WorkflowsMsTeamsMessageUserUpdate",
    "V3WorkflowsMsTeamsMessageUserUpdateData",
    "V3WorkflowsMsTeamsMessageUserUpdateDataTypedDict",
    "V3WorkflowsMsTeamsMessageUserUpdateName",
    "V3WorkflowsMsTeamsMessageUserUpdateTypedDict",
    "V3WorkflowsRunbookResponse",
    "V3WorkflowsRunbookResponseTypedDict",
    "V3WorkflowsSlackArchiveChannel",
    "V3WorkflowsSlackArchiveChannelName",
    "V3WorkflowsSlackArchiveChannelTypedDict",
    "V3WorkflowsSlackArchiveChannelUpdate",
    "V3WorkflowsSlackArchiveChannelUpdateName",
    "V3WorkflowsSlackArchiveChannelUpdateTypedDict",
    "V3WorkflowsSlackCreateIncidentChannel",
    "V3WorkflowsSlackCreateIncidentChannelData",
    "V3WorkflowsSlackCreateIncidentChannelDataTypedDict",
    "V3WorkflowsSlackCreateIncidentChannelName",
    "V3WorkflowsSlackCreateIncidentChannelTypedDict",
    "V3WorkflowsSlackCreateIncidentChannelUpdate",
    "V3WorkflowsSlackCreateIncidentChannelUpdateData",
    "V3WorkflowsSlackCreateIncidentChannelUpdateDataTypedDict",
    "V3WorkflowsSlackCreateIncidentChannelUpdateName",
    "V3WorkflowsSlackCreateIncidentChannelUpdateTypedDict",
    "V3WorkflowsSlackMessageChannel",
    "V3WorkflowsSlackMessageChannelData",
    "V3WorkflowsSlackMessageChannelDataTypedDict",
    "V3WorkflowsSlackMessageChannelName",
    "V3WorkflowsSlackMessageChannelTypedDict",
    "V3WorkflowsSlackMessageChannelUpdate",
    "V3WorkflowsSlackMessageChannelUpdateData",
    "V3WorkflowsSlackMessageChannelUpdateDataTypedDict",
    "V3WorkflowsSlackMessageChannelUpdateName",
    "V3WorkflowsSlackMessageChannelUpdateTypedDict",
    "V3WorkflowsSlackMessageUser",
    "V3WorkflowsSlackMessageUserData",
    "V3WorkflowsSlackMessageUserDataTypedDict",
    "V3WorkflowsSlackMessageUserName",
    "V3WorkflowsSlackMessageUserTypedDict",
    "V3WorkflowsSlackMessageUserUpdate",
    "V3WorkflowsSlackMessageUserUpdateData",
    "V3WorkflowsSlackMessageUserUpdateDataTypedDict",
    "V3WorkflowsSlackMessageUserUpdateName",
    "V3WorkflowsSlackMessageUserUpdateTypedDict",
    "V3WorkflowsSqAddCommunicationChannel",
    "V3WorkflowsSqAddCommunicationChannelData",
    "V3WorkflowsSqAddCommunicationChannelDataTypedDict",
    "V3WorkflowsSqAddCommunicationChannelName",
    "V3WorkflowsSqAddCommunicationChannelTypedDict",
    "V3WorkflowsSqAddCommunicationChannelUpdate",
    "V3WorkflowsSqAddCommunicationChannelUpdateData",
    "V3WorkflowsSqAddCommunicationChannelUpdateDataTypedDict",
    "V3WorkflowsSqAddCommunicationChannelUpdateName",
    "V3WorkflowsSqAddCommunicationChannelUpdateTypedDict",
    "V3WorkflowsSqAddIncidentNote",
    "V3WorkflowsSqAddIncidentNoteData",
    "V3WorkflowsSqAddIncidentNoteDataTypedDict",
    "V3WorkflowsSqAddIncidentNoteName",
    "V3WorkflowsSqAddIncidentNoteTypedDict",
    "V3WorkflowsSqAddIncidentNoteUpdate",
    "V3WorkflowsSqAddIncidentNoteUpdateData",
    "V3WorkflowsSqAddIncidentNoteUpdateDataTypedDict",
    "V3WorkflowsSqAddIncidentNoteUpdateName",
    "V3WorkflowsSqAddIncidentNoteUpdateTypedDict",
    "V3WorkflowsSqCreateStatusPageIssue",
    "V3WorkflowsSqCreateStatusPageIssueData",
    "V3WorkflowsSqCreateStatusPageIssueDataTypedDict",
    "V3WorkflowsSqCreateStatusPageIssueName",
    "V3WorkflowsSqCreateStatusPageIssueTypedDict",
    "V3WorkflowsSqCreateStatusPageIssueUpdate",
    "V3WorkflowsSqCreateStatusPageIssueUpdateData",
    "V3WorkflowsSqCreateStatusPageIssueUpdateDataTypedDict",
    "V3WorkflowsSqCreateStatusPageIssueUpdateName",
    "V3WorkflowsSqCreateStatusPageIssueUpdateTypedDict",
    "V3WorkflowsSqMakeHTTPCall",
    "V3WorkflowsSqMakeHTTPCallData",
    "V3WorkflowsSqMakeHTTPCallDataTypedDict",
    "V3WorkflowsSqMakeHTTPCallHeader",
    "V3WorkflowsSqMakeHTTPCallHeaderTypedDict",
    "V3WorkflowsSqMakeHTTPCallMethod",
    "V3WorkflowsSqMakeHTTPCallName",
    "V3WorkflowsSqMakeHTTPCallTypedDict",
    "V3WorkflowsSqMakeHTTPCallUpdate",
    "V3WorkflowsSqMakeHTTPCallUpdateData",
    "V3WorkflowsSqMakeHTTPCallUpdateDataTypedDict",
    "V3WorkflowsSqMakeHTTPCallUpdateHeader",
    "V3WorkflowsSqMakeHTTPCallUpdateHeaderTypedDict",
    "V3WorkflowsSqMakeHTTPCallUpdateMethod",
    "V3WorkflowsSqMakeHTTPCallUpdateName",
    "V3WorkflowsSqMakeHTTPCallUpdateTypedDict",
    "V3WorkflowsSqMarkIncidentSLOAffecting",
    "V3WorkflowsSqMarkIncidentSLOAffectingData",
    "V3WorkflowsSqMarkIncidentSLOAffectingDataTypedDict",
    "V3WorkflowsSqMarkIncidentSLOAffectingName",
    "V3WorkflowsSqMarkIncidentSLOAffectingTypedDict",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdate",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateData",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateDataTypedDict",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateName",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateTypedDict",
    "V3WorkflowsSqSendEmail",
    "V3WorkflowsSqSendEmailData",
    "V3WorkflowsSqSendEmailDataTypedDict",
    "V3WorkflowsSqSendEmailName",
    "V3WorkflowsSqSendEmailTypedDict",
    "V3WorkflowsSqSendEmailUpdate",
    "V3WorkflowsSqSendEmailUpdateData",
    "V3WorkflowsSqSendEmailUpdateDataTypedDict",
    "V3WorkflowsSqSendEmailUpdateName",
    "V3WorkflowsSqSendEmailUpdateTypedDict",
    "V3WorkflowsSqTriggerManualWebhook",
    "V3WorkflowsSqTriggerManualWebhookData",
    "V3WorkflowsSqTriggerManualWebhookDataTypedDict",
    "V3WorkflowsSqTriggerManualWebhookName",
    "V3WorkflowsSqTriggerManualWebhookTypedDict",
    "V3WorkflowsSqTriggerManualWebhookUpdate",
    "V3WorkflowsSqTriggerManualWebhookUpdateData",
    "V3WorkflowsSqTriggerManualWebhookUpdateDataTypedDict",
    "V3WorkflowsSqTriggerManualWebhookUpdateName",
    "V3WorkflowsSqTriggerManualWebhookUpdateTypedDict",
    "V3WorkflowsTag",
    "V3WorkflowsTagTypedDict",
    "V3WorkflowsUpdateActionsOrderRequest",
    "V3WorkflowsUpdateActionsOrderRequestTypedDict",
    "V3WorkflowsUpdateActionsOrderResponse",
    "V3WorkflowsUpdateActionsOrderResponseData",
    "V3WorkflowsUpdateActionsOrderResponseDataTypedDict",
    "V3WorkflowsUpdateActionsOrderResponseTypedDict",
    "V3WorkflowsUpdateIncidentPriority",
    "V3WorkflowsUpdateIncidentPriorityData",
    "V3WorkflowsUpdateIncidentPriorityDataTypedDict",
    "V3WorkflowsUpdateIncidentPriorityName",
    "V3WorkflowsUpdateIncidentPriorityPriority",
    "V3WorkflowsUpdateIncidentPriorityTypedDict",
    "V3WorkflowsUpdateIncidentPriorityUpdate",
    "V3WorkflowsUpdateIncidentPriorityUpdateData",
    "V3WorkflowsUpdateIncidentPriorityUpdateDataTypedDict",
    "V3WorkflowsUpdateIncidentPriorityUpdateName",
    "V3WorkflowsUpdateIncidentPriorityUpdatePriority",
    "V3WorkflowsUpdateIncidentPriorityUpdateTypedDict",
    "V3WorkflowsUpdateWorkflowAPIResponse",
    "V3WorkflowsUpdateWorkflowAPIResponseTypedDict",
    "V3WorkflowsWorkflowAPIResponse",
    "V3WorkflowsWorkflowAPIResponseTypedDict",
    "V3WorkflowsWorkflowFilters",
    "V3WorkflowsWorkflowFiltersTypedDict",
    "V3WorkflowsWorkflowTrigger",
    "V4ChangeTimezoneResponse",
    "V4ChangeTimezoneResponseTypedDict",
    "V4CreateRotationRequest",
    "V4CreateRotationRequestTypedDict",
    "V4CreateScheduleOverrideRequest",
    "V4CreateScheduleOverrideRequestTypedDict",
    "V4CreateScheduleRequest",
    "V4CreateScheduleRequestOwnerType",
    "V4CreateScheduleRequestTypedDict",
    "V4GetRotationParticipantsResponse",
    "V4GetRotationParticipantsResponseTypedDict",
    "V4ICalLinkResponse",
    "V4ICalLinkResponseTypedDict",
    "V4OverrideParticipantGroup",
    "V4OverrideParticipantGroupTypedDict",
    "V4OverrideResponse",
    "V4OverrideResponseTypedDict",
    "V4Participant",
    "V4ParticipantGroup",
    "V4ParticipantGroupTypedDict",
    "V4ParticipantTypedDict",
    "V4PauseResumeScheduleResponse",
    "V4PauseResumeScheduleResponseTypedDict",
    "V4RotationParticipantsResponse",
    "V4RotationParticipantsResponseTypedDict",
    "V4RotationResponse",
    "V4RotationResponseTypedDict",
    "V4ScheduleResponse",
    "V4ScheduleResponseOwnerType",
    "V4ScheduleResponseTypedDict",
    "V4ShiftTimeSlot",
    "V4ShiftTimeSlotTypedDict",
    "V4SquadsCreateSquadRequest",
    "V4SquadsCreateSquadRequestTypedDict",
    "V4SquadsCreateSquadResponse",
    "V4SquadsCreateSquadResponseTypedDict",
    "V4SquadsRemoveSquadMemberResponse",
    "V4SquadsRemoveSquadMemberResponseTypedDict",
    "V4SquadsSquadMember",
    "V4SquadsSquadMemberTypedDict",
    "V4SquadsSquadResponse",
    "V4SquadsSquadResponseTypedDict",
    "V4SquadsUpdateSquadMemberRequest",
    "V4SquadsUpdateSquadMemberRequestTypedDict",
    "V4SquadsUpdateSquadMemberResponse",
    "V4SquadsUpdateSquadMemberResponseTypedDict",
    "V4SquadsUpdateSquadNameRequest",
    "V4SquadsUpdateSquadNameRequestTypedDict",
    "V4SquadsUpdateSquadNameResponse",
    "V4SquadsUpdateSquadNameResponseTypedDict",
    "V4SquadsUpdateSquadRequest",
    "V4SquadsUpdateSquadRequestTypedDict",
    "V4StatusPagesComponentGroupsComponent",
    "V4StatusPagesComponentGroupsComponentGroupResponse",
    "V4StatusPagesComponentGroupsComponentGroupResponseTypedDict",
    "V4StatusPagesComponentGroupsComponentStatus",
    "V4StatusPagesComponentGroupsComponentStatusTypedDict",
    "V4StatusPagesComponentGroupsComponentTypedDict",
    "V4StatusPagesComponentGroupsCreateComponentGroupRequest",
    "V4StatusPagesComponentGroupsCreateComponentGroupRequestTypedDict",
    "V4StatusPagesComponentGroupsCreateComponentGroupResponse",
    "V4StatusPagesComponentGroupsCreateComponentGroupResponseTypedDict",
    "V4StatusPagesComponentGroupsDeleteComponentGroupByIDResponse",
    "V4StatusPagesComponentGroupsDeleteComponentGroupByIDResponseTypedDict",
    "V4StatusPagesComponentGroupsGetComponentGroupByIDResponse",
    "V4StatusPagesComponentGroupsGetComponentGroupByIDResponseTypedDict",
    "V4StatusPagesComponentsComponent",
    "V4StatusPagesComponentsComponentStatus",
    "V4StatusPagesComponentsComponentStatusTypedDict",
    "V4StatusPagesComponentsComponentTypedDict",
    "V4StatusPagesComponentsCreateComponentRequest",
    "V4StatusPagesComponentsCreateComponentRequestTypedDict",
    "V4StatusPagesComponentsCreateComponentResponse",
    "V4StatusPagesComponentsCreateComponentResponseTypedDict",
    "V4StatusPagesComponentsDeleteComponentByIDResponse",
    "V4StatusPagesComponentsDeleteComponentByIDResponseTypedDict",
    "V4StatusPagesComponentsGetComponentByIDResponse",
    "V4StatusPagesComponentsGetComponentByIDResponseTypedDict",
    "V4StatusPagesComponentsListComponentsResponse",
    "V4StatusPagesComponentsListComponentsResponseTypedDict",
    "V4StatusPagesComponentsUpdateComponentByIDRequest",
    "V4StatusPagesComponentsUpdateComponentByIDRequestTypedDict",
    "V4StatusPagesComponentsUpdateComponentByIDResponse",
    "V4StatusPagesComponentsUpdateComponentByIDResponseTypedDict",
    "V4StatusPagesCreateStatusPageRequest",
    "V4StatusPagesCreateStatusPageRequestOwnerType",
    "V4StatusPagesCreateStatusPageRequestTypedDict",
    "V4StatusPagesCreateStatusPageResponse",
    "V4StatusPagesCreateStatusPageResponseTypedDict",
    "V4StatusPagesDeleteStatusPageByIDResponse",
    "V4StatusPagesDeleteStatusPageByIDResponseTypedDict",
    "V4StatusPagesGetStatusPageByIDResponse",
    "V4StatusPagesGetStatusPageByIDResponseThemeColor",
    "V4StatusPagesGetStatusPageByIDResponseThemeColorTypedDict",
    "V4StatusPagesGetStatusPageByIDResponseTypedDict",
    "V4StatusPagesIssuesComponentStatus",
    "V4StatusPagesIssuesComponentStatusTypedDict",
    "V4StatusPagesIssuesCreateIssueRequest",
    "V4StatusPagesIssuesCreateIssueRequestComponent",
    "V4StatusPagesIssuesCreateIssueRequestComponentTypedDict",
    "V4StatusPagesIssuesCreateIssueRequestIssue",
    "V4StatusPagesIssuesCreateIssueRequestIssueTypedDict",
    "V4StatusPagesIssuesCreateIssueRequestStateMessage",
    "V4StatusPagesIssuesCreateIssueRequestStateMessageTypedDict",
    "V4StatusPagesIssuesCreateIssueRequestTypedDict",
    "V4StatusPagesIssuesCreateIssueResponse",
    "V4StatusPagesIssuesCreateIssueResponseTypedDict",
    "V4StatusPagesIssuesDeleteIssueByIDResponse",
    "V4StatusPagesIssuesDeleteIssueByIDResponseTypedDict",
    "V4StatusPagesIssuesGetIssueByIDResponse",
    "V4StatusPagesIssuesGetIssueByIDResponseTypedDict",
    "V4StatusPagesIssuesIssue",
    "V4StatusPagesIssuesIssueComponent",
    "V4StatusPagesIssuesIssueComponentDetail",
    "V4StatusPagesIssuesIssueComponentDetailTypedDict",
    "V4StatusPagesIssuesIssueComponentTypedDict",
    "V4StatusPagesIssuesIssueDetail",
    "V4StatusPagesIssuesIssueDetailTypedDict",
    "V4StatusPagesIssuesIssueState",
    "V4StatusPagesIssuesIssueStateMessage",
    "V4StatusPagesIssuesIssueStateMessageTypedDict",
    "V4StatusPagesIssuesIssueStateTypedDict",
    "V4StatusPagesIssuesIssueTypedDict",
    "V4StatusPagesIssuesListIssuesResponse",
    "V4StatusPagesIssuesListIssuesResponseMeta",
    "V4StatusPagesIssuesListIssuesResponseMetaTypedDict",
    "V4StatusPagesIssuesListIssuesResponseTypedDict",
    "V4StatusPagesIssuesListStatusPageIssueStatesResponse",
    "V4StatusPagesIssuesListStatusPageIssueStatesResponseTypedDict",
    "V4StatusPagesIssuesUpdateIssueRequest",
    "V4StatusPagesIssuesUpdateIssueRequestComponent",
    "V4StatusPagesIssuesUpdateIssueRequestComponentTypedDict",
    "V4StatusPagesIssuesUpdateIssueRequestIssue",
    "V4StatusPagesIssuesUpdateIssueRequestIssueTypedDict",
    "V4StatusPagesIssuesUpdateIssueRequestStateMessage",
    "V4StatusPagesIssuesUpdateIssueRequestStateMessageTypedDict",
    "V4StatusPagesIssuesUpdateIssueRequestTypedDict",
    "V4StatusPagesIssuesUpdateIssueResponse",
    "V4StatusPagesIssuesUpdateIssueResponseTypedDict",
    "V4StatusPagesListStatusPagesResponse",
    "V4StatusPagesListStatusPagesResponseMeta",
    "V4StatusPagesListStatusPagesResponseMetaTypedDict",
    "V4StatusPagesListStatusPagesResponseTypedDict",
    "V4StatusPagesListSubscribersResponse",
    "V4StatusPagesListSubscribersResponseMeta",
    "V4StatusPagesListSubscribersResponseMetaTypedDict",
    "V4StatusPagesListSubscribersResponseTypedDict",
    "V4StatusPagesMaintenancesCreateMaintenanceRequest",
    "V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict",
    "V4StatusPagesMaintenancesCreateMaintenanceResponse",
    "V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict",
    "V4StatusPagesMaintenancesDeleteMaintenanceByIDResponse",
    "V4StatusPagesMaintenancesDeleteMaintenanceByIDResponseTypedDict",
    "V4StatusPagesMaintenancesGetMaintenanceByIDResponse",
    "V4StatusPagesMaintenancesGetMaintenanceByIDResponseTypedDict",
    "V4StatusPagesMaintenancesListMaintenancesResponse",
    "V4StatusPagesMaintenancesListMaintenancesResponseMeta",
    "V4StatusPagesMaintenancesListMaintenancesResponseMetaTypedDict",
    "V4StatusPagesMaintenancesListMaintenancesResponseTypedDict",
    "V4StatusPagesMaintenancesMaintenance",
    "V4StatusPagesMaintenancesMaintenanceComponent",
    "V4StatusPagesMaintenancesMaintenanceComponentTypedDict",
    "V4StatusPagesMaintenancesMaintenanceTypedDict",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDRequest",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDRequestTypedDict",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDResponse",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDResponseTypedDict",
    "V4StatusPagesNewStatusPageComponent",
    "V4StatusPagesNewStatusPageComponentList",
    "V4StatusPagesNewStatusPageComponentListType",
    "V4StatusPagesNewStatusPageComponentListTypedDict",
    "V4StatusPagesNewStatusPageComponentType",
    "V4StatusPagesNewStatusPageComponentTypedDict",
    "V4StatusPagesNewStatusPageThemeColor",
    "V4StatusPagesNewStatusPageThemeColorTypedDict",
    "V4StatusPagesStatusPage",
    "V4StatusPagesStatusPageComponent",
    "V4StatusPagesStatusPageComponentTypedDict",
    "V4StatusPagesStatusPageStatus",
    "V4StatusPagesStatusPageStatusTypedDict",
    "V4StatusPagesStatusPageStatusesResponse",
    "V4StatusPagesStatusPageStatusesResponseTypedDict",
    "V4StatusPagesStatusPageSubscriber",
    "V4StatusPagesStatusPageSubscriberComponent",
    "V4StatusPagesStatusPageSubscriberComponentTypedDict",
    "V4StatusPagesStatusPageSubscriberTypedDict",
    "V4StatusPagesStatusPageTypedDict",
    "V4StatusPagesTotalSubscribersCount",
    "V4StatusPagesTotalSubscribersCountTypedDict",
    "V4StatusPagesUpdateStatusPageByIDRequest",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent1",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent1TypedDict",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent2",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent2TypedDict",
    "V4StatusPagesUpdateStatusPageByIDRequestThemeColor",
    "V4StatusPagesUpdateStatusPageByIDRequestThemeColorTypedDict",
    "V4StatusPagesUpdateStatusPageByIDRequestTypedDict",
    "V4StatusPagesUpdateStatusPageByIDResponse",
    "V4StatusPagesUpdateStatusPageByIDResponseThemeColor",
    "V4StatusPagesUpdateStatusPageByIDResponseThemeColorTypedDict",
    "V4StatusPagesUpdateStatusPageByIDResponseTypedDict",
    "V4Tag",
    "V4TagTypedDict",
    "V4UpdateRotationParticipantsRequest",
    "V4UpdateRotationParticipantsRequestTypedDict",
    "V4UpdateRotationRequest",
    "V4UpdateRotationRequestTypedDict",
    "V4UpdateScheduleOverrideRequest",
    "V4UpdateScheduleOverrideRequestTypedDict",
    "V4UpdateScheduleRequest",
    "V4UpdateScheduleRequestOwnerType",
    "V4UpdateScheduleRequestTypedDict",
    "Webforms",
    "WebformsCreateWebformData",
    "WebformsCreateWebformDataTypedDict",
    "WebformsCreateWebformResponse",
    "WebformsCreateWebformResponseTypedDict",
    "WebformsGetAllWebformsMeta",
    "WebformsGetAllWebformsMetaTypedDict",
    "WebformsGetAllWebformsRequest",
    "WebformsGetAllWebformsRequestTypedDict",
    "WebformsGetAllWebformsResponse",
    "WebformsGetAllWebformsResponseBody",
    "WebformsGetAllWebformsResponseBodyTypedDict",
    "WebformsGetAllWebformsResponseTypedDict",
    "WebformsGetWebformByIDRequest",
    "WebformsGetWebformByIDRequestTypedDict",
    "WebformsGetWebformByIDResponse",
    "WebformsGetWebformByIDResponseTypedDict",
    "WebformsRemoveWebformRequest",
    "WebformsRemoveWebformRequestTypedDict",
    "WebformsRemoveWebformResponse",
    "WebformsRemoveWebformResponseTypedDict",
    "WebformsTypedDict",
    "WebformsUpdateWebformRequest",
    "WebformsUpdateWebformRequestTypedDict",
    "WebformsUpdateWebformResponse",
    "WebformsUpdateWebformResponseTypedDict",
    "WebhooksCreateWebhookBody",
    "WebhooksCreateWebhookBodyTypedDict",
    "WebhooksCreateWebhookResponse",
    "WebhooksCreateWebhookResponseTypedDict",
    "WebhooksDeleteWebhookRequest",
    "WebhooksDeleteWebhookRequestTypedDict",
    "WebhooksDeleteWebhookResponseBody",
    "WebhooksDeleteWebhookResponseBodyTypedDict",
    "WebhooksGetAllWebhooksRequest",
    "WebhooksGetAllWebhooksRequestTypedDict",
    "WebhooksGetWebhookByIDRequest",
    "WebhooksGetWebhookByIDRequestTypedDict",
    "WebhooksGetWebhookByIDResponse",
    "WebhooksGetWebhookByIDResponseTypedDict",
    "WebhooksUpdateWebhookRequest",
    "WebhooksUpdateWebhookRequestTypedDict",
    "WebhooksUpdateWebhookResponse",
    "WebhooksUpdateWebhookResponseTypedDict",
    "Workflows",
    "WorkflowsBulkEnabledisableWorkflowsResponseBody",
    "WorkflowsBulkEnabledisableWorkflowsResponseBodyTypedDict",
    "WorkflowsCreateActionRequest",
    "WorkflowsCreateActionRequestTypedDict",
    "WorkflowsCreateActionResponse",
    "WorkflowsCreateActionResponseTypedDict",
    "WorkflowsCreateWorkflowResponse",
    "WorkflowsCreateWorkflowResponseTypedDict",
    "WorkflowsDeleteWorkflowActionRequest",
    "WorkflowsDeleteWorkflowActionRequestTypedDict",
    "WorkflowsDeleteWorkflowActionResponseBody",
    "WorkflowsDeleteWorkflowActionResponseBodyTypedDict",
    "WorkflowsDeleteWorkflowRequest",
    "WorkflowsDeleteWorkflowRequestTypedDict",
    "WorkflowsDeleteWorkflowResponseBody",
    "WorkflowsDeleteWorkflowResponseBodyTypedDict",
    "WorkflowsEnabledisableWorkflowRequest",
    "WorkflowsEnabledisableWorkflowRequestTypedDict",
    "WorkflowsEnabledisableWorkflowResponseBody",
    "WorkflowsEnabledisableWorkflowResponseBodyTypedDict",
    "WorkflowsGetWorkflowActionByIDRequest",
    "WorkflowsGetWorkflowActionByIDRequestTypedDict",
    "WorkflowsGetWorkflowActionByIDResponse",
    "WorkflowsGetWorkflowActionByIDResponseTypedDict",
    "WorkflowsGetWorkflowByIDRequest",
    "WorkflowsGetWorkflowByIDRequestTypedDict",
    "WorkflowsGetWorkflowLogsRequest",
    "WorkflowsGetWorkflowLogsRequestTypedDict",
    "WorkflowsGetWorkflowLogsResponse",
    "WorkflowsGetWorkflowLogsResponseTypedDict",
    "WorkflowsListWorkflowsRequest",
    "WorkflowsListWorkflowsRequestTypedDict",
    "WorkflowsListWorkflowsResponse",
    "WorkflowsListWorkflowsResponseTypedDict",
    "WorkflowsTypedDict",
    "WorkflowsUpdateActionsOrderRequest",
    "WorkflowsUpdateActionsOrderRequestTypedDict",
    "WorkflowsUpdateWorkflowActionRequest",
    "WorkflowsUpdateWorkflowActionRequestTypedDict",
    "WorkflowsUpdateWorkflowRequest",
    "WorkflowsUpdateWorkflowRequestTypedDict",
    "WorkflowsUpdateWorkflowResponse",
    "WorkflowsUpdateWorkflowResponseTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "AdditionalRespondersAddAdditionalRespondersRequest": ".additionalresponders_addadditionalrespondersop",
    "AdditionalRespondersAddAdditionalRespondersRequestTypedDict": ".additionalresponders_addadditionalrespondersop",
    "AdditionalRespondersAddAdditionalRespondersResponse": ".additionalresponders_addadditionalrespondersop",
    "AdditionalRespondersAddAdditionalRespondersResponseTypedDict": ".additionalresponders_addadditionalrespondersop",
    "AdditionalRespondersGetAdditionalRespondersRequest": ".additionalresponders_getadditionalrespondersop",
    "AdditionalRespondersGetAdditionalRespondersRequestTypedDict": ".additionalresponders_getadditionalrespondersop",
    "AdditionalRespondersGetAdditionalRespondersResponse": ".additionalresponders_getadditionalrespondersop",
    "AdditionalRespondersGetAdditionalRespondersResponseTypedDict": ".additionalresponders_getadditionalrespondersop",
    "AdditionalRespondersRemoveAdditionalRespondersRequest": ".additionalresponders_removeadditionalrespondersop",
    "AdditionalRespondersRemoveAdditionalRespondersRequestTypedDict": ".additionalresponders_removeadditionalrespondersop",
    "AdditionalRespondersRemoveAdditionalRespondersResponseBody": ".additionalresponders_removeadditionalrespondersop",
    "AdditionalRespondersRemoveAdditionalRespondersResponseBodyTypedDict": ".additionalresponders_removeadditionalrespondersop",
    "AnalyticsGetOrgAnalyticsRequest": ".analytics_getorganalyticsop",
    "AnalyticsGetOrgAnalyticsRequestTypedDict": ".analytics_getorganalyticsop",
    "AnalyticsGetOrgAnalyticsResponse": ".analytics_getorganalyticsop",
    "AnalyticsGetOrgAnalyticsResponseTypedDict": ".analytics_getorganalyticsop",
    "AnalyticsGetTeamAnalyticsRequest": ".analytics_getteamanalyticsop",
    "AnalyticsGetTeamAnalyticsRequestTypedDict": ".analytics_getteamanalyticsop",
    "AnalyticsGetTeamAnalyticsResponse": ".analytics_getteamanalyticsop",
    "AnalyticsGetTeamAnalyticsResponseTypedDict": ".analytics_getteamanalyticsop",
    "AptaMarkAsNotTransientRequest": ".apta_markasnottransientop",
    "AptaMarkAsNotTransientRequestTypedDict": ".apta_markasnottransientop",
    "AptaMarkAsNotTransientResponse": ".apta_markasnottransientop",
    "AptaMarkAsNotTransientResponseTypedDict": ".apta_markasnottransientop",
    "AptaMarkAsTransientRequest": ".apta_markastransientop",
    "AptaMarkAsTransientRequestTypedDict": ".apta_markastransientop",
    "AptaMarkAsTransientResponse": ".apta_markastransientop",
    "AptaMarkAsTransientResponseTypedDict": ".apta_markastransientop",
    "AuditLogsGetAuditLogByIDRequest": ".auditlogs_getauditlogbyidop",
    "AuditLogsGetAuditLogByIDRequestTypedDict": ".auditlogs_getauditlogbyidop",
    "AuditLogsGetAuditLogsExportHistoryByIDRequest": ".auditlogs_getauditlogsexporthistorybyidop",
    "AuditLogsGetAuditLogsExportHistoryByIDRequestTypedDict": ".auditlogs_getauditlogsexporthistorybyidop",
    "AuditLogsListAuditLogsExportHistoryRequest": ".auditlogs_listauditlogsexporthistoryop",
    "AuditLogsListAuditLogsExportHistoryRequestTypedDict": ".auditlogs_listauditlogsexporthistoryop",
    "AuditLogsListAuditLogsExportHistoryResponse": ".auditlogs_listauditlogsexporthistoryop",
    "AuditLogsListAuditLogsExportHistoryResponseTypedDict": ".auditlogs_listauditlogsexporthistoryop",
    "AuditLogsListAuditLogsRequest": ".auditlogs_listauditlogsop",
    "AuditLogsListAuditLogsRequestTypedDict": ".auditlogs_listauditlogsop",
    "AuditLogsListAuditLogsResponse": ".auditlogs_listauditlogsop",
    "AuditLogsListAuditLogsResponseTypedDict": ".auditlogs_listauditlogsop",
    "Client": ".auditlogs_listauditlogsop",
    "CommonV3EntityOwner": ".common_v3_entityowner",
    "CommonV3EntityOwnerTypedDict": ".common_v3_entityowner",
    "CommonV3ErrorMeta": ".common_v3_errormeta",
    "CommonV3ErrorMetaTypedDict": ".common_v3_errormeta",
    "Status": ".common_v3_errormeta",
    "StatusTypedDict": ".common_v3_errormeta",
    "Abilities": ".common_v3_rbacentitypermission",
    "AbilitiesTypedDict": ".common_v3_rbacentitypermission",
    "CommonV3RBACEntityPermission": ".common_v3_rbacentitypermission",
    "CommonV3RBACEntityPermissionTypedDict": ".common_v3_rbacentitypermission",
    "CommonV3RBACOwner": ".common_v3_rbacowner",
    "CommonV3RBACOwnerType": ".common_v3_rbacowner",
    "CommonV3RBACOwnerTypedDict": ".common_v3_rbacowner",
    "Detail": ".common_v4_error",
    "DetailTypedDict": ".common_v4_error",
    "Error": ".common_v4_error",
    "ErrorTypedDict": ".common_v4_error",
    "CommonV4PageInfo": ".common_v4_pageinfo",
    "CommonV4PageInfoTypedDict": ".common_v4_pageinfo",
    "CommunicationCardsArchiveSlackChannelResponse": ".communicationcards_archiveslackchannelop",
    "CommunicationCardsArchiveSlackChannelResponseTypedDict": ".communicationcards_archiveslackchannelop",
    "CommunicationCardsCreateCommunicationCardRequest": ".communicationcards_createcommunicationcardop",
    "CommunicationCardsCreateCommunicationCardRequestTypedDict": ".communicationcards_createcommunicationcardop",
    "CommunicationCardsCreateCommunicationCardResponse": ".communicationcards_createcommunicationcardop",
    "CommunicationCardsCreateCommunicationCardResponseTypedDict": ".communicationcards_createcommunicationcardop",
    "CommunicationCardsCreateSlackChannelInCommunicationCardResponse": ".communicationcards_createslackchannelincommunicationcardop",
    "CommunicationCardsCreateSlackChannelInCommunicationCardResponseTypedDict": ".communicationcards_createslackchannelincommunicationcardop",
    "CommunicationCardsDeleteCommunicationCardRequest": ".communicationcards_deletecommunicationcardop",
    "CommunicationCardsDeleteCommunicationCardRequestTypedDict": ".communicationcards_deletecommunicationcardop",
    "CommunicationCardsDeleteCommunicationCardResponse": ".communicationcards_deletecommunicationcardop",
    "CommunicationCardsDeleteCommunicationCardResponseTypedDict": ".communicationcards_deletecommunicationcardop",
    "CommunicationCardsGetAllCommunicationCardRequest": ".communicationcards_getallcommunicationcardop",
    "CommunicationCardsGetAllCommunicationCardRequestTypedDict": ".communicationcards_getallcommunicationcardop",
    "CommunicationCardsGetAllCommunicationCardResponse": ".communicationcards_getallcommunicationcardop",
    "CommunicationCardsGetAllCommunicationCardResponseTypedDict": ".communicationcards_getallcommunicationcardop",
    "CommunicationCardsUpdateCommunicationCardRequest": ".communicationcards_updatecommunicationcardop",
    "CommunicationCardsUpdateCommunicationCardRequestTypedDict": ".communicationcards_updatecommunicationcardop",
    "CommunicationCardsUpdateCommunicationCardResponse": ".communicationcards_updatecommunicationcardop",
    "CommunicationCardsUpdateCommunicationCardResponseTypedDict": ".communicationcards_updatecommunicationcardop",
    "ComponentGroupsCreateComponentGroupRequest": ".componentgroups_createcomponentgroupop",
    "ComponentGroupsCreateComponentGroupRequestTypedDict": ".componentgroups_createcomponentgroupop",
    "ComponentGroupsCreateComponentGroupResponse": ".componentgroups_createcomponentgroupop",
    "ComponentGroupsCreateComponentGroupResponseTypedDict": ".componentgroups_createcomponentgroupop",
    "ComponentGroupsDeleteComponentGroupByIDRequest": ".componentgroups_deletecomponentgroupbyidop",
    "ComponentGroupsDeleteComponentGroupByIDRequestTypedDict": ".componentgroups_deletecomponentgroupbyidop",
    "ComponentGroupsDeleteComponentGroupByIDResponse": ".componentgroups_deletecomponentgroupbyidop",
    "ComponentGroupsDeleteComponentGroupByIDResponseTypedDict": ".componentgroups_deletecomponentgroupbyidop",
    "ComponentGroupsGetComponentGroupByIDRequest": ".componentgroups_getcomponentgroupbyidop",
    "ComponentGroupsGetComponentGroupByIDRequestTypedDict": ".componentgroups_getcomponentgroupbyidop",
    "ComponentGroupsGetComponentGroupByIDResponse": ".componentgroups_getcomponentgroupbyidop",
    "ComponentGroupsGetComponentGroupByIDResponseTypedDict": ".componentgroups_getcomponentgroupbyidop",
    "ComponentGroupsListComponentGroupsRequest": ".componentgroups_listcomponentgroupsop",
    "ComponentGroupsListComponentGroupsRequestTypedDict": ".componentgroups_listcomponentgroupsop",
    "ComponentGroupsListComponentGroupsResponse": ".componentgroups_listcomponentgroupsop",
    "ComponentGroupsListComponentGroupsResponseTypedDict": ".componentgroups_listcomponentgroupsop",
    "ComponentsCreateComponentRequest": ".components_createcomponentop",
    "ComponentsCreateComponentRequestTypedDict": ".components_createcomponentop",
    "ComponentsCreateComponentResponse": ".components_createcomponentop",
    "ComponentsCreateComponentResponseTypedDict": ".components_createcomponentop",
    "ComponentsDeleteComponentByIDRequest": ".components_deletecomponentbyidop",
    "ComponentsDeleteComponentByIDRequestTypedDict": ".components_deletecomponentbyidop",
    "ComponentsDeleteComponentByIDResponse": ".components_deletecomponentbyidop",
    "ComponentsDeleteComponentByIDResponseTypedDict": ".components_deletecomponentbyidop",
    "ComponentsGetComponentByIDRequest": ".components_getcomponentbyidop",
    "ComponentsGetComponentByIDRequestTypedDict": ".components_getcomponentbyidop",
    "ComponentsGetComponentByIDResponse": ".components_getcomponentbyidop",
    "ComponentsGetComponentByIDResponseTypedDict": ".components_getcomponentbyidop",
    "ComponentsListComponentsRequest": ".components_listcomponentsop",
    "ComponentsListComponentsRequestTypedDict": ".components_listcomponentsop",
    "ComponentsListComponentsResponse": ".components_listcomponentsop",
    "ComponentsListComponentsResponseTypedDict": ".components_listcomponentsop",
    "ComponentsUpdateComponentByIDRequest": ".components_updatecomponentbyidop",
    "ComponentsUpdateComponentByIDRequestTypedDict": ".components_updatecomponentbyidop",
    "ComponentsUpdateComponentByIDResponse": ".components_updatecomponentbyidop",
    "ComponentsUpdateComponentByIDResponseTypedDict": ".components_updatecomponentbyidop",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesData": ".deduplicationrules_createorupdatededuplicationrulesop",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesDataTypedDict": ".deduplicationrules_createorupdatededuplicationrulesop",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesRequest": ".deduplicationrules_createorupdatededuplicationrulesop",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesRequestTypedDict": ".deduplicationrules_createorupdatededuplicationrulesop",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesResponse": ".deduplicationrules_createorupdatededuplicationrulesop",
    "DeduplicationRulesCreateOrUpdateDeduplicationRulesResponseTypedDict": ".deduplicationrules_createorupdatededuplicationrulesop",
    "DeduplicationRulesGetDeduplicationRulesData": ".deduplicationrules_getdeduplicationrulesop",
    "DeduplicationRulesGetDeduplicationRulesDataTypedDict": ".deduplicationrules_getdeduplicationrulesop",
    "DeduplicationRulesGetDeduplicationRulesRequest": ".deduplicationrules_getdeduplicationrulesop",
    "DeduplicationRulesGetDeduplicationRulesRequestTypedDict": ".deduplicationrules_getdeduplicationrulesop",
    "DeduplicationRulesGetDeduplicationRulesResponse": ".deduplicationrules_getdeduplicationrulesop",
    "DeduplicationRulesGetDeduplicationRulesResponseTypedDict": ".deduplicationrules_getdeduplicationrulesop",
    "DependenciesCreateOrUpdateDependenciesData": ".dependencies_createorupdatedependenciesop",
    "DependenciesCreateOrUpdateDependenciesDataTypedDict": ".dependencies_createorupdatedependenciesop",
    "DependenciesCreateOrUpdateDependenciesRequest": ".dependencies_createorupdatedependenciesop",
    "DependenciesCreateOrUpdateDependenciesRequestTypedDict": ".dependencies_createorupdatedependenciesop",
    "DependenciesCreateOrUpdateDependenciesResponse": ".dependencies_createorupdatedependenciesop",
    "DependenciesCreateOrUpdateDependenciesResponseTypedDict": ".dependencies_createorupdatedependenciesop",
    "EscalationPoliciesCreateEscalationPoliciesResponse": ".escalationpolicies_createescalationpoliciesop",
    "EscalationPoliciesCreateEscalationPoliciesResponseTypedDict": ".escalationpolicies_createescalationpoliciesop",
    "EscalationPoliciesGetEscalationPolicyByIDRequest": ".escalationpolicies_getescalationpolicybyidop",
    "EscalationPoliciesGetEscalationPolicyByIDRequestTypedDict": ".escalationpolicies_getescalationpolicybyidop",
    "EscalationPoliciesGetEscalationPolicyByIDResponse": ".escalationpolicies_getescalationpolicybyidop",
    "EscalationPoliciesGetEscalationPolicyByIDResponseTypedDict": ".escalationpolicies_getescalationpolicybyidop",
    "EscalationPoliciesGetEscalationPolicyByTeamMeta": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesGetEscalationPolicyByTeamMetaTypedDict": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesGetEscalationPolicyByTeamRequest": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesGetEscalationPolicyByTeamRequestTypedDict": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesGetEscalationPolicyByTeamResponse": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesGetEscalationPolicyByTeamResponseBody": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesGetEscalationPolicyByTeamResponseBodyTypedDict": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesGetEscalationPolicyByTeamResponseTypedDict": ".escalationpolicies_getescalationpolicybyteamop",
    "EscalationPoliciesRemoveEscalationPolicyRequest": ".escalationpolicies_removeescalationpolicyop",
    "EscalationPoliciesRemoveEscalationPolicyRequestTypedDict": ".escalationpolicies_removeescalationpolicyop",
    "EscalationPoliciesRemoveEscalationPolicyResponseBody": ".escalationpolicies_removeescalationpolicyop",
    "EscalationPoliciesRemoveEscalationPolicyResponseBodyTypedDict": ".escalationpolicies_removeescalationpolicyop",
    "EscalationPoliciesUpdateEscalationPolicyRequest": ".escalationpolicies_updateescalationpolicyop",
    "EscalationPoliciesUpdateEscalationPolicyRequestTypedDict": ".escalationpolicies_updateescalationpolicyop",
    "EscalationPoliciesUpdateEscalationPolicyResponse": ".escalationpolicies_updateescalationpolicyop",
    "EscalationPoliciesUpdateEscalationPolicyResponseTypedDict": ".escalationpolicies_updateescalationpolicyop",
    "ExportCreateScheduleIcalLinkRequest": ".export_createscheduleicallinkop",
    "ExportCreateScheduleIcalLinkRequestBody": ".export_createscheduleicallinkop",
    "ExportCreateScheduleIcalLinkRequestBodyTypedDict": ".export_createscheduleicallinkop",
    "ExportCreateScheduleIcalLinkRequestTypedDict": ".export_createscheduleicallinkop",
    "ExportCreateScheduleIcalLinkResponse": ".export_createscheduleicallinkop",
    "ExportCreateScheduleIcalLinkResponseTypedDict": ".export_createscheduleicallinkop",
    "ExportDeleteIcalLinkRequest": ".export_deleteicallinkop",
    "ExportDeleteIcalLinkRequestTypedDict": ".export_deleteicallinkop",
    "ExportDeleteIcalLinkResponseBody": ".export_deleteicallinkop",
    "ExportDeleteIcalLinkResponseBodyTypedDict": ".export_deleteicallinkop",
    "ExportGetExportDetailsRequest": ".export_getexportdetailsop",
    "ExportGetExportDetailsRequestTypedDict": ".export_getexportdetailsop",
    "ExportGetExportDetailsResponse": ".export_getexportdetailsop",
    "ExportGetExportDetailsResponseTypedDict": ".export_getexportdetailsop",
    "ExportGetScheduleIcalLinkRequest": ".export_getscheduleicallinkop",
    "ExportGetScheduleIcalLinkRequestTypedDict": ".export_getscheduleicallinkop",
    "ExportGetScheduleIcalLinkResponse": ".export_getscheduleicallinkop",
    "ExportGetScheduleIcalLinkResponseTypedDict": ".export_getscheduleicallinkop",
    "ExportRefreshScheduleIcalLinkRequest": ".export_refreshscheduleicallinkop",
    "ExportRefreshScheduleIcalLinkRequestBody": ".export_refreshscheduleicallinkop",
    "ExportRefreshScheduleIcalLinkRequestBodyTypedDict": ".export_refreshscheduleicallinkop",
    "ExportRefreshScheduleIcalLinkRequestTypedDict": ".export_refreshscheduleicallinkop",
    "ExportRefreshScheduleIcalLinkResponse": ".export_refreshscheduleicallinkop",
    "ExportRefreshScheduleIcalLinkResponseTypedDict": ".export_refreshscheduleicallinkop",
    "ExtensionsUpdateSlackExtensionRequest": ".extensions_updateslackextensionop",
    "ExtensionsUpdateSlackExtensionRequestTypedDict": ".extensions_updateslackextensionop",
    "ExtensionsUpdateSlackExtensionResponse": ".extensions_updateslackextensionop",
    "ExtensionsUpdateSlackExtensionResponseTypedDict": ".extensions_updateslackextensionop",
    "GlobalEventRulesCreateGlobalEventRuleResponse": ".globaleventrules_createglobaleventruleop",
    "GlobalEventRulesCreateGlobalEventRuleResponseTypedDict": ".globaleventrules_createglobaleventruleop",
    "GlobalEventRulesCreateRuleRequest": ".globaleventrules_createruleop",
    "GlobalEventRulesCreateRuleRequestTypedDict": ".globaleventrules_createruleop",
    "GlobalEventRulesCreateRuleResponse": ".globaleventrules_createruleop",
    "GlobalEventRulesCreateRuleResponseTypedDict": ".globaleventrules_createruleop",
    "GlobalEventRulesCreateRulesetRequest": ".globaleventrules_createrulesetop",
    "GlobalEventRulesCreateRulesetRequestTypedDict": ".globaleventrules_createrulesetop",
    "GlobalEventRulesCreateRulesetResponse": ".globaleventrules_createrulesetop",
    "GlobalEventRulesCreateRulesetResponseTypedDict": ".globaleventrules_createrulesetop",
    "GlobalEventRulesDeleteGerRulesetRequest": ".globaleventrules_deletegerrulesetop",
    "GlobalEventRulesDeleteGerRulesetRequestTypedDict": ".globaleventrules_deletegerrulesetop",
    "GlobalEventRulesDeleteGerRulesetResponseBody": ".globaleventrules_deletegerrulesetop",
    "GlobalEventRulesDeleteGerRulesetResponseBodyTypedDict": ".globaleventrules_deletegerrulesetop",
    "GlobalEventRulesDeleteGlobalEventRuleByIDRequest": ".globaleventrules_deleteglobaleventrulebyidop",
    "GlobalEventRulesDeleteGlobalEventRuleByIDRequestTypedDict": ".globaleventrules_deleteglobaleventrulebyidop",
    "GlobalEventRulesDeleteGlobalEventRuleByIDResponseBody": ".globaleventrules_deleteglobaleventrulebyidop",
    "GlobalEventRulesDeleteGlobalEventRuleByIDResponseBodyTypedDict": ".globaleventrules_deleteglobaleventrulebyidop",
    "GlobalEventRulesDeleteRuleByIDRequest": ".globaleventrules_deleterulebyidop",
    "GlobalEventRulesDeleteRuleByIDRequestTypedDict": ".globaleventrules_deleterulebyidop",
    "GlobalEventRulesDeleteRuleByIDResponseBody": ".globaleventrules_deleterulebyidop",
    "GlobalEventRulesDeleteRuleByIDResponseBodyTypedDict": ".globaleventrules_deleterulebyidop",
    "GlobalEventRulesGetGlobalEventRuleByIDRequest": ".globaleventrules_getglobaleventrulebyidop",
    "GlobalEventRulesGetGlobalEventRuleByIDRequestTypedDict": ".globaleventrules_getglobaleventrulebyidop",
    "GlobalEventRulesGetGlobalEventRuleByIDResponse": ".globaleventrules_getglobaleventrulebyidop",
    "GlobalEventRulesGetGlobalEventRuleByIDResponseTypedDict": ".globaleventrules_getglobaleventrulebyidop",
    "GlobalEventRulesGetRuleByIDRequest": ".globaleventrules_getrulebyidop",
    "GlobalEventRulesGetRuleByIDRequestTypedDict": ".globaleventrules_getrulebyidop",
    "GlobalEventRulesGetRuleByIDResponse": ".globaleventrules_getrulebyidop",
    "GlobalEventRulesGetRuleByIDResponseTypedDict": ".globaleventrules_getrulebyidop",
    "GlobalEventRulesGetRulesetRequest": ".globaleventrules_getrulesetop",
    "GlobalEventRulesGetRulesetRequestTypedDict": ".globaleventrules_getrulesetop",
    "GlobalEventRulesGetRulesetResponse": ".globaleventrules_getrulesetop",
    "GlobalEventRulesGetRulesetResponseTypedDict": ".globaleventrules_getrulesetop",
    "GlobalEventRulesListGlobalEventRulesMeta": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListGlobalEventRulesMetaTypedDict": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListGlobalEventRulesRequest": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListGlobalEventRulesRequestTypedDict": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListGlobalEventRulesResponse": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListGlobalEventRulesResponseBody": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListGlobalEventRulesResponseBodyTypedDict": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListGlobalEventRulesResponseTypedDict": ".globaleventrules_listglobaleventrulesop",
    "GlobalEventRulesListRulesetRulesMeta": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesListRulesetRulesMetaTypedDict": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesListRulesetRulesRequest": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesListRulesetRulesRequestTypedDict": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesListRulesetRulesResponse": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesListRulesetRulesResponseBody": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesListRulesetRulesResponseBodyTypedDict": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesListRulesetRulesResponseTypedDict": ".globaleventrules_listrulesetrulesop",
    "GlobalEventRulesReorderRulesetByIndexRequest": ".globaleventrules_reorderrulesetbyindexop",
    "GlobalEventRulesReorderRulesetByIndexRequestTypedDict": ".globaleventrules_reorderrulesetbyindexop",
    "GlobalEventRulesReorderRulesetByIndexResponse": ".globaleventrules_reorderrulesetbyindexop",
    "GlobalEventRulesReorderRulesetByIndexResponseTypedDict": ".globaleventrules_reorderrulesetbyindexop",
    "GlobalEventRulesReorderRulesetRequest": ".globaleventrules_reorderrulesetop",
    "GlobalEventRulesReorderRulesetRequestTypedDict": ".globaleventrules_reorderrulesetop",
    "GlobalEventRulesReorderRulesetResponse": ".globaleventrules_reorderrulesetop",
    "GlobalEventRulesReorderRulesetResponseTypedDict": ".globaleventrules_reorderrulesetop",
    "GlobalEventRulesUpdateGlobalEventRuleByIDRequest": ".globaleventrules_updateglobaleventrulebyidop",
    "GlobalEventRulesUpdateGlobalEventRuleByIDRequestTypedDict": ".globaleventrules_updateglobaleventrulebyidop",
    "GlobalEventRulesUpdateGlobalEventRuleByIDResponse": ".globaleventrules_updateglobaleventrulebyidop",
    "GlobalEventRulesUpdateGlobalEventRuleByIDResponseTypedDict": ".globaleventrules_updateglobaleventrulebyidop",
    "GlobalEventRulesUpdateRuleByIDRequest": ".globaleventrules_updaterulebyidop",
    "GlobalEventRulesUpdateRuleByIDRequestTypedDict": ".globaleventrules_updaterulebyidop",
    "GlobalEventRulesUpdateRuleByIDResponse": ".globaleventrules_updaterulebyidop",
    "GlobalEventRulesUpdateRuleByIDResponseTypedDict": ".globaleventrules_updaterulebyidop",
    "GlobalEventRulesUpdateRulesetRequest": ".globaleventrules_updaterulesetop",
    "GlobalEventRulesUpdateRulesetRequestTypedDict": ".globaleventrules_updaterulesetop",
    "GlobalEventRulesUpdateRulesetResponse": ".globaleventrules_updaterulesetop",
    "GlobalEventRulesUpdateRulesetResponseTypedDict": ".globaleventrules_updaterulesetop",
    "GlobalOncallReminderRulesCreateGlobalOncallReminderRulesResponse": ".globaloncallreminderrules_createglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesCreateGlobalOncallReminderRulesResponseTypedDict": ".globaloncallreminderrules_createglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequest": ".globaloncallreminderrules_deleteglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesRequestTypedDict": ".globaloncallreminderrules_deleteglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBody": ".globaloncallreminderrules_deleteglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesDeleteGlobalOncallReminderRulesResponseBodyTypedDict": ".globaloncallreminderrules_deleteglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequest": ".globaloncallreminderrules_getglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesRequestTypedDict": ".globaloncallreminderrules_getglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponse": ".globaloncallreminderrules_getglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesGetGlobalOncallReminderRulesResponseTypedDict": ".globaloncallreminderrules_getglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest": ".globaloncallreminderrules_updateglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict": ".globaloncallreminderrules_updateglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponse": ".globaloncallreminderrules_updateglobaloncallreminderrulesop",
    "GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesResponseTypedDict": ".globaloncallreminderrules_updateglobaloncallreminderrulesop",
    "IncidentActionsCreateAnIncidentInServicenowRequest": ".incidentactions_createanincidentinservicenowop",
    "IncidentActionsCreateAnIncidentInServicenowRequestTypedDict": ".incidentactions_createanincidentinservicenowop",
    "IncidentActionsCreateAnIncidentInServicenowResponse": ".incidentactions_createanincidentinservicenowop",
    "IncidentActionsCreateAnIncidentInServicenowResponseTypedDict": ".incidentactions_createanincidentinservicenowop",
    "IncidentActionsCreateATicketOnJiraCloudRequest": ".incidentactions_createaticketonjiracloudop",
    "IncidentActionsCreateATicketOnJiraCloudRequestTypedDict": ".incidentactions_createaticketonjiracloudop",
    "IncidentActionsCreateATicketOnJiraCloudResponse": ".incidentactions_createaticketonjiracloudop",
    "IncidentActionsCreateATicketOnJiraCloudResponseTypedDict": ".incidentactions_createaticketonjiracloudop",
    "IncidentActionsCreateATicketOnJiraServerRequest": ".incidentactions_createaticketonjiraserverop",
    "IncidentActionsCreateATicketOnJiraServerRequestTypedDict": ".incidentactions_createaticketonjiraserverop",
    "IncidentActionsCreateATicketOnJiraServerResponse": ".incidentactions_createaticketonjiraserverop",
    "IncidentActionsCreateATicketOnJiraServerResponseTypedDict": ".incidentactions_createaticketonjiraserverop",
    "IncidentActionsRebuildAProjectInCircleciMeta": ".incidentactions_rebuildaprojectincircleciop",
    "IncidentActionsRebuildAProjectInCircleciMetaTypedDict": ".incidentactions_rebuildaprojectincircleciop",
    "IncidentActionsRebuildAProjectInCircleciRequest": ".incidentactions_rebuildaprojectincircleciop",
    "IncidentActionsRebuildAProjectInCircleciRequestTypedDict": ".incidentactions_rebuildaprojectincircleciop",
    "IncidentActionsRebuildAProjectInCircleciResponse": ".incidentactions_rebuildaprojectincircleciop",
    "IncidentActionsRebuildAProjectInCircleciResponseTypedDict": ".incidentactions_rebuildaprojectincircleciop",
    "IncidentActionsTriggerAWebhookManuallyRequest": ".incidentactions_triggerawebhookmanuallyop",
    "IncidentActionsTriggerAWebhookManuallyRequestTypedDict": ".incidentactions_triggerawebhookmanuallyop",
    "IncidentActionsTriggerAWebhookManuallyResponse": ".incidentactions_triggerawebhookmanuallyop",
    "IncidentActionsTriggerAWebhookManuallyResponseTypedDict": ".incidentactions_triggerawebhookmanuallyop",
    "IncidentsAcknowledgeIncidentRequest": ".incidents_acknowledgeincidentop",
    "IncidentsAcknowledgeIncidentRequestTypedDict": ".incidents_acknowledgeincidentop",
    "IncidentsAcknowledgeIncidentResponse": ".incidents_acknowledgeincidentop",
    "IncidentsAcknowledgeIncidentResponseTypedDict": ".incidents_acknowledgeincidentop",
    "IncidentsBulkAcknowledgeIncidentsResponse": ".incidents_bulkacknowledgeincidentsop",
    "IncidentsBulkAcknowledgeIncidentsResponseTypedDict": ".incidents_bulkacknowledgeincidentsop",
    "IncidentsBulkIncidentsPriorityUpdateResponseBody": ".incidents_bulkincidentspriorityupdateop",
    "IncidentsBulkIncidentsPriorityUpdateResponseBodyTypedDict": ".incidents_bulkincidentspriorityupdateop",
    "IncidentsBulkResolveIncidentsResponse": ".incidents_bulkresolveincidentsop",
    "IncidentsBulkResolveIncidentsResponseTypedDict": ".incidents_bulkresolveincidentsop",
    "IncidentsGetIncidentByIDRequest": ".incidents_getincidentbyidop",
    "IncidentsGetIncidentByIDRequestTypedDict": ".incidents_getincidentbyidop",
    "IncidentsGetIncidentByIDResponse": ".incidents_getincidentbyidop",
    "IncidentsGetIncidentByIDResponseTypedDict": ".incidents_getincidentbyidop",
    "IncidentsGetIncidentEventsData": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentEventsDataTypedDict": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentEventsMeta": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentEventsMetaTypedDict": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentEventsRequest": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentEventsRequestTypedDict": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentEventsResponse": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentEventsResponseTypedDict": ".incidents_getincidenteventsop",
    "IncidentsGetIncidentsStatusByRequestidsMeta": ".incidents_getincidentsstatusbyrequestidsop",
    "IncidentsGetIncidentsStatusByRequestidsMetaTypedDict": ".incidents_getincidentsstatusbyrequestidsop",
    "IncidentsGetIncidentsStatusByRequestidsResponse": ".incidents_getincidentsstatusbyrequestidsop",
    "IncidentsGetIncidentsStatusByRequestidsResponseTypedDict": ".incidents_getincidentsstatusbyrequestidsop",
    "RequestsStatus": ".incidents_getincidentsstatusbyrequestidsop",
    "RequestsStatusTypedDict": ".incidents_getincidentsstatusbyrequestidsop",
    "IncidentsIncidentExportAsyncBody": ".incidents_incidentexportasyncop",
    "IncidentsIncidentExportAsyncBodyTypedDict": ".incidents_incidentexportasyncop",
    "IncidentsIncidentExportAsyncResponseBody": ".incidents_incidentexportasyncop",
    "IncidentsIncidentExportAsyncResponseBodyTypedDict": ".incidents_incidentexportasyncop",
    "IncidentsIncidentExportRequest": ".incidents_incidentexportop",
    "IncidentsIncidentExportRequestTypedDict": ".incidents_incidentexportop",
    "IncidentsIncidentPriorityUpdateRequest": ".incidents_incidentpriorityupdateop",
    "IncidentsIncidentPriorityUpdateRequestTypedDict": ".incidents_incidentpriorityupdateop",
    "IncidentsIncidentPriorityUpdateResponse": ".incidents_incidentpriorityupdateop",
    "IncidentsIncidentPriorityUpdateResponseTypedDict": ".incidents_incidentpriorityupdateop",
    "IncidentsMarkIncidentSloFalsePositiveRequest": ".incidents_markincidentslofalsepositiveop",
    "IncidentsMarkIncidentSloFalsePositiveRequestTypedDict": ".incidents_markincidentslofalsepositiveop",
    "IncidentsMarkIncidentSloFalsePositiveResponse": ".incidents_markincidentslofalsepositiveop",
    "IncidentsMarkIncidentSloFalsePositiveResponseTypedDict": ".incidents_markincidentslofalsepositiveop",
    "IncidentsReassignIncidentRequest": ".incidents_reassignincidentop",
    "IncidentsReassignIncidentRequestTypedDict": ".incidents_reassignincidentop",
    "IncidentsReassignIncidentResponse": ".incidents_reassignincidentop",
    "IncidentsReassignIncidentResponseTypedDict": ".incidents_reassignincidentop",
    "IncidentsResolveIncidentRequest": ".incidents_resolveincidentop",
    "IncidentsResolveIncidentRequestTypedDict": ".incidents_resolveincidentop",
    "IncidentsResolveIncidentResponse": ".incidents_resolveincidentop",
    "IncidentsResolveIncidentResponseTypedDict": ".incidents_resolveincidentop",
    "IssuesCreateIssueRequest": ".issues_createissueop",
    "IssuesCreateIssueRequestTypedDict": ".issues_createissueop",
    "IssuesCreateIssueResponse": ".issues_createissueop",
    "IssuesCreateIssueResponseTypedDict": ".issues_createissueop",
    "IssuesDeleteIssueByIDRequest": ".issues_deleteissuebyidop",
    "IssuesDeleteIssueByIDRequestTypedDict": ".issues_deleteissuebyidop",
    "IssuesDeleteIssueByIDResponse": ".issues_deleteissuebyidop",
    "IssuesDeleteIssueByIDResponseTypedDict": ".issues_deleteissuebyidop",
    "IssuesGetIssueByIDRequest": ".issues_getissuebyidop",
    "IssuesGetIssueByIDRequestTypedDict": ".issues_getissuebyidop",
    "IssuesGetIssueByIDResponse": ".issues_getissuebyidop",
    "IssuesGetIssueByIDResponseTypedDict": ".issues_getissuebyidop",
    "IssuesListIssuesRequest": ".issues_listissuesop",
    "IssuesListIssuesRequestTypedDict": ".issues_listissuesop",
    "IssuesListStatusPageIssueStatesRequest": ".issues_liststatuspageissuestatesop",
    "IssuesListStatusPageIssueStatesRequestTypedDict": ".issues_liststatuspageissuestatesop",
    "IssuesListStatusPageIssueStatesResponse": ".issues_liststatuspageissuestatesop",
    "IssuesListStatusPageIssueStatesResponseTypedDict": ".issues_liststatuspageissuestatesop",
    "IssuesUpdateIssueRequest": ".issues_updateissueop",
    "IssuesUpdateIssueRequestTypedDict": ".issues_updateissueop",
    "IssuesUpdateIssueResponse": ".issues_updateissueop",
    "IssuesUpdateIssueResponseTypedDict": ".issues_updateissueop",
    "MaintenanceModeCreateOrUpdateMaintenanceModeRequest": ".maintenancemode_createorupdatemaintenancemodeop",
    "MaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict": ".maintenancemode_createorupdatemaintenancemodeop",
    "MaintenanceModeCreateOrUpdateMaintenanceModeResponse": ".maintenancemode_createorupdatemaintenancemodeop",
    "MaintenanceModeCreateOrUpdateMaintenanceModeResponseTypedDict": ".maintenancemode_createorupdatemaintenancemodeop",
    "MaintenanceModeGetMaintenanceModeRequest": ".maintenancemode_getmaintenancemodeop",
    "MaintenanceModeGetMaintenanceModeRequestTypedDict": ".maintenancemode_getmaintenancemodeop",
    "MaintenanceModeGetMaintenanceModeResponse": ".maintenancemode_getmaintenancemodeop",
    "MaintenanceModeGetMaintenanceModeResponseTypedDict": ".maintenancemode_getmaintenancemodeop",
    "MaintenancesCreateMaintenanceRequest": ".maintenances_createmaintenanceop",
    "MaintenancesCreateMaintenanceRequestTypedDict": ".maintenances_createmaintenanceop",
    "MaintenancesCreateMaintenanceResponse": ".maintenances_createmaintenanceop",
    "MaintenancesCreateMaintenanceResponseTypedDict": ".maintenances_createmaintenanceop",
    "MaintenancesDeleteMaintenanceByIDRequest": ".maintenances_deletemaintenancebyidop",
    "MaintenancesDeleteMaintenanceByIDRequestTypedDict": ".maintenances_deletemaintenancebyidop",
    "MaintenancesDeleteMaintenanceByIDResponse": ".maintenances_deletemaintenancebyidop",
    "MaintenancesDeleteMaintenanceByIDResponseTypedDict": ".maintenances_deletemaintenancebyidop",
    "MaintenancesGetMaintenanceByIDRequest": ".maintenances_getmaintenancebyidop",
    "MaintenancesGetMaintenanceByIDRequestTypedDict": ".maintenances_getmaintenancebyidop",
    "MaintenancesGetMaintenanceByIDResponse": ".maintenances_getmaintenancebyidop",
    "MaintenancesGetMaintenanceByIDResponseTypedDict": ".maintenances_getmaintenancebyidop",
    "MaintenancesListMaintenancesRequest": ".maintenances_listmaintenancesop",
    "MaintenancesListMaintenancesRequestTypedDict": ".maintenances_listmaintenancesop",
    "MaintenancesUpdateMaintenanceByIDRequest": ".maintenances_updatemaintenancebyidop",
    "MaintenancesUpdateMaintenanceByIDRequestTypedDict": ".maintenances_updatemaintenancebyidop",
    "MaintenancesUpdateMaintenanceByIDResponse": ".maintenances_updatemaintenancebyidop",
    "MaintenancesUpdateMaintenanceByIDResponseTypedDict": ".maintenances_updatemaintenancebyidop",
    "MSTeamsCreateOrUpdateMsteamsConfigurationResponse": ".msteams_createorupdatemsteamsconfigurationop",
    "MSTeamsCreateOrUpdateMsteamsConfigurationResponseTypedDict": ".msteams_createorupdatemsteamsconfigurationop",
    "MSTeamsGetMsteamsConfigResponse": ".msteams_getmsteamsconfigop",
    "MSTeamsGetMsteamsConfigResponseTypedDict": ".msteams_getmsteamsconfigop",
    "NotesCreateNotesBody": ".notes_createnotesop",
    "NotesCreateNotesBodyTypedDict": ".notes_createnotesop",
    "NotesCreateNotesRequest": ".notes_createnotesop",
    "NotesCreateNotesRequestTypedDict": ".notes_createnotesop",
    "NotesCreateNotesResponse": ".notes_createnotesop",
    "NotesCreateNotesResponseTypedDict": ".notes_createnotesop",
    "NotesDeleteNoteRequest": ".notes_deletenoteop",
    "NotesDeleteNoteRequestTypedDict": ".notes_deletenoteop",
    "NotesDeleteNoteResponseBody": ".notes_deletenoteop",
    "NotesDeleteNoteResponseBodyTypedDict": ".notes_deletenoteop",
    "NotesGetAllNotesRequest": ".notes_getallnotesop",
    "NotesGetAllNotesRequestTypedDict": ".notes_getallnotesop",
    "NotesGetAllNotesResponse": ".notes_getallnotesop",
    "NotesGetAllNotesResponseTypedDict": ".notes_getallnotesop",
    "NotesUpdateNoteRequest": ".notes_updatenoteop",
    "NotesUpdateNoteRequestTypedDict": ".notes_updatenoteop",
    "NotesUpdateNoteResponse": ".notes_updatenoteop",
    "NotesUpdateNoteResponseTypedDict": ".notes_updatenoteop",
    "OverlayCreateOrUpdateNotificationTemplateOverlayRequest": ".overlay_createorupdatenotificationtemplateoverlayop",
    "OverlayCreateOrUpdateNotificationTemplateOverlayRequestTypedDict": ".overlay_createorupdatenotificationtemplateoverlayop",
    "OverlayCreateOrUpdateNotificationTemplateOverlayResponse": ".overlay_createorupdatenotificationtemplateoverlayop",
    "OverlayCreateOrUpdateNotificationTemplateOverlayResponseTypedDict": ".overlay_createorupdatenotificationtemplateoverlayop",
    "OverlayDeleteDedupKeyOverlayRequest": ".overlay_deletededupkeyoverlayop",
    "OverlayDeleteDedupKeyOverlayRequestTypedDict": ".overlay_deletededupkeyoverlayop",
    "OverlayDeleteDedupKeyOverlayResponseBody": ".overlay_deletededupkeyoverlayop",
    "OverlayDeleteDedupKeyOverlayResponseBodyTypedDict": ".overlay_deletededupkeyoverlayop",
    "OverlayDeleteNotificationTemplateOverlayRequest": ".overlay_deletenotificationtemplateoverlayop",
    "OverlayDeleteNotificationTemplateOverlayRequestTypedDict": ".overlay_deletenotificationtemplateoverlayop",
    "OverlayDeleteNotificationTemplateOverlayResponseBody": ".overlay_deletenotificationtemplateoverlayop",
    "OverlayDeleteNotificationTemplateOverlayResponseBodyTypedDict": ".overlay_deletenotificationtemplateoverlayop",
    "OverlayGetAllCustomContentTemplateOverlayByServiceRequest": ".overlay_getallcustomcontenttemplateoverlaybyserviceop",
    "OverlayGetAllCustomContentTemplateOverlayByServiceRequestTypedDict": ".overlay_getallcustomcontenttemplateoverlaybyserviceop",
    "OverlayGetAllCustomContentTemplateOverlayByServiceResponse": ".overlay_getallcustomcontenttemplateoverlaybyserviceop",
    "OverlayGetAllCustomContentTemplateOverlayByServiceResponseTypedDict": ".overlay_getallcustomcontenttemplateoverlaybyserviceop",
    "OverlayGetAllDedupKeyOverlayByServiceRequest": ".overlay_getalldedupkeyoverlaybyserviceop",
    "OverlayGetAllDedupKeyOverlayByServiceRequestTypedDict": ".overlay_getalldedupkeyoverlaybyserviceop",
    "OverlayGetAllDedupKeyOverlayByServiceResponse": ".overlay_getalldedupkeyoverlaybyserviceop",
    "OverlayGetAllDedupKeyOverlayByServiceResponseTypedDict": ".overlay_getalldedupkeyoverlaybyserviceop",
    "OverlayGetCustomContentTemplateOverlayRequest": ".overlay_getcustomcontenttemplateoverlayop",
    "OverlayGetCustomContentTemplateOverlayRequestTypedDict": ".overlay_getcustomcontenttemplateoverlayop",
    "OverlayGetCustomContentTemplateOverlayResponse": ".overlay_getcustomcontenttemplateoverlayop",
    "OverlayGetCustomContentTemplateOverlayResponseTypedDict": ".overlay_getcustomcontenttemplateoverlayop",
    "OverlayGetDedupKeyOverlayForAlertSourceRequest": ".overlay_getdedupkeyoverlayforalertsourceop",
    "OverlayGetDedupKeyOverlayForAlertSourceRequestTypedDict": ".overlay_getdedupkeyoverlayforalertsourceop",
    "OverlayGetDedupKeyOverlayForAlertSourceResponse": ".overlay_getdedupkeyoverlayforalertsourceop",
    "OverlayGetDedupKeyOverlayForAlertSourceResponseTypedDict": ".overlay_getdedupkeyoverlayforalertsourceop",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceData": ".overlay_getoptinforkeybaseddeduplicationforaserviceop",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceDataTypedDict": ".overlay_getoptinforkeybaseddeduplicationforaserviceop",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceRequest": ".overlay_getoptinforkeybaseddeduplicationforaserviceop",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceRequestTypedDict": ".overlay_getoptinforkeybaseddeduplicationforaserviceop",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceResponse": ".overlay_getoptinforkeybaseddeduplicationforaserviceop",
    "OverlayGetOptinForKeyBasedDeduplicationForAServiceResponseTypedDict": ".overlay_getoptinforkeybaseddeduplicationforaserviceop",
    "OverlayOptinForKeyBasedDeduplicationForAServiceRequest": ".overlay_optinforkeybaseddeduplicationforaserviceop",
    "OverlayOptinForKeyBasedDeduplicationForAServiceRequestTypedDict": ".overlay_optinforkeybaseddeduplicationforaserviceop",
    "OverlayOptinForKeyBasedDeduplicationForAServiceResponse": ".overlay_optinforkeybaseddeduplicationforaserviceop",
    "OverlayOptinForKeyBasedDeduplicationForAServiceResponseTypedDict": ".overlay_optinforkeybaseddeduplicationforaserviceop",
    "OverlayRenderCustomContentOverlayRequest": ".overlay_rendercustomcontentoverlayop",
    "OverlayRenderCustomContentOverlayRequestTypedDict": ".overlay_rendercustomcontentoverlayop",
    "OverlayRenderCustomContentOverlayResponse": ".overlay_rendercustomcontentoverlayop",
    "OverlayRenderCustomContentOverlayResponseTypedDict": ".overlay_rendercustomcontentoverlayop",
    "OverlayRenderDedupKeyTemplateRequest": ".overlay_renderdedupkeytemplateop",
    "OverlayRenderDedupKeyTemplateRequestTypedDict": ".overlay_renderdedupkeytemplateop",
    "OverlayRenderDedupKeyTemplateResponse": ".overlay_renderdedupkeytemplateop",
    "OverlayRenderDedupKeyTemplateResponseTypedDict": ".overlay_renderdedupkeytemplateop",
    "OverlayUpdateDedupKeyOverlayRequest": ".overlay_updatededupkeyoverlayop",
    "OverlayUpdateDedupKeyOverlayRequestTypedDict": ".overlay_updatededupkeyoverlayop",
    "OverlayUpdateDedupKeyOverlayResponse": ".overlay_updatededupkeyoverlayop",
    "OverlayUpdateDedupKeyOverlayResponseTypedDict": ".overlay_updatededupkeyoverlayop",
    "ResponseBody1": ".overlay_updatededupkeyoverlayop",
    "ResponseBody1TypedDict": ".overlay_updatededupkeyoverlayop",
    "ResponseBody2": ".overlay_updatededupkeyoverlayop",
    "ResponseBody2TypedDict": ".overlay_updatededupkeyoverlayop",
    "OverridesCreateScheduleOverrideRequest": ".overrides_createscheduleoverrideop",
    "OverridesCreateScheduleOverrideRequestTypedDict": ".overrides_createscheduleoverrideop",
    "OverridesCreateScheduleOverrideResponse": ".overrides_createscheduleoverrideop",
    "OverridesCreateScheduleOverrideResponseTypedDict": ".overrides_createscheduleoverrideop",
    "OverridesDeleteScheduleOverrideRequest": ".overrides_deletescheduleoverrideop",
    "OverridesDeleteScheduleOverrideRequestTypedDict": ".overrides_deletescheduleoverrideop",
    "OverridesDeleteScheduleOverrideResponseBody": ".overrides_deletescheduleoverrideop",
    "OverridesDeleteScheduleOverrideResponseBodyTypedDict": ".overrides_deletescheduleoverrideop",
    "OverridesGetOverrideByIDRequest": ".overrides_getoverridebyidop",
    "OverridesGetOverrideByIDRequestTypedDict": ".overrides_getoverridebyidop",
    "OverridesGetOverrideByIDResponse": ".overrides_getoverridebyidop",
    "OverridesGetOverrideByIDResponseTypedDict": ".overrides_getoverridebyidop",
    "OverridesListOverridesRequest": ".overrides_listoverridesop",
    "OverridesListOverridesRequestTypedDict": ".overrides_listoverridesop",
    "OverridesListOverridesResponse": ".overrides_listoverridesop",
    "OverridesListOverridesResponseTypedDict": ".overrides_listoverridesop",
    "OverridesUpdateScheduleOverrideRequest": ".overrides_updatescheduleoverrideop",
    "OverridesUpdateScheduleOverrideRequestTypedDict": ".overrides_updatescheduleoverrideop",
    "OverridesUpdateScheduleOverrideResponse": ".overrides_updatescheduleoverrideop",
    "OverridesUpdateScheduleOverrideResponseTypedDict": ".overrides_updatescheduleoverrideop",
    "PostmortemsCreatePostmortemBody": ".postmortems_createpostmortemop",
    "PostmortemsCreatePostmortemBodyTypedDict": ".postmortems_createpostmortemop",
    "PostmortemsCreatePostmortemRequest": ".postmortems_createpostmortemop",
    "PostmortemsCreatePostmortemRequestTypedDict": ".postmortems_createpostmortemop",
    "PostmortemsCreatePostmortemResponse": ".postmortems_createpostmortemop",
    "PostmortemsCreatePostmortemResponseTypedDict": ".postmortems_createpostmortemop",
    "PostmortemsDeletePostmortemByIncidentRequest": ".postmortems_deletepostmortembyincidentop",
    "PostmortemsDeletePostmortemByIncidentRequestTypedDict": ".postmortems_deletepostmortembyincidentop",
    "PostmortemsDeletePostmortemByIncidentResponse": ".postmortems_deletepostmortembyincidentop",
    "PostmortemsDeletePostmortemByIncidentResponseTypedDict": ".postmortems_deletepostmortembyincidentop",
    "PostmortemsGetAllPostmortemsData": ".postmortems_getallpostmortemsop",
    "PostmortemsGetAllPostmortemsDataTypedDict": ".postmortems_getallpostmortemsop",
    "PostmortemsGetAllPostmortemsRequest": ".postmortems_getallpostmortemsop",
    "PostmortemsGetAllPostmortemsRequestTypedDict": ".postmortems_getallpostmortemsop",
    "PostmortemsGetAllPostmortemsResponse": ".postmortems_getallpostmortemsop",
    "PostmortemsGetAllPostmortemsResponseTypedDict": ".postmortems_getallpostmortemsop",
    "PostmortemsGetPostmortemByIncidentRequest": ".postmortems_getpostmortembyincidentop",
    "PostmortemsGetPostmortemByIncidentRequestTypedDict": ".postmortems_getpostmortembyincidentop",
    "PostmortemsGetPostmortemByIncidentResponse": ".postmortems_getpostmortembyincidentop",
    "PostmortemsGetPostmortemByIncidentResponseTypedDict": ".postmortems_getpostmortembyincidentop",
    "PostmortemsUpdatePostmortemByIncidentRequest": ".postmortems_updatepostmortembyincidentop",
    "PostmortemsUpdatePostmortemByIncidentRequestTypedDict": ".postmortems_updatepostmortembyincidentop",
    "PostmortemsUpdatePostmortemByIncidentResponse": ".postmortems_updatepostmortembyincidentop",
    "PostmortemsUpdatePostmortemByIncidentResponseTypedDict": ".postmortems_updatepostmortembyincidentop",
    "RotationsCreateRotationRequest": ".rotations_createrotationop",
    "RotationsCreateRotationRequestTypedDict": ".rotations_createrotationop",
    "RotationsCreateRotationResponse": ".rotations_createrotationop",
    "RotationsCreateRotationResponseTypedDict": ".rotations_createrotationop",
    "RotationsDeleteRotationRequest": ".rotations_deleterotationop",
    "RotationsDeleteRotationRequestTypedDict": ".rotations_deleterotationop",
    "RotationsDeleteRotationResponseBody": ".rotations_deleterotationop",
    "RotationsDeleteRotationResponseBodyTypedDict": ".rotations_deleterotationop",
    "RotationsGetRotationParticipantsRequest": ".rotations_getrotationparticipantsop",
    "RotationsGetRotationParticipantsRequestTypedDict": ".rotations_getrotationparticipantsop",
    "RotationsGetRotationParticipantsResponse": ".rotations_getrotationparticipantsop",
    "RotationsGetRotationParticipantsResponseTypedDict": ".rotations_getrotationparticipantsop",
    "RotationsGetScheduleRotationByIDRequest": ".rotations_getschedulerotationbyidop",
    "RotationsGetScheduleRotationByIDRequestTypedDict": ".rotations_getschedulerotationbyidop",
    "RotationsGetScheduleRotationByIDResponse": ".rotations_getschedulerotationbyidop",
    "RotationsGetScheduleRotationByIDResponseTypedDict": ".rotations_getschedulerotationbyidop",
    "RotationsGetScheduleRotationsRequest": ".rotations_getschedulerotationsop",
    "RotationsGetScheduleRotationsRequestTypedDict": ".rotations_getschedulerotationsop",
    "RotationsGetScheduleRotationsResponse": ".rotations_getschedulerotationsop",
    "RotationsGetScheduleRotationsResponseTypedDict": ".rotations_getschedulerotationsop",
    "RotationsUpdateRotationRequest": ".rotations_updaterotationop",
    "RotationsUpdateRotationRequestTypedDict": ".rotations_updaterotationop",
    "RotationsUpdateRotationResponse": ".rotations_updaterotationop",
    "RotationsUpdateRotationResponseTypedDict": ".rotations_updaterotationop",
    "RotationsUpdateRotationParticipantsRequest": ".rotations_updaterotationparticipantsop",
    "RotationsUpdateRotationParticipantsRequestTypedDict": ".rotations_updaterotationparticipantsop",
    "RotationsUpdateRotationParticipantsResponse": ".rotations_updaterotationparticipantsop",
    "RotationsUpdateRotationParticipantsResponseTypedDict": ".rotations_updaterotationparticipantsop",
    "RoutingRulesCreateOrUpdateRoutingRulesData": ".routingrules_createorupdateroutingrulesop",
    "RoutingRulesCreateOrUpdateRoutingRulesDataTypedDict": ".routingrules_createorupdateroutingrulesop",
    "RoutingRulesCreateOrUpdateRoutingRulesRequest": ".routingrules_createorupdateroutingrulesop",
    "RoutingRulesCreateOrUpdateRoutingRulesRequestTypedDict": ".routingrules_createorupdateroutingrulesop",
    "RoutingRulesCreateOrUpdateRoutingRulesResponse": ".routingrules_createorupdateroutingrulesop",
    "RoutingRulesCreateOrUpdateRoutingRulesResponseTypedDict": ".routingrules_createorupdateroutingrulesop",
    "RoutingRulesGetRoutingRulesData": ".routingrules_getroutingrulesop",
    "RoutingRulesGetRoutingRulesDataTypedDict": ".routingrules_getroutingrulesop",
    "RoutingRulesGetRoutingRulesRequest": ".routingrules_getroutingrulesop",
    "RoutingRulesGetRoutingRulesRequestTypedDict": ".routingrules_getroutingrulesop",
    "RoutingRulesGetRoutingRulesResponse": ".routingrules_getroutingrulesop",
    "RoutingRulesGetRoutingRulesResponseTypedDict": ".routingrules_getroutingrulesop",
    "RunbooksAttachRunbooksRequest": ".runbooks_attachrunbooksop",
    "RunbooksAttachRunbooksRequestTypedDict": ".runbooks_attachrunbooksop",
    "RunbooksAttachRunbooksResponse": ".runbooks_attachrunbooksop",
    "RunbooksAttachRunbooksResponseTypedDict": ".runbooks_attachrunbooksop",
    "RunbooksCreateRunbookResponse": ".runbooks_createrunbookop",
    "RunbooksCreateRunbookResponseTypedDict": ".runbooks_createrunbookop",
    "RunbooksGetAllRunbooksByTeamResponse": ".runbooks_getallrunbooksbyteamop",
    "RunbooksGetAllRunbooksByTeamResponseTypedDict": ".runbooks_getallrunbooksbyteamop",
    "RunbooksGetRunbookByIDRequest": ".runbooks_getrunbookbyidop",
    "RunbooksGetRunbookByIDRequestTypedDict": ".runbooks_getrunbookbyidop",
    "RunbooksGetRunbookByIDResponse": ".runbooks_getrunbookbyidop",
    "RunbooksGetRunbookByIDResponseTypedDict": ".runbooks_getrunbookbyidop",
    "RunbooksRemoveRunbookRequest": ".runbooks_removerunbookop",
    "RunbooksRemoveRunbookRequestTypedDict": ".runbooks_removerunbookop",
    "RunbooksRemoveRunbookResponseBody": ".runbooks_removerunbookop",
    "RunbooksRemoveRunbookResponseBodyTypedDict": ".runbooks_removerunbookop",
    "RunbooksUpdateRunbookRequest": ".runbooks_updaterunbookop",
    "RunbooksUpdateRunbookRequestTypedDict": ".runbooks_updaterunbookop",
    "RunbooksUpdateRunbookResponse": ".runbooks_updaterunbookop",
    "RunbooksUpdateRunbookResponseTypedDict": ".runbooks_updaterunbookop",
    "SchedulesChangeTimezoneRequest": ".schedules_changetimezoneop",
    "SchedulesChangeTimezoneRequestBody": ".schedules_changetimezoneop",
    "SchedulesChangeTimezoneRequestBodyTypedDict": ".schedules_changetimezoneop",
    "SchedulesChangeTimezoneRequestTypedDict": ".schedules_changetimezoneop",
    "SchedulesChangeTimezoneResponse": ".schedules_changetimezoneop",
    "SchedulesChangeTimezoneResponseTypedDict": ".schedules_changetimezoneop",
    "SchedulesCloneScheduleRequest": ".schedules_clonescheduleop",
    "SchedulesCloneScheduleRequestBody": ".schedules_clonescheduleop",
    "SchedulesCloneScheduleRequestBodyTypedDict": ".schedules_clonescheduleop",
    "SchedulesCloneScheduleRequestTypedDict": ".schedules_clonescheduleop",
    "SchedulesCloneScheduleResponse": ".schedules_clonescheduleop",
    "SchedulesCloneScheduleResponseTypedDict": ".schedules_clonescheduleop",
    "SchedulesCreateScheduleResponse": ".schedules_createscheduleop",
    "SchedulesCreateScheduleResponseTypedDict": ".schedules_createscheduleop",
    "SchedulesDeleteScheduleRequest": ".schedules_deletescheduleop",
    "SchedulesDeleteScheduleRequestTypedDict": ".schedules_deletescheduleop",
    "SchedulesDeleteScheduleResponseBody": ".schedules_deletescheduleop",
    "SchedulesDeleteScheduleResponseBodyTypedDict": ".schedules_deletescheduleop",
    "SchedulesGetScheduleByIDRequest": ".schedules_getschedulebyidop",
    "SchedulesGetScheduleByIDRequestTypedDict": ".schedules_getschedulebyidop",
    "SchedulesGetScheduleByIDResponse": ".schedules_getschedulebyidop",
    "SchedulesGetScheduleByIDResponseTypedDict": ".schedules_getschedulebyidop",
    "SchedulesListSchedulesRequest": ".schedules_listschedulesop",
    "SchedulesListSchedulesRequestTypedDict": ".schedules_listschedulesop",
    "SchedulesListSchedulesResponse": ".schedules_listschedulesop",
    "SchedulesListSchedulesResponseBody": ".schedules_listschedulesop",
    "SchedulesListSchedulesResponseBodyTypedDict": ".schedules_listschedulesop",
    "SchedulesListSchedulesResponseTypedDict": ".schedules_listschedulesop",
    "Action": ".schedules_pauseresumescheduleop",
    "SchedulesPauseresumeScheduleRequest": ".schedules_pauseresumescheduleop",
    "SchedulesPauseresumeScheduleRequestBody": ".schedules_pauseresumescheduleop",
    "SchedulesPauseresumeScheduleRequestBodyTypedDict": ".schedules_pauseresumescheduleop",
    "SchedulesPauseresumeScheduleRequestTypedDict": ".schedules_pauseresumescheduleop",
    "SchedulesPauseresumeScheduleResponse": ".schedules_pauseresumescheduleop",
    "SchedulesPauseresumeScheduleResponseTypedDict": ".schedules_pauseresumescheduleop",
    "SchedulesUpdateScheduleRequest": ".schedules_updatescheduleop",
    "SchedulesUpdateScheduleRequestTypedDict": ".schedules_updatescheduleop",
    "SchedulesUpdateScheduleResponse": ".schedules_updatescheduleop",
    "SchedulesUpdateScheduleResponseTypedDict": ".schedules_updatescheduleop",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "ServicesCreateOrUpdateAPTAConfigData": ".services_createorupdateaptaconfigop",
    "ServicesCreateOrUpdateAPTAConfigDataTypedDict": ".services_createorupdateaptaconfigop",
    "ServicesCreateOrUpdateAPTAConfigRequest": ".services_createorupdateaptaconfigop",
    "ServicesCreateOrUpdateAPTAConfigRequestTypedDict": ".services_createorupdateaptaconfigop",
    "ServicesCreateOrUpdateAPTAConfigResponse": ".services_createorupdateaptaconfigop",
    "ServicesCreateOrUpdateAPTAConfigResponseTypedDict": ".services_createorupdateaptaconfigop",
    "ServicesCreateOrUpdateIAGConfigData": ".services_createorupdateiagconfigop",
    "ServicesCreateOrUpdateIAGConfigDataTypedDict": ".services_createorupdateiagconfigop",
    "ServicesCreateOrUpdateIAGConfigRequest": ".services_createorupdateiagconfigop",
    "ServicesCreateOrUpdateIAGConfigRequestTypedDict": ".services_createorupdateiagconfigop",
    "ServicesCreateOrUpdateIAGConfigResponse": ".services_createorupdateiagconfigop",
    "ServicesCreateOrUpdateIAGConfigResponseTypedDict": ".services_createorupdateiagconfigop",
    "ServicesCreateServiceBody": ".services_createserviceop",
    "ServicesCreateServiceBodyTypedDict": ".services_createserviceop",
    "ServicesCreateServiceRequest": ".services_createserviceop",
    "ServicesCreateServiceRequestTypedDict": ".services_createserviceop",
    "ServicesCreateServiceResponse": ".services_createserviceop",
    "ServicesCreateServiceResponseTypedDict": ".services_createserviceop",
    "ServicesDelayedNotificationConfigRequest": ".services_delayednotificationconfigop",
    "ServicesDelayedNotificationConfigRequestTypedDict": ".services_delayednotificationconfigop",
    "ServicesDelayedNotificationConfigResponse": ".services_delayednotificationconfigop",
    "ServicesDelayedNotificationConfigResponseTypedDict": ".services_delayednotificationconfigop",
    "ServicesDeleteServiceRequest": ".services_deleteserviceop",
    "ServicesDeleteServiceRequestTypedDict": ".services_deleteserviceop",
    "ServicesDeleteServiceResponseBody": ".services_deleteserviceop",
    "ServicesDeleteServiceResponseBodyTypedDict": ".services_deleteserviceop",
    "ServicesGetServiceByIDRequest": ".services_getservicebyidop",
    "ServicesGetServiceByIDRequestTypedDict": ".services_getservicebyidop",
    "ServicesGetServiceByIDResponse": ".services_getservicebyidop",
    "ServicesGetServiceByIDResponseTypedDict": ".services_getservicebyidop",
    "ServicesGetServicesByNameRequest": ".services_getservicesbynameop",
    "ServicesGetServicesByNameRequestTypedDict": ".services_getservicesbynameop",
    "ServicesGetServicesByNameResponse": ".services_getservicesbynameop",
    "ServicesGetServicesByNameResponseTypedDict": ".services_getservicesbynameop",
    "ServicesGetServicesRequest": ".services_getservicesop",
    "ServicesGetServicesRequestTypedDict": ".services_getservicesop",
    "ServicesGetServicesResponse": ".services_getservicesop",
    "ServicesGetServicesResponseTypedDict": ".services_getservicesop",
    "ServicesUpdateServiceRequest": ".services_updateserviceop",
    "ServicesUpdateServiceRequestTypedDict": ".services_updateserviceop",
    "ServicesUpdateServiceResponse": ".services_updateserviceop",
    "ServicesUpdateServiceResponseTypedDict": ".services_updateserviceop",
    "SLOCreateSLOData": ".slo_createsloop",
    "SLOCreateSLODataTypedDict": ".slo_createsloop",
    "SLOCreateSLOResponse": ".slo_createsloop",
    "SLOCreateSLOResponseTypedDict": ".slo_createsloop",
    "SLOGetAllSLOsData": ".slo_getallslosop",
    "SLOGetAllSLOsDataTypedDict": ".slo_getallslosop",
    "SLOGetAllSLOsMeta": ".slo_getallslosop",
    "SLOGetAllSLOsMetaTypedDict": ".slo_getallslosop",
    "SLOGetAllSLOsRequest": ".slo_getallslosop",
    "SLOGetAllSLOsRequestTypedDict": ".slo_getallslosop",
    "SLOGetAllSLOsResponse": ".slo_getallslosop",
    "SLOGetAllSLOsResponseTypedDict": ".slo_getallslosop",
    "SLOGetSLOByIDRequest": ".slo_getslobyidop",
    "SLOGetSLOByIDRequestTypedDict": ".slo_getslobyidop",
    "SLOGetSLOByIDResponse": ".slo_getslobyidop",
    "SLOGetSLOByIDResponseTypedDict": ".slo_getslobyidop",
    "SLOMarkSLOAffectedData": ".slo_marksloaffectedop",
    "SLOMarkSLOAffectedDataTypedDict": ".slo_marksloaffectedop",
    "SLOMarkSLOAffectedRequest": ".slo_marksloaffectedop",
    "SLOMarkSLOAffectedRequestTypedDict": ".slo_marksloaffectedop",
    "SLOMarkSLOAffectedResponse": ".slo_marksloaffectedop",
    "SLOMarkSLOAffectedResponseTypedDict": ".slo_marksloaffectedop",
    "SLOMarkSLOFalsePositiveData": ".slo_markslofalsepositiveop",
    "SLOMarkSLOFalsePositiveDataTypedDict": ".slo_markslofalsepositiveop",
    "SLOMarkSLOFalsePositiveRequest": ".slo_markslofalsepositiveop",
    "SLOMarkSLOFalsePositiveRequestBody": ".slo_markslofalsepositiveop",
    "SLOMarkSLOFalsePositiveRequestBodyTypedDict": ".slo_markslofalsepositiveop",
    "SLOMarkSLOFalsePositiveRequestTypedDict": ".slo_markslofalsepositiveop",
    "SLOMarkSLOFalsePositiveResponse": ".slo_markslofalsepositiveop",
    "SLOMarkSLOFalsePositiveResponseTypedDict": ".slo_markslofalsepositiveop",
    "SLORemoveSLORequest": ".slo_removesloop",
    "SLORemoveSLORequestTypedDict": ".slo_removesloop",
    "SLORemoveSLOResponse": ".slo_removesloop",
    "SLORemoveSLOResponseTypedDict": ".slo_removesloop",
    "SLOUpdateSLOData": ".slo_updatesloop",
    "SLOUpdateSLODataTypedDict": ".slo_updatesloop",
    "SLOUpdateSLORequest": ".slo_updatesloop",
    "SLOUpdateSLORequestTypedDict": ".slo_updatesloop",
    "SLOUpdateSLOResponse": ".slo_updatesloop",
    "SLOUpdateSLOResponseTypedDict": ".slo_updatesloop",
    "SnoozeNotificationsSnoozeIncidentNotificationsRequest": ".snoozenotifications_snoozeincidentnotificationsop",
    "SnoozeNotificationsSnoozeIncidentNotificationsRequestTypedDict": ".snoozenotifications_snoozeincidentnotificationsop",
    "SnoozeNotificationsSnoozeIncidentNotificationsResponse": ".snoozenotifications_snoozeincidentnotificationsop",
    "SnoozeNotificationsSnoozeIncidentNotificationsResponseTypedDict": ".snoozenotifications_snoozeincidentnotificationsop",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsRequest": ".snoozenotifications_unsnoozeincidentnotificationsop",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsRequestTypedDict": ".snoozenotifications_unsnoozeincidentnotificationsop",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsResponse": ".snoozenotifications_unsnoozeincidentnotificationsop",
    "SnoozeNotificationsUnsnoozeIncidentNotificationsResponseTypedDict": ".snoozenotifications_unsnoozeincidentnotificationsop",
    "SquadsCreateSquadResponse": ".squads_createsquadop",
    "SquadsCreateSquadResponseTypedDict": ".squads_createsquadop",
    "SquadsDeleteSquadRequest": ".squads_deletesquadop",
    "SquadsDeleteSquadRequestTypedDict": ".squads_deletesquadop",
    "SquadsDeleteSquadResponseBody": ".squads_deletesquadop",
    "SquadsDeleteSquadResponseBodyTypedDict": ".squads_deletesquadop",
    "SquadsGetAllSquadsRequest": ".squads_getallsquadsop",
    "SquadsGetAllSquadsRequestTypedDict": ".squads_getallsquadsop",
    "SquadsGetAllSquadsResponse": ".squads_getallsquadsop",
    "SquadsGetAllSquadsResponseTypedDict": ".squads_getallsquadsop",
    "SquadsGetSquadByIDRequest": ".squads_getsquadbyidop",
    "SquadsGetSquadByIDRequestTypedDict": ".squads_getsquadbyidop",
    "SquadsGetSquadByIDResponse": ".squads_getsquadbyidop",
    "SquadsGetSquadByIDResponseTypedDict": ".squads_getsquadbyidop",
    "SquadsRemoveSquadMemberRequest": ".squads_removesquadmemberop",
    "SquadsRemoveSquadMemberRequestTypedDict": ".squads_removesquadmemberop",
    "SquadsUpdateSquadMemberRequest": ".squads_updatesquadmemberop",
    "SquadsUpdateSquadMemberRequestTypedDict": ".squads_updatesquadmemberop",
    "SquadsUpdateSquadNameRequest": ".squads_updatesquadnameop",
    "SquadsUpdateSquadNameRequestTypedDict": ".squads_updatesquadnameop",
    "SquadsUpdateSquadNameResponse": ".squads_updatesquadnameop",
    "SquadsUpdateSquadNameResponseTypedDict": ".squads_updatesquadnameop",
    "SquadsUpdateSquadRequest": ".squads_updatesquadop",
    "SquadsUpdateSquadRequestTypedDict": ".squads_updatesquadop",
    "SquadsUpdateSquadResponse": ".squads_updatesquadop",
    "SquadsUpdateSquadResponseTypedDict": ".squads_updatesquadop",
    "StatusPagesCreateStatusPageResponse": ".statuspages_createstatuspageop",
    "StatusPagesCreateStatusPageResponseTypedDict": ".statuspages_createstatuspageop",
    "StatusPagesDeleteStatusPageByIDRequest": ".statuspages_deletestatuspagebyidop",
    "StatusPagesDeleteStatusPageByIDRequestTypedDict": ".statuspages_deletestatuspagebyidop",
    "StatusPagesDeleteStatusPageByIDResponse": ".statuspages_deletestatuspagebyidop",
    "StatusPagesDeleteStatusPageByIDResponseTypedDict": ".statuspages_deletestatuspagebyidop",
    "StatusPagesGetStatusPageByIDRequest": ".statuspages_getstatuspagebyidop",
    "StatusPagesGetStatusPageByIDRequestTypedDict": ".statuspages_getstatuspagebyidop",
    "StatusPagesGetStatusPageByIDResponse": ".statuspages_getstatuspagebyidop",
    "StatusPagesGetStatusPageByIDResponseTypedDict": ".statuspages_getstatuspagebyidop",
    "StatusPagesListStatusPagesRequest": ".statuspages_liststatuspagesop",
    "StatusPagesListStatusPagesRequestTypedDict": ".statuspages_liststatuspagesop",
    "StatusPagesListStatusPagesResponse": ".statuspages_liststatuspagesop",
    "StatusPagesListStatusPagesResponseTypedDict": ".statuspages_liststatuspagesop",
    "StatusPagesListStatusPageStatusesRequest": ".statuspages_liststatuspagestatusesop",
    "StatusPagesListStatusPageStatusesRequestTypedDict": ".statuspages_liststatuspagestatusesop",
    "StatusPagesListStatusPageStatusesResponse": ".statuspages_liststatuspagestatusesop",
    "StatusPagesListStatusPageStatusesResponseTypedDict": ".statuspages_liststatuspagestatusesop",
    "StatusPagesListSubscribersRequest": ".statuspages_listsubscribersop",
    "StatusPagesListSubscribersRequestTypedDict": ".statuspages_listsubscribersop",
    "StatusPagesUpdateStatusPageByIDRequest": ".statuspages_updatestatuspagebyidop",
    "StatusPagesUpdateStatusPageByIDRequestTypedDict": ".statuspages_updatestatuspagebyidop",
    "StatusPagesUpdateStatusPageByIDResponse": ".statuspages_updatestatuspagebyidop",
    "StatusPagesUpdateStatusPageByIDResponseTypedDict": ".statuspages_updatestatuspagebyidop",
    "SuppressionRulesCreateOrUpdateSuppressionRulesRequest": ".suppressionrules_createorupdatesuppressionrulesop",
    "SuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict": ".suppressionrules_createorupdatesuppressionrulesop",
    "SuppressionRulesCreateOrUpdateSuppressionRulesResponse": ".suppressionrules_createorupdatesuppressionrulesop",
    "SuppressionRulesCreateOrUpdateSuppressionRulesResponseTypedDict": ".suppressionrules_createorupdatesuppressionrulesop",
    "SuppressionRulesGetSuppressionRulesData": ".suppressionrules_getsuppressionrulesop",
    "SuppressionRulesGetSuppressionRulesDataTypedDict": ".suppressionrules_getsuppressionrulesop",
    "SuppressionRulesGetSuppressionRulesRequest": ".suppressionrules_getsuppressionrulesop",
    "SuppressionRulesGetSuppressionRulesRequestTypedDict": ".suppressionrules_getsuppressionrulesop",
    "SuppressionRulesGetSuppressionRulesResponse": ".suppressionrules_getsuppressionrulesop",
    "SuppressionRulesGetSuppressionRulesResponseTypedDict": ".suppressionrules_getsuppressionrulesop",
    "TaggingRulesCreateOrUpdateTaggingRulesData": ".taggingrules_createorupdatetaggingrulesop",
    "TaggingRulesCreateOrUpdateTaggingRulesDataTypedDict": ".taggingrules_createorupdatetaggingrulesop",
    "TaggingRulesCreateOrUpdateTaggingRulesRequest": ".taggingrules_createorupdatetaggingrulesop",
    "TaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict": ".taggingrules_createorupdatetaggingrulesop",
    "TaggingRulesCreateOrUpdateTaggingRulesResponse": ".taggingrules_createorupdatetaggingrulesop",
    "TaggingRulesCreateOrUpdateTaggingRulesResponseTypedDict": ".taggingrules_createorupdatetaggingrulesop",
    "TaggingRulesGetTaggingRulesData": ".taggingrules_gettaggingrulesop",
    "TaggingRulesGetTaggingRulesDataTypedDict": ".taggingrules_gettaggingrulesop",
    "TaggingRulesGetTaggingRulesRequest": ".taggingrules_gettaggingrulesop",
    "TaggingRulesGetTaggingRulesRequestTypedDict": ".taggingrules_gettaggingrulesop",
    "TaggingRulesGetTaggingRulesResponse": ".taggingrules_gettaggingrulesop",
    "TaggingRulesGetTaggingRulesResponseTypedDict": ".taggingrules_gettaggingrulesop",
    "TagsAppendTagRequest": ".tags_appendtagop",
    "TagsAppendTagRequestTypedDict": ".tags_appendtagop",
    "TagsAppendTagResponse": ".tags_appendtagop",
    "TagsAppendTagResponseTypedDict": ".tags_appendtagop",
    "TagsUpdateTagRequest": ".tags_updatetagop",
    "TagsUpdateTagRequestTypedDict": ".tags_updatetagop",
    "TagsUpdateTagResponse": ".tags_updatetagop",
    "TagsUpdateTagResponseTypedDict": ".tags_updatetagop",
    "TeamsAddBulkTeamMemberData": ".teams_addbulkteammemberop",
    "TeamsAddBulkTeamMemberDataTypedDict": ".teams_addbulkteammemberop",
    "TeamsAddBulkTeamMemberMember": ".teams_addbulkteammemberop",
    "TeamsAddBulkTeamMemberMemberTypedDict": ".teams_addbulkteammemberop",
    "TeamsAddBulkTeamMemberRequest": ".teams_addbulkteammemberop",
    "TeamsAddBulkTeamMemberRequestTypedDict": ".teams_addbulkteammemberop",
    "TeamsAddBulkTeamMemberResponse": ".teams_addbulkteammemberop",
    "TeamsAddBulkTeamMemberResponseTypedDict": ".teams_addbulkteammemberop",
    "TeamsAddTeamMemberRequest": ".teams_addteammemberop",
    "TeamsAddTeamMemberRequestTypedDict": ".teams_addteammemberop",
    "TeamsAddTeamMemberResponse": ".teams_addteammemberop",
    "TeamsAddTeamMemberResponseTypedDict": ".teams_addteammemberop",
    "TeamsCreateTeamResponse": ".teams_createteamop",
    "TeamsCreateTeamResponseTypedDict": ".teams_createteamop",
    "TeamsCreateTeamRoleRequest": ".teams_createteamroleop",
    "TeamsCreateTeamRoleRequestTypedDict": ".teams_createteamroleop",
    "TeamsCreateTeamRoleResponse": ".teams_createteamroleop",
    "TeamsCreateTeamRoleResponseTypedDict": ".teams_createteamroleop",
    "TeamsGetAllTeamMembersRequest": ".teams_getallteammembersop",
    "TeamsGetAllTeamMembersRequestTypedDict": ".teams_getallteammembersop",
    "TeamsGetAllTeamMembersResponse": ".teams_getallteammembersop",
    "TeamsGetAllTeamMembersResponseTypedDict": ".teams_getallteammembersop",
    "TeamsGetAllTeamRolesRequest": ".teams_getallteamrolesop",
    "TeamsGetAllTeamRolesRequestTypedDict": ".teams_getallteamrolesop",
    "TeamsGetAllTeamRolesResponse": ".teams_getallteamrolesop",
    "TeamsGetAllTeamRolesResponseTypedDict": ".teams_getallteamrolesop",
    "TeamsGetAllTeamsResponse": ".teams_getallteamsop",
    "TeamsGetAllTeamsResponseTypedDict": ".teams_getallteamsop",
    "TeamsGetTeamByIDRequest": ".teams_getteambyidop",
    "TeamsGetTeamByIDRequestTypedDict": ".teams_getteambyidop",
    "TeamsGetTeamByIDResponse": ".teams_getteambyidop",
    "TeamsGetTeamByIDResponseTypedDict": ".teams_getteambyidop",
    "TeamsRemoveTeamMemberRequest": ".teams_removeteammemberop",
    "TeamsRemoveTeamMemberRequestTypedDict": ".teams_removeteammemberop",
    "TeamsRemoveTeamMemberResponseBody": ".teams_removeteammemberop",
    "TeamsRemoveTeamMemberResponseBodyTypedDict": ".teams_removeteammemberop",
    "TeamsRemoveTeamRequest": ".teams_removeteamop",
    "TeamsRemoveTeamRequestTypedDict": ".teams_removeteamop",
    "TeamsRemoveTeamResponseBody": ".teams_removeteamop",
    "TeamsRemoveTeamResponseBodyTypedDict": ".teams_removeteamop",
    "TeamsRemoveTeamRoleRequest": ".teams_removeteamroleop",
    "TeamsRemoveTeamRoleRequestTypedDict": ".teams_removeteamroleop",
    "TeamsRemoveTeamRoleResponseBody": ".teams_removeteamroleop",
    "TeamsRemoveTeamRoleResponseBodyTypedDict": ".teams_removeteamroleop",
    "TeamsUpdateTeamMemberRequest": ".teams_updateteammemberop",
    "TeamsUpdateTeamMemberRequestTypedDict": ".teams_updateteammemberop",
    "TeamsUpdateTeamMemberResponse": ".teams_updateteammemberop",
    "TeamsUpdateTeamMemberResponseTypedDict": ".teams_updateteammemberop",
    "TeamsUpdateTeamRequest": ".teams_updateteamop",
    "TeamsUpdateTeamRequestTypedDict": ".teams_updateteamop",
    "TeamsUpdateTeamResponse": ".teams_updateteamop",
    "TeamsUpdateTeamResponseTypedDict": ".teams_updateteamop",
    "TeamsUpdateTeamRoleRequest": ".teams_updateteamroleop",
    "TeamsUpdateTeamRoleRequestTypedDict": ".teams_updateteamroleop",
    "TeamsUpdateTeamRoleResponse": ".teams_updateteamroleop",
    "TeamsUpdateTeamRoleResponseTypedDict": ".teams_updateteamroleop",
    "UsersAddUserResponse": ".users_adduserop",
    "UsersAddUserResponseTypedDict": ".users_adduserop",
    "UsersCreateTokenRequest": ".users_createtokenop",
    "UsersCreateTokenRequestTypedDict": ".users_createtokenop",
    "UsersCreateTokenResponse": ".users_createtokenop",
    "UsersCreateTokenResponseTypedDict": ".users_createtokenop",
    "UsersDeleteUserData": ".users_deleteuserop",
    "UsersDeleteUserDataTypedDict": ".users_deleteuserop",
    "UsersDeleteUserRequest": ".users_deleteuserop",
    "UsersDeleteUserRequestTypedDict": ".users_deleteuserop",
    "UsersDeleteUserResponse": ".users_deleteuserop",
    "UsersDeleteUserResponseTypedDict": ".users_deleteuserop",
    "UsersGetAllTokensResponse": ".users_getalltokensop",
    "UsersGetAllTokensResponseTypedDict": ".users_getalltokensop",
    "UsersGetAllUsersResponse": ".users_getallusersop",
    "UsersGetAllUsersResponseTypedDict": ".users_getallusersop",
    "UsersGetUserByIDRequest": ".users_getuserbyidop",
    "UsersGetUserByIDRequestTypedDict": ".users_getuserbyidop",
    "UsersGetUserByIDResponse": ".users_getuserbyidop",
    "UsersGetUserByIDResponseTypedDict": ".users_getuserbyidop",
    "UsersGetUserRolesResponse": ".users_getuserrolesop",
    "UsersGetUserRolesResponseTypedDict": ".users_getuserrolesop",
    "UsersRemoveTokenRequest": ".users_removetokenop",
    "UsersRemoveTokenRequestTypedDict": ".users_removetokenop",
    "UsersRemoveTokenResponseBody": ".users_removetokenop",
    "UsersRemoveTokenResponseBodyTypedDict": ".users_removetokenop",
    "UsersRemoveUserFromOrgRequest": ".users_removeuserfromorgop",
    "UsersRemoveUserFromOrgRequestTypedDict": ".users_removeuserfromorgop",
    "UsersRemoveUserFromOrgResponseBody": ".users_removeuserfromorgop",
    "UsersRemoveUserFromOrgResponseBodyTypedDict": ".users_removeuserfromorgop",
    "UsersUpdateOrgLevelPermissionsResponse": ".users_updateorglevelpermissionsop",
    "UsersUpdateOrgLevelPermissionsResponseTypedDict": ".users_updateorglevelpermissionsop",
    "UsersUpdateUserByIDRequest": ".users_updateuserbyidop",
    "UsersUpdateUserByIDRequestTypedDict": ".users_updateuserbyidop",
    "UsersUpdateUserByIDResponse": ".users_updateuserbyidop",
    "UsersUpdateUserByIDResponseTypedDict": ".users_updateuserbyidop",
    "V3AnalyticsAnalyticsResponse": ".v3_analytics_analyticsresponse",
    "V3AnalyticsAnalyticsResponseTypedDict": ".v3_analytics_analyticsresponse",
    "V3AuditLogsActor": ".v3_auditlogs_actor",
    "V3AuditLogsActorTypedDict": ".v3_auditlogs_actor",
    "V3AuditLogsAuditLogIDResponse": ".v3_auditlogs_auditlogidresponse",
    "V3AuditLogsAuditLogIDResponseMeta": ".v3_auditlogs_auditlogidresponse",
    "V3AuditLogsAuditLogIDResponseMetaTypedDict": ".v3_auditlogs_auditlogidresponse",
    "V3AuditLogsAuditLogIDResponseTypedDict": ".v3_auditlogs_auditlogidresponse",
    "V3AuditLogsAuditLogResponse": ".v3_auditlogs_auditlogresponse",
    "V3AuditLogsAuditLogResponseTypedDict": ".v3_auditlogs_auditlogresponse",
    "V3AuditLogsAuditLogsExportHistoryResponse": ".v3_auditlogs_auditlogsexporthistoryresponse",
    "V3AuditLogsAuditLogsExportHistoryResponseTypedDict": ".v3_auditlogs_auditlogsexporthistoryresponse",
    "ExportType": ".v3_auditlogs_exportauditlogsrequest",
    "Filters": ".v3_auditlogs_exportauditlogsrequest",
    "FiltersTypedDict": ".v3_auditlogs_exportauditlogsrequest",
    "V3AuditLogsExportAuditLogsRequest": ".v3_auditlogs_exportauditlogsrequest",
    "V3AuditLogsExportAuditLogsRequestTypedDict": ".v3_auditlogs_exportauditlogsrequest",
    "V3AuditLogsExportAuditLogsResponse": ".v3_auditlogs_exportauditlogsresponse",
    "V3AuditLogsExportAuditLogsResponseData": ".v3_auditlogs_exportauditlogsresponse",
    "V3AuditLogsExportAuditLogsResponseDataTypedDict": ".v3_auditlogs_exportauditlogsresponse",
    "V3AuditLogsExportAuditLogsResponseTypedDict": ".v3_auditlogs_exportauditlogsresponse",
    "V3AuditLogsFilters": ".v3_auditlogs_filters",
    "V3AuditLogsFiltersTypedDict": ".v3_auditlogs_filters",
    "V3AuditLogsGetAuditLogByIDResponse": ".v3_auditlogs_getauditlogbyidresponse",
    "V3AuditLogsGetAuditLogByIDResponseTypedDict": ".v3_auditlogs_getauditlogbyidresponse",
    "V3AuditLogsGetAuditLogExportHistoryByIDResponse": ".v3_auditlogs_getauditlogexporthistorybyidresponse",
    "V3AuditLogsGetAuditLogExportHistoryByIDResponseTypedDict": ".v3_auditlogs_getauditlogexporthistorybyidresponse",
    "V3AuditLogsListAuditLogsExportHistoryResponse": ".v3_auditlogs_listauditlogsexporthistoryresponse",
    "V3AuditLogsListAuditLogsExportHistoryResponseMetadata": ".v3_auditlogs_listauditlogsexporthistoryresponse",
    "V3AuditLogsListAuditLogsExportHistoryResponseMetadataTypedDict": ".v3_auditlogs_listauditlogsexporthistoryresponse",
    "V3AuditLogsListAuditLogsExportHistoryResponseTypedDict": ".v3_auditlogs_listauditlogsexporthistoryresponse",
    "V3AuditLogsListAuditLogsResponse": ".v3_auditlogs_listauditlogsresponse",
    "V3AuditLogsListAuditLogsResponseMetadata": ".v3_auditlogs_listauditlogsresponse",
    "V3AuditLogsListAuditLogsResponseMetadataTypedDict": ".v3_auditlogs_listauditlogsresponse",
    "V3AuditLogsListAuditLogsResponseTypedDict": ".v3_auditlogs_listauditlogsresponse",
    "V3AuditLogsTeam": ".v3_auditlogs_team",
    "V3AuditLogsTeamTypedDict": ".v3_auditlogs_team",
    "V3EscalationPoliciesCreateEscalationPolicyRequest": ".v3_escalationpolicies_createescalationpolicyrequest",
    "V3EscalationPoliciesCreateEscalationPolicyRequestTypedDict": ".v3_escalationpolicies_createescalationpolicyrequest",
    "V3EscalationPoliciesEscalationEntity": ".v3_escalationpolicies_escalationentity",
    "V3EscalationPoliciesEscalationEntityType": ".v3_escalationpolicies_escalationentity",
    "V3EscalationPoliciesEscalationEntityTypedDict": ".v3_escalationpolicies_escalationentity",
    "V3EscalationPoliciesEscalationPolicyResponse": ".v3_escalationpolicies_escalationpolicyresponse",
    "V3EscalationPoliciesEscalationPolicyResponseTypedDict": ".v3_escalationpolicies_escalationpolicyresponse",
    "V3EscalationPoliciesEscalationPolicyRule": ".v3_escalationpolicies_escalationpolicyrule",
    "V3EscalationPoliciesEscalationPolicyRuleTypedDict": ".v3_escalationpolicies_escalationpolicyrule",
    "V3EscalationPoliciesIncidentReminderRule": ".v3_escalationpolicies_incidentreminderrule",
    "V3EscalationPoliciesIncidentReminderRuleTypedDict": ".v3_escalationpolicies_incidentreminderrule",
    "V3ExportExportResponse": ".v3_export_exportresponse",
    "V3ExportExportResponseTypedDict": ".v3_export_exportresponse",
    "V3ExtensionsMSTeamsChannelConfiguration": ".v3_extensions_msteams_channelconfiguration",
    "V3ExtensionsMSTeamsChannelConfigurationTypedDict": ".v3_extensions_msteams_channelconfiguration",
    "V3ExtensionsMSTeamsConnectedTeams": ".v3_extensions_msteams_connectedteams",
    "V3ExtensionsMSTeamsConnectedTeamsTypedDict": ".v3_extensions_msteams_connectedteams",
    "V3ExtensionsMSTeamsCreateOrUpdateMSTeamsConfigRequest": ".v3_extensions_msteams_createorupdatemsteamsconfigrequest",
    "V3ExtensionsMSTeamsCreateOrUpdateMSTeamsConfigRequestTypedDict": ".v3_extensions_msteams_createorupdatemsteamsconfigrequest",
    "V3ExtensionsMSTeamsEventClass": ".v3_extensions_msteams_eventclass",
    "V3ExtensionsMSTeamsEventClassEnum": ".v3_extensions_msteams_eventclass",
    "V3ExtensionsMSTeamsEventClassTypedDict": ".v3_extensions_msteams_eventclass",
    "V3ExtensionsMSTeamsIncidentActionAlertState": ".v3_extensions_msteams_incidentactionalertstate",
    "V3ExtensionsMSTeamsIncidentActionAlertStateTypedDict": ".v3_extensions_msteams_incidentactionalertstate",
    "V3ExtensionsMSTeamsMSTeamsConfigResponse": ".v3_extensions_msteams_msteamsconfigresponse",
    "V3ExtensionsMSTeamsMSTeamsConfigResponseTypedDict": ".v3_extensions_msteams_msteamsconfigresponse",
    "V3ExtensionsMSTeamsSquadCastServiceMapping": ".v3_extensions_msteams_squadcastservicemapping",
    "V3ExtensionsMSTeamsSquadCastServiceMappingTypedDict": ".v3_extensions_msteams_squadcastservicemapping",
    "V3ExtensionsMSTeamsTriggers": ".v3_extensions_msteams_triggers",
    "V3ExtensionsMSTeamsTriggersTypedDict": ".v3_extensions_msteams_triggers",
    "V3ExtensionsWebhooksGetAllWebhooksResponse": ".v3_extensions_webhooks_getallwebhooksresponse",
    "V3ExtensionsWebhooksGetAllWebhooksResponseData": ".v3_extensions_webhooks_getallwebhooksresponse",
    "V3ExtensionsWebhooksGetAllWebhooksResponseDataTypedDict": ".v3_extensions_webhooks_getallwebhooksresponse",
    "V3ExtensionsWebhooksGetAllWebhooksResponseMeta": ".v3_extensions_webhooks_getallwebhooksresponse",
    "V3ExtensionsWebhooksGetAllWebhooksResponseMetaTypedDict": ".v3_extensions_webhooks_getallwebhooksresponse",
    "V3ExtensionsWebhooksGetAllWebhooksResponseTypedDict": ".v3_extensions_webhooks_getallwebhooksresponse",
    "V3ExtensionsWebhooksWebhook": ".v3_extensions_webhooks_webhook",
    "V3ExtensionsWebhooksWebhookHeader": ".v3_extensions_webhooks_webhook",
    "V3ExtensionsWebhooksWebhookHeaderTypedDict": ".v3_extensions_webhooks_webhook",
    "V3ExtensionsWebhooksWebhookTypedDict": ".v3_extensions_webhooks_webhook",
    "V3ExtensionsWebhooksWebhookFilter": ".v3_extensions_webhooks_webhookfilter",
    "V3ExtensionsWebhooksWebhookFilterTypedDict": ".v3_extensions_webhooks_webhookfilter",
    "V3ExtensionsWebhooksWebhookFilterCondition": ".v3_extensions_webhooks_webhookfiltercondition",
    "V3ExtensionsWebhooksWebhookFilterConditionTypedDict": ".v3_extensions_webhooks_webhookfiltercondition",
    "V3ExtensionsWebhooksWebhookListItem": ".v3_extensions_webhooks_webhooklistitem",
    "V3ExtensionsWebhooksWebhookListItemTypedDict": ".v3_extensions_webhooks_webhooklistitem",
    "V3ExtensionsWebhooksWebhookResponse": ".v3_extensions_webhooks_webhookresponse",
    "V3ExtensionsWebhooksWebhookResponseHeader": ".v3_extensions_webhooks_webhookresponse",
    "V3ExtensionsWebhooksWebhookResponseHeaderTypedDict": ".v3_extensions_webhooks_webhookresponse",
    "V3ExtensionsWebhooksWebhookResponseTypedDict": ".v3_extensions_webhooks_webhookresponse",
    "V3ExtensionsWebhooksWebhookTrigger": ".v3_extensions_webhooks_webhooktrigger",
    "V3ExtensionsWebhooksWebhookTriggerTypedDict": ".v3_extensions_webhooks_webhooktrigger",
    "V3ExtensionsWebhooksWebhookURL": ".v3_extensions_webhooks_webhookurl",
    "V3ExtensionsWebhooksWebhookURLTypedDict": ".v3_extensions_webhooks_webhookurl",
    "V3GlobalEventRulesCreatedGlobalEventRuleResponse": ".v3_globaleventrules_createdglobaleventruleresponse",
    "V3GlobalEventRulesCreatedGlobalEventRuleResponseTypedDict": ".v3_globaleventrules_createdglobaleventruleresponse",
    "V3GlobalEventRulesCreateGlobalEventRuleRequest": ".v3_globaleventrules_createglobaleventrulerequest",
    "V3GlobalEventRulesCreateGlobalEventRuleRequestTypedDict": ".v3_globaleventrules_createglobaleventrulerequest",
    "V3GlobalEventRulesCreateOrUpdateRuleRequest": ".v3_globaleventrules_createorupdaterulerequest",
    "V3GlobalEventRulesCreateOrUpdateRuleRequestTypedDict": ".v3_globaleventrules_createorupdaterulerequest",
    "V3GlobalEventRulesCreateRulesetRequest": ".v3_globaleventrules_createrulesetrequest",
    "V3GlobalEventRulesCreateRulesetRequestTypedDict": ".v3_globaleventrules_createrulesetrequest",
    "V3GlobalEventRulesEntityOwner": ".v3_globaleventrules_entityowner",
    "V3GlobalEventRulesEntityOwnerType": ".v3_globaleventrules_entityowner",
    "V3GlobalEventRulesEntityOwnerTypedDict": ".v3_globaleventrules_entityowner",
    "V3GlobalEventRulesEntityOwnerUpdate": ".v3_globaleventrules_entityownerupdate",
    "V3GlobalEventRulesEntityOwnerUpdateType": ".v3_globaleventrules_entityownerupdate",
    "V3GlobalEventRulesEntityOwnerUpdateTypedDict": ".v3_globaleventrules_entityownerupdate",
    "V3GlobalEventRulesGlobalEventRuleInList": ".v3_globaleventrules_globaleventruleinlist",
    "V3GlobalEventRulesGlobalEventRuleInListTypedDict": ".v3_globaleventrules_globaleventruleinlist",
    "V3GlobalEventRulesGlobalEventRuleResponse": ".v3_globaleventrules_globaleventruleresponse",
    "V3GlobalEventRulesGlobalEventRuleResponseTypedDict": ".v3_globaleventrules_globaleventruleresponse",
    "V3GlobalEventRulesOrderingResponse": ".v3_globaleventrules_orderingresponse",
    "V3GlobalEventRulesOrderingResponseTypedDict": ".v3_globaleventrules_orderingresponse",
    "V3GlobalEventRulesReorderRuleRequest": ".v3_globaleventrules_reorderrulerequest",
    "V3GlobalEventRulesReorderRuleRequestTypedDict": ".v3_globaleventrules_reorderrulerequest",
    "V3GlobalEventRulesReorderRulesetRequest": ".v3_globaleventrules_reorderrulesetrequest",
    "V3GlobalEventRulesReorderRulesetRequestTypedDict": ".v3_globaleventrules_reorderrulesetrequest",
    "V3GlobalEventRulesRuleAction": ".v3_globaleventrules_ruleaction",
    "V3GlobalEventRulesRuleActionTypedDict": ".v3_globaleventrules_ruleaction",
    "V3GlobalEventRulesRuleActionUpdate": ".v3_globaleventrules_ruleactionupdate",
    "V3GlobalEventRulesRuleActionUpdateTypedDict": ".v3_globaleventrules_ruleactionupdate",
    "V3GlobalEventRulesRuleset": ".v3_globaleventrules_ruleset",
    "V3GlobalEventRulesRulesetTypedDict": ".v3_globaleventrules_ruleset",
    "V3GlobalEventRulesRulesetResponse": ".v3_globaleventrules_rulesetresponse",
    "V3GlobalEventRulesRulesetResponseTypedDict": ".v3_globaleventrules_rulesetresponse",
    "V3GlobalEventRulesRulesetRuleResponse": ".v3_globaleventrules_rulesetruleresponse",
    "V3GlobalEventRulesRulesetRuleResponseTypedDict": ".v3_globaleventrules_rulesetruleresponse",
    "V3GlobalEventRulesUpdateGlobalEventRuleRequest": ".v3_globaleventrules_updateglobaleventrulerequest",
    "V3GlobalEventRulesUpdateGlobalEventRuleRequestTypedDict": ".v3_globaleventrules_updateglobaleventrulerequest",
    "V3GlobalEventRulesUpdateRuleRequest": ".v3_globaleventrules_updaterulerequest",
    "V3GlobalEventRulesUpdateRuleRequestTypedDict": ".v3_globaleventrules_updaterulerequest",
    "V3GlobalEventRulesUpdateRulesetRequest": ".v3_globaleventrules_updaterulesetrequest",
    "V3GlobalEventRulesUpdateRulesetRequestTypedDict": ".v3_globaleventrules_updaterulesetrequest",
    "V3GlobalOncallReminderRulesCreateGlobalOncallReminderRulesRequest": ".v3_globaloncallreminderrules_createglobaloncallreminderrulesrequest",
    "V3GlobalOncallReminderRulesCreateGlobalOncallReminderRulesRequestTypedDict": ".v3_globaloncallreminderrules_createglobaloncallreminderrulesrequest",
    "V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponse": ".v3_globaloncallreminderrules_globaloncallreminderruleresponse",
    "V3GlobalOncallReminderRulesGlobalOncallReminderRuleResponseTypedDict": ".v3_globaloncallreminderrules_globaloncallreminderruleresponse",
    "V3GlobalOncallReminderRulesRule": ".v3_globaloncallreminderrules_rule",
    "V3GlobalOncallReminderRulesRuleTypedDict": ".v3_globaloncallreminderrules_rule",
    "V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequest": ".v3_globaloncallreminderrules_updateglobaloncallreminderrulesrequest",
    "V3GlobalOncallReminderRulesUpdateGlobalOncallReminderRulesRequestTypedDict": ".v3_globaloncallreminderrules_updateglobaloncallreminderrulesrequest",
    "V3IncidentsAdditionalResponderDetails": ".v3_incidents_additionalresponderdetails",
    "V3IncidentsAdditionalResponderDetailsTypedDict": ".v3_incidents_additionalresponderdetails",
    "AdditionalResponder": ".v3_incidents_additionalresponders_addadditionalrespondersrequest",
    "AdditionalResponderTypedDict": ".v3_incidents_additionalresponders_addadditionalrespondersrequest",
    "V3IncidentsAdditionalRespondersAddAdditionalRespondersRequest": ".v3_incidents_additionalresponders_addadditionalrespondersrequest",
    "V3IncidentsAdditionalRespondersAddAdditionalRespondersRequestTypedDict": ".v3_incidents_additionalresponders_addadditionalrespondersrequest",
    "V3IncidentsAdditionalRespondersAdditionalResponder": ".v3_incidents_additionalresponders_additionalresponder",
    "V3IncidentsAdditionalRespondersAdditionalResponderTypedDict": ".v3_incidents_additionalresponders_additionalresponder",
    "V3IncidentsAdditionalRespondersAdditionalResponderResponse": ".v3_incidents_additionalresponders_additionalresponderresponse",
    "V3IncidentsAdditionalRespondersAdditionalResponderResponseTypedDict": ".v3_incidents_additionalresponders_additionalresponderresponse",
    "V3IncidentsAnalytics": ".v3_incidents_analytics",
    "V3IncidentsAnalyticsTypedDict": ".v3_incidents_analytics",
    "V3IncidentsAnalyticsMetrics": ".v3_incidents_analyticsmetrics",
    "V3IncidentsAnalyticsMetricsTypedDict": ".v3_incidents_analyticsmetrics",
    "V3IncidentsAptaMessageResponse": ".v3_incidents_apta_messageresponse",
    "V3IncidentsAptaMessageResponseTypedDict": ".v3_incidents_apta_messageresponse",
    "V3IncidentsAssignedTo": ".v3_incidents_assignedto",
    "V3IncidentsAssignedToTypedDict": ".v3_incidents_assignedto",
    "V3IncidentsAssignTo": ".v3_incidents_assignto",
    "V3IncidentsAssignToTypedDict": ".v3_incidents_assignto",
    "V3IncidentsBulkIncidentIDsRequest": ".v3_incidents_bulkincidentidsrequest",
    "V3IncidentsBulkIncidentIDsRequestTypedDict": ".v3_incidents_bulkincidentidsrequest",
    "V3IncidentsBulkIncidentsPriorityUpdateRequest": ".v3_incidents_bulkincidentspriorityupdaterequest",
    "V3IncidentsBulkIncidentsPriorityUpdateRequestTypedDict": ".v3_incidents_bulkincidentspriorityupdaterequest",
    "V3IncidentsCommunicationCardsArchiveSlackChannelRequest": ".v3_incidents_communicationcards_archiveslackchannelrequest",
    "V3IncidentsCommunicationCardsArchiveSlackChannelRequestTypedDict": ".v3_incidents_communicationcards_archiveslackchannelrequest",
    "V3IncidentsCommunicationCardsCommunicationCardResponse": ".v3_incidents_communicationcards_communicationcardresponse",
    "V3IncidentsCommunicationCardsCommunicationCardResponseTypedDict": ".v3_incidents_communicationcards_communicationcardresponse",
    "V3IncidentsCommunicationCardsCreateCommunicationCardRequest": ".v3_incidents_communicationcards_createcommunicationcardrequest",
    "V3IncidentsCommunicationCardsCreateCommunicationCardRequestTypedDict": ".v3_incidents_communicationcards_createcommunicationcardrequest",
    "V3IncidentsCommunicationCardsCreateSlackChannelRequest": ".v3_incidents_communicationcards_createslackchannelrequest",
    "V3IncidentsCommunicationCardsCreateSlackChannelRequestTypedDict": ".v3_incidents_communicationcards_createslackchannelrequest",
    "V3IncidentsCommunicationCardsUpdateCommunicationCardRequest": ".v3_incidents_communicationcards_updatecommunicationcardrequest",
    "V3IncidentsCommunicationCardsUpdateCommunicationCardRequestTypedDict": ".v3_incidents_communicationcards_updatecommunicationcardrequest",
    "V3IncidentsDedupData": ".v3_incidents_dedupdata",
    "V3IncidentsDedupDataTypedDict": ".v3_incidents_dedupdata",
    "V3IncidentsExportFormat": ".v3_incidents_exportformat",
    "V3IncidentsExportIncidentsFilter": ".v3_incidents_exportincidentsfilter",
    "V3IncidentsExportIncidentsFilterTypedDict": ".v3_incidents_exportincidentsfilter",
    "V3IncidentsIncidentActionsCircleCIErrorMeta": ".v3_incidents_incidentactions_circlecierrormeta",
    "V3IncidentsIncidentActionsCircleCIErrorMetaTypedDict": ".v3_incidents_incidentactions_circlecierrormeta",
    "BuildParameters": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "BuildParametersTypedDict": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "CircleciResponse": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "CircleciResponseTypedDict": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "Previous": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "PreviousSuccessfulBuild": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "PreviousSuccessfulBuildTypedDict": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "PreviousTypedDict": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "V3IncidentsIncidentActionsCircleCIRebuildResponse": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "V3IncidentsIncidentActionsCircleCIRebuildResponseTypedDict": ".v3_incidents_incidentactions_circlecirebuildresponse",
    "V3IncidentsIncidentActionsRebuildCircleCIProjectRequest": ".v3_incidents_incidentactions_rebuildcircleciprojectrequest",
    "V3IncidentsIncidentActionsRebuildCircleCIProjectRequestTypedDict": ".v3_incidents_incidentactions_rebuildcircleciprojectrequest",
    "URL": ".v3_incidents_incidentactions_webhookactionresponse",
    "URLTypedDict": ".v3_incidents_incidentactions_webhookactionresponse",
    "V3IncidentsIncidentActionsWebhookActionResponse": ".v3_incidents_incidentactions_webhookactionresponse",
    "V3IncidentsIncidentActionsWebhookActionResponseHeader": ".v3_incidents_incidentactions_webhookactionresponse",
    "V3IncidentsIncidentActionsWebhookActionResponseHeaderTypedDict": ".v3_incidents_incidentactions_webhookactionresponse",
    "V3IncidentsIncidentActionsWebhookActionResponseTypedDict": ".v3_incidents_incidentactions_webhookactionresponse",
    "DeduplicationReason": ".v3_incidents_incidenteventresponse",
    "DeduplicationReasonTypedDict": ".v3_incidents_incidenteventresponse",
    "Payload": ".v3_incidents_incidenteventresponse",
    "PayloadTypedDict": ".v3_incidents_incidenteventresponse",
    "V3IncidentsIncidentEventResponse": ".v3_incidents_incidenteventresponse",
    "V3IncidentsIncidentEventResponseTags": ".v3_incidents_incidenteventresponse",
    "V3IncidentsIncidentEventResponseTagsTypedDict": ".v3_incidents_incidenteventresponse",
    "V3IncidentsIncidentEventResponseTypedDict": ".v3_incidents_incidenteventresponse",
    "V3IncidentsIncidentExportAsyncRequest": ".v3_incidents_incidentexportasyncrequest",
    "V3IncidentsIncidentExportAsyncRequestTypedDict": ".v3_incidents_incidentexportasyncrequest",
    "V3IncidentsIncidentExportAsyncResponse": ".v3_incidents_incidentexportasyncresponse",
    "V3IncidentsIncidentExportAsyncResponseTypedDict": ".v3_incidents_incidentexportasyncresponse",
    "V3IncidentsIncidentExportRequestIsStarred": ".v3_incidents_incidentexportrequest_is_starred",
    "V3IncidentsIncidentExportRequestNotes": ".v3_incidents_incidentexportrequest_notes",
    "V3IncidentsIncidentExportRequestRetrospectives": ".v3_incidents_incidentexportrequest_retrospectives",
    "V3IncidentsIncidentExportRequestSloAffecting": ".v3_incidents_incidentexportrequest_slo_affecting",
    "V3IncidentsIncidentExportRequestSortBy": ".v3_incidents_incidentexportrequest_sort_by",
    "V3IncidentsIncidentPriority": ".v3_incidents_incidentpriority",
    "V3IncidentsIncidentPriorityUpdateRequest": ".v3_incidents_incidentpriorityupdaterequest",
    "V3IncidentsIncidentPriorityUpdateRequestTypedDict": ".v3_incidents_incidentpriorityupdaterequest",
    "V3IncidentsIncidentPriorityUpdateResponse": ".v3_incidents_incidentpriorityupdateresponse",
    "V3IncidentsIncidentPriorityUpdateResponseTypedDict": ".v3_incidents_incidentpriorityupdateresponse",
    "V3IncidentsIncidentResponse": ".v3_incidents_incidentresponse",
    "V3IncidentsIncidentResponseRetriggerPolicy": ".v3_incidents_incidentresponse",
    "V3IncidentsIncidentResponseRetriggerPolicyTypedDict": ".v3_incidents_incidentresponse",
    "V3IncidentsIncidentResponseTags": ".v3_incidents_incidentresponse",
    "V3IncidentsIncidentResponseTagsTypedDict": ".v3_incidents_incidentresponse",
    "V3IncidentsIncidentResponseTypedDict": ".v3_incidents_incidentresponse",
    "V3IncidentsIngestionStatusRequest": ".v3_incidents_ingestionstatusrequest",
    "V3IncidentsIngestionStatusRequestTypedDict": ".v3_incidents_ingestionstatusrequest",
    "V3IncidentsLogs": ".v3_incidents_logs",
    "V3IncidentsLogsAdditionalInfo": ".v3_incidents_logs",
    "V3IncidentsLogsAdditionalInfoTypedDict": ".v3_incidents_logs",
    "V3IncidentsLogsTypedDict": ".v3_incidents_logs",
    "V3IncidentsMergeIncidentEntityReference": ".v3_incidents_mergeincidententityreference",
    "V3IncidentsMergeIncidentEntityReferenceTypedDict": ".v3_incidents_mergeincidententityreference",
    "V3IncidentsNotesCreateNoteRequest": ".v3_incidents_notes_createnoterequest",
    "V3IncidentsNotesCreateNoteRequestTypedDict": ".v3_incidents_notes_createnoterequest",
    "User": ".v3_incidents_notes_noteresponse",
    "UserTypedDict": ".v3_incidents_notes_noteresponse",
    "V3IncidentsNotesNoteResponse": ".v3_incidents_notes_noteresponse",
    "V3IncidentsNotesNoteResponseTypedDict": ".v3_incidents_notes_noteresponse",
    "V3IncidentsNotesUpdateNoteRequest": ".v3_incidents_notes_updatenoterequest",
    "V3IncidentsNotesUpdateNoteRequestTypedDict": ".v3_incidents_notes_updatenoterequest",
    "V3IncidentsNotificationDelayPolicy": ".v3_incidents_notificationdelaypolicy",
    "V3IncidentsNotificationDelayPolicyTypedDict": ".v3_incidents_notificationdelaypolicy",
    "V3IncidentsPinnedMessage": ".v3_incidents_pinnedmessage",
    "V3IncidentsPinnedMessageTypedDict": ".v3_incidents_pinnedmessage",
    "V3IncidentsPostmortemsCreatePostmortemRequest": ".v3_incidents_postmortems_createpostmortemrequest",
    "V3IncidentsPostmortemsCreatePostmortemRequestTypedDict": ".v3_incidents_postmortems_createpostmortemrequest",
    "V3IncidentsPostmortemsPostmortemAttachmentRequest": ".v3_incidents_postmortems_postmortemattachmentrequest",
    "V3IncidentsPostmortemsPostmortemAttachmentRequestTypedDict": ".v3_incidents_postmortems_postmortemattachmentrequest",
    "V3IncidentsPostmortemsPostmortemFollowUp": ".v3_incidents_postmortems_postmortemfollowup",
    "V3IncidentsPostmortemsPostmortemFollowUpTypedDict": ".v3_incidents_postmortems_postmortemfollowup",
    "V3IncidentsPostmortemsPostmortemListResult": ".v3_incidents_postmortems_postmortemlistresult",
    "V3IncidentsPostmortemsPostmortemListResultIncident": ".v3_incidents_postmortems_postmortemlistresult",
    "V3IncidentsPostmortemsPostmortemListResultIncidentTypedDict": ".v3_incidents_postmortems_postmortemlistresult",
    "V3IncidentsPostmortemsPostmortemListResultTypedDict": ".v3_incidents_postmortems_postmortemlistresult",
    "V3IncidentsPostmortemsPostmortemResponse": ".v3_incidents_postmortems_postmortemresponse",
    "V3IncidentsPostmortemsPostmortemResponseIncident": ".v3_incidents_postmortems_postmortemresponse",
    "V3IncidentsPostmortemsPostmortemResponseIncidentTypedDict": ".v3_incidents_postmortems_postmortemresponse",
    "V3IncidentsPostmortemsPostmortemResponseTypedDict": ".v3_incidents_postmortems_postmortemresponse",
    "V3IncidentsPostmortemsPostmortemStatus": ".v3_incidents_postmortems_postmortemstatus",
    "V3IncidentsPostmortemsTotalPostmortemCount": ".v3_incidents_postmortems_totalpostmortemcount",
    "V3IncidentsPostmortemsTotalPostmortemCountTypedDict": ".v3_incidents_postmortems_totalpostmortemcount",
    "V3IncidentsPostmortemsUpdatePostmortemRequest": ".v3_incidents_postmortems_updatepostmortemrequest",
    "V3IncidentsPostmortemsUpdatePostmortemRequestTypedDict": ".v3_incidents_postmortems_updatepostmortemrequest",
    "ReassignTo": ".v3_incidents_reassignincidentrequest",
    "ReassignToTypedDict": ".v3_incidents_reassignincidentrequest",
    "V3IncidentsReassignIncidentRequest": ".v3_incidents_reassignincidentrequest",
    "V3IncidentsReassignIncidentRequestTypedDict": ".v3_incidents_reassignincidentrequest",
    "V3IncidentsRelevantPeopleLog": ".v3_incidents_relevantpeoplelog",
    "V3IncidentsRelevantPeopleLogTypedDict": ".v3_incidents_relevantpeoplelog",
    "ResolutionReason": ".v3_incidents_resolveincidentrequest",
    "ResolutionReasonTypedDict": ".v3_incidents_resolveincidentrequest",
    "V3IncidentsResolveIncidentRequest": ".v3_incidents_resolveincidentrequest",
    "V3IncidentsResolveIncidentRequestTypedDict": ".v3_incidents_resolveincidentrequest",
    "V3IncidentsResponseNote": ".v3_incidents_responsenote",
    "V3IncidentsResponseNoteTypedDict": ".v3_incidents_responsenote",
    "V3IncidentsRunbooksAttachRunbooksRequest": ".v3_incidents_runbooks_attachrunbooksrequest",
    "V3IncidentsRunbooksAttachRunbooksRequestTypedDict": ".v3_incidents_runbooks_attachrunbooksrequest",
    "Step": ".v3_incidents_runbooks_runbookresponse",
    "StepTypedDict": ".v3_incidents_runbooks_runbookresponse",
    "V3IncidentsRunbooksRunbookResponse": ".v3_incidents_runbooks_runbookresponse",
    "V3IncidentsRunbooksRunbookResponseTypedDict": ".v3_incidents_runbooks_runbookresponse",
    "V3IncidentsServiceOwnerFilter": ".v3_incidents_serviceownerfilter",
    "V3IncidentsServiceOwnerFilterTypedDict": ".v3_incidents_serviceownerfilter",
    "V3IncidentsSnoozeDetails": ".v3_incidents_snoozedetails",
    "V3IncidentsSnoozeDetailsTypedDict": ".v3_incidents_snoozedetails",
    "V3IncidentsSnoozeNotificationsReassignTo": ".v3_incidents_snoozenotifications_reassignto",
    "V3IncidentsSnoozeNotificationsReassignToTypedDict": ".v3_incidents_snoozenotifications_reassignto",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentRequest": ".v3_incidents_snoozenotifications_snoozeincidentrequest",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentRequestTypedDict": ".v3_incidents_snoozenotifications_snoozeincidentrequest",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentResponse": ".v3_incidents_snoozenotifications_snoozeincidentresponse",
    "V3IncidentsSnoozeNotificationsSnoozeIncidentResponseTypedDict": ".v3_incidents_snoozenotifications_snoozeincidentresponse",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequest": ".v3_incidents_snoozenotifications_unsnoozeincidentrequest",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentRequestTypedDict": ".v3_incidents_snoozenotifications_unsnoozeincidentrequest",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentResponse": ".v3_incidents_snoozenotifications_unsnoozeincidentresponse",
    "V3IncidentsSnoozeNotificationsUnsnoozeIncidentResponseTypedDict": ".v3_incidents_snoozenotifications_unsnoozeincidentresponse",
    "V3IncidentsTagsAdditionalResponderDetails": ".v3_incidents_tags_additionalresponderdetails",
    "V3IncidentsTagsAdditionalResponderDetailsTypedDict": ".v3_incidents_tags_additionalresponderdetails",
    "V3IncidentsTagsAnalytics": ".v3_incidents_tags_analytics",
    "V3IncidentsTagsAnalyticsTypedDict": ".v3_incidents_tags_analytics",
    "V3IncidentsTagsAnalyticsMetrics": ".v3_incidents_tags_analyticsmetrics",
    "V3IncidentsTagsAnalyticsMetricsTypedDict": ".v3_incidents_tags_analyticsmetrics",
    "V3IncidentsTagsAppendTagRequest": ".v3_incidents_tags_appendtagrequest",
    "V3IncidentsTagsAppendTagRequestTags": ".v3_incidents_tags_appendtagrequest",
    "V3IncidentsTagsAppendTagRequestTagsTypedDict": ".v3_incidents_tags_appendtagrequest",
    "V3IncidentsTagsAppendTagRequestTypedDict": ".v3_incidents_tags_appendtagrequest",
    "V3IncidentsTagsAssignedTo": ".v3_incidents_tags_assignedto",
    "V3IncidentsTagsAssignedToTypedDict": ".v3_incidents_tags_assignedto",
    "V3IncidentsTagsAssignTo": ".v3_incidents_tags_assignto",
    "V3IncidentsTagsAssignToTypedDict": ".v3_incidents_tags_assignto",
    "V3IncidentsTagsDedupData": ".v3_incidents_tags_dedupdata",
    "V3IncidentsTagsDedupDataTypedDict": ".v3_incidents_tags_dedupdata",
    "V3IncidentsTagsIncidentForTagsResponse": ".v3_incidents_tags_incidentfortagsresponse",
    "V3IncidentsTagsIncidentForTagsResponseRetriggerPolicy": ".v3_incidents_tags_incidentfortagsresponse",
    "V3IncidentsTagsIncidentForTagsResponseRetriggerPolicyTypedDict": ".v3_incidents_tags_incidentfortagsresponse",
    "V3IncidentsTagsIncidentForTagsResponseTags": ".v3_incidents_tags_incidentfortagsresponse",
    "V3IncidentsTagsIncidentForTagsResponseTagsTypedDict": ".v3_incidents_tags_incidentfortagsresponse",
    "V3IncidentsTagsIncidentForTagsResponseTypedDict": ".v3_incidents_tags_incidentfortagsresponse",
    "V3IncidentsTagsIncidentPriority": ".v3_incidents_tags_incidentpriority",
    "V3IncidentsTagsLogs": ".v3_incidents_tags_logs",
    "V3IncidentsTagsLogsAdditionalInfo": ".v3_incidents_tags_logs",
    "V3IncidentsTagsLogsAdditionalInfoTypedDict": ".v3_incidents_tags_logs",
    "V3IncidentsTagsLogsTypedDict": ".v3_incidents_tags_logs",
    "V3IncidentsTagsMergeIncidentEntityReference": ".v3_incidents_tags_mergeincidententityreference",
    "V3IncidentsTagsMergeIncidentEntityReferenceTypedDict": ".v3_incidents_tags_mergeincidententityreference",
    "V3IncidentsTagsNotificationDelayPolicy": ".v3_incidents_tags_notificationdelaypolicy",
    "V3IncidentsTagsNotificationDelayPolicyTypedDict": ".v3_incidents_tags_notificationdelaypolicy",
    "V3IncidentsTagsPinnedMessage": ".v3_incidents_tags_pinnedmessage",
    "V3IncidentsTagsPinnedMessageTypedDict": ".v3_incidents_tags_pinnedmessage",
    "V3IncidentsTagsRelevantPeopleLog": ".v3_incidents_tags_relevantpeoplelog",
    "V3IncidentsTagsRelevantPeopleLogTypedDict": ".v3_incidents_tags_relevantpeoplelog",
    "V3IncidentsTagsResponseNote": ".v3_incidents_tags_responsenote",
    "V3IncidentsTagsResponseNoteTypedDict": ".v3_incidents_tags_responsenote",
    "V3IncidentsTagsSnoozeDetails": ".v3_incidents_tags_snoozedetails",
    "V3IncidentsTagsSnoozeDetailsTypedDict": ".v3_incidents_tags_snoozedetails",
    "V3IncidentsTagsUpdateTagRequest": ".v3_incidents_tags_updatetagrequest",
    "V3IncidentsTagsUpdateTagRequestTags": ".v3_incidents_tags_updatetagrequest",
    "V3IncidentsTagsUpdateTagRequestTagsTypedDict": ".v3_incidents_tags_updatetagrequest",
    "V3IncidentsTagsUpdateTagRequestTypedDict": ".v3_incidents_tags_updatetagrequest",
    "V3RunbooksCreateRunbookRequest": ".v3_runbooks_createrunbookrequest",
    "V3RunbooksCreateRunbookRequestTypedDict": ".v3_runbooks_createrunbookrequest",
    "V3RunbooksRunbookResponse": ".v3_runbooks_runbookresponse",
    "V3RunbooksRunbookResponseTypedDict": ".v3_runbooks_runbookresponse",
    "V3RunbooksStep": ".v3_runbooks_step",
    "V3RunbooksStepTypedDict": ".v3_runbooks_step",
    "V3RunbooksUpdateRunbookRequest": ".v3_runbooks_updaterunbookrequest",
    "V3RunbooksUpdateRunbookRequestTypedDict": ".v3_runbooks_updaterunbookrequest",
    "V3RunbooksUpdationInfo": ".v3_runbooks_updationinfo",
    "V3RunbooksUpdationInfoTypedDict": ".v3_runbooks_updationinfo",
    "V3ServicesAPTAConfig": ".v3_services_aptaconfig",
    "V3ServicesAPTAConfigTypedDict": ".v3_services_aptaconfig",
    "V3ServicesAPTAConfigRequest": ".v3_services_aptaconfigrequest",
    "V3ServicesAPTAConfigRequestTypedDict": ".v3_services_aptaconfigrequest",
    "V3ServicesCreateServiceRequest": ".v3_services_createservicerequest",
    "V3ServicesCreateServiceRequestTypedDict": ".v3_services_createservicerequest",
    "V3ServicesDedupInitConfig": ".v3_services_dedupinitconfig",
    "V3ServicesDedupInitConfigTimeUnit": ".v3_services_dedupinitconfig",
    "V3ServicesDedupInitConfigTypedDict": ".v3_services_dedupinitconfig",
    "V3ServicesDeduplicationRulesCreateDeduplicationRulesRequest": ".v3_services_deduplicationrules_creatededuplicationrulesrequest",
    "V3ServicesDeduplicationRulesCreateDeduplicationRulesRequestTypedDict": ".v3_services_deduplicationrules_creatededuplicationrulesrequest",
    "V3ServicesDeduplicationRulesDeduplicationRule": ".v3_services_deduplicationrules_deduplicationrule",
    "V3ServicesDeduplicationRulesDeduplicationRuleTimeUnit": ".v3_services_deduplicationrules_deduplicationrule",
    "V3ServicesDeduplicationRulesDeduplicationRuleTypedDict": ".v3_services_deduplicationrules_deduplicationrule",
    "V3ServicesDeduplicationRulesDeduplicationRuleResponse": ".v3_services_deduplicationrules_deduplicationruleresponse",
    "V3ServicesDeduplicationRulesDeduplicationRuleResponseTimeUnit": ".v3_services_deduplicationrules_deduplicationruleresponse",
    "V3ServicesDeduplicationRulesDeduplicationRuleResponseTypedDict": ".v3_services_deduplicationrules_deduplicationruleresponse",
    "V3ServicesDeduplicationRulesExpressionBranch": ".v3_services_deduplicationrules_expressionbranch",
    "V3ServicesDeduplicationRulesExpressionBranchOp": ".v3_services_deduplicationrules_expressionbranch",
    "V3ServicesDeduplicationRulesExpressionBranchRHS": ".v3_services_deduplicationrules_expressionbranch",
    "V3ServicesDeduplicationRulesExpressionBranchRHSTypedDict": ".v3_services_deduplicationrules_expressionbranch",
    "V3ServicesDeduplicationRulesExpressionBranchTypedDict": ".v3_services_deduplicationrules_expressionbranch",
    "V3ServicesDependenciesCreateOrUpdateDependenciesRequest": ".v3_services_dependencies_createorupdatedependenciesrequest",
    "V3ServicesDependenciesCreateOrUpdateDependenciesRequestTypedDict": ".v3_services_dependencies_createorupdatedependenciesrequest",
    "V3ServicesEscalationPolicyBasic": ".v3_services_escalationpolicybasic",
    "V3ServicesEscalationPolicyBasicTypedDict": ".v3_services_escalationpolicybasic",
    "V3ServicesExtensionsSlackExtensionResponse": ".v3_services_extensions_slackextensionresponse",
    "V3ServicesExtensionsSlackExtensionResponseTypedDict": ".v3_services_extensions_slackextensionresponse",
    "V3ServicesExtensionsUpdateSlackExtensionRequest": ".v3_services_extensions_updateslackextensionrequest",
    "V3ServicesExtensionsUpdateSlackExtensionRequestTypedDict": ".v3_services_extensions_updateslackextensionrequest",
    "V3ServicesIAGConfig": ".v3_services_iagconfig",
    "V3ServicesIAGConfigTypedDict": ".v3_services_iagconfig",
    "V3ServicesIAGConfigRequest": ".v3_services_iagconfigrequest",
    "V3ServicesIAGConfigRequestTypedDict": ".v3_services_iagconfigrequest",
    "V3ServicesJiraCloudExtension": ".v3_services_jiracloudextension",
    "V3ServicesJiraCloudExtensionTypedDict": ".v3_services_jiracloudextension",
    "V3ServicesJiraIssueType": ".v3_services_jiraissuetype",
    "V3ServicesJiraIssueTypeTypedDict": ".v3_services_jiraissuetype",
    "V3ServicesJiraProject": ".v3_services_jiraproject",
    "V3ServicesJiraProjectTypedDict": ".v3_services_jiraproject",
    "V3ServicesJiraStatus": ".v3_services_jirastatus",
    "V3ServicesJiraStatusTypedDict": ".v3_services_jirastatus",
    "V3ServicesJiraStatusMap": ".v3_services_jirastatusmap",
    "V3ServicesJiraStatusMapTypedDict": ".v3_services_jirastatusmap",
    "V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequest": ".v3_services_maintenancemode_createorupdatemaintenancemoderequest",
    "V3ServicesMaintenanceModeCreateOrUpdateMaintenanceModeRequestTypedDict": ".v3_services_maintenancemode_createorupdatemaintenancemoderequest",
    "V3ServicesMaintenanceModeMaintenanceModeResponse": ".v3_services_maintenancemode_maintenancemoderesponse",
    "V3ServicesMaintenanceModeMaintenanceModeResponseTypedDict": ".v3_services_maintenancemode_maintenancemoderesponse",
    "V3ServicesMaintenanceModeServiceMaintenance": ".v3_services_maintenancemode_servicemaintenance",
    "V3ServicesMaintenanceModeServiceMaintenanceTypedDict": ".v3_services_maintenancemode_servicemaintenance",
    "V3ServicesNotificationDelayConfig": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigAssignedTo": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigAssignedToTypedDict": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigCustomTimeslots": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigCustomTimeslotsTypedDict": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigFixedTimeslotConfig": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigFixedTimeslotConfigTypedDict": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigTypedDict": ".v3_services_notificationdelayconfig",
    "V3ServicesNotificationDelayConfigRequest": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesNotificationDelayConfigRequestAssignedTo": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesNotificationDelayConfigRequestAssignedToTypedDict": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesNotificationDelayConfigRequestCustomTimeslots": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesNotificationDelayConfigRequestCustomTimeslotsTypedDict": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesNotificationDelayConfigRequestFixedTimeslotConfig": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesNotificationDelayConfigRequestFixedTimeslotConfigTypedDict": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesNotificationDelayConfigRequestTypedDict": ".v3_services_notificationdelayconfigrequest",
    "V3ServicesOverlayCustomContent": ".v3_services_overlay_customcontent",
    "V3ServicesOverlayCustomContentTypedDict": ".v3_services_overlay_customcontent",
    "V3ServicesOverlayCustomContentOverlayResponse": ".v3_services_overlay_customcontentoverlayresponse",
    "V3ServicesOverlayCustomContentOverlayResponseOverlayTemplateType": ".v3_services_overlay_customcontentoverlayresponse",
    "V3ServicesOverlayCustomContentOverlayResponseTypedDict": ".v3_services_overlay_customcontentoverlayresponse",
    "V3ServicesOverlayDedupKeyOverlay": ".v3_services_overlay_dedupkeyoverlay",
    "V3ServicesOverlayDedupKeyOverlayTypedDict": ".v3_services_overlay_dedupkeyoverlay",
    "V3ServicesOverlayOptInForKeyBasedDeduplicationRequest": ".v3_services_overlay_optinforkeybaseddeduplicationrequest",
    "V3ServicesOverlayOptInForKeyBasedDeduplicationRequestTypedDict": ".v3_services_overlay_optinforkeybaseddeduplicationrequest",
    "V3ServicesOverlayOverlayResponse": ".v3_services_overlay_overlayresponse",
    "V3ServicesOverlayOverlayResponseOverlayTemplateType": ".v3_services_overlay_overlayresponse",
    "V3ServicesOverlayOverlayResponseTypedDict": ".v3_services_overlay_overlayresponse",
    "V3ServicesOverlayRenderCustomContentOverlayRequest": ".v3_services_overlay_rendercustomcontentoverlayrequest",
    "V3ServicesOverlayRenderCustomContentOverlayRequestTypedDict": ".v3_services_overlay_rendercustomcontentoverlayrequest",
    "V3ServicesOverlayRenderDedupKeyTemplateRequest": ".v3_services_overlay_renderdedupkeytemplaterequest",
    "V3ServicesOverlayRenderDedupKeyTemplateRequestTypedDict": ".v3_services_overlay_renderdedupkeytemplaterequest",
    "DescriptionOverlay": ".v3_services_overlay_updatecustomcontenttemplateoverlayrequest",
    "DescriptionOverlayTypedDict": ".v3_services_overlay_updatecustomcontenttemplateoverlayrequest",
    "MessageOverlay": ".v3_services_overlay_updatecustomcontenttemplateoverlayrequest",
    "MessageOverlayTypedDict": ".v3_services_overlay_updatecustomcontenttemplateoverlayrequest",
    "V3ServicesOverlayUpdateCustomContentTemplateOverlayRequest": ".v3_services_overlay_updatecustomcontenttemplateoverlayrequest",
    "V3ServicesOverlayUpdateCustomContentTemplateOverlayRequestTypedDict": ".v3_services_overlay_updatecustomcontenttemplateoverlayrequest",
    "DedupKeyOverlay": ".v3_services_overlay_updatededupkeyoverlayrequest",
    "DedupKeyOverlayTypedDict": ".v3_services_overlay_updatededupkeyoverlayrequest",
    "V3ServicesOverlayUpdateDedupKeyOverlayRequest": ".v3_services_overlay_updatededupkeyoverlayrequest",
    "V3ServicesOverlayUpdateDedupKeyOverlayRequestTypedDict": ".v3_services_overlay_updatededupkeyoverlayrequest",
    "V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequest": ".v3_services_routingrules_createorupdateroutingrulesrequest",
    "V3ServicesRoutingRulesCreateOrUpdateRoutingRulesRequestTypedDict": ".v3_services_routingrules_createorupdateroutingrulesrequest",
    "V3ServicesRoutingRulesExpressionBranch": ".v3_services_routingrules_expressionbranch",
    "V3ServicesRoutingRulesExpressionBranchOp": ".v3_services_routingrules_expressionbranch",
    "V3ServicesRoutingRulesExpressionBranchRHS": ".v3_services_routingrules_expressionbranch",
    "V3ServicesRoutingRulesExpressionBranchRHSTypedDict": ".v3_services_routingrules_expressionbranch",
    "V3ServicesRoutingRulesExpressionBranchTypedDict": ".v3_services_routingrules_expressionbranch",
    "V3ServicesRoutingRulesRoutingRule": ".v3_services_routingrules_routingrule",
    "V3ServicesRoutingRulesRoutingRuleEntityType": ".v3_services_routingrules_routingrule",
    "V3ServicesRoutingRulesRoutingRuleRouteTo": ".v3_services_routingrules_routingrule",
    "V3ServicesRoutingRulesRoutingRuleRouteToTypedDict": ".v3_services_routingrules_routingrule",
    "V3ServicesRoutingRulesRoutingRuleTypedDict": ".v3_services_routingrules_routingrule",
    "V3ServicesRoutingRulesRoutingRuleResponse": ".v3_services_routingrules_routingruleresponse",
    "V3ServicesRoutingRulesRoutingRuleResponseEntityType": ".v3_services_routingrules_routingruleresponse",
    "V3ServicesRoutingRulesRoutingRuleResponseRouteTo": ".v3_services_routingrules_routingruleresponse",
    "V3ServicesRoutingRulesRoutingRuleResponseRouteToTypedDict": ".v3_services_routingrules_routingruleresponse",
    "V3ServicesRoutingRulesRoutingRuleResponseTypedDict": ".v3_services_routingrules_routingruleresponse",
    "V3ServicesServiceMaintainer": ".v3_services_servicemaintainer",
    "V3ServicesServiceMaintainerType": ".v3_services_servicemaintainer",
    "V3ServicesServiceMaintainerTypedDict": ".v3_services_servicemaintainer",
    "Config": ".v3_services_serviceresponse",
    "ConfigTypedDict": ".v3_services_serviceresponse",
    "V3ServicesServiceResponse": ".v3_services_serviceresponse",
    "V3ServicesServiceResponseTypedDict": ".v3_services_serviceresponse",
    "V3ServicesServiceSlack": ".v3_services_serviceslack",
    "V3ServicesServiceSlackTypedDict": ".v3_services_serviceslack",
    "V3ServicesServiceTag": ".v3_services_servicetag",
    "V3ServicesServiceTagTypedDict": ".v3_services_servicetag",
    "V3ServicesSuppressionRulesBasicExpression": ".v3_services_suppressionrules_basicexpression",
    "V3ServicesSuppressionRulesBasicExpressionTypedDict": ".v3_services_suppressionrules_basicexpression",
    "V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequest": ".v3_services_suppressionrules_createorupdatesuppressionrulesrequest",
    "V3ServicesSuppressionRulesCreateOrUpdateSuppressionRulesRequestTypedDict": ".v3_services_suppressionrules_createorupdatesuppressionrulesrequest",
    "V3ServicesSuppressionRulesCustomRepetition": ".v3_services_suppressionrules_customrepetition",
    "V3ServicesSuppressionRulesCustomRepetitionTypedDict": ".v3_services_suppressionrules_customrepetition",
    "V3ServicesSuppressionRulesSuppressionRule": ".v3_services_suppressionrules_suppressionrule",
    "V3ServicesSuppressionRulesSuppressionRuleTypedDict": ".v3_services_suppressionrules_suppressionrule",
    "V3ServicesSuppressionRulesSuppressionRuleResponse": ".v3_services_suppressionrules_suppressionruleresponse",
    "V3ServicesSuppressionRulesSuppressionRuleResponseTypedDict": ".v3_services_suppressionrules_suppressionruleresponse",
    "V3ServicesSuppressionRulesSuppressionRulesContainerResponse": ".v3_services_suppressionrules_suppressionrulescontainerresponse",
    "V3ServicesSuppressionRulesSuppressionRulesContainerResponseTypedDict": ".v3_services_suppressionrules_suppressionrulescontainerresponse",
    "V3ServicesSuppressionRulesTimeslot": ".v3_services_suppressionrules_timeslot",
    "V3ServicesSuppressionRulesTimeslotTypedDict": ".v3_services_suppressionrules_timeslot",
    "V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequest": ".v3_services_taggingrules_createorupdatetaggingrulesrequest",
    "V3ServicesTaggingRulesCreateOrUpdateTaggingRulesRequestTypedDict": ".v3_services_taggingrules_createorupdatetaggingrulesrequest",
    "V3ServicesTaggingRulesExpressionBranch": ".v3_services_taggingrules_expressionbranch",
    "V3ServicesTaggingRulesExpressionBranchOp": ".v3_services_taggingrules_expressionbranch",
    "V3ServicesTaggingRulesExpressionBranchRHS": ".v3_services_taggingrules_expressionbranch",
    "V3ServicesTaggingRulesExpressionBranchRHSTypedDict": ".v3_services_taggingrules_expressionbranch",
    "V3ServicesTaggingRulesExpressionBranchTypedDict": ".v3_services_taggingrules_expressionbranch",
    "V3ServicesTaggingRulesTagConfigObject": ".v3_services_taggingrules_tagconfigobject",
    "V3ServicesTaggingRulesTagConfigObjectTypedDict": ".v3_services_taggingrules_tagconfigobject",
    "V3ServicesTaggingRulesTaggingRuleResponse": ".v3_services_taggingrules_taggingruleresponse",
    "V3ServicesTaggingRulesTaggingRuleResponseTypedDict": ".v3_services_taggingrules_taggingruleresponse",
    "V3ServicesTaggingRulesTagRule": ".v3_services_taggingrules_tagrule",
    "V3ServicesTaggingRulesTagRuleTypedDict": ".v3_services_taggingrules_tagrule",
    "V3ServicesTaggingRulesTagsObject": ".v3_services_taggingrules_tagsobject",
    "V3ServicesTaggingRulesTagsObjectTypedDict": ".v3_services_taggingrules_tagsobject",
    "V3ServicesUpdateServiceRequest": ".v3_services_updateservicerequest",
    "V3ServicesUpdateServiceRequestTypedDict": ".v3_services_updateservicerequest",
    "V3SLOCreateSLORequest": ".v3_slo_createslorequest",
    "V3SLOCreateSLORequestTags": ".v3_slo_createslorequest",
    "V3SLOCreateSLORequestTagsTypedDict": ".v3_slo_createslorequest",
    "V3SLOCreateSLORequestTypedDict": ".v3_slo_createslorequest",
    "V3SLOMarkSLOAffectedRequest": ".v3_slo_marksloaffectedrequest",
    "V3SLOMarkSLOAffectedRequestTypedDict": ".v3_slo_marksloaffectedrequest",
    "V3SLOSLOTags": ".v3_slo_slo",
    "V3SLOSLOTagsTypedDict": ".v3_slo_slo",
    "V3SloSlo": ".v3_slo_slo",
    "V3SloSloTypedDict": ".v3_slo_slo",
    "V3SLOSLOAction": ".v3_slo_sloaction",
    "V3SLOSLOActionTypedDict": ".v3_slo_sloaction",
    "V3SLOSLOActionType": ".v3_slo_sloactiontype",
    "V3SLOSLODetailedResponse": ".v3_slo_slodetailedresponse",
    "V3SLOSLODetailedResponseTags": ".v3_slo_slodetailedresponse",
    "V3SLOSLODetailedResponseTagsTypedDict": ".v3_slo_slodetailedresponse",
    "V3SLOSLODetailedResponseTypedDict": ".v3_slo_slodetailedresponse",
    "V3SLOSLOMonitoringCheck": ".v3_slo_slomonitoringcheck",
    "V3SLOSLOMonitoringCheckTypedDict": ".v3_slo_slomonitoringcheck",
    "V3SLOSLOOwnerType": ".v3_slo_sloownertype",
    "V3SLOSLOResponse": ".v3_slo_sloresponse",
    "V3SLOSLOResponseTags": ".v3_slo_sloresponse",
    "V3SLOSLOResponseTagsTypedDict": ".v3_slo_sloresponse",
    "V3SLOSLOResponseTypedDict": ".v3_slo_sloresponse",
    "V3SLOSLOViolatingIncidentResponse": ".v3_slo_sloviolatingincidentresponse",
    "V3SLOSLOViolatingIncidentResponseTypedDict": ".v3_slo_sloviolatingincidentresponse",
    "Insights": ".v3_slo_slowithinsightsresponse",
    "InsightsTypedDict": ".v3_slo_slowithinsightsresponse",
    "V3SLOSLOWithInsightsResponse": ".v3_slo_slowithinsightsresponse",
    "V3SLOSLOWithInsightsResponseTypedDict": ".v3_slo_slowithinsightsresponse",
    "V3SLOTimeIntervalType": ".v3_slo_timeintervaltype",
    "EscalationPolicies": ".v3_teams_abilities",
    "EscalationPoliciesTypedDict": ".v3_teams_abilities",
    "Ger": ".v3_teams_abilities",
    "GerTypedDict": ".v3_teams_abilities",
    "GlobalOncallReminderRules": ".v3_teams_abilities",
    "GlobalOncallReminderRulesTypedDict": ".v3_teams_abilities",
    "Postmortems": ".v3_teams_abilities",
    "PostmortemsTypedDict": ".v3_teams_abilities",
    "RoutingNumbers": ".v3_teams_abilities",
    "RoutingNumbersTypedDict": ".v3_teams_abilities",
    "Runbooks": ".v3_teams_abilities",
    "RunbooksTypedDict": ".v3_teams_abilities",
    "Schedules": ".v3_teams_abilities",
    "SchedulesTypedDict": ".v3_teams_abilities",
    "Services": ".v3_teams_abilities",
    "ServicesTypedDict": ".v3_teams_abilities",
    "Slos": ".v3_teams_abilities",
    "SlosTypedDict": ".v3_teams_abilities",
    "Squads": ".v3_teams_abilities",
    "SquadsTypedDict": ".v3_teams_abilities",
    "StakeholderGroups": ".v3_teams_abilities",
    "StakeholderGroupsTypedDict": ".v3_teams_abilities",
    "StatusPages": ".v3_teams_abilities",
    "StatusPagesTypedDict": ".v3_teams_abilities",
    "TeamAnalytics": ".v3_teams_abilities",
    "TeamAnalyticsTypedDict": ".v3_teams_abilities",
    "V3TeamsAbilities": ".v3_teams_abilities",
    "V3TeamsAbilitiesTypedDict": ".v3_teams_abilities",
    "Webforms": ".v3_teams_abilities",
    "WebformsTypedDict": ".v3_teams_abilities",
    "Workflows": ".v3_teams_abilities",
    "WorkflowsTypedDict": ".v3_teams_abilities",
    "V3TeamsAddBulkTeamMemberRequest": ".v3_teams_addbulkteammemberrequest",
    "V3TeamsAddBulkTeamMemberRequestMember": ".v3_teams_addbulkteammemberrequest",
    "V3TeamsAddBulkTeamMemberRequestMemberTypedDict": ".v3_teams_addbulkteammemberrequest",
    "V3TeamsAddBulkTeamMemberRequestTypedDict": ".v3_teams_addbulkteammemberrequest",
    "V3TeamsAddTeamMemberRequest": ".v3_teams_addteammemberrequest",
    "V3TeamsAddTeamMemberRequestTypedDict": ".v3_teams_addteammemberrequest",
    "V3TeamsCreateTeamRequest": ".v3_teams_createteamrequest",
    "V3TeamsCreateTeamRequestTypedDict": ".v3_teams_createteamrequest",
    "V3TeamsCreateTeamRoleRequest": ".v3_teams_createteamrolerequest",
    "V3TeamsCreateTeamRoleRequestTypedDict": ".v3_teams_createteamrolerequest",
    "V3TeamsTeamBaseResponse": ".v3_teams_teambaseresponse",
    "V3TeamsTeamBaseResponseTypedDict": ".v3_teams_teambaseresponse",
    "V3TeamsTeamMember": ".v3_teams_teammember",
    "V3TeamsTeamMemberTypedDict": ".v3_teams_teammember",
    "V3TeamsTeamMemberResponse": ".v3_teams_teammemberresponse",
    "V3TeamsTeamMemberResponseTypedDict": ".v3_teams_teammemberresponse",
    "Organization": ".v3_teams_teamresponse",
    "OrganizationTypedDict": ".v3_teams_teamresponse",
    "V3TeamsTeamResponse": ".v3_teams_teamresponse",
    "V3TeamsTeamResponseTypedDict": ".v3_teams_teamresponse",
    "V3TeamsTeamRole": ".v3_teams_teamrole",
    "V3TeamsTeamRoleTypedDict": ".v3_teams_teamrole",
    "V3TeamsTeamRoleResponse": ".v3_teams_teamroleresponse",
    "V3TeamsTeamRoleResponseTypedDict": ".v3_teams_teamroleresponse",
    "V3TeamsUpdateTeamMemberRequest": ".v3_teams_updateteammemberrequest",
    "V3TeamsUpdateTeamMemberRequestTypedDict": ".v3_teams_updateteammemberrequest",
    "V3TeamsUpdateTeamRequest": ".v3_teams_updateteamrequest",
    "V3TeamsUpdateTeamRequestMember": ".v3_teams_updateteamrequest",
    "V3TeamsUpdateTeamRequestMemberTypedDict": ".v3_teams_updateteamrequest",
    "V3TeamsUpdateTeamRequestTypedDict": ".v3_teams_updateteamrequest",
    "V3TeamsUpdateTeamRoleRequest": ".v3_teams_updateteamrolerequest",
    "V3TeamsUpdateTeamRoleRequestTypedDict": ".v3_teams_updateteamrolerequest",
    "V3UsersAddUserRequest": ".v3_users_adduserrequest",
    "V3UsersAddUserRequestRole": ".v3_users_adduserrequest",
    "V3UsersAddUserRequestTypedDict": ".v3_users_adduserrequest",
    "V3UsersAPITokenResponse": ".v3_users_apitokenresponse",
    "V3UsersAPITokenResponseTypedDict": ".v3_users_apitokenresponse",
    "V3UsersContact": ".v3_users_contact",
    "V3UsersContactTypedDict": ".v3_users_contact",
    "V3UsersGlobalRBACAbilityName": ".v3_users_globalrbacabilityname",
    "V3UsersNotificationRule": ".v3_users_notificationrule",
    "V3UsersNotificationRuleTypedDict": ".v3_users_notificationrule",
    "V3UsersUpdateUserAbilitiesRequest": ".v3_users_updateuserabilitiesrequest",
    "V3UsersUpdateUserAbilitiesRequestData": ".v3_users_updateuserabilitiesrequest",
    "V3UsersUpdateUserAbilitiesRequestDataTypedDict": ".v3_users_updateuserabilitiesrequest",
    "V3UsersUpdateUserAbilitiesRequestTypedDict": ".v3_users_updateuserabilitiesrequest",
    "V3UsersUpdateUserRequest": ".v3_users_updateuserrequest",
    "V3UsersUpdateUserRequestRole": ".v3_users_updateuserrequest",
    "V3UsersUpdateUserRequestTypedDict": ".v3_users_updateuserrequest",
    "V3UsersUserResponse": ".v3_users_userresponse",
    "V3UsersUserResponseTypedDict": ".v3_users_userresponse",
    "V3UsersUserRoleResponse": ".v3_users_userroleresponse",
    "V3UsersUserRoleResponseTypedDict": ".v3_users_userroleresponse",
    "V3WebformsCreateOrUpdateWebformRequest": ".v3_webforms_createorupdatewebformrequest",
    "V3WebformsCreateOrUpdateWebformRequestTags": ".v3_webforms_createorupdatewebformrequest",
    "V3WebformsCreateOrUpdateWebformRequestTagsTypedDict": ".v3_webforms_createorupdatewebformrequest",
    "V3WebformsCreateOrUpdateWebformRequestTypedDict": ".v3_webforms_createorupdatewebformrequest",
    "V3WebformsRecaptchaSecrets": ".v3_webforms_recaptchasecrets",
    "V3WebformsRecaptchaSecretsTypedDict": ".v3_webforms_recaptchasecrets",
    "V3WebformsWebformResponse": ".v3_webforms_webformresponse",
    "V3WebformsWebformResponseTags": ".v3_webforms_webformresponse",
    "V3WebformsWebformResponseTagsTypedDict": ".v3_webforms_webformresponse",
    "V3WebformsWebformResponseTypedDict": ".v3_webforms_webformresponse",
    "V3WebformsWFInputField": ".v3_webforms_wfinputfield",
    "V3WebformsWFInputFieldTypedDict": ".v3_webforms_wfinputfield",
    "V3WebformsWFService": ".v3_webforms_wfservice",
    "V3WebformsWFServiceTypedDict": ".v3_webforms_wfservice",
    "V3WorkflowsActionRequest": ".v3_workflows_actionrequest",
    "V3WorkflowsActionRequestData": ".v3_workflows_actionrequest",
    "V3WorkflowsActionRequestDataTypedDict": ".v3_workflows_actionrequest",
    "V3WorkflowsActionRequestName": ".v3_workflows_actionrequest",
    "V3WorkflowsActionRequestSqAttachRunbooks": ".v3_workflows_actionrequest",
    "V3WorkflowsActionRequestSqAttachRunbooksTypedDict": ".v3_workflows_actionrequest",
    "V3WorkflowsActionRequestTypedDict": ".v3_workflows_actionrequest",
    "V3WorkflowsActionRequestUpdate": ".v3_workflows_actionrequestupdate",
    "V3WorkflowsActionRequestUpdateData": ".v3_workflows_actionrequestupdate",
    "V3WorkflowsActionRequestUpdateDataTypedDict": ".v3_workflows_actionrequestupdate",
    "V3WorkflowsActionRequestUpdateName": ".v3_workflows_actionrequestupdate",
    "V3WorkflowsActionRequestUpdateSqAttachRunbooks": ".v3_workflows_actionrequestupdate",
    "V3WorkflowsActionRequestUpdateSqAttachRunbooksTypedDict": ".v3_workflows_actionrequestupdate",
    "V3WorkflowsActionRequestUpdateTypedDict": ".v3_workflows_actionrequestupdate",
    "V3WorkflowsActionResponse": ".v3_workflows_actionresponse",
    "V3WorkflowsActionResponseData": ".v3_workflows_actionresponse",
    "V3WorkflowsActionResponseDataTypedDict": ".v3_workflows_actionresponse",
    "V3WorkflowsActionResponseName": ".v3_workflows_actionresponse",
    "V3WorkflowsActionResponseSqAttachRunbooks": ".v3_workflows_actionresponse",
    "V3WorkflowsActionResponseSqAttachRunbooksTypedDict": ".v3_workflows_actionresponse",
    "V3WorkflowsActionResponseTypedDict": ".v3_workflows_actionresponse",
    "V3WorkflowsBulkEnableDisableWorkflowsRequest": ".v3_workflows_bulkenabledisableworkflowsrequest",
    "V3WorkflowsBulkEnableDisableWorkflowsRequestTypedDict": ".v3_workflows_bulkenabledisableworkflowsrequest",
    "V3WorkflowsCommunicationChannel": ".v3_workflows_communicationchannel",
    "V3WorkflowsCommunicationChannelType": ".v3_workflows_communicationchannel",
    "V3WorkflowsCommunicationChannelTypedDict": ".v3_workflows_communicationchannel",
    "V3WorkflowsComponentAndImpact": ".v3_workflows_componentandimpact",
    "V3WorkflowsComponentAndImpactTypedDict": ".v3_workflows_componentandimpact",
    "Entity": ".v3_workflows_createworkflowfilter",
    "EntityTypedDict": ".v3_workflows_createworkflowfilter",
    "V3WorkflowsCreateWorkflowFilter": ".v3_workflows_createworkflowfilter",
    "V3WorkflowsCreateWorkflowFilterTypedDict": ".v3_workflows_createworkflowfilter",
    "V3WorkflowsCreateWorkflowRequest": ".v3_workflows_createworkflowrequest",
    "V3WorkflowsCreateWorkflowRequestOwnerType": ".v3_workflows_createworkflowrequest",
    "V3WorkflowsCreateWorkflowRequestTypedDict": ".v3_workflows_createworkflowrequest",
    "V3WorkflowsCreateWorkflowRequestUpdate": ".v3_workflows_createworkflowrequestupdate",
    "V3WorkflowsCreateWorkflowRequestUpdateOwnerType": ".v3_workflows_createworkflowrequestupdate",
    "V3WorkflowsCreateWorkflowRequestUpdateTypedDict": ".v3_workflows_createworkflowrequestupdate",
    "V3WorkflowsEnableDisableWorkflowRequest": ".v3_workflows_enabledisableworkflowrequest",
    "V3WorkflowsEnableDisableWorkflowRequestTypedDict": ".v3_workflows_enabledisableworkflowrequest",
    "V3WorkflowsEntityOwner": ".v3_workflows_entityowner",
    "V3WorkflowsEntityOwnerTypedDict": ".v3_workflows_entityowner",
    "V3WorkflowsEntityOwnerUpdate": ".v3_workflows_entityownerupdate",
    "V3WorkflowsEntityOwnerUpdateTypedDict": ".v3_workflows_entityownerupdate",
    "V3WorkflowsGetWorkflowActionByIDResponse": ".v3_workflows_getworkflowactionbyidresponse",
    "V3WorkflowsGetWorkflowActionByIDResponseTypedDict": ".v3_workflows_getworkflowactionbyidresponse",
    "V3WorkflowsGetWorkflowByIDResponse": ".v3_workflows_getworkflowbyidresponse",
    "V3WorkflowsGetWorkflowByIDResponseTypedDict": ".v3_workflows_getworkflowbyidresponse",
    "StatusEnum": ".v3_workflows_getworkflowlogsresponse",
    "V3WorkflowsGetWorkflowLogsResponse": ".v3_workflows_getworkflowlogsresponse",
    "V3WorkflowsGetWorkflowLogsResponseData": ".v3_workflows_getworkflowlogsresponse",
    "V3WorkflowsGetWorkflowLogsResponseDataTypedDict": ".v3_workflows_getworkflowlogsresponse",
    "V3WorkflowsGetWorkflowLogsResponseMeta": ".v3_workflows_getworkflowlogsresponse",
    "V3WorkflowsGetWorkflowLogsResponseMetaTypedDict": ".v3_workflows_getworkflowlogsresponse",
    "V3WorkflowsGetWorkflowLogsResponseTypedDict": ".v3_workflows_getworkflowlogsresponse",
    "V3WorkflowsIssueStatusAndMessage": ".v3_workflows_issuestatusandmessage",
    "V3WorkflowsIssueStatusAndMessageTypedDict": ".v3_workflows_issuestatusandmessage",
    "V3WorkflowsJiraCreateTicket": ".v3_workflows_jiracreateticket",
    "V3WorkflowsJiraCreateTicketData": ".v3_workflows_jiracreateticket",
    "V3WorkflowsJiraCreateTicketDataTypedDict": ".v3_workflows_jiracreateticket",
    "V3WorkflowsJiraCreateTicketName": ".v3_workflows_jiracreateticket",
    "V3WorkflowsJiraCreateTicketTypedDict": ".v3_workflows_jiracreateticket",
    "V3WorkflowsJiraCreateTicketUpdate": ".v3_workflows_jiracreateticketupdate",
    "V3WorkflowsJiraCreateTicketUpdateData": ".v3_workflows_jiracreateticketupdate",
    "V3WorkflowsJiraCreateTicketUpdateDataTypedDict": ".v3_workflows_jiracreateticketupdate",
    "V3WorkflowsJiraCreateTicketUpdateName": ".v3_workflows_jiracreateticketupdate",
    "V3WorkflowsJiraCreateTicketUpdateTypedDict": ".v3_workflows_jiracreateticketupdate",
    "ACL": ".v3_workflows_listworkflowapiresponse",
    "ACLTypedDict": ".v3_workflows_listworkflowapiresponse",
    "V3WorkflowsListWorkflowAPIResponse": ".v3_workflows_listworkflowapiresponse",
    "V3WorkflowsListWorkflowAPIResponseMeta": ".v3_workflows_listworkflowapiresponse",
    "V3WorkflowsListWorkflowAPIResponseMetaTypedDict": ".v3_workflows_listworkflowapiresponse",
    "V3WorkflowsListWorkflowAPIResponseTypedDict": ".v3_workflows_listworkflowapiresponse",
    "V3WorkflowsMsTeamsCreateMeetingLink": ".v3_workflows_msteamscreatemeetinglink",
    "V3WorkflowsMsTeamsCreateMeetingLinkName": ".v3_workflows_msteamscreatemeetinglink",
    "V3WorkflowsMsTeamsCreateMeetingLinkTypedDict": ".v3_workflows_msteamscreatemeetinglink",
    "V3WorkflowsMsTeamsCreateMeetingLinkUpdate": ".v3_workflows_msteamscreatemeetinglinkupdate",
    "V3WorkflowsMsTeamsCreateMeetingLinkUpdateName": ".v3_workflows_msteamscreatemeetinglinkupdate",
    "V3WorkflowsMsTeamsCreateMeetingLinkUpdateTypedDict": ".v3_workflows_msteamscreatemeetinglinkupdate",
    "V3WorkflowsMsTeamsMessageChannel": ".v3_workflows_msteamsmessagechannel",
    "V3WorkflowsMsTeamsMessageChannelData": ".v3_workflows_msteamsmessagechannel",
    "V3WorkflowsMsTeamsMessageChannelDataTypedDict": ".v3_workflows_msteamsmessagechannel",
    "V3WorkflowsMsTeamsMessageChannelName": ".v3_workflows_msteamsmessagechannel",
    "V3WorkflowsMsTeamsMessageChannelTypedDict": ".v3_workflows_msteamsmessagechannel",
    "V3WorkflowsMsTeamsMessageChannelUpdate": ".v3_workflows_msteamsmessagechannelupdate",
    "V3WorkflowsMsTeamsMessageChannelUpdateData": ".v3_workflows_msteamsmessagechannelupdate",
    "V3WorkflowsMsTeamsMessageChannelUpdateDataTypedDict": ".v3_workflows_msteamsmessagechannelupdate",
    "V3WorkflowsMsTeamsMessageChannelUpdateName": ".v3_workflows_msteamsmessagechannelupdate",
    "V3WorkflowsMsTeamsMessageChannelUpdateTypedDict": ".v3_workflows_msteamsmessagechannelupdate",
    "V3WorkflowsMsTeamsMessageUser": ".v3_workflows_msteamsmessageuser",
    "V3WorkflowsMsTeamsMessageUserData": ".v3_workflows_msteamsmessageuser",
    "V3WorkflowsMsTeamsMessageUserDataTypedDict": ".v3_workflows_msteamsmessageuser",
    "V3WorkflowsMsTeamsMessageUserName": ".v3_workflows_msteamsmessageuser",
    "V3WorkflowsMsTeamsMessageUserTypedDict": ".v3_workflows_msteamsmessageuser",
    "V3WorkflowsMsTeamsMessageUserUpdate": ".v3_workflows_msteamsmessageuserupdate",
    "V3WorkflowsMsTeamsMessageUserUpdateData": ".v3_workflows_msteamsmessageuserupdate",
    "V3WorkflowsMsTeamsMessageUserUpdateDataTypedDict": ".v3_workflows_msteamsmessageuserupdate",
    "V3WorkflowsMsTeamsMessageUserUpdateName": ".v3_workflows_msteamsmessageuserupdate",
    "V3WorkflowsMsTeamsMessageUserUpdateTypedDict": ".v3_workflows_msteamsmessageuserupdate",
    "V3WorkflowsRunbookResponse": ".v3_workflows_runbookresponse",
    "V3WorkflowsRunbookResponseTypedDict": ".v3_workflows_runbookresponse",
    "V3WorkflowsSlackArchiveChannel": ".v3_workflows_slackarchivechannel",
    "V3WorkflowsSlackArchiveChannelName": ".v3_workflows_slackarchivechannel",
    "V3WorkflowsSlackArchiveChannelTypedDict": ".v3_workflows_slackarchivechannel",
    "V3WorkflowsSlackArchiveChannelUpdate": ".v3_workflows_slackarchivechannelupdate",
    "V3WorkflowsSlackArchiveChannelUpdateName": ".v3_workflows_slackarchivechannelupdate",
    "V3WorkflowsSlackArchiveChannelUpdateTypedDict": ".v3_workflows_slackarchivechannelupdate",
    "V3WorkflowsSlackCreateIncidentChannel": ".v3_workflows_slackcreateincidentchannel",
    "V3WorkflowsSlackCreateIncidentChannelData": ".v3_workflows_slackcreateincidentchannel",
    "V3WorkflowsSlackCreateIncidentChannelDataTypedDict": ".v3_workflows_slackcreateincidentchannel",
    "V3WorkflowsSlackCreateIncidentChannelName": ".v3_workflows_slackcreateincidentchannel",
    "V3WorkflowsSlackCreateIncidentChannelTypedDict": ".v3_workflows_slackcreateincidentchannel",
    "V3WorkflowsSlackCreateIncidentChannelUpdate": ".v3_workflows_slackcreateincidentchannelupdate",
    "V3WorkflowsSlackCreateIncidentChannelUpdateData": ".v3_workflows_slackcreateincidentchannelupdate",
    "V3WorkflowsSlackCreateIncidentChannelUpdateDataTypedDict": ".v3_workflows_slackcreateincidentchannelupdate",
    "V3WorkflowsSlackCreateIncidentChannelUpdateName": ".v3_workflows_slackcreateincidentchannelupdate",
    "V3WorkflowsSlackCreateIncidentChannelUpdateTypedDict": ".v3_workflows_slackcreateincidentchannelupdate",
    "V3WorkflowsSlackMessageChannel": ".v3_workflows_slackmessagechannel",
    "V3WorkflowsSlackMessageChannelData": ".v3_workflows_slackmessagechannel",
    "V3WorkflowsSlackMessageChannelDataTypedDict": ".v3_workflows_slackmessagechannel",
    "V3WorkflowsSlackMessageChannelName": ".v3_workflows_slackmessagechannel",
    "V3WorkflowsSlackMessageChannelTypedDict": ".v3_workflows_slackmessagechannel",
    "V3WorkflowsSlackMessageChannelUpdate": ".v3_workflows_slackmessagechannelupdate",
    "V3WorkflowsSlackMessageChannelUpdateData": ".v3_workflows_slackmessagechannelupdate",
    "V3WorkflowsSlackMessageChannelUpdateDataTypedDict": ".v3_workflows_slackmessagechannelupdate",
    "V3WorkflowsSlackMessageChannelUpdateName": ".v3_workflows_slackmessagechannelupdate",
    "V3WorkflowsSlackMessageChannelUpdateTypedDict": ".v3_workflows_slackmessagechannelupdate",
    "V3WorkflowsSlackMessageUser": ".v3_workflows_slackmessageuser",
    "V3WorkflowsSlackMessageUserData": ".v3_workflows_slackmessageuser",
    "V3WorkflowsSlackMessageUserDataTypedDict": ".v3_workflows_slackmessageuser",
    "V3WorkflowsSlackMessageUserName": ".v3_workflows_slackmessageuser",
    "V3WorkflowsSlackMessageUserTypedDict": ".v3_workflows_slackmessageuser",
    "V3WorkflowsSlackMessageUserUpdate": ".v3_workflows_slackmessageuserupdate",
    "V3WorkflowsSlackMessageUserUpdateData": ".v3_workflows_slackmessageuserupdate",
    "V3WorkflowsSlackMessageUserUpdateDataTypedDict": ".v3_workflows_slackmessageuserupdate",
    "V3WorkflowsSlackMessageUserUpdateName": ".v3_workflows_slackmessageuserupdate",
    "V3WorkflowsSlackMessageUserUpdateTypedDict": ".v3_workflows_slackmessageuserupdate",
    "V3WorkflowsSqAddCommunicationChannel": ".v3_workflows_sqaddcommunicationchannel",
    "V3WorkflowsSqAddCommunicationChannelData": ".v3_workflows_sqaddcommunicationchannel",
    "V3WorkflowsSqAddCommunicationChannelDataTypedDict": ".v3_workflows_sqaddcommunicationchannel",
    "V3WorkflowsSqAddCommunicationChannelName": ".v3_workflows_sqaddcommunicationchannel",
    "V3WorkflowsSqAddCommunicationChannelTypedDict": ".v3_workflows_sqaddcommunicationchannel",
    "V3WorkflowsSqAddCommunicationChannelUpdate": ".v3_workflows_sqaddcommunicationchannelupdate",
    "V3WorkflowsSqAddCommunicationChannelUpdateData": ".v3_workflows_sqaddcommunicationchannelupdate",
    "V3WorkflowsSqAddCommunicationChannelUpdateDataTypedDict": ".v3_workflows_sqaddcommunicationchannelupdate",
    "V3WorkflowsSqAddCommunicationChannelUpdateName": ".v3_workflows_sqaddcommunicationchannelupdate",
    "V3WorkflowsSqAddCommunicationChannelUpdateTypedDict": ".v3_workflows_sqaddcommunicationchannelupdate",
    "V3WorkflowsSqAddIncidentNote": ".v3_workflows_sqaddincidentnote",
    "V3WorkflowsSqAddIncidentNoteData": ".v3_workflows_sqaddincidentnote",
    "V3WorkflowsSqAddIncidentNoteDataTypedDict": ".v3_workflows_sqaddincidentnote",
    "V3WorkflowsSqAddIncidentNoteName": ".v3_workflows_sqaddincidentnote",
    "V3WorkflowsSqAddIncidentNoteTypedDict": ".v3_workflows_sqaddincidentnote",
    "V3WorkflowsSqAddIncidentNoteUpdate": ".v3_workflows_sqaddincidentnoteupdate",
    "V3WorkflowsSqAddIncidentNoteUpdateData": ".v3_workflows_sqaddincidentnoteupdate",
    "V3WorkflowsSqAddIncidentNoteUpdateDataTypedDict": ".v3_workflows_sqaddincidentnoteupdate",
    "V3WorkflowsSqAddIncidentNoteUpdateName": ".v3_workflows_sqaddincidentnoteupdate",
    "V3WorkflowsSqAddIncidentNoteUpdateTypedDict": ".v3_workflows_sqaddincidentnoteupdate",
    "V3WorkflowsSqCreateStatusPageIssue": ".v3_workflows_sqcreatestatuspageissue",
    "V3WorkflowsSqCreateStatusPageIssueData": ".v3_workflows_sqcreatestatuspageissue",
    "V3WorkflowsSqCreateStatusPageIssueDataTypedDict": ".v3_workflows_sqcreatestatuspageissue",
    "V3WorkflowsSqCreateStatusPageIssueName": ".v3_workflows_sqcreatestatuspageissue",
    "V3WorkflowsSqCreateStatusPageIssueTypedDict": ".v3_workflows_sqcreatestatuspageissue",
    "V3WorkflowsSqCreateStatusPageIssueUpdate": ".v3_workflows_sqcreatestatuspageissueupdate",
    "V3WorkflowsSqCreateStatusPageIssueUpdateData": ".v3_workflows_sqcreatestatuspageissueupdate",
    "V3WorkflowsSqCreateStatusPageIssueUpdateDataTypedDict": ".v3_workflows_sqcreatestatuspageissueupdate",
    "V3WorkflowsSqCreateStatusPageIssueUpdateName": ".v3_workflows_sqcreatestatuspageissueupdate",
    "V3WorkflowsSqCreateStatusPageIssueUpdateTypedDict": ".v3_workflows_sqcreatestatuspageissueupdate",
    "V3WorkflowsSqMakeHTTPCall": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallData": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallDataTypedDict": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallHeader": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallHeaderTypedDict": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallMethod": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallName": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallTypedDict": ".v3_workflows_sqmakehttpcall",
    "V3WorkflowsSqMakeHTTPCallUpdate": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMakeHTTPCallUpdateData": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMakeHTTPCallUpdateDataTypedDict": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMakeHTTPCallUpdateHeader": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMakeHTTPCallUpdateHeaderTypedDict": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMakeHTTPCallUpdateMethod": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMakeHTTPCallUpdateName": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMakeHTTPCallUpdateTypedDict": ".v3_workflows_sqmakehttpcallupdate",
    "V3WorkflowsSqMarkIncidentSLOAffecting": ".v3_workflows_sqmarkincidentsloaffecting",
    "V3WorkflowsSqMarkIncidentSLOAffectingData": ".v3_workflows_sqmarkincidentsloaffecting",
    "V3WorkflowsSqMarkIncidentSLOAffectingDataTypedDict": ".v3_workflows_sqmarkincidentsloaffecting",
    "V3WorkflowsSqMarkIncidentSLOAffectingName": ".v3_workflows_sqmarkincidentsloaffecting",
    "V3WorkflowsSqMarkIncidentSLOAffectingTypedDict": ".v3_workflows_sqmarkincidentsloaffecting",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdate": ".v3_workflows_sqmarkincidentsloaffectingupdate",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateData": ".v3_workflows_sqmarkincidentsloaffectingupdate",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateDataTypedDict": ".v3_workflows_sqmarkincidentsloaffectingupdate",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateName": ".v3_workflows_sqmarkincidentsloaffectingupdate",
    "V3WorkflowsSqMarkIncidentSLOAffectingUpdateTypedDict": ".v3_workflows_sqmarkincidentsloaffectingupdate",
    "V3WorkflowsSqSendEmail": ".v3_workflows_sqsendemail",
    "V3WorkflowsSqSendEmailData": ".v3_workflows_sqsendemail",
    "V3WorkflowsSqSendEmailDataTypedDict": ".v3_workflows_sqsendemail",
    "V3WorkflowsSqSendEmailName": ".v3_workflows_sqsendemail",
    "V3WorkflowsSqSendEmailTypedDict": ".v3_workflows_sqsendemail",
    "V3WorkflowsSqSendEmailUpdate": ".v3_workflows_sqsendemailupdate",
    "V3WorkflowsSqSendEmailUpdateData": ".v3_workflows_sqsendemailupdate",
    "V3WorkflowsSqSendEmailUpdateDataTypedDict": ".v3_workflows_sqsendemailupdate",
    "V3WorkflowsSqSendEmailUpdateName": ".v3_workflows_sqsendemailupdate",
    "V3WorkflowsSqSendEmailUpdateTypedDict": ".v3_workflows_sqsendemailupdate",
    "V3WorkflowsSqTriggerManualWebhook": ".v3_workflows_sqtriggermanualwebhook",
    "V3WorkflowsSqTriggerManualWebhookData": ".v3_workflows_sqtriggermanualwebhook",
    "V3WorkflowsSqTriggerManualWebhookDataTypedDict": ".v3_workflows_sqtriggermanualwebhook",
    "V3WorkflowsSqTriggerManualWebhookName": ".v3_workflows_sqtriggermanualwebhook",
    "V3WorkflowsSqTriggerManualWebhookTypedDict": ".v3_workflows_sqtriggermanualwebhook",
    "V3WorkflowsSqTriggerManualWebhookUpdate": ".v3_workflows_sqtriggermanualwebhookupdate",
    "V3WorkflowsSqTriggerManualWebhookUpdateData": ".v3_workflows_sqtriggermanualwebhookupdate",
    "V3WorkflowsSqTriggerManualWebhookUpdateDataTypedDict": ".v3_workflows_sqtriggermanualwebhookupdate",
    "V3WorkflowsSqTriggerManualWebhookUpdateName": ".v3_workflows_sqtriggermanualwebhookupdate",
    "V3WorkflowsSqTriggerManualWebhookUpdateTypedDict": ".v3_workflows_sqtriggermanualwebhookupdate",
    "V3WorkflowsTag": ".v3_workflows_tag",
    "V3WorkflowsTagTypedDict": ".v3_workflows_tag",
    "V3WorkflowsUpdateActionsOrderRequest": ".v3_workflows_updateactionsorderrequest",
    "V3WorkflowsUpdateActionsOrderRequestTypedDict": ".v3_workflows_updateactionsorderrequest",
    "V3WorkflowsUpdateActionsOrderResponse": ".v3_workflows_updateactionsorderresponse",
    "V3WorkflowsUpdateActionsOrderResponseData": ".v3_workflows_updateactionsorderresponse",
    "V3WorkflowsUpdateActionsOrderResponseDataTypedDict": ".v3_workflows_updateactionsorderresponse",
    "V3WorkflowsUpdateActionsOrderResponseTypedDict": ".v3_workflows_updateactionsorderresponse",
    "V3WorkflowsUpdateIncidentPriority": ".v3_workflows_updateincidentpriority",
    "V3WorkflowsUpdateIncidentPriorityData": ".v3_workflows_updateincidentpriority",
    "V3WorkflowsUpdateIncidentPriorityDataTypedDict": ".v3_workflows_updateincidentpriority",
    "V3WorkflowsUpdateIncidentPriorityName": ".v3_workflows_updateincidentpriority",
    "V3WorkflowsUpdateIncidentPriorityPriority": ".v3_workflows_updateincidentpriority",
    "V3WorkflowsUpdateIncidentPriorityTypedDict": ".v3_workflows_updateincidentpriority",
    "V3WorkflowsUpdateIncidentPriorityUpdate": ".v3_workflows_updateincidentpriorityupdate",
    "V3WorkflowsUpdateIncidentPriorityUpdateData": ".v3_workflows_updateincidentpriorityupdate",
    "V3WorkflowsUpdateIncidentPriorityUpdateDataTypedDict": ".v3_workflows_updateincidentpriorityupdate",
    "V3WorkflowsUpdateIncidentPriorityUpdateName": ".v3_workflows_updateincidentpriorityupdate",
    "V3WorkflowsUpdateIncidentPriorityUpdatePriority": ".v3_workflows_updateincidentpriorityupdate",
    "V3WorkflowsUpdateIncidentPriorityUpdateTypedDict": ".v3_workflows_updateincidentpriorityupdate",
    "V3WorkflowsUpdateWorkflowAPIResponse": ".v3_workflows_updateworkflowapiresponse",
    "V3WorkflowsUpdateWorkflowAPIResponseTypedDict": ".v3_workflows_updateworkflowapiresponse",
    "V3WorkflowsWorkflowAPIResponse": ".v3_workflows_workflowapiresponse",
    "V3WorkflowsWorkflowAPIResponseTypedDict": ".v3_workflows_workflowapiresponse",
    "Condition": ".v3_workflows_workflowfilters",
    "V3WorkflowsWorkflowFilters": ".v3_workflows_workflowfilters",
    "V3WorkflowsWorkflowFiltersTypedDict": ".v3_workflows_workflowfilters",
    "V3WorkflowsWorkflowTrigger": ".v3_workflows_workflowtrigger",
    "V4ChangeTimezoneResponse": ".v4_changetimezoneresponse",
    "V4ChangeTimezoneResponseTypedDict": ".v4_changetimezoneresponse",
    "V4CreateRotationRequest": ".v4_createrotationrequest",
    "V4CreateRotationRequestTypedDict": ".v4_createrotationrequest",
    "V4CreateScheduleOverrideRequest": ".v4_createscheduleoverriderequest",
    "V4CreateScheduleOverrideRequestTypedDict": ".v4_createscheduleoverriderequest",
    "V4CreateScheduleRequest": ".v4_createschedulerequest",
    "V4CreateScheduleRequestOwnerType": ".v4_createschedulerequest",
    "V4CreateScheduleRequestTypedDict": ".v4_createschedulerequest",
    "V4GetRotationParticipantsResponse": ".v4_getrotationparticipantsresponse",
    "V4GetRotationParticipantsResponseTypedDict": ".v4_getrotationparticipantsresponse",
    "V4ICalLinkResponse": ".v4_icallinkresponse",
    "V4ICalLinkResponseTypedDict": ".v4_icallinkresponse",
    "V4OverrideParticipantGroup": ".v4_overrideparticipantgroup",
    "V4OverrideParticipantGroupTypedDict": ".v4_overrideparticipantgroup",
    "V4OverrideResponse": ".v4_overrideresponse",
    "V4OverrideResponseTypedDict": ".v4_overrideresponse",
    "V4Participant": ".v4_participant",
    "V4ParticipantTypedDict": ".v4_participant",
    "V4ParticipantGroup": ".v4_participantgroup",
    "V4ParticipantGroupTypedDict": ".v4_participantgroup",
    "V4PauseResumeScheduleResponse": ".v4_pauseresumescheduleresponse",
    "V4PauseResumeScheduleResponseTypedDict": ".v4_pauseresumescheduleresponse",
    "V4RotationParticipantsResponse": ".v4_rotationparticipantsresponse",
    "V4RotationParticipantsResponseTypedDict": ".v4_rotationparticipantsresponse",
    "V4RotationResponse": ".v4_rotationresponse",
    "V4RotationResponseTypedDict": ".v4_rotationresponse",
    "V4ScheduleResponse": ".v4_scheduleresponse",
    "V4ScheduleResponseOwnerType": ".v4_scheduleresponse",
    "V4ScheduleResponseTypedDict": ".v4_scheduleresponse",
    "V4ShiftTimeSlot": ".v4_shifttimeslot",
    "V4ShiftTimeSlotTypedDict": ".v4_shifttimeslot",
    "V4SquadsCreateSquadRequest": ".v4_squads_createsquadrequest",
    "V4SquadsCreateSquadRequestTypedDict": ".v4_squads_createsquadrequest",
    "V4SquadsCreateSquadResponse": ".v4_squads_createsquadresponse",
    "V4SquadsCreateSquadResponseTypedDict": ".v4_squads_createsquadresponse",
    "V4SquadsRemoveSquadMemberResponse": ".v4_squads_removesquadmemberresponse",
    "V4SquadsRemoveSquadMemberResponseTypedDict": ".v4_squads_removesquadmemberresponse",
    "V4SquadsSquadMember": ".v4_squads_squadmember",
    "V4SquadsSquadMemberTypedDict": ".v4_squads_squadmember",
    "V4SquadsSquadResponse": ".v4_squads_squadresponse",
    "V4SquadsSquadResponseTypedDict": ".v4_squads_squadresponse",
    "V4SquadsUpdateSquadMemberRequest": ".v4_squads_updatesquadmemberrequest",
    "V4SquadsUpdateSquadMemberRequestTypedDict": ".v4_squads_updatesquadmemberrequest",
    "V4SquadsUpdateSquadMemberResponse": ".v4_squads_updatesquadmemberresponse",
    "V4SquadsUpdateSquadMemberResponseTypedDict": ".v4_squads_updatesquadmemberresponse",
    "V4SquadsUpdateSquadNameRequest": ".v4_squads_updatesquadnamerequest",
    "V4SquadsUpdateSquadNameRequestTypedDict": ".v4_squads_updatesquadnamerequest",
    "V4SquadsUpdateSquadNameResponse": ".v4_squads_updatesquadnameresponse",
    "V4SquadsUpdateSquadNameResponseTypedDict": ".v4_squads_updatesquadnameresponse",
    "V4SquadsUpdateSquadRequest": ".v4_squads_updatesquadrequest",
    "V4SquadsUpdateSquadRequestTypedDict": ".v4_squads_updatesquadrequest",
    "V4StatusPagesComponentGroupsComponent": ".v4_statuspages_componentgroups_component",
    "V4StatusPagesComponentGroupsComponentTypedDict": ".v4_statuspages_componentgroups_component",
    "V4StatusPagesComponentGroupsComponentGroupResponse": ".v4_statuspages_componentgroups_componentgroupresponse",
    "V4StatusPagesComponentGroupsComponentGroupResponseTypedDict": ".v4_statuspages_componentgroups_componentgroupresponse",
    "V4StatusPagesComponentGroupsComponentStatus": ".v4_statuspages_componentgroups_componentstatus",
    "V4StatusPagesComponentGroupsComponentStatusTypedDict": ".v4_statuspages_componentgroups_componentstatus",
    "V4StatusPagesComponentGroupsCreateComponentGroupRequest": ".v4_statuspages_componentgroups_createcomponentgrouprequest",
    "V4StatusPagesComponentGroupsCreateComponentGroupRequestTypedDict": ".v4_statuspages_componentgroups_createcomponentgrouprequest",
    "V4StatusPagesComponentGroupsCreateComponentGroupResponse": ".v4_statuspages_componentgroups_createcomponentgroupresponse",
    "V4StatusPagesComponentGroupsCreateComponentGroupResponseTypedDict": ".v4_statuspages_componentgroups_createcomponentgroupresponse",
    "V4StatusPagesComponentGroupsDeleteComponentGroupByIDResponse": ".v4_statuspages_componentgroups_deletecomponentgroupbyidresponse",
    "V4StatusPagesComponentGroupsDeleteComponentGroupByIDResponseTypedDict": ".v4_statuspages_componentgroups_deletecomponentgroupbyidresponse",
    "V4StatusPagesComponentGroupsGetComponentGroupByIDResponse": ".v4_statuspages_componentgroups_getcomponentgroupbyidresponse",
    "V4StatusPagesComponentGroupsGetComponentGroupByIDResponseTypedDict": ".v4_statuspages_componentgroups_getcomponentgroupbyidresponse",
    "V4StatusPagesComponentsComponent": ".v4_statuspages_components_component",
    "V4StatusPagesComponentsComponentTypedDict": ".v4_statuspages_components_component",
    "V4StatusPagesComponentsComponentStatus": ".v4_statuspages_components_componentstatus",
    "V4StatusPagesComponentsComponentStatusTypedDict": ".v4_statuspages_components_componentstatus",
    "V4StatusPagesComponentsCreateComponentRequest": ".v4_statuspages_components_createcomponentrequest",
    "V4StatusPagesComponentsCreateComponentRequestTypedDict": ".v4_statuspages_components_createcomponentrequest",
    "V4StatusPagesComponentsCreateComponentResponse": ".v4_statuspages_components_createcomponentresponse",
    "V4StatusPagesComponentsCreateComponentResponseTypedDict": ".v4_statuspages_components_createcomponentresponse",
    "V4StatusPagesComponentsDeleteComponentByIDResponse": ".v4_statuspages_components_deletecomponentbyidresponse",
    "V4StatusPagesComponentsDeleteComponentByIDResponseTypedDict": ".v4_statuspages_components_deletecomponentbyidresponse",
    "V4StatusPagesComponentsGetComponentByIDResponse": ".v4_statuspages_components_getcomponentbyidresponse",
    "V4StatusPagesComponentsGetComponentByIDResponseTypedDict": ".v4_statuspages_components_getcomponentbyidresponse",
    "V4StatusPagesComponentsListComponentsResponse": ".v4_statuspages_components_listcomponentsresponse",
    "V4StatusPagesComponentsListComponentsResponseTypedDict": ".v4_statuspages_components_listcomponentsresponse",
    "V4StatusPagesComponentsUpdateComponentByIDRequest": ".v4_statuspages_components_updatecomponentbyidrequest",
    "V4StatusPagesComponentsUpdateComponentByIDRequestTypedDict": ".v4_statuspages_components_updatecomponentbyidrequest",
    "V4StatusPagesComponentsUpdateComponentByIDResponse": ".v4_statuspages_components_updatecomponentbyidresponse",
    "V4StatusPagesComponentsUpdateComponentByIDResponseTypedDict": ".v4_statuspages_components_updatecomponentbyidresponse",
    "V4StatusPagesCreateStatusPageRequest": ".v4_statuspages_createstatuspagerequest",
    "V4StatusPagesCreateStatusPageRequestOwnerType": ".v4_statuspages_createstatuspagerequest",
    "V4StatusPagesCreateStatusPageRequestTypedDict": ".v4_statuspages_createstatuspagerequest",
    "V4StatusPagesCreateStatusPageResponse": ".v4_statuspages_createstatuspageresponse",
    "V4StatusPagesCreateStatusPageResponseTypedDict": ".v4_statuspages_createstatuspageresponse",
    "V4StatusPagesDeleteStatusPageByIDResponse": ".v4_statuspages_deletestatuspagebyidresponse",
    "V4StatusPagesDeleteStatusPageByIDResponseTypedDict": ".v4_statuspages_deletestatuspagebyidresponse",
    "V4StatusPagesGetStatusPageByIDResponse": ".v4_statuspages_getstatuspagebyidresponse",
    "V4StatusPagesGetStatusPageByIDResponseThemeColor": ".v4_statuspages_getstatuspagebyidresponse",
    "V4StatusPagesGetStatusPageByIDResponseThemeColorTypedDict": ".v4_statuspages_getstatuspagebyidresponse",
    "V4StatusPagesGetStatusPageByIDResponseTypedDict": ".v4_statuspages_getstatuspagebyidresponse",
    "V4StatusPagesIssuesComponentStatus": ".v4_statuspages_issues_componentstatus",
    "V4StatusPagesIssuesComponentStatusTypedDict": ".v4_statuspages_issues_componentstatus",
    "V4StatusPagesIssuesCreateIssueRequest": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueRequestComponent": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueRequestComponentTypedDict": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueRequestIssue": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueRequestIssueTypedDict": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueRequestStateMessage": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueRequestStateMessageTypedDict": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueRequestTypedDict": ".v4_statuspages_issues_createissuerequest",
    "V4StatusPagesIssuesCreateIssueResponse": ".v4_statuspages_issues_createissueresponse",
    "V4StatusPagesIssuesCreateIssueResponseTypedDict": ".v4_statuspages_issues_createissueresponse",
    "V4StatusPagesIssuesDeleteIssueByIDResponse": ".v4_statuspages_issues_deleteissuebyidresponse",
    "V4StatusPagesIssuesDeleteIssueByIDResponseTypedDict": ".v4_statuspages_issues_deleteissuebyidresponse",
    "V4StatusPagesIssuesGetIssueByIDResponse": ".v4_statuspages_issues_getissuebyidresponse",
    "V4StatusPagesIssuesGetIssueByIDResponseTypedDict": ".v4_statuspages_issues_getissuebyidresponse",
    "V4StatusPagesIssuesIssue": ".v4_statuspages_issues_issue",
    "V4StatusPagesIssuesIssueTypedDict": ".v4_statuspages_issues_issue",
    "V4StatusPagesIssuesIssueComponent": ".v4_statuspages_issues_issuecomponent",
    "V4StatusPagesIssuesIssueComponentTypedDict": ".v4_statuspages_issues_issuecomponent",
    "V4StatusPagesIssuesIssueComponentDetail": ".v4_statuspages_issues_issuecomponentdetail",
    "V4StatusPagesIssuesIssueComponentDetailTypedDict": ".v4_statuspages_issues_issuecomponentdetail",
    "V4StatusPagesIssuesIssueDetail": ".v4_statuspages_issues_issuedetail",
    "V4StatusPagesIssuesIssueDetailTypedDict": ".v4_statuspages_issues_issuedetail",
    "V4StatusPagesIssuesIssueState": ".v4_statuspages_issues_issuestate",
    "V4StatusPagesIssuesIssueStateTypedDict": ".v4_statuspages_issues_issuestate",
    "V4StatusPagesIssuesIssueStateMessage": ".v4_statuspages_issues_issuestatemessage",
    "V4StatusPagesIssuesIssueStateMessageTypedDict": ".v4_statuspages_issues_issuestatemessage",
    "V4StatusPagesIssuesListIssuesResponse": ".v4_statuspages_issues_listissuesresponse",
    "V4StatusPagesIssuesListIssuesResponseMeta": ".v4_statuspages_issues_listissuesresponse",
    "V4StatusPagesIssuesListIssuesResponseMetaTypedDict": ".v4_statuspages_issues_listissuesresponse",
    "V4StatusPagesIssuesListIssuesResponseTypedDict": ".v4_statuspages_issues_listissuesresponse",
    "V4StatusPagesIssuesListStatusPageIssueStatesResponse": ".v4_statuspages_issues_liststatuspageissuestatesresponse",
    "V4StatusPagesIssuesListStatusPageIssueStatesResponseTypedDict": ".v4_statuspages_issues_liststatuspageissuestatesresponse",
    "V4StatusPagesIssuesUpdateIssueRequest": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueRequestComponent": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueRequestComponentTypedDict": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueRequestIssue": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueRequestIssueTypedDict": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueRequestStateMessage": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueRequestStateMessageTypedDict": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueRequestTypedDict": ".v4_statuspages_issues_updateissuerequest",
    "V4StatusPagesIssuesUpdateIssueResponse": ".v4_statuspages_issues_updateissueresponse",
    "V4StatusPagesIssuesUpdateIssueResponseTypedDict": ".v4_statuspages_issues_updateissueresponse",
    "V4StatusPagesListStatusPagesResponse": ".v4_statuspages_liststatuspagesresponse",
    "V4StatusPagesListStatusPagesResponseMeta": ".v4_statuspages_liststatuspagesresponse",
    "V4StatusPagesListStatusPagesResponseMetaTypedDict": ".v4_statuspages_liststatuspagesresponse",
    "V4StatusPagesListStatusPagesResponseTypedDict": ".v4_statuspages_liststatuspagesresponse",
    "V4StatusPagesListSubscribersResponse": ".v4_statuspages_listsubscribersresponse",
    "V4StatusPagesListSubscribersResponseTypedDict": ".v4_statuspages_listsubscribersresponse",
    "V4StatusPagesListSubscribersResponseMeta": ".v4_statuspages_listsubscribersresponsemeta",
    "V4StatusPagesListSubscribersResponseMetaTypedDict": ".v4_statuspages_listsubscribersresponsemeta",
    "V4StatusPagesMaintenancesCreateMaintenanceRequest": ".v4_statuspages_maintenances_createmaintenancerequest",
    "V4StatusPagesMaintenancesCreateMaintenanceRequestTypedDict": ".v4_statuspages_maintenances_createmaintenancerequest",
    "V4StatusPagesMaintenancesCreateMaintenanceResponse": ".v4_statuspages_maintenances_createmaintenanceresponse",
    "V4StatusPagesMaintenancesCreateMaintenanceResponseTypedDict": ".v4_statuspages_maintenances_createmaintenanceresponse",
    "V4StatusPagesMaintenancesDeleteMaintenanceByIDResponse": ".v4_statuspages_maintenances_deletemaintenancebyidresponse",
    "V4StatusPagesMaintenancesDeleteMaintenanceByIDResponseTypedDict": ".v4_statuspages_maintenances_deletemaintenancebyidresponse",
    "V4StatusPagesMaintenancesGetMaintenanceByIDResponse": ".v4_statuspages_maintenances_getmaintenancebyidresponse",
    "V4StatusPagesMaintenancesGetMaintenanceByIDResponseTypedDict": ".v4_statuspages_maintenances_getmaintenancebyidresponse",
    "V4StatusPagesMaintenancesListMaintenancesResponse": ".v4_statuspages_maintenances_listmaintenancesresponse",
    "V4StatusPagesMaintenancesListMaintenancesResponseMeta": ".v4_statuspages_maintenances_listmaintenancesresponse",
    "V4StatusPagesMaintenancesListMaintenancesResponseMetaTypedDict": ".v4_statuspages_maintenances_listmaintenancesresponse",
    "V4StatusPagesMaintenancesListMaintenancesResponseTypedDict": ".v4_statuspages_maintenances_listmaintenancesresponse",
    "V4StatusPagesMaintenancesMaintenance": ".v4_statuspages_maintenances_maintenance",
    "V4StatusPagesMaintenancesMaintenanceComponent": ".v4_statuspages_maintenances_maintenance",
    "V4StatusPagesMaintenancesMaintenanceComponentTypedDict": ".v4_statuspages_maintenances_maintenance",
    "V4StatusPagesMaintenancesMaintenanceTypedDict": ".v4_statuspages_maintenances_maintenance",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDRequest": ".v4_statuspages_maintenances_updatemaintenancebyidrequest",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDRequestTypedDict": ".v4_statuspages_maintenances_updatemaintenancebyidrequest",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDResponse": ".v4_statuspages_maintenances_updatemaintenancebyidresponse",
    "V4StatusPagesMaintenancesUpdateMaintenanceByIDResponseTypedDict": ".v4_statuspages_maintenances_updatemaintenancebyidresponse",
    "V4StatusPagesNewStatusPageComponent": ".v4_statuspages_newstatuspagecomponent",
    "V4StatusPagesNewStatusPageComponentType": ".v4_statuspages_newstatuspagecomponent",
    "V4StatusPagesNewStatusPageComponentTypedDict": ".v4_statuspages_newstatuspagecomponent",
    "V4StatusPagesNewStatusPageComponentList": ".v4_statuspages_newstatuspagecomponentlist",
    "V4StatusPagesNewStatusPageComponentListType": ".v4_statuspages_newstatuspagecomponentlist",
    "V4StatusPagesNewStatusPageComponentListTypedDict": ".v4_statuspages_newstatuspagecomponentlist",
    "V4StatusPagesNewStatusPageThemeColor": ".v4_statuspages_newstatuspagethemecolor",
    "V4StatusPagesNewStatusPageThemeColorTypedDict": ".v4_statuspages_newstatuspagethemecolor",
    "StatusMaintenance": ".v4_statuspages_statuspage",
    "StatusMaintenanceTypedDict": ".v4_statuspages_statuspage",
    "V4StatusPagesStatusPage": ".v4_statuspages_statuspage",
    "V4StatusPagesStatusPageComponent": ".v4_statuspages_statuspage",
    "V4StatusPagesStatusPageComponentTypedDict": ".v4_statuspages_statuspage",
    "V4StatusPagesStatusPageStatus": ".v4_statuspages_statuspage",
    "V4StatusPagesStatusPageStatusTypedDict": ".v4_statuspages_statuspage",
    "V4StatusPagesStatusPageTypedDict": ".v4_statuspages_statuspage",
    "V4StatusPagesStatusPageStatusesResponse": ".v4_statuspages_statuspagestatusesresponse",
    "V4StatusPagesStatusPageStatusesResponseTypedDict": ".v4_statuspages_statuspagestatusesresponse",
    "V4StatusPagesStatusPageSubscriber": ".v4_statuspages_statuspagesubscriber",
    "V4StatusPagesStatusPageSubscriberTypedDict": ".v4_statuspages_statuspagesubscriber",
    "V4StatusPagesStatusPageSubscriberComponent": ".v4_statuspages_statuspagesubscribercomponent",
    "V4StatusPagesStatusPageSubscriberComponentTypedDict": ".v4_statuspages_statuspagesubscribercomponent",
    "V4StatusPagesTotalSubscribersCount": ".v4_statuspages_totalsubscriberscount",
    "V4StatusPagesTotalSubscribersCountTypedDict": ".v4_statuspages_totalsubscriberscount",
    "V4StatusPagesUpdateStatusPageByIDRequest": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent1": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent1TypedDict": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent2": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDRequestComponent2TypedDict": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDRequestThemeColor": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDRequestThemeColorTypedDict": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDRequestTypedDict": ".v4_statuspages_updatestatuspagebyidrequest",
    "V4StatusPagesUpdateStatusPageByIDResponse": ".v4_statuspages_updatestatuspagebyidresponse",
    "V4StatusPagesUpdateStatusPageByIDResponseThemeColor": ".v4_statuspages_updatestatuspagebyidresponse",
    "V4StatusPagesUpdateStatusPageByIDResponseThemeColorTypedDict": ".v4_statuspages_updatestatuspagebyidresponse",
    "V4StatusPagesUpdateStatusPageByIDResponseTypedDict": ".v4_statuspages_updatestatuspagebyidresponse",
    "V4Tag": ".v4_tag",
    "V4TagTypedDict": ".v4_tag",
    "V4UpdateRotationParticipantsRequest": ".v4_updaterotationparticipantsrequest",
    "V4UpdateRotationParticipantsRequestTypedDict": ".v4_updaterotationparticipantsrequest",
    "V4UpdateRotationRequest": ".v4_updaterotationrequest",
    "V4UpdateRotationRequestTypedDict": ".v4_updaterotationrequest",
    "V4UpdateScheduleOverrideRequest": ".v4_updatescheduleoverriderequest",
    "V4UpdateScheduleOverrideRequestTypedDict": ".v4_updatescheduleoverriderequest",
    "V4UpdateScheduleRequest": ".v4_updateschedulerequest",
    "V4UpdateScheduleRequestOwnerType": ".v4_updateschedulerequest",
    "V4UpdateScheduleRequestTypedDict": ".v4_updateschedulerequest",
    "WebformsCreateWebformData": ".webforms_createwebformop",
    "WebformsCreateWebformDataTypedDict": ".webforms_createwebformop",
    "WebformsCreateWebformResponse": ".webforms_createwebformop",
    "WebformsCreateWebformResponseTypedDict": ".webforms_createwebformop",
    "WebformsGetAllWebformsMeta": ".webforms_getallwebformsop",
    "WebformsGetAllWebformsMetaTypedDict": ".webforms_getallwebformsop",
    "WebformsGetAllWebformsRequest": ".webforms_getallwebformsop",
    "WebformsGetAllWebformsRequestTypedDict": ".webforms_getallwebformsop",
    "WebformsGetAllWebformsResponse": ".webforms_getallwebformsop",
    "WebformsGetAllWebformsResponseBody": ".webforms_getallwebformsop",
    "WebformsGetAllWebformsResponseBodyTypedDict": ".webforms_getallwebformsop",
    "WebformsGetAllWebformsResponseTypedDict": ".webforms_getallwebformsop",
    "WebformsGetWebformByIDRequest": ".webforms_getwebformbyidop",
    "WebformsGetWebformByIDRequestTypedDict": ".webforms_getwebformbyidop",
    "WebformsGetWebformByIDResponse": ".webforms_getwebformbyidop",
    "WebformsGetWebformByIDResponseTypedDict": ".webforms_getwebformbyidop",
    "WebformsRemoveWebformRequest": ".webforms_removewebformop",
    "WebformsRemoveWebformRequestTypedDict": ".webforms_removewebformop",
    "WebformsRemoveWebformResponse": ".webforms_removewebformop",
    "WebformsRemoveWebformResponseTypedDict": ".webforms_removewebformop",
    "WebformsUpdateWebformRequest": ".webforms_updatewebformop",
    "WebformsUpdateWebformRequestTypedDict": ".webforms_updatewebformop",
    "WebformsUpdateWebformResponse": ".webforms_updatewebformop",
    "WebformsUpdateWebformResponseTypedDict": ".webforms_updatewebformop",
    "WebhooksCreateWebhookBody": ".webhooks_createwebhookop",
    "WebhooksCreateWebhookBodyTypedDict": ".webhooks_createwebhookop",
    "WebhooksCreateWebhookResponse": ".webhooks_createwebhookop",
    "WebhooksCreateWebhookResponseTypedDict": ".webhooks_createwebhookop",
    "WebhooksDeleteWebhookRequest": ".webhooks_deletewebhookop",
    "WebhooksDeleteWebhookRequestTypedDict": ".webhooks_deletewebhookop",
    "WebhooksDeleteWebhookResponseBody": ".webhooks_deletewebhookop",
    "WebhooksDeleteWebhookResponseBodyTypedDict": ".webhooks_deletewebhookop",
    "WebhooksGetAllWebhooksRequest": ".webhooks_getallwebhooksop",
    "WebhooksGetAllWebhooksRequestTypedDict": ".webhooks_getallwebhooksop",
    "WebhooksGetWebhookByIDRequest": ".webhooks_getwebhookbyidop",
    "WebhooksGetWebhookByIDRequestTypedDict": ".webhooks_getwebhookbyidop",
    "WebhooksGetWebhookByIDResponse": ".webhooks_getwebhookbyidop",
    "WebhooksGetWebhookByIDResponseTypedDict": ".webhooks_getwebhookbyidop",
    "WebhooksUpdateWebhookRequest": ".webhooks_updatewebhookop",
    "WebhooksUpdateWebhookRequestTypedDict": ".webhooks_updatewebhookop",
    "WebhooksUpdateWebhookResponse": ".webhooks_updatewebhookop",
    "WebhooksUpdateWebhookResponseTypedDict": ".webhooks_updatewebhookop",
    "WorkflowsBulkEnabledisableWorkflowsResponseBody": ".workflows_bulkenabledisableworkflowsop",
    "WorkflowsBulkEnabledisableWorkflowsResponseBodyTypedDict": ".workflows_bulkenabledisableworkflowsop",
    "WorkflowsCreateActionRequest": ".workflows_createactionop",
    "WorkflowsCreateActionRequestTypedDict": ".workflows_createactionop",
    "WorkflowsCreateActionResponse": ".workflows_createactionop",
    "WorkflowsCreateActionResponseTypedDict": ".workflows_createactionop",
    "WorkflowsCreateWorkflowResponse": ".workflows_createworkflowop",
    "WorkflowsCreateWorkflowResponseTypedDict": ".workflows_createworkflowop",
    "WorkflowsDeleteWorkflowActionRequest": ".workflows_deleteworkflowactionop",
    "WorkflowsDeleteWorkflowActionRequestTypedDict": ".workflows_deleteworkflowactionop",
    "WorkflowsDeleteWorkflowActionResponseBody": ".workflows_deleteworkflowactionop",
    "WorkflowsDeleteWorkflowActionResponseBodyTypedDict": ".workflows_deleteworkflowactionop",
    "WorkflowsDeleteWorkflowRequest": ".workflows_deleteworkflowop",
    "WorkflowsDeleteWorkflowRequestTypedDict": ".workflows_deleteworkflowop",
    "WorkflowsDeleteWorkflowResponseBody": ".workflows_deleteworkflowop",
    "WorkflowsDeleteWorkflowResponseBodyTypedDict": ".workflows_deleteworkflowop",
    "WorkflowsEnabledisableWorkflowRequest": ".workflows_enabledisableworkflowop",
    "WorkflowsEnabledisableWorkflowRequestTypedDict": ".workflows_enabledisableworkflowop",
    "WorkflowsEnabledisableWorkflowResponseBody": ".workflows_enabledisableworkflowop",
    "WorkflowsEnabledisableWorkflowResponseBodyTypedDict": ".workflows_enabledisableworkflowop",
    "WorkflowsGetWorkflowActionByIDRequest": ".workflows_getworkflowactionbyidop",
    "WorkflowsGetWorkflowActionByIDRequestTypedDict": ".workflows_getworkflowactionbyidop",
    "WorkflowsGetWorkflowActionByIDResponse": ".workflows_getworkflowactionbyidop",
    "WorkflowsGetWorkflowActionByIDResponseTypedDict": ".workflows_getworkflowactionbyidop",
    "WorkflowsGetWorkflowByIDRequest": ".workflows_getworkflowbyidop",
    "WorkflowsGetWorkflowByIDRequestTypedDict": ".workflows_getworkflowbyidop",
    "WorkflowsGetWorkflowLogsRequest": ".workflows_getworkflowlogsop",
    "WorkflowsGetWorkflowLogsRequestTypedDict": ".workflows_getworkflowlogsop",
    "WorkflowsGetWorkflowLogsResponse": ".workflows_getworkflowlogsop",
    "WorkflowsGetWorkflowLogsResponseTypedDict": ".workflows_getworkflowlogsop",
    "WorkflowsListWorkflowsRequest": ".workflows_listworkflowsop",
    "WorkflowsListWorkflowsRequestTypedDict": ".workflows_listworkflowsop",
    "WorkflowsListWorkflowsResponse": ".workflows_listworkflowsop",
    "WorkflowsListWorkflowsResponseTypedDict": ".workflows_listworkflowsop",
    "WorkflowsUpdateActionsOrderRequest": ".workflows_updateactionsorderop",
    "WorkflowsUpdateActionsOrderRequestTypedDict": ".workflows_updateactionsorderop",
    "WorkflowsUpdateWorkflowActionRequest": ".workflows_updateworkflowactionop",
    "WorkflowsUpdateWorkflowActionRequestTypedDict": ".workflows_updateworkflowactionop",
    "WorkflowsUpdateWorkflowRequest": ".workflows_updateworkflowop",
    "WorkflowsUpdateWorkflowRequestTypedDict": ".workflows_updateworkflowop",
    "WorkflowsUpdateWorkflowResponse": ".workflows_updateworkflowop",
    "WorkflowsUpdateWorkflowResponseTypedDict": ".workflows_updateworkflowop",
}


def dynamic_import(modname, retries=3):
    for attempt in range(retries):
        try:
            return import_module(modname, __package__)
        except KeyError:
            # Clear any half-initialized module and retry
            sys.modules.pop(modname, None)
            if attempt == retries - 1:
                break
    raise KeyError(f"Failed to import module '{modname}' after {retries} attempts")


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = dynamic_import(module_name)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
